Show / Hide Table of Contents

Class B58

Inheritance
object
B58
Namespace: Xrpl.AddressCodec
Assembly: Xrpl.AddressCodec.dll
Syntax
public class B58

Constructors

| Edit this page View Source

B58(string)

Declaration
public B58(string alphabet)
Parameters
Type Name Description
string alphabet

Methods

| Edit this page View Source

Decode(string)

Decoder

Declaration
public byte[] Decode(string input)
Parameters
Type Name Description
string input

Base58Check-encoded string to decode

Returns
Type Description
byte[]
| Edit this page View Source

Decode(string, Version)

Decoder

Declaration
public byte[] Decode(string input, B58.Version version)
Parameters
Type Name Description
string input

Base58Check-encoded string to decode

B58.Version version

Options object including the version byte(s) and the expected length of the data after decoding

Returns
Type Description
byte[]
| Edit this page View Source

Decode(string, Versions)

Decoder

Declaration
public B58.Decoded Decode(string input, B58.Versions versions)
Parameters
Type Name Description
string input

Base58Check-encoded string to decode

B58.Versions versions

Options object including the version byte(s) and the expected length of the data after decoding

Returns
Type Description
B58.Decoded
| Edit this page View Source

Encode(byte[], string, Versions)

Encoder

Declaration
public string Encode(byte[] buffer, string versionName, B58.Versions versions)
Parameters
Type Name Description
byte[] buffer

Buffer of data to encode.

string versionName
B58.Versions versions

Options object including the version bytes and the expected length of the data to encode.

Returns
Type Description
string
| Edit this page View Source

Encode(byte[], Version)

Declaration
public string Encode(byte[] buffer, B58.Version version)
Parameters
Type Name Description
byte[] buffer
B58.Version version
Returns
Type Description
string
| Edit this page View Source

EncodeToBytes(byte[])

Encodes the given bytes in base58. No checksum is appended.

Declaration
public byte[] EncodeToBytes(byte[] input)
Parameters
Type Name Description
byte[] input
Returns
Type Description
byte[]
| Edit this page View Source

EncodeToBytesChecked(byte[], byte[])

Declaration
public byte[] EncodeToBytesChecked(byte[] input, byte[] version)
Parameters
Type Name Description
byte[] input
byte[] version
Returns
Type Description
byte[]
| Edit this page View Source

EncodeToBytesChecked(byte[], int)

Declaration
public byte[] EncodeToBytesChecked(byte[] input, int version)
Parameters
Type Name Description
byte[] input
int version
Returns
Type Description
byte[]
| Edit this page View Source

EncodeToString(byte[])

Encodes the given bytes in base58. No checksum is appended.

Declaration
public string EncodeToString(byte[] input)
Parameters
Type Name Description
byte[] input
Returns
Type Description
string

ASCII string

| Edit this page View Source

EncodeToStringChecked(byte[], byte[])

Declaration
public string EncodeToStringChecked(byte[] input, byte[] version)
Parameters
Type Name Description
byte[] input
byte[] version
Returns
Type Description
string
| Edit this page View Source

EncodeToStringChecked(byte[], int)

Declaration
public string EncodeToStringChecked(byte[] input, int version)
Parameters
Type Name Description
byte[] input
int version
Returns
Type Description
string
| Edit this page View Source

FindPrefix(int, string)

Declaration
public byte[] FindPrefix(int payLoadLength, string desiredPrefix)
Parameters
Type Name Description
int payLoadLength
string desiredPrefix
Returns
Type Description
byte[]
| Edit this page View Source

IsValid(string, Version)

Declaration
public bool IsValid(string input, B58.Version version)
Parameters
Type Name Description
string input
B58.Version version
Returns
Type Description
bool
| Edit this page View Source

IsValid(string, Versions)

Declaration
public bool IsValid(string input, B58.Versions version)
Parameters
Type Name Description
string input
B58.Versions version
Returns
Type Description
bool
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX