Show / Hide Table of Contents

Class XrplCodec

Inheritance
object
XrplCodec
Namespace: Xrpl.AddressCodec
Assembly: Xrpl.AddressCodec.dll
Syntax
public class XrplCodec

Fields

| Edit this page View Source

AccountID

Account address (20 bytes)

Declaration
public static B58.Version AccountID
Field Value
Type Description
B58.Version
| Edit this page View Source

Alphabet

Declaration
public const string Alphabet = "rpshnaf39wBUDNEGHJKLM4PQRST7VWXYZ2bcdeCg65jkm8oFqi1tuvAxyz"
Field Value
Type Description
string
| Edit this page View Source

AnySeed

Declaration
public static B58.Versions AnySeed
Field Value
Type Description
B58.Versions
| Edit this page View Source

Ed25519Seed

[1, 225, 75]

Declaration
public static B58.Version Ed25519Seed
Field Value
Type Description
B58.Version
| Edit this page View Source

K256Seed

33; Seed value (for secret keys) (16 bytes)

Declaration
public static B58.Version K256Seed
Field Value
Type Description
B58.Version
| Edit this page View Source

NodePublic

28; Validation public key (33 bytes)

Declaration
public static B58.Version NodePublic
Field Value
Type Description
B58.Version
| Edit this page View Source

PublicKey

Account public key (33 bytes)

Declaration
public static B58.Version PublicKey
Field Value
Type Description
B58.Version

Methods

| Edit this page View Source

DecodeAccountID(string)

Returns the decoded bytes of the classic address.

Declaration
public static byte[] DecodeAccountID(string accountId)
Parameters
Type Name Description
string accountId

Classic address to be decoded.

Returns
Type Description
byte[]

The decoded bytes of the classic address.

| Edit this page View Source

DecodeAccountPublic(string)

Returns the decoded bytes of the account public key.

Declaration
public static byte[] DecodeAccountPublic(string address)
Parameters
Type Name Description
string address

Account public key to be decoded.

Returns
Type Description
byte[]

The decoded bytes of the account public key.

| Edit this page View Source

DecodeNodePublic(string)

Returns the decoded bytes of the node public key

Declaration
public static byte[] DecodeNodePublic(string publicKey)
Parameters
Type Name Description
string publicKey

Node public key to be decoded.

Returns
Type Description
byte[]

The decoded bytes of the node public key.

| Edit this page View Source

DecodeSeed(string)

Returns (decoded seed, its algorithm).

Declaration
public static XrplCodec.DecodedSeed DecodeSeed(string seed)
Parameters
Type Name Description
string seed

The b58 encoding of a seed.

Returns
Type Description
XrplCodec.DecodedSeed

A(decoded seed, its algorithm).

| Edit this page View Source

EncodeAccountID(byte[])

Returns the classic address encoding of these bytes as a base58 string.

Declaration
public static string EncodeAccountID(byte[] bytes)
Parameters
Type Name Description
byte[] bytes

Bytes to be encoded.

Returns
Type Description
string

The classic address encoding of these bytes as a base58 string.

| Edit this page View Source

EncodeAccountPublic(byte[])

Returns the account public key encoding of these bytes as a base58 string.

Declaration
public static string EncodeAccountPublic(byte[] bytes)
Parameters
Type Name Description
byte[] bytes

Bytes to be encoded.

Returns
Type Description
string

The account public key encoding of these bytes as a base58 string.

| Edit this page View Source

EncodeNodePublic(byte[])

Returns the node public key encoding of these bytes as a base58 string.

Declaration
public static string EncodeNodePublic(byte[] bytes)
Parameters
Type Name Description
byte[] bytes

Bytes to be encoded.

Returns
Type Description
string

The node public key encoding of these bytes as a base58 string.

| Edit this page View Source

EncodeSeed(byte[], string)

Returns an encoded seed.

Declaration
public static string EncodeSeed(byte[] bytes, string type)
Parameters
Type Name Description
byte[] bytes

Entropy bytes of SEED_LENGTH.

string type

Either ED25519 or SECP256K1.

Returns
Type Description
string

An encoded seed.

| Edit this page View Source

IsValidClassicAddress(string)

Returns a bool representing if the classic address is valid.

Declaration
public static bool IsValidClassicAddress(string address)
Parameters
Type Name Description
string address

Classic address to validate.

Returns
Type Description
bool

A bool representing if the classic address is valid.

  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX