Show / Hide Table of Contents

Namespace Xrpl.BinaryCodec.Binary

Classes

BinaryParser

BinaryParser is used to compute fields and values from a HexString

BinarySerializer

BinarySerializer is used to write fields and values to buffers

BufferParser

BinaryParser is used to compute fields and values from a HexString

BytesList

Bytes list is a collection of buffer objects

StreamParser

BinaryParser is used to compute fields and values from a HexString

Interfaces

IBytesSink

base Bytes Sink

In this article
Back to top Generated by DocFX