Class Field
Assembly: Xrpl.BinaryCodec.dll
Syntax
public class Field : EnumItem
Constructors
|
Edit this page
Field(string, int, FieldType, bool, bool)
Declaration
public Field(string name, int nthOfType, FieldType type, bool isSigningField = true, bool isSerialised = true)
Parameters
| Type |
Name |
Description |
| string |
name |
|
| int |
nthOfType |
|
| FieldType |
type |
|
| bool |
isSigningField |
|
| bool |
isSerialised |
|
Fields
|
Edit this page
AMMID
Declaration
public static readonly Hash256Field AMMID
Field Value
|
Edit this page
AcceptedCredentials
Declaration
public static readonly StArrayField AcceptedCredentials
Field Value
|
Edit this page
Account
Declaration
public static readonly AccountIdField Account
Field Value
|
Edit this page
AccountHash
Declaration
public static readonly Hash256Field AccountHash
Field Value
|
Edit this page
AccountTxnID
Declaration
public static readonly Hash256Field AccountTxnID
Field Value
|
Edit this page
AdditionalBooks
Declaration
public static readonly StArrayField AdditionalBooks
Field Value
|
Edit this page
AffectedNodes
Declaration
public static readonly StArrayField AffectedNodes
Field Value
|
Edit this page
Amendment
Declaration
public static readonly Hash256Field Amendment
Field Value
|
Edit this page
Amendments
Declaration
public static readonly Vector256Field Amendments
Field Value
|
Edit this page
Amount
Declaration
public static readonly AmountField Amount
Field Value
|
Edit this page
Amount2
Declaration
public static readonly AmountField Amount2
Field Value
|
Edit this page
ArrayEndMarker
Declaration
public static readonly StArrayField ArrayEndMarker
Field Value
|
Edit this page
Asset
Declaration
public static readonly IssueField Asset
Field Value
|
Edit this page
Asset2
Declaration
public static readonly IssueField Asset2
Field Value
|
Edit this page
AssetClass
Describes the type of asset, such as "currency", "commodity", or "index".
Declaration
public static readonly BlobField AssetClass
Field Value
|
Edit this page
AssetPrice
The asset price after applying the Scale precision level.
Declaration
public static readonly Uint64Field AssetPrice
Field Value
|
Edit this page
AssetScale
The decimal precision level (0-10) for the asset price in Oracle PriceData.
Declaration
public static readonly Uint8Field AssetScale
Field Value
|
Edit this page
AuctionSlot
Declaration
public static readonly StObjectField AuctionSlot
Field Value
|
Edit this page
AuthAccount
Declaration
public static readonly StObjectField AuthAccount
Field Value
|
Edit this page
AuthAccounts
Declaration
public static readonly StArrayField AuthAccounts
Field Value
|
Edit this page
Authorize
Declaration
public static readonly AccountIdField Authorize
Field Value
|
Edit this page
AuthorizeCredentials
Declaration
public static readonly StArrayField AuthorizeCredentials
Field Value
|
Edit this page
Balance
Declaration
public static readonly AmountField Balance
Field Value
|
Edit this page
BaseAsset
The primary asset in a trading pair for Oracle price data.
Declaration
public static readonly CurrencyField BaseAsset
Field Value
|
Edit this page
BaseFee
Declaration
public static readonly Uint64Field BaseFee
Field Value
|
Edit this page
BaseFeeDrops
Declaration
public static readonly AmountField BaseFeeDrops
Field Value
|
Edit this page
BatchSigner
Declaration
public static readonly StObjectField BatchSigner
Field Value
|
Edit this page
BatchSigners
Declaration
public static readonly StArrayField BatchSigners
Field Value
|
Edit this page
BidMax
Declaration
public static readonly AmountField BidMax
Field Value
|
Edit this page
BidMin
Declaration
public static readonly AmountField BidMin
Field Value
|
Edit this page
BondAmount
Declaration
public static readonly Uint32Field BondAmount
Field Value
|
Edit this page
Book
Declaration
public static readonly StObjectField Book
Field Value
|
Edit this page
BookDirectory
Declaration
public static readonly Hash256Field BookDirectory
Field Value
|
Edit this page
BookNode
Declaration
public static readonly Uint64Field BookNode
Field Value
|
Edit this page
BurnedTokens
Declaration
public static readonly Uint32Field BurnedTokens
Field Value
|
Edit this page
CancelAfter
Declaration
public static readonly Uint32Field CancelAfter
Field Value
|
Edit this page
Channel
Declaration
public static readonly Hash256Field Channel
Field Value
|
Edit this page
CheckID
Declaration
public static readonly Hash256Field CheckID
Field Value
|
Edit this page
ClearFlag
Declaration
public static readonly Uint32Field ClearFlag
Field Value
|
Edit this page
CloseResolution
Declaration
public static readonly Uint8Field CloseResolution
Field Value
|
Edit this page
CloseTime
Declaration
public static readonly Uint32Field CloseTime
Field Value
|
Edit this page
Condition
Declaration
public static readonly BlobField Condition
Field Value
|
Edit this page
ConsensusHash
Declaration
public static readonly Hash256Field ConsensusHash
Field Value
|
Edit this page
Cookie
Declaration
public static readonly Uint64Field Cookie
Field Value
|
Edit this page
CreateCode
Declaration
public static readonly BlobField CreateCode
Field Value
|
Edit this page
CreatedNode
Declaration
public static readonly StObjectField CreatedNode
Field Value
|
Edit this page
Credential
Declaration
public static readonly StObjectField Credential
Field Value
|
Edit this page
CredentialIDs
Declaration
public static readonly Vector256Field CredentialIDs
Field Value
|
Edit this page
CredentialType
The type of credential, as hexadecimal. This is an arbitrary value from 1 to 64 bytes.
Declaration
public static readonly BlobField CredentialType
Field Value
|
Edit this page
DIDDocument
The DID document for the DID. This field is encoded as a hexadecimal string.
Declaration
public static readonly BlobField DIDDocument
Field Value
|
Edit this page
Data
The public attestations of identity credentials associated with the DID.
Declaration
public static readonly BlobField Data
Field Value
|
Edit this page
DeletedNode
Declaration
public static readonly StObjectField DeletedNode
Field Value
|
Edit this page
DeliverMin
Declaration
public static readonly AmountField DeliverMin
Field Value
|
Edit this page
DeliveredAmount
Declaration
public static readonly AmountField DeliveredAmount
Field Value
|
Edit this page
Destination
Declaration
public static readonly AccountIdField Destination
Field Value
|
Edit this page
DestinationNode
Declaration
public static readonly Uint64Field DestinationNode
Field Value
|
Edit this page
DestinationTag
Declaration
public static readonly Uint32Field DestinationTag
Field Value
|
Edit this page
Digest
Declaration
public static readonly Hash256Field Digest
Field Value
|
Edit this page
DisabledValidator
Declaration
public static readonly StObjectField DisabledValidator
Field Value
|
Edit this page
DisabledValidators
Declaration
public static readonly StArrayField DisabledValidators
Field Value
|
Edit this page
DiscountedFee
Declaration
public static readonly Uint32Field DiscountedFee
Field Value
|
Edit this page
Domain
Declaration
public static readonly BlobField Domain
Field Value
|
Edit this page
DomainID
The ledger entry ID of a permissioned domain.
Declaration
public static readonly Hash256Field DomainID
Field Value
|
Edit this page
EPrice
Declaration
public static readonly AmountField EPrice
Field Value
|
Edit this page
EmailHash
Declaration
public static readonly Hash128Field EmailHash
Field Value
|
Edit this page
EmitBurden
Declaration
public static readonly Uint64Field EmitBurden
Field Value
|
Edit this page
EmitCallback
Declaration
public static readonly AccountIdField EmitCallback
Field Value
|
Edit this page
EmitDetails
Declaration
public static readonly StObjectField EmitDetails
Field Value
|
Edit this page
EmitGeneration
Declaration
public static readonly Uint32Field EmitGeneration
Field Value
|
Edit this page
EmitHookHash
Declaration
public static readonly Hash256Field EmitHookHash
Field Value
|
Edit this page
EmitNonce
Declaration
public static readonly Hash256Field EmitNonce
Field Value
|
Edit this page
EmitParentTxnID
Declaration
public static readonly Hash256Field EmitParentTxnID
Field Value
|
Edit this page
EmittedTxn
Declaration
public static readonly StObjectField EmittedTxn
Field Value
|
Edit this page
ExchangeRate
Declaration
public static readonly Uint64Field ExchangeRate
Field Value
|
Edit this page
Expiration
Declaration
public static readonly Uint32Field Expiration
Field Value
|
Edit this page
ExpireCode
Declaration
public static readonly BlobField ExpireCode
Field Value
|
Edit this page
Fee
Declaration
public static readonly AmountField Fee
Field Value
|
Edit this page
FinalFields
Declaration
public static readonly StObjectField FinalFields
Field Value
|
Edit this page
FinishAfter
Declaration
public static readonly Uint32Field FinishAfter
Field Value
|
Edit this page
FirstLedgerSequence
Declaration
[Obsolete]
public static readonly Uint32Field FirstLedgerSequence
Field Value
|
Edit this page
Flags
Declaration
public static readonly Uint32Field Flags
Field Value
|
Edit this page
FromJson
Declaration
Field Value
|
Edit this page
FromParser
Declaration
public FromParser FromParser
Field Value
|
Edit this page
Fulfillment
Declaration
public static readonly BlobField Fulfillment
Field Value
|
Edit this page
FundCode
Declaration
public static readonly BlobField FundCode
Field Value
|
Edit this page
Generic
Declaration
public static readonly Field Generic
Field Value
|
Edit this page
Hashes
Declaration
public static readonly Vector256Field Hashes
Field Value
|
Edit this page
Declaration
public readonly byte[] Header
Field Value
|
Edit this page
HighLimit
Declaration
public static readonly AmountField HighLimit
Field Value
|
Edit this page
HighNode
Declaration
public static readonly Uint64Field HighNode
Field Value
|
Edit this page
HighQualityIn
Declaration
public static readonly Uint32Field HighQualityIn
Field Value
|
Edit this page
HighQualityOut
Declaration
public static readonly Uint32Field HighQualityOut
Field Value
|
Edit this page
Holder
Declaration
public static readonly AccountIdField Holder
Field Value
|
Edit this page
Hook
Declaration
public static readonly StObjectField Hook
Field Value
|
Edit this page
HookAccount
Declaration
public static readonly AccountIdField HookAccount
Field Value
|
Edit this page
HookApiVersion
Declaration
public static readonly Uint16Field HookApiVersion
Field Value
|
Edit this page
HookDefinition
Declaration
public static readonly StObjectField HookDefinition
Field Value
|
Edit this page
HookExecution
Declaration
public static readonly StObjectField HookExecution
Field Value
|
Edit this page
HookExecutions
Declaration
public static readonly StArrayField HookExecutions
Field Value
|
Edit this page
HookGrant
Declaration
public static readonly StObjectField HookGrant
Field Value
|
Edit this page
HookGrants
Declaration
public static readonly StArrayField HookGrants
Field Value
|
Edit this page
HookHash
Declaration
public static readonly Hash256Field HookHash
Field Value
|
Edit this page
HookInstructionCount
Declaration
public static readonly Uint64Field HookInstructionCount
Field Value
|
Edit this page
HookNamespace
Declaration
public static readonly Hash256Field HookNamespace
Field Value
|
Edit this page
HookNamespaces
Declaration
public static readonly Vector256Field HookNamespaces
Field Value
|
Edit this page
HookOn
Declaration
public static readonly Uint64Field HookOn
Field Value
|
Edit this page
HookParameter
Declaration
public static readonly StObjectField HookParameter
Field Value
|
Edit this page
HookParameterName
Declaration
public static readonly BlobField HookParameterName
Field Value
|
Edit this page
HookParameterValue
Declaration
public static readonly BlobField HookParameterValue
Field Value
|
Edit this page
HookParameters
Declaration
public static readonly StArrayField HookParameters
Field Value
|
Edit this page
HookResult
Declaration
public static readonly Uint8Field HookResult
Field Value
|
Edit this page
HookReturnCode
Declaration
public static readonly Uint64Field HookReturnCode
Field Value
|
Edit this page
HookReturnString
Declaration
public static readonly BlobField HookReturnString
Field Value
|
Edit this page
HookSetTxnID
Declaration
public static readonly Hash256Field HookSetTxnID
Field Value
|
Edit this page
HookStateChangeCount
Declaration
public static readonly Uint16Field HookStateChangeCount
Field Value
|
Edit this page
HookStateCount
Declaration
public static readonly Uint32Field HookStateCount
Field Value
|
Edit this page
HookStateData
Declaration
public static readonly BlobField HookStateData
Field Value
|
Edit this page
HookStateEmitCount
Declaration
public static readonly Uint16Field HookStateEmitCount
Field Value
|
Edit this page
HookStateExecutionIndex
Declaration
public static readonly Uint16Field HookStateExecutionIndex
Field Value
|
Edit this page
HookStateKey
Declaration
public static readonly Hash256Field HookStateKey
Field Value
|
Edit this page
Hooks
Declaration
public static readonly StArrayField Hooks
Field Value
|
Edit this page
IndexNext
Declaration
public static readonly Uint64Field IndexNext
Field Value
|
Edit this page
IndexPrevious
Declaration
public static readonly Uint64Field IndexPrevious
Field Value
|
Edit this page
Indexes
Declaration
public static readonly Vector256Field Indexes
Field Value
|
Edit this page
Invalid
Declaration
public static readonly Field Invalid
Field Value
|
Edit this page
InvoiceID
Declaration
public static readonly Hash256Field InvoiceID
Field Value
|
Edit this page
IsSerialised
Declaration
public readonly bool IsSerialised
Field Value
|
Edit this page
IsSigningField
Declaration
public readonly bool IsSigningField
Field Value
|
Edit this page
IsVlEncoded
Declaration
public readonly bool IsVlEncoded
Field Value
|
Edit this page
Issuer
Declaration
public static readonly AccountIdField Issuer
Field Value
|
Edit this page
LPTokenBalance
Declaration
public static readonly AmountField LPTokenBalance
Field Value
|
Edit this page
LPTokenIn
Declaration
public static readonly AmountField LPTokenIn
Field Value
|
Edit this page
LPTokenOut
Declaration
public static readonly AmountField LPTokenOut
Field Value
|
Edit this page
LastLedgerSequence
Declaration
public static readonly Uint32Field LastLedgerSequence
Field Value
|
Edit this page
LastUpdateTime
The time the oracle data was last updated, as a unix timestamp.
Declaration
public static readonly Uint32Field LastUpdateTime
Field Value
|
Edit this page
LedgerEntry
Declaration
public static readonly Field LedgerEntry
Field Value
|
Edit this page
LedgerEntryType
Declaration
public static readonly LedgerEntryTypeField LedgerEntryType
Field Value
|
Edit this page
LedgerHash
Declaration
public static readonly Hash256Field LedgerHash
Field Value
|
Edit this page
LedgerIndex
Declaration
public static readonly Hash256Field LedgerIndex
Field Value
|
Edit this page
LedgerSequence
Declaration
public static readonly Uint32Field LedgerSequence
Field Value
|
Edit this page
LimitAmount
Declaration
public static readonly AmountField LimitAmount
Field Value
|
Edit this page
LoadFee
Declaration
public static readonly Uint32Field LoadFee
Field Value
|
Edit this page
LowLimit
Declaration
public static readonly AmountField LowLimit
Field Value
|
Edit this page
LowNode
Declaration
public static readonly Uint64Field LowNode
Field Value
|
Edit this page
LowQualityIn
Declaration
public static readonly Uint32Field LowQualityIn
Field Value
|
Edit this page
LowQualityOut
Declaration
public static readonly Uint32Field LowQualityOut
Field Value
|
Edit this page
MPTAmount
Declaration
public static readonly Uint64Field MPTAmount
Field Value
|
Edit this page
MPTokenIssuanceID
Declaration
public static readonly Hash192Field MPTokenIssuanceID
Field Value
|
Edit this page
Declaration
public static readonly BlobField MPTokenMetadata
Field Value
|
Edit this page
Majorities
Declaration
public static readonly StArrayField Majorities
Field Value
|
Edit this page
Majority
Declaration
public static readonly StObjectField Majority
Field Value
|
Edit this page
MasterSignature
Declaration
public static readonly BlobField MasterSignature
Field Value
|
Edit this page
MaximumAmount
Declaration
public static readonly Uint64Field MaximumAmount
Field Value
|
Edit this page
Memo
Declaration
public static readonly StObjectField Memo
Field Value
|
Edit this page
MemoData
Declaration
public static readonly BlobField MemoData
Field Value
|
Edit this page
Declaration
public static readonly BlobField MemoFormat
Field Value
|
Edit this page
MemoType
Declaration
public static readonly BlobField MemoType
Field Value
|
Edit this page
Memos
Declaration
public static readonly StArrayField Memos
Field Value
|
Edit this page
MessageKey
Declaration
public static readonly BlobField MessageKey
Field Value
|
Edit this page
Declaration
public static readonly Field Metadata
Field Value
|
Edit this page
Method
Declaration
public static readonly Uint8Field Method
Field Value
|
Edit this page
MinAccountCreateAmount
Declaration
public static readonly AmountField MinAccountCreateAmount
Field Value
|
Edit this page
MinimumOffer
Declaration
public static readonly AmountField MinimumOffer
Field Value
|
Edit this page
MintedTokens
Declaration
public static readonly Uint32Field MintedTokens
Field Value
|
Edit this page
ModifiedNode
Declaration
public static readonly StObjectField ModifiedNode
Field Value
|
Edit this page
NFToken
Declaration
public static readonly StObjectField NFToken
Field Value
|
Edit this page
NFTokenBrokerFee
Declaration
public static readonly AmountField NFTokenBrokerFee
Field Value
|
Edit this page
NFTokenBuyOffer
Declaration
public static readonly Hash256Field NFTokenBuyOffer
Field Value
|
Edit this page
NFTokenID
Declaration
public static readonly Hash256Field NFTokenID
Field Value
|
Edit this page
NFTokenMinter
Declaration
public static readonly AccountIdField NFTokenMinter
Field Value
|
Edit this page
NFTokenOfferNode
Declaration
public static readonly Uint64Field NFTokenOfferNode
Field Value
|
Edit this page
NFTokenOffers
Declaration
public static readonly Vector256Field NFTokenOffers
Field Value
|
Edit this page
NFTokenSellOffer
Declaration
public static readonly Hash256Field NFTokenSellOffer
Field Value
|
Edit this page
NFTokenTaxon
Declaration
public static readonly Uint32Field NFTokenTaxon
Field Value
|
Edit this page
NFTokens
Declaration
public static readonly StArrayField NFTokens
Field Value
|
Edit this page
Necessary
Declaration
public static readonly StArrayField Necessary
Field Value
|
Edit this page
NetworkID
Declaration
public static readonly Uint32Field NetworkID
Field Value
|
Edit this page
NewFields
Declaration
public static readonly StObjectField NewFields
Field Value
|
Edit this page
NextPageMin
Declaration
public static readonly Hash256Field NextPageMin
Field Value
|
Edit this page
Nickname
Declaration
public static readonly Hash256Field Nickname
Field Value
|
Edit this page
NthOfType
Declaration
public readonly int NthOfType
Field Value
|
Edit this page
ObjectEndMarker
Declaration
public static readonly StObjectField ObjectEndMarker
Field Value
|
Edit this page
OfferSequence
Declaration
public static readonly Uint32Field OfferSequence
Field Value
|
Edit this page
OperationLimit
Declaration
public static readonly Uint32Field OperationLimit
Field Value
|
Edit this page
OracleDocumentID
A unique identifier of the price oracle for the Account.
Declaration
public static readonly Uint32Field OracleDocumentID
Field Value
|
Edit this page
OutstandingAmount
Declaration
public static readonly Uint64Field OutstandingAmount
Field Value
|
Edit this page
Owner
Declaration
public static readonly AccountIdField Owner
Field Value
|
Edit this page
OwnerCount
Declaration
public static readonly Uint32Field OwnerCount
Field Value
|
Edit this page
OwnerNode
Declaration
public static readonly Uint64Field OwnerNode
Field Value
|
Edit this page
ParentCloseTime
Declaration
public static readonly Uint32Field ParentCloseTime
Field Value
|
Edit this page
ParentHash
Declaration
public static readonly Hash256Field ParentHash
Field Value
|
Edit this page
Paths
Declaration
public static readonly PathSetField Paths
Field Value
|
Edit this page
Permission
Declaration
public static readonly StObjectField Permission
Field Value
|
Edit this page
Permissions
Declaration
public static readonly StArrayField Permissions
Field Value
|
Edit this page
PreviousFields
Declaration
public static readonly StObjectField PreviousFields
Field Value
|
Edit this page
PreviousPageMin
Declaration
public static readonly Hash256Field PreviousPageMin
Field Value
|
Edit this page
PreviousTxnID
Declaration
public static readonly Hash256Field PreviousTxnID
Field Value
|
Edit this page
PreviousTxnLgrSeq
Declaration
public static readonly Uint32Field PreviousTxnLgrSeq
Field Value
|
Edit this page
Price
Declaration
public static readonly AmountField Price
Field Value
|
Edit this page
PriceData
Declaration
public static readonly StObjectField PriceData
Field Value
|
Edit this page
PriceDataSeries
Declaration
public static readonly StArrayField PriceDataSeries
Field Value
|
Edit this page
Provider
An arbitrary value that identifies an oracle provider.
Declaration
public static readonly BlobField Provider
Field Value
|
Edit this page
PublicKey
Declaration
public static readonly BlobField PublicKey
Field Value
|
Edit this page
QualityIn
Declaration
public static readonly Uint32Field QualityIn
Field Value
|
Edit this page
QualityOut
Declaration
public static readonly Uint32Field QualityOut
Field Value
|
Edit this page
QuoteAsset
The quote asset in a trading pair for Oracle price data.
Declaration
public static readonly CurrencyField QuoteAsset
Field Value
|
Edit this page
RawTransaction
Declaration
public static readonly StObjectField RawTransaction
Field Value
|
Edit this page
RawTransactions
Declaration
public static readonly StArrayField RawTransactions
Field Value
|
Edit this page
ReferenceCount
Declaration
public static readonly Uint64Field ReferenceCount
Field Value
|
Edit this page
ReferenceFeeUnits
Declaration
public static readonly Uint32Field ReferenceFeeUnits
Field Value
|
Edit this page
RegularKey
Declaration
public static readonly AccountIdField RegularKey
Field Value
|
Edit this page
RemoveCode
Declaration
public static readonly BlobField RemoveCode
Field Value
|
Edit this page
ReserveBase
Declaration
public static readonly Uint32Field ReserveBase
Field Value
|
Edit this page
ReserveBaseDrops
Declaration
public static readonly AmountField ReserveBaseDrops
Field Value
|
Edit this page
ReserveIncrement
Declaration
public static readonly Uint32Field ReserveIncrement
Field Value
|
Edit this page
ReserveIncrementDrops
Declaration
public static readonly AmountField ReserveIncrementDrops
Field Value
|
Edit this page
RippleEscrow
Declaration
public static readonly AmountField RippleEscrow
Field Value
|
Edit this page
RootIndex
Declaration
public static readonly Hash256Field RootIndex
Field Value
|
Edit this page
Scale
Declaration
public static readonly Uint8Field Scale
Field Value
|
Edit this page
SendMax
Declaration
public static readonly AmountField SendMax
Field Value
|
Edit this page
Sequence
Declaration
public static readonly Uint32Field Sequence
Field Value
|
Edit this page
ServerVersion
Declaration
public static readonly Uint64Field ServerVersion
Field Value
|
Edit this page
SetFlag
Declaration
public static readonly Uint32Field SetFlag
Field Value
|
Edit this page
SettleDelay
Declaration
public static readonly Uint32Field SettleDelay
Field Value
|
Edit this page
Signature
Declaration
public static readonly BlobField Signature
Field Value
|
Edit this page
SignatureReward
Declaration
public static readonly AmountField SignatureReward
Field Value
|
Edit this page
Signer
Declaration
public static readonly StObjectField Signer
Field Value
|
Edit this page
SignerEntries
Declaration
public static readonly StArrayField SignerEntries
Field Value
|
Edit this page
SignerEntry
Declaration
public static readonly StObjectField SignerEntry
Field Value
|
Edit this page
SignerListID
Declaration
public static readonly Uint32Field SignerListID
Field Value
|
Edit this page
SignerQuorum
Declaration
public static readonly Uint32Field SignerQuorum
Field Value
|
Edit this page
SignerWeight
Declaration
public static readonly Uint16Field SignerWeight
Field Value
|
Edit this page
Signers
Declaration
public static readonly StArrayField Signers
Field Value
|
Edit this page
SigningPubKey
Declaration
public static readonly BlobField SigningPubKey
Field Value
|
Edit this page
SigningTime
Declaration
public static readonly Uint32Field SigningTime
Field Value
|
Edit this page
SourceTag
Declaration
public static readonly Uint32Field SourceTag
Field Value
|
Edit this page
StampEscrow
Declaration
public static readonly Uint32Field StampEscrow
Field Value
|
Edit this page
Subject
Declaration
public static readonly AccountIdField Subject
Field Value
|
Edit this page
Sufficient
Declaration
public static readonly StArrayField Sufficient
Field Value
|
Edit this page
TakerGets
Declaration
public static readonly AmountField TakerGets
Field Value
|
Edit this page
TakerGetsCurrency
Declaration
public static readonly Hash160Field TakerGetsCurrency
Field Value
|
Edit this page
TakerGetsIssuer
Declaration
public static readonly Hash160Field TakerGetsIssuer
Field Value
|
Edit this page
TakerPays
Declaration
public static readonly AmountField TakerPays
Field Value
|
Edit this page
TakerPaysCurrency
Declaration
public static readonly Hash160Field TakerPaysCurrency
Field Value
|
Edit this page
TakerPaysIssuer
Declaration
public static readonly Hash160Field TakerPaysIssuer
Field Value
|
Edit this page
Target
Declaration
public static readonly AccountIdField Target
Field Value
|
Edit this page
Template
Declaration
public static readonly StArrayField Template
Field Value
|
Edit this page
TemplateEntry
Declaration
public static readonly StObjectField TemplateEntry
Field Value
|
Edit this page
TickSize
Declaration
public static readonly Uint8Field TickSize
Field Value
|
Edit this page
TicketCount
Declaration
public static readonly Uint32Field TicketCount
Field Value
|
Edit this page
TicketID
Declaration
public static readonly Hash256Field TicketID
Field Value
|
Edit this page
TicketSequence
Declaration
public static readonly Uint32Field TicketSequence
Field Value
|
Edit this page
TradingFee
Declaration
public static readonly Uint16Field TradingFee
Field Value
|
Edit this page
Transaction
Declaration
public static readonly Field Transaction
Field Value
|
Edit this page
TransactionHash
Declaration
public static readonly Hash256Field TransactionHash
Field Value
|
Edit this page
TransactionIndex
Declaration
public static readonly Uint32Field TransactionIndex
Field Value
|
Edit this page
Declaration
public static readonly StObjectField TransactionMetaData
Field Value
|
Edit this page
TransactionResult
Declaration
public static readonly EngineResultField TransactionResult
Field Value
|
Edit this page
TransactionType
Declaration
public static readonly TransactionTypeField TransactionType
Field Value
|
Edit this page
TransferFee
Declaration
public static readonly Uint16Field TransferFee
Field Value
|
Edit this page
TransferRate
Declaration
public static readonly Uint32Field TransferRate
Field Value
|
Edit this page
TxnSignature
Declaration
public static readonly BlobField TxnSignature
Field Value
|
Edit this page
Type
Declaration
public readonly FieldType Type
Field Value
|
Edit this page
UNLModifyDisabling
Declaration
public static readonly Uint8Field UNLModifyDisabling
Field Value
|
Edit this page
UNLModifyValidator
Declaration
public static readonly BlobField UNLModifyValidator
Field Value
|
Edit this page
URI
Declaration
public static readonly BlobField URI
Field Value
|
Edit this page
Unauthorize
Declaration
public static readonly AccountIdField Unauthorize
Field Value
|
Edit this page
UnauthorizeCredentials
Declaration
public static readonly StArrayField UnauthorizeCredentials
Field Value
|
Edit this page
ValidatedHash
Declaration
public static readonly Hash256Field ValidatedHash
Field Value
|
Edit this page
Validation
Declaration
public static readonly Field Validation
Field Value
|
Edit this page
ValidatorToDisable
Declaration
public static readonly BlobField ValidatorToDisable
Field Value
|
Edit this page
ValidatorToReEnable
Declaration
public static readonly BlobField ValidatorToReEnable
Field Value
|
Edit this page
Values
Declaration
public static readonly Enumeration<Field> Values
Field Value
|
Edit this page
Version
Declaration
public static readonly Uint16Field Version
Field Value
|
Edit this page
VoteEntry
Declaration
public static readonly StObjectField VoteEntry
Field Value
|
Edit this page
VoteSlots
Declaration
public static readonly StArrayField VoteSlots
Field Value
|
Edit this page
VoteWeight
Declaration
public static readonly Uint32Field VoteWeight
Field Value
|
Edit this page
WalletLocator
Declaration
public static readonly Hash256Field WalletLocator
Field Value
|
Edit this page
WalletSize
Declaration
public static readonly Uint32Field WalletSize
Field Value
|
Edit this page
XChainClaimAttestationCollectionElement
Declaration
public static readonly StObjectField XChainClaimAttestationCollectionElement
Field Value
|
Edit this page
XChainClaimAttestations
Declaration
public static readonly StArrayField XChainClaimAttestations
Field Value
|
Edit this page
XChainClaimProofSig
Declaration
public static readonly StObjectField XChainClaimProofSig
Field Value
|
Edit this page
XChainCreateAccountAttestationCollectionElement
Declaration
public static readonly StObjectField XChainCreateAccountAttestationCollectionElement
Field Value
|
Edit this page
XChainCreateAccountAttestations
Declaration
public static readonly StArrayField XChainCreateAccountAttestations
Field Value
|
Edit this page
XChainCreateAccountProofSig
Declaration
public static readonly StObjectField XChainCreateAccountProofSig
Field Value
|
Edit this page
hash
Declaration
public static readonly Hash256Field hash
Field Value
|
Edit this page
index
Declaration
public static readonly Hash256Field index
Field Value
|
Edit this page
taker_gets_funded
Declaration
public static readonly AmountField taker_gets_funded
Field Value
|
Edit this page
taker_pays_funded
Declaration
public static readonly AmountField taker_pays_funded
Field Value
Operators
|
Edit this page
implicit operator Field(string)
Declaration
public static implicit operator Field(string s)
Parameters
| Type |
Name |
Description |
| string |
s |
|
Returns