Show / Hide Table of Contents

Class LedgerEntryType

Inheritance
object
EnumItem
SerializedEnumItem<ushort>
LedgerEntryType
Implements
ISerializedType
Inherited Members
SerializedEnumItem<ushort>.Bytes
SerializedEnumItem<ushort>.ToBytes(IBytesSink)
SerializedEnumItem<ushort>.ToJson()
EnumItem.Ordinal
EnumItem.Name
EnumItem.CompareTo(EnumItem)
EnumItem.ToString()
EnumItem.GetHashCode()
Namespace: Xrpl.BinaryCodec.Enums
Assembly: Xrpl.BinaryCodec.dll
Syntax
public class LedgerEntryType : SerializedEnumItem<ushort>, ISerializedType

Fields

| Edit this page View Source

AMM

Declaration
public static readonly LedgerEntryType AMM
Field Value
Type Description
LedgerEntryType
| Edit this page View Source

AccountRoot

Declaration
public static readonly LedgerEntryType AccountRoot
Field Value
Type Description
LedgerEntryType
| Edit this page View Source

Amendments

Declaration
public static readonly LedgerEntryType Amendments
Field Value
Type Description
LedgerEntryType
| Edit this page View Source

Bridge

Declaration
public static readonly LedgerEntryType Bridge
Field Value
Type Description
LedgerEntryType
| Edit this page View Source

Check

Declaration
public static readonly LedgerEntryType Check
Field Value
Type Description
LedgerEntryType
| Edit this page View Source

Contract

Declaration
[Obsolete("Contract is deprecated and no longer used in the protocol.")]
public static readonly LedgerEntryType Contract
Field Value
Type Description
LedgerEntryType
| Edit this page View Source

Credential

Declaration
public static readonly LedgerEntryType Credential
Field Value
Type Description
LedgerEntryType
| Edit this page View Source

DID

Declaration
public static readonly LedgerEntryType DID
Field Value
Type Description
LedgerEntryType
| Edit this page View Source

Delegate

Declaration
public static readonly LedgerEntryType Delegate
Field Value
Type Description
LedgerEntryType
| Edit this page View Source

DepositPreauth

Declaration
public static readonly LedgerEntryType DepositPreauth
Field Value
Type Description
LedgerEntryType
| Edit this page View Source

DirectoryNode

Declaration
public static readonly LedgerEntryType DirectoryNode
Field Value
Type Description
LedgerEntryType
| Edit this page View Source

Escrow

Declaration
public static readonly LedgerEntryType Escrow
Field Value
Type Description
LedgerEntryType
| Edit this page View Source

FeeSettings

Declaration
public static readonly LedgerEntryType FeeSettings
Field Value
Type Description
LedgerEntryType
| Edit this page View Source

GeneratorMap

Declaration
[Obsolete("GeneratorMap is deprecated and no longer used in the protocol.")]
public static readonly LedgerEntryType GeneratorMap
Field Value
Type Description
LedgerEntryType
| Edit this page View Source

Invalid

Declaration
public static readonly LedgerEntryType Invalid
Field Value
Type Description
LedgerEntryType
| Edit this page View Source

LedgerHashes

Declaration
public static readonly LedgerEntryType LedgerHashes
Field Value
Type Description
LedgerEntryType
| Edit this page View Source

Loan

Declaration
public static readonly LedgerEntryType Loan
Field Value
Type Description
LedgerEntryType
| Edit this page View Source

LoanBroker

Declaration
public static readonly LedgerEntryType LoanBroker
Field Value
Type Description
LedgerEntryType
| Edit this page View Source

MPToken

Declaration
public static readonly LedgerEntryType MPToken
Field Value
Type Description
LedgerEntryType
| Edit this page View Source

MPTokenIssuance

Declaration
public static readonly LedgerEntryType MPTokenIssuance
Field Value
Type Description
LedgerEntryType
| Edit this page View Source

NFTokenOffer

Declaration
public static readonly LedgerEntryType NFTokenOffer
Field Value
Type Description
LedgerEntryType
| Edit this page View Source

NFTokenPage

Declaration
public static readonly LedgerEntryType NFTokenPage
Field Value
Type Description
LedgerEntryType
| Edit this page View Source

NegativeUNL

Declaration
public static readonly LedgerEntryType NegativeUNL
Field Value
Type Description
LedgerEntryType
| Edit this page View Source

Offer

Declaration
public static readonly LedgerEntryType Offer
Field Value
Type Description
LedgerEntryType
| Edit this page View Source

Oracle

Declaration
public static readonly LedgerEntryType Oracle
Field Value
Type Description
LedgerEntryType
| Edit this page View Source

PayChannel

Declaration
public static readonly LedgerEntryType PayChannel
Field Value
Type Description
LedgerEntryType
| Edit this page View Source

PermissionedDomain

Declaration
public static readonly LedgerEntryType PermissionedDomain
Field Value
Type Description
LedgerEntryType
| Edit this page View Source

RippleState

Declaration
public static readonly LedgerEntryType RippleState
Field Value
Type Description
LedgerEntryType
| Edit this page View Source

SignerList

Declaration
public static readonly LedgerEntryType SignerList
Field Value
Type Description
LedgerEntryType
| Edit this page View Source

Ticket

Declaration
public static readonly LedgerEntryType Ticket
Field Value
Type Description
LedgerEntryType
| Edit this page View Source

Values

Declaration
public static LedgerEntryType.Enumeration Values
Field Value
Type Description
LedgerEntryType.Enumeration
| Edit this page View Source

Vault

Declaration
public static readonly LedgerEntryType Vault
Field Value
Type Description
LedgerEntryType
| Edit this page View Source

XChainOwnedClaimID

Declaration
public static readonly LedgerEntryType XChainOwnedClaimID
Field Value
Type Description
LedgerEntryType
| Edit this page View Source

XChainOwnedCreateAccountClaimID

Declaration
public static readonly LedgerEntryType XChainOwnedCreateAccountClaimID
Field Value
Type Description
LedgerEntryType

Properties

| Edit this page View Source

EnabledAmendments

Declaration
[Obsolete("Use Amendments instead. EnabledAmendments is the legacy name.")]
public static LedgerEntryType EnabledAmendments { get; }
Property Value
Type Description
LedgerEntryType

Methods

| Edit this page View Source

FromJson(JsonNode)

Declaration
public static LedgerEntryType FromJson(JsonNode jToken)
Parameters
Type Name Description
JsonNode jToken
Returns
Type Description
LedgerEntryType

Implements

ISerializedType

Extension Methods

StExtensions.ToDebuggedHex(ISerializedType)
StExtensions.ToHex(ISerializedType)
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX