Show / Hide Table of Contents

Class TransactionType

Inheritance
object
EnumItem
SerializedEnumItem<ushort>
TransactionType
Implements
ISerializedType
Inherited Members
SerializedEnumItem<ushort>.Bytes
SerializedEnumItem<ushort>.ToBytes(IBytesSink)
SerializedEnumItem<ushort>.ToJson()
EnumItem.Ordinal
EnumItem.Name
EnumItem.CompareTo(EnumItem)
EnumItem.ToString()
EnumItem.GetHashCode()
Namespace: Xrpl.BinaryCodec.Types
Assembly: Xrpl.BinaryCodec.dll
Syntax
public class TransactionType : SerializedEnumItem<ushort>, ISerializedType

Fields

| Edit this page View Source

AMMBid

Declaration
public static readonly TransactionType AMMBid
Field Value
Type Description
TransactionType
| Edit this page View Source

AMMClawback

Claw back tokens from an Automated Market Maker (AMM) pool.

Declaration
public static readonly TransactionType AMMClawback
Field Value
Type Description
TransactionType
| Edit this page View Source

AMMCreate

Declaration
public static readonly TransactionType AMMCreate
Field Value
Type Description
TransactionType
| Edit this page View Source

AMMDelete

Declaration
public static readonly TransactionType AMMDelete
Field Value
Type Description
TransactionType
| Edit this page View Source

AMMDeposit

Declaration
public static readonly TransactionType AMMDeposit
Field Value
Type Description
TransactionType
| Edit this page View Source

AMMVote

Declaration
public static readonly TransactionType AMMVote
Field Value
Type Description
TransactionType
| Edit this page View Source

AMMWithdraw

Declaration
public static readonly TransactionType AMMWithdraw
Field Value
Type Description
TransactionType
| Edit this page View Source

AccountDelete

This transaction type deletes an existing account.

Declaration
public static readonly TransactionType AccountDelete
Field Value
Type Description
TransactionType
| Edit this page View Source

AccountSet

This transaction type adjusts various account settings.

Declaration
public static readonly TransactionType AccountSet
Field Value
Type Description
TransactionType
| Edit this page View Source

Batch

Batch Transactions let you package multiple transactions together and execute them as a single unit.
It eliminates the risk of partial completion and unexpected outcomes,
giving you a more reliable and predictable experience for complex operations.
Up to eight transactions can be submitted in a single batch.
For details, see: https://xrpl.org/docs/concepts/transactions/batch-transactions

Declaration
public static readonly TransactionType Batch
Field Value
Type Description
TransactionType
| Edit this page View Source

CheckCancel

This transaction type cancels an existing check.

Declaration
public static readonly TransactionType CheckCancel
Field Value
Type Description
TransactionType
| Edit this page View Source

CheckCash

This transaction type cashes an existing check.

Declaration
public static readonly TransactionType CheckCash
Field Value
Type Description
TransactionType
| Edit this page View Source

CheckCreate

This transaction type creates a new check.

Declaration
public static readonly TransactionType CheckCreate
Field Value
Type Description
TransactionType
| Edit this page View Source

Clawback

Claw back tokens issued by your account from a holder.

Declaration
public static readonly TransactionType Clawback
Field Value
Type Description
TransactionType
| Edit this page View Source

CredentialAccept

Accepts a provisionally-issued credential, making it valid.

Declaration
public static readonly TransactionType CredentialAccept
Field Value
Type Description
TransactionType
| Edit this page View Source

CredentialCreate

Creates a new credential issued to a subject account.

Declaration
public static readonly TransactionType CredentialCreate
Field Value
Type Description
TransactionType
| Edit this page View Source

CredentialDelete

Deletes (revokes) a credential from the ledger.

Declaration
public static readonly TransactionType CredentialDelete
Field Value
Type Description
TransactionType
| Edit this page View Source

DIDDelete

Deletes the DID associated with the sending account.

Declaration
public static readonly TransactionType DIDDelete
Field Value
Type Description
TransactionType
| Edit this page View Source

DIDSet

Creates or updates a Decentralized Identifier (DID) associated with the sending account.

Declaration
public static readonly TransactionType DIDSet
Field Value
Type Description
TransactionType
| Edit this page View Source

DepositPreauth

This transaction type grants or revokes authorization to transfer funds.

Declaration
public static readonly TransactionType DepositPreauth
Field Value
Type Description
TransactionType
| Edit this page View Source

EnableAmendment

This system-generated transaction type is used to update the status of the various amendments.
For details, see: https://xrpl.org/amendments.html

Declaration
public static readonly TransactionType EnableAmendment
Field Value
Type Description
TransactionType
| Edit this page View Source

EscrowCancel

This transaction type cancels an existing escrow.

Declaration
public static readonly TransactionType EscrowCancel
Field Value
Type Description
TransactionType
| Edit this page View Source

EscrowCreate

This transaction type creates an escrow object.

Declaration
public static readonly TransactionType EscrowCreate
Field Value
Type Description
TransactionType
| Edit this page View Source

EscrowFinish

This transaction type completes an existing escrow.

Declaration
public static readonly TransactionType EscrowFinish
Field Value
Type Description
TransactionType
| Edit this page View Source

HookSet

This transaction type installs a hook.
NOTE*: maybe_unused

Declaration
public static readonly TransactionType HookSet
Field Value
Type Description
TransactionType
| Edit this page View Source

Invalid

invalid transaction

Declaration
public static readonly TransactionType Invalid
Field Value
Type Description
TransactionType
| Edit this page View Source

MPTokenAuthorize

This transaction authorizes or unauthorizes a holder for an MPT.

Declaration
public static readonly TransactionType MPTokenAuthorize
Field Value
Type Description
TransactionType
| Edit this page View Source

MPTokenIssuanceCreate

This transaction creates a new Multi-Purpose Token (MPT) issuance.

Declaration
public static readonly TransactionType MPTokenIssuanceCreate
Field Value
Type Description
TransactionType
| Edit this page View Source

MPTokenIssuanceDestroy

This transaction destroys an existing MPT issuance.

Declaration
public static readonly TransactionType MPTokenIssuanceDestroy
Field Value
Type Description
TransactionType
| Edit this page View Source

MPTokenIssuanceSet

This transaction modifies settings of an existing MPT issuance.

Declaration
public static readonly TransactionType MPTokenIssuanceSet
Field Value
Type Description
TransactionType
| Edit this page View Source

NFTokenAcceptOffer

This transaction accepts an existing offer to buy or sell an existing NFT.

Declaration
public static readonly TransactionType NFTokenAcceptOffer
Field Value
Type Description
TransactionType
| Edit this page View Source

NFTokenBurn

This transaction burns (i.e. destroys) an existing NFT.

Declaration
public static readonly TransactionType NFTokenBurn
Field Value
Type Description
TransactionType
| Edit this page View Source

NFTokenCancelOffer

This transaction cancels an existing offer to buy or sell an existing NFT.

Declaration
public static readonly TransactionType NFTokenCancelOffer
Field Value
Type Description
TransactionType
| Edit this page View Source

NFTokenCreateOffer

This transaction creates a new offer to buy or sell an NFT.

Declaration
public static readonly TransactionType NFTokenCreateOffer
Field Value
Type Description
TransactionType
| Edit this page View Source

NFTokenMint

This transaction mints a new NFT

Declaration
public static readonly TransactionType NFTokenMint
Field Value
Type Description
TransactionType
| Edit this page View Source

NFTokenModify

Declaration
public static readonly TransactionType NFTokenModify
Field Value
Type Description
TransactionType
| Edit this page View Source

OfferCancel

This transaction type cancels existing offers to trade one asset for another.

Declaration
public static readonly TransactionType OfferCancel
Field Value
Type Description
TransactionType
| Edit this page View Source

OfferCreate

This transaction type creates an offer to trade one asset for another.

Declaration
public static readonly TransactionType OfferCreate
Field Value
Type Description
TransactionType
| Edit this page View Source

OracleDelete

Deletes a price oracle from the ledger.

Declaration
public static readonly TransactionType OracleDelete
Field Value
Type Description
TransactionType
| Edit this page View Source

OracleSet

Creates or updates a price oracle on the ledger.

Declaration
public static readonly TransactionType OracleSet
Field Value
Type Description
TransactionType
| Edit this page View Source

Payment

This transaction type executes a payment

Declaration
public static readonly TransactionType Payment
Field Value
Type Description
TransactionType
| Edit this page View Source

PaymentChannelClaim

This transaction type submits a claim against an existing unidirectional payment channel.

Declaration
public static readonly TransactionType PaymentChannelClaim
Field Value
Type Description
TransactionType
| Edit this page View Source

PaymentChannelCreate

This transaction type creates a new unidirectional XRP payment channel.

Declaration
public static readonly TransactionType PaymentChannelCreate
Field Value
Type Description
TransactionType
| Edit this page View Source

PaymentChannelFund

This transaction type funds an existing unidirectional XRP payment channel.

Declaration
public static readonly TransactionType PaymentChannelFund
Field Value
Type Description
TransactionType
| Edit this page View Source

PermissionedDomainDelete

Delete a permissioned domain that you own.

Declaration
public static readonly TransactionType PermissionedDomainDelete
Field Value
Type Description
TransactionType
| Edit this page View Source

PermissionedDomainSet

Create a permissioned domain, or modify one that you own.

Declaration
public static readonly TransactionType PermissionedDomainSet
Field Value
Type Description
TransactionType
| Edit this page View Source

SetFee

This system-generated transaction type is used to update the network's fee settings.
For details, see: https://xrpl.org/fee-voting.html

Declaration
public static readonly TransactionType SetFee
Field Value
Type Description
TransactionType
| Edit this page View Source

SetRegularKey

This transaction type sets or clears an account's "regular key"

Declaration
public static readonly TransactionType SetRegularKey
Field Value
Type Description
TransactionType
| Edit this page View Source

SignerListSet

This transaction type modifies the signer list associated with an account.

Declaration
public static readonly TransactionType SignerListSet
Field Value
Type Description
TransactionType
| Edit this page View Source

TicketCreate

This transaction type creates a new set of tickets.

Declaration
public static readonly TransactionType TicketCreate
Field Value
Type Description
TransactionType
| Edit this page View Source

TrustSet

This transaction type modifies a trustline between two accounts.

Declaration
public static readonly TransactionType TrustSet
Field Value
Type Description
TransactionType
| Edit this page View Source

UNLModify

This system-generated transaction type is used to update the network's negative UNL For details, see: https://xrpl.org/negative-unl.html

Declaration
public static readonly TransactionType UNLModify
Field Value
Type Description
TransactionType
| Edit this page View Source

Values

Declaration
public static TransactionType.Enumeration Values
Field Value
Type Description
TransactionType.Enumeration

Implements

ISerializedType

Extension Methods

StExtensions.ToDebuggedHex(ISerializedType)
StExtensions.ToHex(ISerializedType)
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX