Show / Hide Table of Contents

Class AdminCredentials

rippled's admin_user/admin_password port-stanza credentials. They are carried inside the JSON body of each request, which is the only mechanism rippled accepts for admin commands over ws/wss.

Inheritance
object
AdminCredentials
Namespace: Xrpl.Client
Assembly: Xrpl.dll
Syntax
public sealed record AdminCredentials

Constructors

| Edit this page View Source

AdminCredentials(string, string)

rippled's admin_user/admin_password port-stanza credentials. They are carried inside the JSON body of each request, which is the only mechanism rippled accepts for admin commands over ws/wss.

Declaration
public AdminCredentials(string User, string Password)
Parameters
Type Name Description
string User
string Password

Properties

| Edit this page View Source

Password

Declaration
public string Password { get; init; }
Property Value
Type Description
string
| Edit this page View Source

User

Declaration
public string User { get; init; }
Property Value
Type Description
string
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX