Show / Hide Table of Contents

Class ClientDisconnectedException

The client is not connected because the consumer disconnected it.

Inheritance
object
Exception
XrplException
NotConnectedException
ClientDisconnectedException
Inherited Members
NotConnectedException.DefaultMessage
Namespace: Xrpl.Client.Exceptions
Assembly: Xrpl.dll
Syntax
public class ClientDisconnectedException : NotConnectedException
Remarks

Nothing is going to bring the connection back on its own: Connect() is the only way out. A consumer that reacts to a lost connection by failing over to another server must not do so here - the client is down because it was asked to be.

Constructors

| Edit this page View Source

ClientDisconnectedException(string)

Declaration
public ClientDisconnectedException(string message = null)
Parameters
Type Name Description
string message

Extension Methods

XrplErrorClassifier.Classify(Exception)
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX