Show / Hide Table of Contents

Class TimeoutException

Exception thrown when a request to rippled times out.

IMPORTANT: this is Xrpl.Client.Exceptions.TimeoutException, NOT System.TimeoutException. It derives from XrplException, so a catch (System.TimeoutException) will NOT catch it. Catch this type (or its base XrplException) explicitly; if both using System; and using Xrpl.Client.Exceptions; are in scope, fully-qualify the type to avoid catching the wrong one.

Inheritance
object
Exception
XrplException
TimeoutException
Namespace: Xrpl.Client.Exceptions
Assembly: Xrpl.dll
Syntax
public class TimeoutException : XrplException

Constructors

| Edit this page View Source

TimeoutException(string, object)

Declaration
public TimeoutException(string message, object data = null)
Parameters
Type Name Description
string message
object data

Extension Methods

XrplErrorClassifier.Classify(Exception)
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX