Class XrplClient
Inheritance
Implements
Namespace: Xrpl.Client
Assembly: Xrpl.dll
Syntax
public class XrplClient : IXrplClient
Constructors
| Edit this page View SourceXrplClient(string, ClientOptions?)
Declaration
public XrplClient(string server, XrplClient.ClientOptions? options = null)
Parameters
| Type | Name | Description |
|---|---|---|
| string | server | |
| XrplClient.ClientOptions | options |
Properties
| Edit this page View SourceApiVersion
The API version to use when making requests.
Declaration
public uint ApiVersion { get; set; }
Property Value
| Type | Description |
|---|---|
| uint |
connection
Declaration
public Connection connection { get; set; }
Property Value
| Type | Description |
|---|---|
| Connection |
feeCushion
Declaration
public double feeCushion { get; set; }
Property Value
| Type | Description |
|---|---|
| double |
maxFeeXRP
Declaration
public string maxFeeXRP { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
networkID
Declaration
public uint? networkID { get; set; }
Property Value
| Type | Description |
|---|---|
| uint? |
Methods
| Edit this page View SourceAccountChannels(AccountChannelsRequest, CancellationToken)
The account_channels method returns information about an account's Payment Channels. This includes only channels where the specified account is the channel's source, not the destination.
Declaration
public Task<AccountChannels> AccountChannels(AccountChannelsRequest request, CancellationToken cancellationToken = default)
Parameters
| Type | Name | Description |
|---|---|---|
| AccountChannelsRequest | request | An AccountChannelsRequest request. |
| CancellationToken | cancellationToken |
Returns
| Type | Description |
|---|---|
| Task<AccountChannels> | An AccountChannels response. |
AccountCurrencies(AccountCurrenciesRequest, CancellationToken)
The account_currencies command retrieves a list of currencies that an account can send or receive, based on its trust lines.
Declaration
public Task<AccountCurrencies> AccountCurrencies(AccountCurrenciesRequest request, CancellationToken cancellationToken = default)
Parameters
| Type | Name | Description |
|---|---|---|
| AccountCurrenciesRequest | request | An AccountCurrenciesRequest request. |
| CancellationToken | cancellationToken |
Returns
| Type | Description |
|---|---|
| Task<AccountCurrencies> | An AccountCurrencies response. |
AccountInfo(AccountInfoRequest, CancellationToken)
The account_info command retrieves information about an account, its activity, and its XRP balance.
Declaration
public Task<AccountInfo> AccountInfo(AccountInfoRequest request, CancellationToken cancellationToken = default)
Parameters
| Type | Name | Description |
|---|---|---|
| AccountInfoRequest | request | An AccountInfoRequest request. |
| CancellationToken | cancellationToken |
Returns
| Type | Description |
|---|---|
| Task<AccountInfo> | An AccountInfo response. |
AccountLines(AccountLinesRequest, CancellationToken)
The account_lines method returns information about an account's trust lines, including balances in all non-XRP currencies and assets.
Declaration
public Task<AccountLines> AccountLines(AccountLinesRequest request, CancellationToken cancellationToken = default)
Parameters
| Type | Name | Description |
|---|---|---|
| AccountLinesRequest | request | An AccountLinesRequest request. |
| CancellationToken | cancellationToken |
Returns
| Type | Description |
|---|---|
| Task<AccountLines> | An AccountLines response. |
AccountNFTs(AccountNFTsRequest, CancellationToken)
The account_nfts method returns a list of NFToken objects for the specified account.
Declaration
public Task<AccountNFTs> AccountNFTs(AccountNFTsRequest request, CancellationToken cancellationToken = default)
Parameters
| Type | Name | Description |
|---|---|---|
| AccountNFTsRequest | request | An AccountNFTsRequest request. |
| CancellationToken | cancellationToken |
Returns
| Type | Description |
|---|---|
| Task<AccountNFTs> | An AccountNFTs response. |
AccountObjects(AccountObjectsRequest, CancellationToken)
The AccountObjects command returns the raw ledger format for all objects owned by an account. For a higher-level view of an account's trust lines and balances, see AccountLines instead.
Declaration
public Task<AccountObjects> AccountObjects(AccountObjectsRequest request, CancellationToken cancellationToken = default)
Parameters
| Type | Name | Description |
|---|---|---|
| AccountObjectsRequest | request | An AccountObjectsRequest request. |
| CancellationToken | cancellationToken |
Returns
| Type | Description |
|---|---|
| Task<AccountObjects> | An AccountObjects response. |
AccountOffers(AccountOffersRequest, CancellationToken)
The account_offers method retrieves a list of offers made by a given account that are outstanding as of a particular ledger version
Declaration
public Task<AccountOffers> AccountOffers(AccountOffersRequest request, CancellationToken cancellationToken = default)
Parameters
| Type | Name | Description |
|---|---|---|
| AccountOffersRequest | request | An AccountOffersRequest request. |
| CancellationToken | cancellationToken |
Returns
| Type | Description |
|---|---|
| Task<AccountOffers> | An AccountOffers response. |
AccountTransactions(AccountTransactionsRequest, CancellationToken)
The account_tx method retrieves a list of transactions that involved the specified account
Declaration
public Task<AccountTransactions> AccountTransactions(AccountTransactionsRequest request, CancellationToken cancellationToken = default)
Parameters
| Type | Name | Description |
|---|---|---|
| AccountTransactionsRequest | request | An AccountTransactionsRequest request. |
| CancellationToken | cancellationToken |
Returns
| Type | Description |
|---|---|
| Task<AccountTransactions> | An AccountTransactions response. |
AmmInfo(AMMInfoRequest, CancellationToken)
The amm_info method gets information about an Automated Market Maker (AMM) instance.
Declaration
public Task<AMMInfoResponse> AmmInfo(AMMInfoRequest request, CancellationToken cancellationToken = default)
Parameters
| Type | Name | Description |
|---|---|---|
| AMMInfoRequest | request | An AMMInfoRequest request. |
| CancellationToken | cancellationToken |
Returns
| Type | Description |
|---|---|
| Task<AMMInfoResponse> | An AMMInfoResponse response. |
AnyRequest(BaseRequest, CancellationToken)
Declaration
public Task<object> AnyRequest(BaseRequest request, CancellationToken cancellationToken = default)
Parameters
| Type | Name | Description |
|---|---|---|
| BaseRequest | request | |
| CancellationToken | cancellationToken |
Returns
| Type | Description |
|---|---|
| Task<object> |
Autofill(Dictionary<string, object>, int?, CancellationToken)
Autofills fields in a transaction. This will set Sequence, Fee,
lastLedgerSequence according to the current state of the server this Client
is connected to. It also converts all X-Addresses to classic addresses and
flags interfaces into numbers.
Declaration
public Task<Dictionary<string, object>> Autofill(Dictionary<string, object> tx, int? signersCount = null, CancellationToken cancellationToken = default)
Parameters
| Type | Name | Description |
|---|---|---|
| Dictionary<string, object> | tx | A {@link Transaction} in JSON format |
| int? | signersCount | The expected number of signers for this transaction. Only used for multisigned transactions. |
| CancellationToken | cancellationToken |
Returns
| Type | Description |
|---|---|
| Task<Dictionary<string, object>> | The autofilled transaction. |
Autofill<T>(T, int?, CancellationToken)
Autofills fields in a transaction. This will set Sequence, Fee,
lastLedgerSequence according to the current state of the server this Client
is connected to. It also converts all X-Addresses to classic addresses and
flags interfaces into numbers.
Declaration
public Task<T> Autofill<T>(T tx, int? signersCount = null, CancellationToken cancellationToken = default) where T : ITransactionRequest
Parameters
| Type | Name | Description |
|---|---|---|
| T | tx | A {@link Transaction} in JSON format |
| int? | signersCount | The expected number of signers for this transaction. Only used for multisigned transactions. |
| CancellationToken | cancellationToken |
Returns
| Type | Description |
|---|---|
| Task<T> | The autofilled transaction. |
Type Parameters
| Name | Description |
|---|---|
| T |
BookOffers(BookOffersRequest, CancellationToken)
The book_offers method retrieves a list of offers, also known as the order book , between two currencies
Declaration
public Task<BookOffers> BookOffers(BookOffersRequest request, CancellationToken cancellationToken = default)
Parameters
| Type | Name | Description |
|---|---|---|
| BookOffersRequest | request | An BookOffersRequest request. |
| CancellationToken | cancellationToken |
Returns
| Type | Description |
|---|---|
| Task<BookOffers> | An BookOffers response. |
ChangeServer(string, ClientOptions?, CancellationToken)
Declaration
public Task ChangeServer(string server, XrplClient.ClientOptions? options = null, CancellationToken cancellationToken = default)
Parameters
| Type | Name | Description |
|---|---|---|
| string | server | |
| XrplClient.ClientOptions | options | |
| CancellationToken | cancellationToken |
Returns
| Type | Description |
|---|---|
| Task |
Connect(CancellationToken)
Connect to the server
Declaration
public Task Connect(CancellationToken cancellationToken = default)
Parameters
| Type | Name | Description |
|---|---|---|
| CancellationToken | cancellationToken | cancellation token |
Returns
| Type | Description |
|---|---|
| Task |
DepositAuthorized(DepositAuthorizedRequest, CancellationToken)
The deposit_authorized command indicates whether one account is authorized to send payments
directly to another. https://xrpl.org/deposit_authorized.html
Declaration
public Task<DepositAuthorized> DepositAuthorized(DepositAuthorizedRequest request, CancellationToken cancellationToken = default)
Parameters
| Type | Name | Description |
|---|---|---|
| DepositAuthorizedRequest | request | |
| CancellationToken | cancellationToken | Cancellation token. |
Returns
| Type | Description |
|---|---|
| Task<DepositAuthorized> | A DepositAuthorized(DepositAuthorizedRequest, CancellationToken) response. |
Disconnect()
Disconnect from server
Declaration
public Task Disconnect()
Returns
| Type | Description |
|---|---|
| Task |
DisconnectAndWaitAsync(TimeSpan, CancellationToken)
Disconnects and waits for the WebSocket to be fully closed and cleaned up.
Declaration
public Task DisconnectAndWaitAsync(TimeSpan timeout, CancellationToken cancellationToken = default)
Parameters
| Type | Name | Description |
|---|---|---|
| TimeSpan | timeout | Maximum time to wait for cleanup. |
| CancellationToken | cancellationToken | Cancellation token. |
Returns
| Type | Description |
|---|---|
| Task |
Dispose()
Performs application-defined tasks associated with freeing, releasing, or resetting unmanaged resources.
Declaration
public void Dispose()
EnsureClassicAddress(string)
Declaration
public string EnsureClassicAddress(string address)
Parameters
| Type | Name | Description |
|---|---|---|
| string | address |
Returns
| Type | Description |
|---|---|
| string |
Fee(CancellationToken)
The fee command reports the current state of the open-ledger requirements for the transaction cost.
Declaration
public Task<Fee> Fee(CancellationToken cancellationToken = default)
Parameters
| Type | Name | Description |
|---|---|---|
| CancellationToken | cancellationToken |
Returns
| Type | Description |
|---|---|
| Task<Fee> | An Fee response. |
GRequest<T, R>(R, CancellationToken)
Declaration
public Task<T> GRequest<T, R>(R request, CancellationToken cancellationToken = default) where R : BaseRequest
Parameters
| Type | Name | Description |
|---|---|---|
| R | request | |
| CancellationToken | cancellationToken |
Returns
| Type | Description |
|---|---|
| Task<T> |
Type Parameters
| Name | Description |
|---|---|
| T | |
| R |
GatewayBalances(GatewayBalancesRequest, CancellationToken)
The gateway_balances command calculates the total balances issued by a given account, optionally excluding amounts held by operational addresses.
Declaration
public Task<GatewayBalancesResponse> GatewayBalances(GatewayBalancesRequest request, CancellationToken cancellationToken = default)
Parameters
| Type | Name | Description |
|---|---|---|
| GatewayBalancesRequest | request | An GatewayBalancesRequest request. |
| CancellationToken | cancellationToken |
Returns
| Type | Description |
|---|---|
| Task<GatewayBalancesResponse> | An GatewayBalancesResponse response. |
GetLedgerIndex(CancellationToken)
Declaration
public Task<uint> GetLedgerIndex(CancellationToken cancellationToken = default)
Parameters
| Type | Name | Description |
|---|---|---|
| CancellationToken | cancellationToken |
Returns
| Type | Description |
|---|---|
| Task<uint> |
GetXrpBalance(string, CancellationToken)
Declaration
public Task<string> GetXrpBalance(string address, CancellationToken cancellationToken = default)
Parameters
| Type | Name | Description |
|---|---|---|
| string | address | |
| CancellationToken | cancellationToken |
Returns
| Type | Description |
|---|---|
| Task<string> |
IsConnected()
if the websocket is connected
Declaration
public bool IsConnected()
Returns
| Type | Description |
|---|---|
| bool |
IsValidWss(string)
Declaration
public bool IsValidWss(string server)
Parameters
| Type | Name | Description |
|---|---|---|
| string | server |
Returns
| Type | Description |
|---|---|
| bool |
Ledger(LedgerRequest, CancellationToken)
The ledger_request command tells server to fetch a specific ledger version from its connected peers. This only works if one of the server's immediately-connected peers has that ledger. You may need to run the command several times to completely fetch a ledger
Declaration
public Task<LOLedger> Ledger(LedgerRequest request, CancellationToken cancellationToken = default)
Parameters
| Type | Name | Description |
|---|---|---|
| LedgerRequest | request | An LedgerRequest request. |
| CancellationToken | cancellationToken |
Returns
| Type | Description |
|---|---|
| Task<LOLedger> | An LOLedger response. |
LedgerClosed(LedgerClosedRequest, CancellationToken)
The ledger_closed method returns the unique identifiers of the most recently closed ledger.
Declaration
public Task<LOBaseLedger> LedgerClosed(LedgerClosedRequest request, CancellationToken cancellationToken = default)
Parameters
| Type | Name | Description |
|---|---|---|
| LedgerClosedRequest | request | An LedgerClosedRequest response. |
| CancellationToken | cancellationToken |
Returns
| Type | Description |
|---|---|
| Task<LOBaseLedger> | An LOBaseLedger response. |
LedgerCurrent(LedgerCurrentRequest, CancellationToken)
The ledger_current method returns the unique identifiers of the current in-progress ledger.
This command is mostly useful for testing, because the ledger returned is still in flux.
Declaration
public Task<LOLedgerCurrentIndex> LedgerCurrent(LedgerCurrentRequest request, CancellationToken cancellationToken = default)
Parameters
| Type | Name | Description |
|---|---|---|
| LedgerCurrentRequest | request | An LedgerCurrentRequest response. |
| CancellationToken | cancellationToken |
Returns
| Type | Description |
|---|---|
| Task<LOLedgerCurrentIndex> | An LOLedgerCurrentIndex response. |
LedgerData(LedgerDataRequest, CancellationToken)
The ledger_data method retrieves contents of the specified ledger. You can iterate through several calls to retrieve the entire contents of a single ledger version.
Declaration
public Task<LOLedgerData> LedgerData(LedgerDataRequest request, CancellationToken cancellationToken = default)
Parameters
| Type | Name | Description |
|---|---|---|
| LedgerDataRequest | request | An LedgerDataRequest request. |
| CancellationToken | cancellationToken |
Returns
| Type | Description |
|---|---|
| Task<LOLedgerData> | An LOLedgerData response. |
LedgerEntry(LedgerEntryRequest, CancellationToken)
The ledger_entry method returns a single ledger object from the XRP Ledger in its raw format.
See ledger format for information on the different types of objects you can retrieve.
Declaration
public Task<LedgerEntryResponse> LedgerEntry(LedgerEntryRequest request, CancellationToken cancellationToken = default)
Parameters
| Type | Name | Description |
|---|---|---|
| LedgerEntryRequest | request | An LedgerEntryRequest response. |
| CancellationToken | cancellationToken |
Returns
| Type | Description |
|---|---|
| Task<LedgerEntryResponse> | An LedgerEntryResponse response. |
NFTBuyOffers(NFTBuyOffersRequest, CancellationToken)
The nft_buy_offers method returns a list of buy offers for a given NFToken object.
Declaration
public Task<NFTBuyOffers> NFTBuyOffers(NFTBuyOffersRequest request, CancellationToken cancellationToken = default)
Parameters
| Type | Name | Description |
|---|---|---|
| NFTBuyOffersRequest | request | An NFTBuyOffersRequest request. |
| CancellationToken | cancellationToken |
Returns
| Type | Description |
|---|---|
| Task<NFTBuyOffers> | An NFTBuyOffers response. |
NFTSellOffers(NFTSellOffersRequest, CancellationToken)
The nft_sell_offers method returns a list of sell offers for a given NFToken object
Declaration
public Task<NFTSellOffers> NFTSellOffers(NFTSellOffersRequest request, CancellationToken cancellationToken = default)
Parameters
| Type | Name | Description |
|---|---|---|
| NFTSellOffersRequest | request | An NFTSellOffersRequest request. |
| CancellationToken | cancellationToken |
Returns
| Type | Description |
|---|---|
| Task<NFTSellOffers> | An NFTSellOffers response. |
NoRippleCheck(NoRippleCheckRequest, CancellationToken)
The noripple_check command provides a quick way to check the status of the Default Ripple field for an account and the No Ripple flag of its trust lines, compared with the recommended settings
Declaration
public Task<NoRippleCheck> NoRippleCheck(NoRippleCheckRequest request, CancellationToken cancellationToken = default)
Parameters
| Type | Name | Description |
|---|---|---|
| NoRippleCheckRequest | request | |
| CancellationToken | cancellationToken |
Returns
| Type | Description |
|---|---|
| Task<NoRippleCheck> | An NoRippleCheckRequest response. |
PathFind(PathFindCreateRequest, CancellationToken)
The path_find create sub-command creates an ongoing request to find possible paths
along which a payment transaction could be made.
WebSocket API only.
After the initial response, the server sends asynchronous follow-ups via the OnPathFind event.
Declaration
public Task<PathFindResponse> PathFind(PathFindCreateRequest request, CancellationToken cancellationToken = default)
Parameters
| Type | Name | Description |
|---|---|---|
| PathFindCreateRequest | request | |
| CancellationToken | cancellationToken | Cancellation token. |
Returns
| Type | Description |
|---|---|
| Task<PathFindResponse> | A PathFindResponse with initial path alternatives. |
PathFindClose(PathFindCloseRequest, CancellationToken)
The path_find close sub-command instructs the server to stop sending information
about the current open pathfinding request.
Declaration
public Task<PathFindResponse> PathFindClose(PathFindCloseRequest request, CancellationToken cancellationToken = default)
Parameters
| Type | Name | Description |
|---|---|---|
| PathFindCloseRequest | request | |
| CancellationToken | cancellationToken | Cancellation token. |
Returns
| Type | Description |
|---|---|
| Task<PathFindResponse> |
PathFindStatus(PathFindStatusRequest, CancellationToken)
The path_find status sub-command requests an immediate update about the client's
currently-open pathfinding request.
Declaration
public Task<PathFindResponse> PathFindStatus(PathFindStatusRequest request, CancellationToken cancellationToken = default)
Parameters
| Type | Name | Description |
|---|---|---|
| PathFindStatusRequest | request | |
| CancellationToken | cancellationToken | Cancellation token. |
Returns
| Type | Description |
|---|---|
| Task<PathFindResponse> |
Ping(CancellationToken)
The ping command returns an acknowledgement, so that clients can test the connection status and latency
Declaration
public Task<object> Ping(CancellationToken cancellationToken = default)
Parameters
| Type | Name | Description |
|---|---|---|
| CancellationToken | cancellationToken |
Returns
| Type | Description |
|---|---|
| Task<object> |
Random(CancellationToken)
The random command provides a random number to be used as a source of entropy for random number generation by clients.
https://xrpl.org/random.html#random
Declaration
public Task<object> Random(CancellationToken cancellationToken = default)
Parameters
| Type | Name | Description |
|---|---|---|
| CancellationToken | cancellationToken |
Returns
| Type | Description |
|---|---|
| Task<object> |
Request(Dictionary<string, object>, CancellationToken)
Declaration
public Task<Dictionary<string, object>> Request(Dictionary<string, object> request, CancellationToken cancellationToken = default)
Parameters
| Type | Name | Description |
|---|---|---|
| Dictionary<string, object> | request | |
| CancellationToken | cancellationToken |
Returns
| Type | Description |
|---|---|
| Task<Dictionary<string, object>> |
RipplePathFind(RipplePathFindRequest, CancellationToken)
The ripple_path_find method is a simplified version of the path_find method
that provides a single response with a payment path you can use right away.
Available in both WebSocket and JSON-RPC APIs.
Declaration
public Task<RipplePathFindResponse> RipplePathFind(RipplePathFindRequest request, CancellationToken cancellationToken = default)
Parameters
| Type | Name | Description |
|---|---|---|
| RipplePathFindRequest | request | |
| CancellationToken | cancellationToken | Cancellation token. |
Returns
| Type | Description |
|---|---|
| Task<RipplePathFindResponse> |
ServerFeatures(string, CancellationToken)
The feature command returns information about amendments this server knows about,
including whether they are enabled and if the server knows how to apply the amendments.
This is the non-admin version of the feature admin command.
It follows the same formatting as the admin command, but hides potentially sensitive data.
Declaration
public Task<ServerFeatures> ServerFeatures(string feature = null, CancellationToken cancellationToken = default)
Parameters
| Type | Name | Description |
|---|---|---|
| string | feature | (Optional) The unique ID of an amendment, as hexadecimal; |
| CancellationToken | cancellationToken |
Returns
| Type | Description |
|---|---|
| Task<ServerFeatures> | A ServerFeatures(string, CancellationToken) response. Feature and their states |
ServerInfo(ServerInfoRequest, CancellationToken)
The server_info command asks the server for a human-readable version of various information about the rippled server being queried.
Declaration
public Task<ServerInfo> ServerInfo(ServerInfoRequest request, CancellationToken cancellationToken = default)
Parameters
| Type | Name | Description |
|---|---|---|
| ServerInfoRequest | request | An ServerInfoRequest request. |
| CancellationToken | cancellationToken |
Returns
| Type | Description |
|---|---|
| Task<ServerInfo> | A ServerInfo(ServerInfoRequest, CancellationToken) response. |
ServerState(ServerStateRequest, CancellationToken)
The server_state command asks the server for a human-readable version of various information about the rippled server being queried.
Declaration
public Task<ServerState> ServerState(ServerStateRequest request, CancellationToken cancellationToken = default)
Parameters
| Type | Name | Description |
|---|---|---|
| ServerStateRequest | request | An ServerStateRequest request. |
| CancellationToken | cancellationToken |
Returns
| Type | Description |
|---|---|
| Task<ServerState> | A ServerState(ServerStateRequest, CancellationToken) response. |
SetNetworkId(uint?)
Set network id for transactions, required in network where Id > 1024
Declaration
public void SetNetworkId(uint? networkId)
Parameters
| Type | Name | Description |
|---|---|---|
| uint? | networkId | network id |
Simulate(SimulateRequest, CancellationToken)
The simulate method executes a dry run of any transaction type,
enabling you to preview the results and metadata of a transaction without committing them to the XRP Ledger.
Since this command never submits a transaction to the network, it doesn't incur any fees.
Expects a response in the form of a SimulateRequest .
Declaration
public Task<SimulateResponse> Simulate(SimulateRequest request, CancellationToken cancellationToken = default)
Parameters
| Type | Name | Description |
|---|---|---|
| SimulateRequest | request | |
| CancellationToken | cancellationToken |
Returns
| Type | Description |
|---|---|
| Task<SimulateResponse> |
Submit(Dictionary<string, object>, XrplWallet, bool, bool, CancellationToken)
Submits a transaction to the XRP Ledger for processing.
Declaration
public Task<Submit> Submit(Dictionary<string, object> tx, XrplWallet wallet, bool autoFill = true, bool failHard = false, CancellationToken cancellationToken = default)
Parameters
| Type | Name | Description |
|---|---|---|
| Dictionary<string, object> | tx | Transaction in JSON format with an array of Signers. |
| XrplWallet | wallet | wallet |
| bool | autoFill | use autofill for tx |
| bool | failHard | yse fail hard |
| CancellationToken | cancellationToken |
Returns
| Type | Description |
|---|---|
| Task<Submit> | An Submit response. |
Submit(ITransactionRequest, XrplWallet, bool, bool, CancellationToken)
Submits a transaction to the XRP Ledger for processing.
Declaration
public Task<Submit> Submit(ITransactionRequest tx, XrplWallet wallet, bool autoFill = true, bool failHard = false, CancellationToken cancellationToken = default)
Parameters
| Type | Name | Description |
|---|---|---|
| ITransactionRequest | tx | Transaction. |
| XrplWallet | wallet | wallet |
| bool | autoFill | use autofill for tx |
| bool | failHard | yse fail hard |
| CancellationToken | cancellationToken |
Returns
| Type | Description |
|---|---|
| Task<Submit> | An Submit response. |
Subscribe(SubscribeRequest, CancellationToken)
The subscribe method requests periodic notifications from the server when certain events happen.
Declaration
public Task<object> Subscribe(SubscribeRequest request, CancellationToken cancellationToken = default)
Parameters
| Type | Name | Description |
|---|---|---|
| SubscribeRequest | request | An SubscribeRequest request. |
| CancellationToken | cancellationToken |
Returns
| Type | Description |
|---|---|
| Task<object> |
Tx(TxRequest, CancellationToken)
The tx method retrieves information on a single transaction, by its identifying hash
Declaration
public Task<TransactionResponse> Tx(TxRequest request, CancellationToken cancellationToken = default)
Parameters
| Type | Name | Description |
|---|---|---|
| TxRequest | request | An TxRequest request. |
| CancellationToken | cancellationToken |
Returns
| Type | Description |
|---|---|
| Task<TransactionResponse> | An TransactionResponse response. |
TxV2(TxRequest, CancellationToken)
Declaration
public Task<TransactionSummary> TxV2(TxRequest request, CancellationToken cancellationToken = default)
Parameters
| Type | Name | Description |
|---|---|---|
| TxRequest | request | |
| CancellationToken | cancellationToken |
Returns
| Type | Description |
|---|---|
| Task<TransactionSummary> |
Unsubscribe(UnsubscribeRequest, CancellationToken)
The unsubscribe command tells the server to stop sending messages for a particular subscription or set of subscriptions.
Declaration
public Task<object> Unsubscribe(UnsubscribeRequest request, CancellationToken cancellationToken = default)
Parameters
| Type | Name | Description |
|---|---|---|
| UnsubscribeRequest | request | An UnsubscribeRequest request. |
| CancellationToken | cancellationToken |
Returns
| Type | Description |
|---|---|
| Task<object> |
Url()
the url
Declaration
public string Url()
Returns
| Type | Description |
|---|---|
| string |