Show / Hide Table of Contents

Class K256KeyGenerator

Inheritance
object
K256KeyGenerator
Namespace: Xrpl.Keypairs.K256
Assembly: Xrpl.Keypairs.dll
Syntax
public class K256KeyGenerator

Methods

| Edit this page View Source

ComputePrivateGen(byte[])

Declaration
public static BigInteger ComputePrivateGen(byte[] seedBytes)
Parameters
Type Name Description
byte[] seedBytes
Returns
Type Description
BigInteger
| Edit this page View Source

ComputePublicGenerator(BigInteger)

Declaration
public static ECPoint ComputePublicGenerator(BigInteger privateGen)
Parameters
Type Name Description
BigInteger privateGen

secret scalar

Returns
Type Description
ECPoint

the corresponding public key is the public generator (aka public root key, master public key).

| Edit this page View Source

ComputePublicKey(BigInteger)

Compute Public Key

Declaration
public static ECPoint ComputePublicKey(BigInteger secretKey)
Parameters
Type Name Description
BigInteger secretKey

secret point on the curve as BigInteger

Returns
Type Description
ECPoint

corresponding public point

| Edit this page View Source

ComputePublicKey(byte[], uint)

Declaration
public static byte[] ComputePublicKey(byte[] publicGenBytes, uint accountNumber)
Parameters
Type Name Description
byte[] publicGenBytes
uint accountNumber
Returns
Type Description
byte[]
| Edit this page View Source

ComputeScalar(byte[], uint?)

Declaration
public static BigInteger ComputeScalar(byte[] seedBytes, uint? discriminator)
Parameters
Type Name Description
byte[] seedBytes
  • a bytes sequence of arbitrary length which will be hashed
uint? discriminator
  • nullable optional uint32 to hash
Returns
Type Description
BigInteger

a number between [1, order -1] suitable as a private key

| Edit this page View Source

ComputeSecretKey(BigInteger, uint)

Declaration
public static BigInteger ComputeSecretKey(BigInteger privateGen, uint accountNumber)
Parameters
Type Name Description
BigInteger privateGen
uint accountNumber
Returns
Type Description
BigInteger
| Edit this page View Source

From128Seed(byte[], int)

Declaration
public static K256KeyPair From128Seed(byte[] seedBytes, int keyIndex)
Parameters
Type Name Description
byte[] seedBytes
int keyIndex
Returns
Type Description
K256KeyPair
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX