Show / Hide Table of Contents

Namespace Xrpl.Models

Enums

LedgerEntryType

Each ledger version's state data is a set of ledger objects, sometimes called ledger entries, which collectively represent all settings, balances, and relationships at a given point in time.
To store or retrieve an object in the state data, the protocol uses that object's unique Ledger Object ID.
In the peer protocol, ledger objects have a canonical binary format.In rippled APIs, ledger objects are represented as JSON objects.

StreamType

TransactionType

The type of a transaction (TransactionType field) is the most fundamental information about a transaction.
This indicates what type of operation the transaction is supposed to do.

In this article
Back to top Generated by DocFX