Show / Hide Table of Contents

Namespace Xrpl.Models.Common

Classes

Common

common class

Common.IssuedCurrency

currency with issuer

Common.IssuedCurrencyAmount

currency with amount and issuer

Common.MPTAmount

Represents a Multi-Purpose Token (MPT) amount with value.

Common.MPTCurrency

Represents a Multi-Purpose Token (MPT) currency identifier.

Common.XRP

is XRP currency

Currency

The XRP Ledger has two kinds of digital asset: XRP and tokens.
Both types have high precision, although their formats are different

CurrencyExtensions

LedgerIndex

MPTokenIssuanceIdData

Decoded components of an MPTokenIssuanceID (XLS-33).

NFTokenIdData

PermissionEntry

Represents a single permission granted to a delegate account.

PermissionWrapper

A wrapper for a single permission entry in a Permissions array.

PriceData

Represents the price information for a single asset pair in a price oracle.

PriceDataWrapper

Represents price information for a token pair in a price oracle.

XChainBridgeModel

Represents the XChainBridge field, which identifies a cross-chain bridge. The bridge is defined by the door accounts and issued currencies on both chains.

XChainClaimAttestationCollectionElement

An attestation element within an XChainClaimAttestations array on an XChainOwnedClaimID ledger object.

XChainClaimProofSig

The proof signature data for a cross-chain claim attestation.

XChainCreateAccountAttestationCollectionElement

An attestation element within an XChainCreateAccountAttestations array.

XChainCreateAccountProofSig

The proof signature data for a cross-chain account create attestation.

In this article
Back to top Generated by DocFX