Show / Hide Table of Contents

Class PriceData

Represents the price information for a single asset pair in a price oracle.

Inheritance
object
PriceData
Namespace: Xrpl.Models.Common
Assembly: Xrpl.dll
Syntax
public class PriceData

Properties

| Edit this page View Source

AssetPrice

The asset price after applying the Scale precision level. It's not included if the last update transaction didn't include the BaseAsset/QuoteAsset pair. Serialized as a lowercase hexadecimal string for XRPL protocol.

Declaration
[JsonPropertyName("AssetPrice")]
[JsonConverter(typeof(AssetPriceConverter))]
public object AssetPrice { get; set; }
Property Value
Type Description
object
| Edit this page View Source

BaseAsset

The primary asset in a trading pair. Any valid identifier, such as a stock symbol, bond CUSIP, or currency code is allowed. For example, in the BTC/USD pair, BTC is the base asset; in 912810RR9/BTC, 912810RR9 is the base asset. Serialized as a 40-character hex string for XRPL protocol.

Declaration
[JsonPropertyName("BaseAsset")]
[JsonConverter(typeof(OracleCurrencyConverter))]
public string BaseAsset { get; set; }
Property Value
Type Description
string
| Edit this page View Source

QuoteAsset

The quote asset in a trading pair. The quote asset denotes the price of one unit of the base asset. For example, in the BTC/USD pair, USD is the quote asset. Serialized as a 40-character hex string for XRPL protocol.

Declaration
[JsonPropertyName("QuoteAsset")]
[JsonConverter(typeof(OracleCurrencyConverter))]
public string QuoteAsset { get; set; }
Property Value
Type Description
string
| Edit this page View Source

Scale

The scaling factor to apply to an asset price. For example, if Scale is 6 and original price is 0.155, then the scaled price is 155000. Valid scale ranges are 0-10. It's not included if the last update transaction didn't include the BaseAsset/QuoteAsset pair.

Declaration
[JsonPropertyName("Scale")]
public uint? Scale { get; set; }
Property Value
Type Description
uint?
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX