Class XChainClaimProofSig
The proof signature data for a cross-chain claim attestation.
Inheritance
object
XChainClaimProofSig
Namespace: Xrpl.Models.Common
Assembly: Xrpl.dll
Syntax
public class XChainClaimProofSig
Properties
| Edit this page View SourceAmount
The amount to claim in the XChainCommit transaction on the destination chain.
Declaration
[JsonPropertyName("Amount")]
public Currency Amount { get; set; }
Property Value
| Type | Description |
|---|---|
| Currency |
AttestationRewardAccount
The account that should receive this signer's share of the SignatureReward.
Declaration
[JsonPropertyName("AttestationRewardAccount")]
public string AttestationRewardAccount { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
AttestationSignerAccount
The account on the door account's signer list that is signing the transaction.
Declaration
[JsonPropertyName("AttestationSignerAccount")]
public string AttestationSignerAccount { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
Destination
The destination account for the funds on the destination chain.
Declaration
[JsonPropertyName("Destination")]
public string Destination { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
PublicKey
The public key used to verify the signature.
Declaration
[JsonPropertyName("PublicKey")]
public string PublicKey { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
WasLockingChainSend
A boolean representing the chain where the event occurred (1 = locking chain, 0 = issuing chain).
Declaration
[JsonPropertyName("WasLockingChainSend")]
public byte WasLockingChainSend { get; set; }
Property Value
| Type | Description |
|---|---|
| byte |