Show / Hide Table of Contents

Enum AccountRootFlags

There are several options which can be either enabled or disabled for an account.
These options can be changed with an AccountSet transaction.
In the ledger, flags are represented as binary values that can be combined with bitwise-or operations.
The bit values for the flags in the ledger are different than the values used to enable or disable those flags in a transaction.

Namespace: Xrpl.Models.Ledger
Assembly: Xrpl.dll
Syntax
[Flags]
public enum AccountRootFlags : uint

Fields

Name Description
lsfAllowTrustLineClawback

Allow this account to claw back tokens it has issued. Once enabled, cannot be disabled. Requires the Clawback amendment.

lsfAllowTrustLineLocking

Allow Trust Line Tokens issued by this account to be held in escrow. Once enabled, cannot be disabled. Requires the TokenEscrow amendment.

lsfDefaultRipple

Enable rippling on this addresses's trust lines by default. Required for issuing addresses; discouraged for others.

lsfDepositAuth

This account can only receive funds from transactions it sends, and from preauthorized accounts.
(It has DepositAuth enabled.)

lsfDisableMaster

Disallows use of the master key to sign transactions for this account.

lsfDisallowIncomingCheck

This account blocks incoming Checks. (Requires the DisallowIncoming amendment .)

lsfDisallowIncomingNFTokenOffer

This account blocks incoming NFTokenOffers. (Requires the DisallowIncoming amendment .)

lsfDisallowIncomingPayChan

This account blocks incoming Payment Channels. (Requires the DisallowIncoming amendment .)

lsfDisallowIncomingTrustline

This account blocks incoming trust lines. (Requires the DisallowIncoming amendment .)

lsfDisallowXRP

Client applications should not send XRP to this account. Not enforced by rippled.

lsfGlobalFreeze

All assets issued by this address are frozen.

lsfNoFreeze

This address cannot freeze trust lines connected to it. Once enabled, cannot be disabled.

lsfPasswordSpent

The account has used its free SetRegularKey transaction.

lsfRequireAuth

This account must individually approve other users for those users to hold this account's issued currencies.

lsfRequireDestTag

Requires incoming payments to specify a Destination Tag.

Extension Methods

EmumExtensions.DecodeFlags<AccountRootFlags>(AccountRootFlags)
EmumExtensions.FlagsValues<AccountRootFlags>(AccountRootFlags)
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX