Show / Hide Table of Contents

Class BookReference

Represents a reference to an order book directory page for hybrid offers. Used in AdditionalBooks array for offers that participate in multiple order books.

Inheritance
object
BookReference
Namespace: Xrpl.Models.Ledger
Assembly: Xrpl.dll
Syntax
public class BookReference

Properties

| Edit this page View Source

BookDirectory

The ID of the offer directory that links to this offer.

Declaration
[JsonPropertyName("BookDirectory")]
public string BookDirectory { get; set; }
Property Value
Type Description
string
| Edit this page View Source

BookNode

A hint indicating which page of the offer directory links to this entry.

Declaration
[JsonPropertyName("BookNode")]
public string BookNode { get; set; }
Property Value
Type Description
string
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX