Show / Hide Table of Contents

Enum EnableAmendmentFlags

Namespace: Xrpl.Models.Ledger
Assembly: Xrpl.dll
Syntax
public enum EnableAmendmentFlags

Fields

Name Description
tfGotMajority

The tfGotMajority flag means that support for the amendment has increased to more than 80% of trusted validators.

tfLostMajority

The tfLostMajority flag means that support for the amendment has decreased to 80% of trusted validators or less.

Extension Methods

EmumExtensions.DecodeFlags<EnableAmendmentFlags>(EnableAmendmentFlags)
EmumExtensions.FlagsValues<EnableAmendmentFlags>(EnableAmendmentFlags)
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX