Show / Hide Table of Contents

Class LOAmm

Inheritance
object
BaseLedgerEntry
LOAmm
Inherited Members
BaseLedgerEntry.LedgerEntryType
BaseLedgerEntry.Index
BaseLedgerEntry.LedgerIndex
BaseLedgerEntry.UnknownFields
Namespace: Xrpl.Models.Ledger
Assembly: Xrpl.dll
Syntax
public class LOAmm : BaseLedgerEntry

Properties

| Edit this page View Source

AMMAccount

The special account that holds the AMM's assets and issues its LPTokens. Serialized as Account, which is the name rippled gives this field.

Declaration
[JsonPropertyName("Account")]
public string AMMAccount { get; set; }
Property Value
Type Description
string
| Edit this page View Source

Asset

Specifies one of the pool assets (XRP or token) of the AMM instance.

Declaration
[JsonConverter(typeof(CurrencyConverter))]
public Currency Asset { get; set; }
Property Value
Type Description
Currency
| Edit this page View Source

Asset2

Specifies the other pool asset of the AMM instance.

Declaration
[JsonConverter(typeof(CurrencyConverter))]
public Currency Asset2 { get; set; }
Property Value
Type Description
Currency
| Edit this page View Source

AuctionSlot

Details of the current owner of the auction slot.

Declaration
public AuctionSlot AuctionSlot { get; set; }
Property Value
Type Description
AuctionSlot
| Edit this page View Source

LPTokenBalance

The total outstanding balance of liquidity provider tokens from this AMM instance.
The holders of these tokens can vote on the AMM's trading fee in proportion to their holdings, or redeem the tokens for a share of the AMM's assets which grows with the trading fees collected.

Declaration
[JsonConverter(typeof(CurrencyConverter))]
public Currency LPTokenBalance { get; set; }
Property Value
Type Description
Currency
| Edit this page View Source

OwnerNode

Owner directory page hint (hex UInt64).

Declaration
[JsonPropertyName("OwnerNode")]
public string OwnerNode { get; set; }
Property Value
Type Description
string
| Edit this page View Source

PreviousTxnID

The identifying hash of the transaction that most recently modified this object.

Declaration
[JsonPropertyName("PreviousTxnID")]
public string PreviousTxnID { get; set; }
Property Value
Type Description
string
| Edit this page View Source

PreviousTxnLgrSeq

The index of the ledger that contains the transaction that most recently modified this object.

Declaration
[JsonPropertyName("PreviousTxnLgrSeq")]
public uint? PreviousTxnLgrSeq { get; set; }
Property Value
Type Description
uint?
| Edit this page View Source

TradingFee

Specifies the fee, in basis point, to be charged to the traders for the trades executed against the AMM instance.
Trading fee is a percentage of the trading volume.
Valid values for this field are between 0 and 1000 inclusive.
A value of 1 is equivalent to 1/10 bps or 0.001%, allowing trading fee between 0% and 1%.
This field is required.

Declaration
public uint? TradingFee { get; set; }
Property Value
Type Description
uint?
| Edit this page View Source

VoteSlots

A list of vote objects, representing votes on the pool's trading fee..

Declaration
public List<VoteEntry> VoteSlots { get; set; }
Property Value
Type Description
List<VoteEntry>
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX