Show / Hide Table of Contents

Class LOCheck

A Check object describes a check, similar to a paper personal check, which can be cashed by its destination to get money from its sender.

Inheritance
object
BaseLedgerEntry
LOCheck
Implements
IDestination
Inherited Members
BaseLedgerEntry.LedgerEntryType
BaseLedgerEntry.Index
BaseLedgerEntry.LedgerIndex
Namespace: Xrpl.Models.Ledger
Assembly: Xrpl.dll
Syntax
public class LOCheck : BaseLedgerEntry, IDestination

Constructors

| Edit this page View Source

LOCheck()

Declaration
public LOCheck()

Properties

| Edit this page View Source

Account

The sender of the Check. Cashing the Check debits this address's balance.

Declaration
public string Account { get; set; }
Property Value
Type Description
string
| Edit this page View Source

Destination

The intended recipient of the Check.Only this address can cash the Check, using a CheckCash transaction.

Declaration
public string Destination { get; set; }
Property Value
Type Description
string
| Edit this page View Source

DestinationNode

A hint indicating which page of the destination's owner directory links to this object, in case the directory consists of multiple pages.

Declaration
public string DestinationNode { get; set; }
Property Value
Type Description
string
| Edit this page View Source

DestinationTag

An arbitrary tag to further specify the destination for this Check, such as a hosted recipient at the destination address.

Declaration
public uint? DestinationTag { get; set; }
Property Value
Type Description
uint?
| Edit this page View Source

Expiration

Indicates the time after which this Check is considered expired.

Declaration
[JsonConverter(typeof(RippleDateTimeConverter))]
public DateTime? Expiration { get; set; }
Property Value
Type Description
Nullable
| Edit this page View Source

Flags

A bit-map of boolean flags.
No flags are defined for Checks, so this value is always 0.

Declaration
[JsonConverter(typeof(NumberOrStringConverter))]
public string Flags { get; set; }
Property Value
Type Description
string
| Edit this page View Source

InvoiceID

Arbitrary 256-bit hash provided by the sender as a specific reason or identifier for this Check.

Declaration
public string InvoiceID { get; set; }
Property Value
Type Description
string
| Edit this page View Source

OwnerNode

A hint indicating which page of the sender's owner directory links to this object, in case the directory consists of multiple pages.

Declaration
public string OwnerNode { get; set; }
Property Value
Type Description
string
| Edit this page View Source

PreviousTxnID

The identifying hash of the transaction that most recently modified this object.

Declaration
public string PreviousTxnID { get; set; }
Property Value
Type Description
string
| Edit this page View Source

PreviousTxnLgrSeq

The index of the ledger that contains the transaction that most recently modified this object.

Declaration
public uint PreviousTxnLgrSeq { get; set; }
Property Value
Type Description
uint
| Edit this page View Source

SendMax

The maximum amount of currency this Check can debit the sender.
If the Check is successfully cashed, the destination is credited in the same currency for up to this amount.

Declaration
[JsonConverter(typeof(CurrencyConverter))]
public Currency SendMax { get; set; }
Property Value
Type Description
Currency
| Edit this page View Source

Sequence

The sequence number of the CheckCreate transaction that created this check.

Declaration
public uint Sequence { get; set; }
Property Value
Type Description
uint
| Edit this page View Source

SourceTag

An arbitrary tag to further specify the source for this Check, such as a hosted recipient at the sender's address.

Declaration
public string SourceTag { get; set; }
Property Value
Type Description
string

Implements

IDestination
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX