Show / Hide Table of Contents

Class LOCredential

A Credential ledger entry represents a verifiable credential issued by one account (the issuer) to another (the subject). Credentials are used for on-chain identity verification and permissioned domain access control on the XRP Ledger.

Inheritance
object
BaseLedgerEntry
LOCredential
Inherited Members
BaseLedgerEntry.LedgerEntryType
BaseLedgerEntry.Index
BaseLedgerEntry.LedgerIndex
Namespace: Xrpl.Models.Ledger
Assembly: Xrpl.dll
Syntax
public class LOCredential : BaseLedgerEntry

Constructors

| Edit this page View Source

LOCredential()

Declaration
public LOCredential()

Properties

| Edit this page View Source

CredentialType

A value identifying the type of credential, stored as a hex-encoded string. Automatically normalizes text input to hex on assignment.

Declaration
[JsonPropertyName("CredentialType")]
public string CredentialType { get; set; }
Property Value
Type Description
string
| Edit this page View Source

CredentialTypeValue

Decoded human-readable value of CredentialType (UTF-8, trimmed by 0x00).

Declaration
[JsonIgnore]
public string CredentialTypeValue { get; }
Property Value
Type Description
string
| Edit this page View Source

Expiration

The time after which the credential expires, in seconds since the Ripple Epoch.

Declaration
[JsonPropertyName("Expiration")]
[JsonConverter(typeof(RippleDateTimeConverter))]
public DateTime? Expiration { get; set; }
Property Value
Type Description
Nullable
| Edit this page View Source

Flags

A bit-map of boolean flags. See CredentialFlags.

Declaration
[JsonPropertyName("Flags")]
public uint Flags { get; set; }
Property Value
Type Description
uint
| Edit this page View Source

Issuer

The account that issued the credential.

Declaration
[JsonPropertyName("Issuer")]
public string Issuer { get; set; }
Property Value
Type Description
string
| Edit this page View Source

IssuerNode

A hint indicating which page of the issuer's owner directory links to this entry.

Declaration
[JsonPropertyName("IssuerNode")]
public string IssuerNode { get; set; }
Property Value
Type Description
string
| Edit this page View Source

OwnerNode

A hint indicating which page of the owner directory links to this entry.

Declaration
[JsonPropertyName("OwnerNode")]
public string OwnerNode { get; set; }
Property Value
Type Description
string
| Edit this page View Source

PreviousTxnID

The identifying hash of the transaction that most recently modified this entry.

Declaration
[JsonPropertyName("PreviousTxnID")]
public string PreviousTxnID { get; set; }
Property Value
Type Description
string
| Edit this page View Source

PreviousTxnLgrSeq

The index of the ledger that contains the transaction that most recently modified this entry.

Declaration
[JsonPropertyName("PreviousTxnLgrSeq")]
public uint PreviousTxnLgrSeq { get; set; }
Property Value
Type Description
uint
| Edit this page View Source

Subject

The account that is the subject (holder) of the credential.

Declaration
[JsonPropertyName("Subject")]
public string Subject { get; set; }
Property Value
Type Description
string
| Edit this page View Source

SubjectNode

A hint indicating which page of the subject's owner directory links to this entry.

Declaration
[JsonPropertyName("SubjectNode")]
public string SubjectNode { get; set; }
Property Value
Type Description
string
| Edit this page View Source

URI

An arbitrary URI reference for additional credential data, stored as a hex-encoded string. Automatically normalizes text input to hex on assignment.

Declaration
[JsonPropertyName("URI")]
public string URI { get; set; }
Property Value
Type Description
string
| Edit this page View Source

URIValue

Decoded human-readable value of URI (UTF-8, trimmed by 0x00).

Declaration
[JsonIgnore]
public string URIValue { get; }
Property Value
Type Description
string
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX