Show / Hide Table of Contents

Class LODID

A DID ledger entry holds references to, or data associated with, a single DID (Decentralized Identifier).

Inheritance
object
BaseLedgerEntry
LODID
Inherited Members
BaseLedgerEntry.LedgerEntryType
BaseLedgerEntry.Index
BaseLedgerEntry.LedgerIndex
Namespace: Xrpl.Models.Ledger
Assembly: Xrpl.dll
Syntax
public class LODID : BaseLedgerEntry

Constructors

| Edit this page View Source

LODID()

Initializes a new instance of the LODID class.

Declaration
public LODID()

Properties

| Edit this page View Source

Account

The account that controls the DID.

Declaration
[JsonPropertyName("Account")]
public string Account { get; set; }
Property Value
Type Description
string
| Edit this page View Source

DIDDocument

The DID document associated with the DID.

Declaration
[JsonPropertyName("DIDDocument")]
public string DIDDocument { get; set; }
Property Value
Type Description
string
| Edit this page View Source

Data

The public attestations of identity credentials associated with the DID.

Declaration
[JsonPropertyName("Data")]
public string Data { get; set; }
Property Value
Type Description
string
| Edit this page View Source

OwnerNode

A hint indicating which page of the owner directory links to this entry, in case the directory consists of multiple pages.

Declaration
[JsonPropertyName("OwnerNode")]
public string OwnerNode { get; set; }
Property Value
Type Description
string
| Edit this page View Source

PreviousTxnID

The identifying hash of the transaction that most recently modified this entry.

Declaration
[JsonPropertyName("PreviousTxnID")]
public string PreviousTxnID { get; set; }
Property Value
Type Description
string
| Edit this page View Source

PreviousTxnLgrSeq

The index of the ledger that contains the transaction that most recently modified this entry.

Declaration
[JsonPropertyName("PreviousTxnLgrSeq")]
public uint PreviousTxnLgrSeq { get; set; }
Property Value
Type Description
uint
| Edit this page View Source

URI

The Universal Resource Identifier associated with the DID.

Declaration
[JsonPropertyName("URI")]
public string URI { get; set; }
Property Value
Type Description
string
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX