Class LODelegate
A Delegate ledger object records which permissions have been granted by one account to another.
Inherited Members
Namespace: Xrpl.Models.Ledger
Assembly: Xrpl.dll
Syntax
public class LODelegate : BaseLedgerEntry
Properties
| Edit this page View SourceAccount
The account that granted the permissions.
Declaration
[JsonPropertyName("Account")]
public string Account { get; init; }
Property Value
| Type | Description |
|---|---|
| string |
Authorize
The account that received the permissions (sfAuthorize in PermissionDelegationV1_1).
Declaration
[JsonPropertyName("Authorize")]
public string Authorize { get; init; }
Property Value
| Type | Description |
|---|---|
| string |
DestinationNode
Destination directory page hint (hex UInt64).
Declaration
[JsonPropertyName("DestinationNode")]
public string DestinationNode { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
OwnerNode
A hint indicating which page of the owner's directory links to this object.
Declaration
[JsonPropertyName("OwnerNode")]
public string OwnerNode { get; init; }
Property Value
| Type | Description |
|---|---|
| string |
Permissions
The permissions granted to the delegate.
Declaration
[JsonPropertyName("Permissions")]
public List<PermissionWrapper> Permissions { get; init; }
Property Value
| Type | Description |
|---|---|
| List<PermissionWrapper> |
PreviousTxnID
The identifying hash of the transaction that most recently modified this object.
Declaration
[JsonPropertyName("PreviousTxnID")]
public string PreviousTxnID { get; init; }
Property Value
| Type | Description |
|---|---|
| string |
PreviousTxnLgrSeq
The index of the ledger that contains the transaction that most recently modified this object.
Declaration
[JsonPropertyName("PreviousTxnLgrSeq")]
public uint? PreviousTxnLgrSeq { get; init; }
Property Value
| Type | Description |
|---|---|
| uint? |