Class LODirectoryNode
The DirectoryNode object type provides a list of links to other objects in the ledger's state tree.
Inherited Members
Namespace: Xrpl.Models.Ledger
Assembly: Xrpl.dll
Syntax
public class LODirectoryNode : BaseLedgerEntry
Properties
| Edit this page View SourceDomainID
PermissionedDEX: the domain this order book belongs to.
Declaration
[JsonPropertyName("DomainID")]
public string DomainID { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
ExchangeRate
Order book directories: the exchange rate portion of the directory index (hex UInt64).
Declaration
[JsonPropertyName("ExchangeRate")]
public string ExchangeRate { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
Flags
A bit-map of boolean flags enabled for this directory. See DirectoryNodeFlags for the values the protocol defines.
Declaration
public uint? Flags { get; set; }
Property Value
| Type | Description |
|---|---|
| uint? |
IndexNext
If this Directory consists of multiple pages, this ID links to the next object in the chain, wrapping around at the end.
Declaration
public string IndexNext { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
IndexPrevious
If this Directory consists of multiple pages, this ID links to the previous object in the chain, wrapping around at the beginning.
Declaration
public string IndexPrevious { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
Indexes
The contents of this Directory: an array of IDs of other objects.
Declaration
public List<string> Indexes { get; set; }
Property Value
| Type | Description |
|---|---|
| List<string> |
NFTokenID
NFT offer directories: the NFToken this directory relates to.
Declaration
[JsonPropertyName("NFTokenID")]
public string NFTokenID { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
Owner
The address of the account that owns the objects in this directory.
Declaration
public string Owner { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
PreviousTxnID
The identifying hash of the transaction that most recently modified this object.
Declaration
[JsonPropertyName("PreviousTxnID")]
public string PreviousTxnID { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
PreviousTxnLgrSeq
The index of the ledger that contains the transaction that most recently modified this object.
Declaration
[JsonPropertyName("PreviousTxnLgrSeq")]
public uint? PreviousTxnLgrSeq { get; set; }
Property Value
| Type | Description |
|---|---|
| uint? |
RootIndex
The ID of root object for this directory.
Declaration
public string RootIndex { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
TakerGetsCurrency
The currency code of the TakerGets amount from the offers in this directory.
Declaration
public string TakerGetsCurrency { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
TakerGetsIssuer
The issuer of the TakerGets amount from the offers in this directory.
Declaration
public string TakerGetsIssuer { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
TakerGetsMPT
MPT order books: MPT issuance id on the TakerGets side.
Declaration
[JsonPropertyName("TakerGetsMPT")]
public string TakerGetsMPT { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
TakerPaysCurrency
The currency code of the TakerPays amount from the offers in this directory.
Declaration
public string TakerPaysCurrency { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
TakerPaysIssuer
The issuer of the TakerPays amount from the offers in this directory.
Declaration
public string TakerPaysIssuer { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
TakerPaysMPT
MPT order books: MPT issuance id on the TakerPays side.
Declaration
[JsonPropertyName("TakerPaysMPT")]
public string TakerPaysMPT { get; set; }
Property Value
| Type | Description |
|---|---|
| string |