Show / Hide Table of Contents

Class LOLedgerHashes

The LedgerHashes objects exist to make it possible to look up a previous ledger's hash with only the current ledger version and at most one lookup of a previous ledger version.

Inheritance
object
BaseLedgerEntry
LOLedgerHashes
Inherited Members
BaseLedgerEntry.LedgerEntryType
BaseLedgerEntry.Index
BaseLedgerEntry.LedgerIndex
Namespace: Xrpl.Models.Ledger
Assembly: Xrpl.dll
Syntax
public class LOLedgerHashes : BaseLedgerEntry

Constructors

| Edit this page View Source

LOLedgerHashes()

Declaration
public LOLedgerHashes()

Properties

| Edit this page View Source

FirstLedgerSequence

Declaration
public uint FirstLedgerSequence { get; set; }
Property Value
Type Description
uint
| Edit this page View Source

Flags

A bit-map of boolean flags for this object. No flags are defined for this type

Declaration
public uint Flags { get; set; }
Property Value
Type Description
uint
| Edit this page View Source

Hashes

An array of up to 256 ledger hashes. The contents depend on which sub-type of LedgerHashes object this is.

Declaration
public List<string> Hashes { get; set; }
Property Value
Type Description
List<string>
| Edit this page View Source

LastLedgerSequence

The Ledger Index of the last entry in this object's Hashes array.

Declaration
public uint LastLedgerSequence { get; set; }
Property Value
Type Description
uint
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX