Show / Hide Table of Contents

Class LOLoan

A Loan ledger object represents a loan between a borrower and a loan broker.

Inheritance
object
BaseLedgerEntry
LOLoan
Inherited Members
BaseLedgerEntry.LedgerEntryType
BaseLedgerEntry.Index
BaseLedgerEntry.LedgerIndex
Namespace: Xrpl.Models.Ledger
Assembly: Xrpl.dll
Syntax
public class LOLoan : BaseLedgerEntry
Remarks

Requires the Loan amendment (XLS-66d). This feature is in draft and subject to change.

Constructors

| Edit this page View Source

LOLoan()

Declaration
public LOLoan()

Properties

| Edit this page View Source

Borrower

The account address of the Borrower.

Declaration
[JsonPropertyName("Borrower")]
public string Borrower { get; init; }
Property Value
Type Description
string
| Edit this page View Source

CloseInterestRate

The early repayment interest rate, in 1/10th basis points (0-100000).

Declaration
[JsonPropertyName("CloseInterestRate")]
public uint? CloseInterestRate { get; init; }
Property Value
Type Description
uint?
| Edit this page View Source

ClosePaymentFee

The fee for early full repayment (Number type, string representation).

Declaration
[JsonPropertyName("ClosePaymentFee")]
public string ClosePaymentFee { get; init; }
Property Value
Type Description
string
| Edit this page View Source

GracePeriod

The grace period before late fees apply, in seconds.

Declaration
[JsonPropertyName("GracePeriod")]
public uint? GracePeriod { get; init; }
Property Value
Type Description
uint?
| Edit this page View Source

InterestRate

The interest rate for the loan, in 1/10th basis points (0-100000).

Declaration
[JsonPropertyName("InterestRate")]
public uint? InterestRate { get; init; }
Property Value
Type Description
uint?
| Edit this page View Source

LateInterestRate

The premium added for late payments, in 1/10th basis points (0-100000).

Declaration
[JsonPropertyName("LateInterestRate")]
public uint? LateInterestRate { get; init; }
Property Value
Type Description
uint?
| Edit this page View Source

LatePaymentFee

The fee for late payments (Number type, string representation).

Declaration
[JsonPropertyName("LatePaymentFee")]
public string LatePaymentFee { get; init; }
Property Value
Type Description
string
| Edit this page View Source

LoanBrokerID

The ID of the Loan Broker associated with this loan.

Declaration
[JsonPropertyName("LoanBrokerID")]
public string LoanBrokerID { get; init; }
Property Value
Type Description
string
| Edit this page View Source

LoanBrokerNode

A hint linking to the loan broker's directory node (UInt64).

Declaration
[JsonPropertyName("LoanBrokerNode")]
public string LoanBrokerNode { get; init; }
Property Value
Type Description
string
| Edit this page View Source

LoanOriginationFee

The fee paid to broker at loan creation (Number type, string representation).

Declaration
[JsonPropertyName("LoanOriginationFee")]
public string LoanOriginationFee { get; init; }
Property Value
Type Description
string
| Edit this page View Source

LoanScale

The scale factor for decimal place rounding.

Declaration
[JsonPropertyName("LoanScale")]
public int? LoanScale { get; init; }
Property Value
Type Description
int?
| Edit this page View Source

LoanSequence

The loan's sequence number.

Declaration
[JsonPropertyName("LoanSequence")]
public uint? LoanSequence { get; init; }
Property Value
Type Description
uint?
| Edit this page View Source

LoanServiceFee

The fee paid to broker with each payment (Number type, string representation).

Declaration
[JsonPropertyName("LoanServiceFee")]
public string LoanServiceFee { get; init; }
Property Value
Type Description
string
| Edit this page View Source

ManagementFeeOutstanding

The remaining management fee to broker (Number type, string representation).

Declaration
[JsonPropertyName("ManagementFeeOutstanding")]
public string ManagementFeeOutstanding { get; init; }
Property Value
Type Description
string
| Edit this page View Source

NextPaymentDueDate

The timestamp of when the next payment is due, in seconds since the Ripple Epoch.

Declaration
[JsonPropertyName("NextPaymentDueDate")]
[JsonConverter(typeof(RippleDateTimeConverter))]
public DateTime? NextPaymentDueDate { get; init; }
Property Value
Type Description
Nullable
| Edit this page View Source

OverpaymentFee

The fee charged for overpayments, in 1/10th basis points (0-100000).

Declaration
[JsonPropertyName("OverpaymentFee")]
public uint? OverpaymentFee { get; init; }
Property Value
Type Description
uint?
| Edit this page View Source

OverpaymentInterestRate

The overpayment interest rate, in 1/10th basis points (0-100000).

Declaration
[JsonPropertyName("OverpaymentInterestRate")]
public uint? OverpaymentInterestRate { get; init; }
Property Value
Type Description
uint?
| Edit this page View Source

OwnerNode

A hint indicating which page of the owner's directory links to this object (UInt64).

Declaration
[JsonPropertyName("OwnerNode")]
public string OwnerNode { get; init; }
Property Value
Type Description
string
| Edit this page View Source

PaymentInterval

The interval between payments, in seconds.

Declaration
[JsonPropertyName("PaymentInterval")]
public uint? PaymentInterval { get; init; }
Property Value
Type Description
uint?
| Edit this page View Source

PaymentRemaining

The number of payments remaining.

Declaration
[JsonPropertyName("PaymentRemaining")]
public uint? PaymentRemaining { get; init; }
Property Value
Type Description
uint?
| Edit this page View Source

PeriodicPayment

The amount due per payment interval (Number type, string representation).

Declaration
[JsonPropertyName("PeriodicPayment")]
public string PeriodicPayment { get; init; }
Property Value
Type Description
string
| Edit this page View Source

PreviousPaymentDueDate

The timestamp of when the previous payment was made, in seconds since the Ripple Epoch.

Declaration
[JsonPropertyName("PreviousPaymentDueDate")]
[JsonConverter(typeof(RippleDateTimeConverter))]
public DateTime? PreviousPaymentDueDate { get; init; }
Property Value
Type Description
Nullable
| Edit this page View Source

PreviousTxnID

The identifying hash of the transaction that most recently modified this object.

Declaration
[JsonPropertyName("PreviousTxnID")]
public string PreviousTxnID { get; init; }
Property Value
Type Description
string
| Edit this page View Source

PreviousTxnLgrSeq

The index of the ledger that contains the transaction that most recently modified this object.

Declaration
[JsonPropertyName("PreviousTxnLgrSeq")]
public uint? PreviousTxnLgrSeq { get; init; }
Property Value
Type Description
uint?
| Edit this page View Source

PrincipalOutstanding

The remaining principal owed (Number type, string representation).

Declaration
[JsonPropertyName("PrincipalOutstanding")]
public string PrincipalOutstanding { get; init; }
Property Value
Type Description
string
| Edit this page View Source

PrincipalRequested

The principal amount originally requested (Number type, string representation).

Declaration
[JsonPropertyName("PrincipalRequested")]
public string PrincipalRequested { get; init; }
Property Value
Type Description
string
| Edit this page View Source

StartDate

The timestamp of when the loan started, in seconds since the Ripple Epoch.

Declaration
[JsonPropertyName("StartDate")]
[JsonConverter(typeof(RippleDateTimeConverter))]
public DateTime? StartDate { get; init; }
Property Value
Type Description
Nullable
| Edit this page View Source

TotalValueOutstanding

The total amount owed including fees (Number type, string representation).

Declaration
[JsonPropertyName("TotalValueOutstanding")]
public string TotalValueOutstanding { get; init; }
Property Value
Type Description
string
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX