Show / Hide Table of Contents

Class LOLoanBroker

A LoanBroker ledger object represents a loan broker that manages lending pools and cover deposits.

Inheritance
object
BaseLedgerEntry
LOLoanBroker
Inherited Members
BaseLedgerEntry.LedgerEntryType
BaseLedgerEntry.Index
BaseLedgerEntry.LedgerIndex
Namespace: Xrpl.Models.Ledger
Assembly: Xrpl.dll
Syntax
public class LOLoanBroker : BaseLedgerEntry
Remarks

Requires the Loan amendment (XLS-66d). This feature is in draft and subject to change.

Constructors

| Edit this page View Source

LOLoanBroker()

Declaration
public LOLoanBroker()

Properties

| Edit this page View Source

Account

The address of the LoanBroker pseudo-account.

Declaration
[JsonPropertyName("Account")]
public string Account { get; init; }
Property Value
Type Description
string
| Edit this page View Source

CoverAvailable

Total amount of first-loss capital deposited (Number type, string representation).

Declaration
[JsonPropertyName("CoverAvailable")]
public string CoverAvailable { get; init; }
Property Value
Type Description
string
| Edit this page View Source

CoverRateLiquidation

Minimum required first-loss capital moved to cover loan default.

Declaration
[JsonPropertyName("CoverRateLiquidation")]
public uint? CoverRateLiquidation { get; init; }
Property Value
Type Description
uint?
| Edit this page View Source

CoverRateMinimum

Minimum first-loss capital coverage ratio, in 1/10th basis points.

Declaration
[JsonPropertyName("CoverRateMinimum")]
public uint? CoverRateMinimum { get; init; }
Property Value
Type Description
uint?
| Edit this page View Source

Data

Arbitrary metadata about the loan broker, limited to 256 bytes. Hex-encoded string.

Declaration
[JsonPropertyName("Data")]
public string Data { get; init; }
Property Value
Type Description
string
| Edit this page View Source

DebtMaximum

Protocol debt ceiling; 0 indicates unlimited (Number type, string representation).

Declaration
[JsonPropertyName("DebtMaximum")]
public string DebtMaximum { get; init; }
Property Value
Type Description
string
| Edit this page View Source

DebtTotal

Total asset amount the protocol owes the vault, including interest (Number type, string representation).

Declaration
[JsonPropertyName("DebtTotal")]
public string DebtTotal { get; init; }
Property Value
Type Description
string
| Edit this page View Source

LoanSequence

Sequential identifier for Loan ledger entries, incremented each time a new loan is created.

Declaration
[JsonPropertyName("LoanSequence")]
public uint? LoanSequence { get; init; }
Property Value
Type Description
uint?
| Edit this page View Source

ManagementFeeRate

Protocol fee in 1/10th basis points (0-100000).

Declaration
[JsonPropertyName("ManagementFeeRate")]
public ushort? ManagementFeeRate { get; init; }
Property Value
Type Description
ushort?
| Edit this page View Source

Owner

The account address of the vault owner.

Declaration
[JsonPropertyName("Owner")]
public string Owner { get; init; }
Property Value
Type Description
string
| Edit this page View Source

OwnerCount

The number of active loans issued by the LoanBroker.

Declaration
[JsonPropertyName("OwnerCount")]
public uint? OwnerCount { get; init; }
Property Value
Type Description
uint?
| Edit this page View Source

OwnerNode

A hint indicating which page of the owner's directory links to this object (UInt64).

Declaration
[JsonPropertyName("OwnerNode")]
public string OwnerNode { get; init; }
Property Value
Type Description
string
| Edit this page View Source

PreviousTxnID

The identifying hash of the transaction that most recently modified this object.

Declaration
[JsonPropertyName("PreviousTxnID")]
public string PreviousTxnID { get; init; }
Property Value
Type Description
string
| Edit this page View Source

PreviousTxnLgrSeq

The index of the ledger that contains the transaction that most recently modified this object.

Declaration
[JsonPropertyName("PreviousTxnLgrSeq")]
public uint? PreviousTxnLgrSeq { get; init; }
Property Value
Type Description
uint?
| Edit this page View Source

Sequence

The transaction sequence number that created the LoanBroker.

Declaration
[JsonPropertyName("Sequence")]
public uint? Sequence { get; init; }
Property Value
Type Description
uint?
| Edit this page View Source

VaultID

The associated vault identifier.

Declaration
[JsonPropertyName("VaultID")]
public string VaultID { get; init; }
Property Value
Type Description
string
| Edit this page View Source

VaultNode

Reference page in vault's pseudo-account directory (UInt64).

Declaration
[JsonPropertyName("VaultNode")]
public string VaultNode { get; init; }
Property Value
Type Description
string
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX