Show / Hide Table of Contents

Class LOMPTokenIssuance

The MPTokenIssuance object represents a Multi-Purpose Token (MPT) issuance.

Inheritance
object
BaseLedgerEntry
LOMPTokenIssuance
Inherited Members
BaseLedgerEntry.LedgerEntryType
BaseLedgerEntry.Index
BaseLedgerEntry.LedgerIndex
Namespace: Xrpl.Models.Ledger
Assembly: Xrpl.dll
Syntax
public class LOMPTokenIssuance : BaseLedgerEntry

Constructors

| Edit this page View Source

LOMPTokenIssuance()

Declaration
public LOMPTokenIssuance()

Properties

| Edit this page View Source

AssetScale

Asset scale (decimal places). UInt8

Declaration
[JsonPropertyName("AssetScale")]
public byte AssetScale { get; init; }
Property Value
Type Description
byte
| Edit this page View Source

Flags

Declaration
[JsonPropertyName("Flags")]
public MPTokenIssuanceFlags? Flags { get; init; }
Property Value
Type Description
MPTokenIssuanceFlags?
| Edit this page View Source

Issuer

The address of the account that controls the issuance. AccountID

Declaration
[JsonPropertyName("Issuer")]
public string Issuer { get; init; }
Property Value
Type Description
string
| Edit this page View Source

LockedAmount

Amount of tokens currently locked (included in OutstandingAmount). UInt64 (0 .. 2^63-1) Requires TokenEscrow amendment. Optional

Declaration
[JsonPropertyName("LockedAmount")]
[JsonConverter(typeof(UInt64StringJsonConverter))]
public ulong? LockedAmount { get; init; }
Property Value
Type Description
ulong?
| Edit this page View Source

MPTokenIssuanceID

Computed 192-bit MPTokenIssuanceID (48 hex chars, uppercase). Derived from Sequence and Issuer per XLS-33.

Declaration
[JsonIgnore]
public string MPTokenIssuanceID { get; }
Property Value
Type Description
string
| Edit this page View Source

MPTokenMetadata

Arbitrary metadata in hex format (max 1024 bytes). Blob

Declaration
[JsonPropertyName("MPTokenMetadata")]
public string? MPTokenMetadata { get; init; }
Property Value
Type Description
string
| Edit this page View Source

MPTokenMetadataRow

Declaration
[JsonIgnore]
public string? MPTokenMetadataRow { get; }
Property Value
Type Description
string
| Edit this page View Source

MaximumAmount

Maximum number of tokens that can exist. UInt64 (0 .. 2^63-1) Optional

Declaration
[JsonPropertyName("MaximumAmount")]
[JsonConverter(typeof(UInt64StringJsonConverter))]
public ulong? MaximumAmount { get; init; }
Property Value
Type Description
ulong?
| Edit this page View Source

Metadata

Parsed metadata object conforming to the XLS-89 Multi-Purpose Token Metadata Schema. Lazily deserialized from the MPTokenMetadata hex field.

Declaration
[JsonIgnore]
public MPTokenMetadataSchema? Metadata { get; }
Property Value
Type Description
MPTokenMetadataSchema
| Edit this page View Source

OutstandingAmount

Total amount of tokens currently in circulation. UInt64 (0 .. 2^63-1)

Declaration
[JsonPropertyName("OutstandingAmount")]
[JsonConverter(typeof(UInt64StringJsonConverter))]
public ulong OutstandingAmount { get; init; }
Property Value
Type Description
ulong
| Edit this page View Source

OwnerNode

Owner directory page hint. UInt64

Declaration
[JsonPropertyName("OwnerNode")]
[JsonConverter(typeof(UInt64HexJsonConverter))]
public ulong? OwnerNode { get; init; }
Property Value
Type Description
ulong?
| Edit this page View Source

PreviousTxnID

Hash of the transaction that last modified this entry. UInt256

Declaration
[JsonPropertyName("PreviousTxnID")]
public string PreviousTxnID { get; init; }
Property Value
Type Description
string
| Edit this page View Source

PreviousTxnLgrSeq

Ledger index of the previous modifying transaction. UInt32

Declaration
[JsonPropertyName("PreviousTxnLgrSeq")]
public uint PreviousTxnLgrSeq { get; init; }
Property Value
Type Description
uint
| Edit this page View Source

Sequence

Sequence or Ticket number that created this issuance. UInt32

Declaration
[JsonPropertyName("Sequence")]
public uint Sequence { get; init; }
Property Value
Type Description
uint
| Edit this page View Source

TransferFee

Transfer fee in tenths of a basis point. UInt16 (0 .. 50000)

Declaration
[JsonPropertyName("TransferFee")]
public ushort? TransferFee { get; init; }
Property Value
Type Description
ushort?
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX