Show / Hide Table of Contents

Class LOOffer

Inheritance
object
BaseLedgerEntry
LOOffer
Inherited Members
BaseLedgerEntry.LedgerEntryType
BaseLedgerEntry.Index
BaseLedgerEntry.LedgerIndex
Namespace: Xrpl.Models.Ledger
Assembly: Xrpl.dll
Syntax
public class LOOffer : BaseLedgerEntry

Constructors

| Edit this page View Source

LOOffer()

Declaration
public LOOffer()

Properties

| Edit this page View Source

Account

The address of the account that placed this Offer.

Declaration
public string Account { get; set; }
Property Value
Type Description
string
| Edit this page View Source

AdditionalBooks

An additional list of order book directories that this offer belongs to. Currently this field is only applicable to hybrid offers.

Declaration
public List<BookWrapper> AdditionalBooks { get; set; }
Property Value
Type Description
List<BookWrapper>
| Edit this page View Source

BookDirectory

The ID of the Offer Directory that links to this Offer.

Declaration
public string BookDirectory { get; set; }
Property Value
Type Description
string
| Edit this page View Source

BookNode

A hint indicating which page of the Offer Directory links to this object, in case the directory consists of multiple pages.

Declaration
public string BookNode { get; set; }
Property Value
Type Description
string
| Edit this page View Source

DomainID

The domain that the offer must be a part of. Only present for permissioned offers.

Declaration
public string DomainID { get; set; }
Property Value
Type Description
string
| Edit this page View Source

Expiration

The time this Offer expires, in seconds since the Ripple Epoch.

Declaration
[JsonConverter(typeof(RippleDateTimeConverter))]
public DateTime? Expiration { get; set; }
Property Value
Type Description
Nullable
| Edit this page View Source

Flags

A bit-map of boolean flags enabled for this Offer. Uses OfferFlags enum which includes lsfPassive, lsfSell, and lsfHybrid flags.

Declaration
public OfferFlags Flags { get; set; }
Property Value
Type Description
OfferFlags
| Edit this page View Source

OwnerNode

A hint indicating which page of the Owner Directory links to this object, in case the directory consists of multiple pages.

Declaration
public string OwnerNode { get; set; }
Property Value
Type Description
string
| Edit this page View Source

PreviousTxnID

The identifying hash of the transaction that most recently modified this object.

Declaration
[JsonPropertyName("PreviousTxnID")]
public string PreviousTxnID { get; set; }
Property Value
Type Description
string
| Edit this page View Source

PreviousTxnLgrSeq

The index of the ledger that contains the transaction that most recently modified this object.

Declaration
[JsonPropertyName("PreviousTxnLgrSeq")]
public uint PreviousTxnLgrSeq { get; set; }
Property Value
Type Description
uint
| Edit this page View Source

Sequence

The Sequence value of the OfferCreate transaction that created this Offer object.
Used in combination with the Account to identify this Offer.

Declaration
public uint Sequence { get; set; }
Property Value
Type Description
uint
| Edit this page View Source

TakerGets

The remaining amount and type of currency being provided by the Offer creator

Declaration
[JsonConverter(typeof(CurrencyConverter))]
public Currency TakerGets { get; set; }
Property Value
Type Description
Currency
| Edit this page View Source

TakerPays

The remaining amount and type of currency requested by the Offer creator.

Declaration
[JsonConverter(typeof(CurrencyConverter))]
public Currency TakerPays { get; set; }
Property Value
Type Description
Currency
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX