Show / Hide Table of Contents

Class LOPermissionedDomain

A PermissionedDomain ledger entry describes a single permissioned domain instance. You can create a permissioned domain by sending a PermissionedDomainSet transaction. Requires the PermissionedDomains amendment.

Inheritance
object
BaseLedgerEntry
LOPermissionedDomain
Inherited Members
BaseLedgerEntry.LedgerEntryType
BaseLedgerEntry.Index
BaseLedgerEntry.LedgerIndex
Namespace: Xrpl.Models.Ledger
Assembly: Xrpl.dll
Syntax
public class LOPermissionedDomain : BaseLedgerEntry

Constructors

| Edit this page View Source

LOPermissionedDomain()

Initializes a new instance of the LOPermissionedDomain class.

Declaration
public LOPermissionedDomain()

Properties

| Edit this page View Source

AcceptedCredentials

A list of 1 to 10 Credential objects that grant access to this domain. The array is stored sorted by issuer.

Declaration
[JsonPropertyName("AcceptedCredentials")]
public List<AcceptedCredentialWrapper> AcceptedCredentials { get; set; }
Property Value
Type Description
List<AcceptedCredentialWrapper>
| Edit this page View Source

Owner

The address of the account that owns this domain.

Declaration
[JsonPropertyName("Owner")]
public string Owner { get; set; }
Property Value
Type Description
string
| Edit this page View Source

OwnerNode

A hint indicating which page of the owner directory links to this entry, in case the directory consists of multiple pages.

Declaration
[JsonPropertyName("OwnerNode")]
public string OwnerNode { get; set; }
Property Value
Type Description
string
| Edit this page View Source

PreviousTxnID

The identifying hash of the transaction that most recently modified this entry.

Declaration
[JsonPropertyName("PreviousTxnID")]
public string PreviousTxnID { get; set; }
Property Value
Type Description
string
| Edit this page View Source

PreviousTxnLgrSeq

The index of the ledger that contains the transaction that most recently modified this object.

Declaration
[JsonPropertyName("PreviousTxnLgrSeq")]
public uint PreviousTxnLgrSeq { get; set; }
Property Value
Type Description
uint
| Edit this page View Source

Sequence

The Sequence value of the transaction that created this entry.

Declaration
[JsonPropertyName("Sequence")]
public uint Sequence { get; set; }
Property Value
Type Description
uint
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX