Show / Hide Table of Contents

Class LOSignerList

The SignerList object type represents a list of parties that, as a group, are authorized to sign a transaction in place of an individual account.
You can create, replace, or remove a signer list using a SignerListSet transaction.

Inheritance
object
BaseLedgerEntry
LOSignerList
Inherited Members
BaseLedgerEntry.LedgerEntryType
BaseLedgerEntry.Index
BaseLedgerEntry.LedgerIndex
Namespace: Xrpl.Models.Ledger
Assembly: Xrpl.dll
Syntax
public class LOSignerList : BaseLedgerEntry

Constructors

| Edit this page View Source

LOSignerList()

create base object

Declaration
public LOSignerList()

Properties

| Edit this page View Source

Flags

A bit-map of Boolean flags enabled for this signer list.
For more information, see SignerList Flags.

Declaration
public uint Flags { get; set; }
Property Value
Type Description
uint
| Edit this page View Source

OwnerNode

A hint indicating which page of the owner directory links to this object, in case the directory consists of multiple pages.

Declaration
public string OwnerNode { get; set; }
Property Value
Type Description
string
| Edit this page View Source

PreviousTxnID

The identifying hash of the transaction that most recently modified this object.

Declaration
public string PreviousTxnID { get; set; }
Property Value
Type Description
string
| Edit this page View Source

PreviousTxnLgrSeq

The index of the ledger that contains the transaction that most recently modified this object.

Declaration
public uint PreviousTxnLgrSeq { get; set; }
Property Value
Type Description
uint
| Edit this page View Source

SignerEntries

An array of Signer Entry objects representing the parties who are part of this signer list.

Declaration
public List<SignerEntryWrapper> SignerEntries { get; set; }
Property Value
Type Description
List<SignerEntryWrapper>
| Edit this page View Source

SignerListId

An ID for this signer list.
Currently always set to 0.
If a future amendment allows multiple signer lists for an account, this may change.

Declaration
public uint SignerListId { get; set; }
Property Value
Type Description
uint
| Edit this page View Source

SignerQuorum

A target number for signer weights.
To produce a valid signature for the owner of this SignerList, the signers must provide valid signatures whose weights sum to this value or more.

Declaration
public uint SignerQuorum { get; set; }
Property Value
Type Description
uint
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX