Show / Hide Table of Contents

Class LOTicket

The Ticket object type represents a Ticket, which tracks an account sequence number that has been set aside for future use.
You can create new tickets with a TicketCreate transaction.

Inheritance
object
BaseLedgerEntry
LOTicket
Inherited Members
BaseLedgerEntry.LedgerEntryType
BaseLedgerEntry.Index
BaseLedgerEntry.LedgerIndex
BaseLedgerEntry.UnknownFields
Namespace: Xrpl.Models.Ledger
Assembly: Xrpl.dll
Syntax
public class LOTicket : BaseLedgerEntry

Properties

| Edit this page View Source

Account

The account that owns this Ticket.

Declaration
public string Account { get; set; }
Property Value
Type Description
string
| Edit this page View Source

Flags

A bit-map of Boolean flags enabled for this Ticket.
Currently, there are no flags defined for Tickets, so this value is always 0.

Declaration
[JsonConverter(typeof(NumberOrStringConverter))]
public string Flags { get; set; }
Property Value
Type Description
string
| Edit this page View Source

OwnerNode

A hint indicating which page of the sender's owner directory links to this object, in case the directory consists of multiple pages.

Declaration
public string OwnerNode { get; set; }
Property Value
Type Description
string
| Edit this page View Source

PreviousTxnID

The identifying hash of the transaction that most recently modified this object.

Declaration
public string PreviousTxnID { get; set; }
Property Value
Type Description
string
| Edit this page View Source

PreviousTxnLgrSeq

The index of the ledger that contains the transaction that most recently modified this object.

Declaration
public uint? PreviousTxnLgrSeq { get; set; }
Property Value
Type Description
uint?
| Edit this page View Source

TicketSequence

The Sequence Number this Ticket sets aside.

Declaration
public uint? TicketSequence { get; set; }
Property Value
Type Description
uint?
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX