Show / Hide Table of Contents

Class LOXChainOwnedClaimID

An XChainOwnedClaimID ledger object represents one cross-chain transfer of value and includes information of the value locked on the source chain.

Inheritance
object
BaseLedgerEntry
LOXChainOwnedClaimID
Inherited Members
BaseLedgerEntry.LedgerEntryType
BaseLedgerEntry.Index
BaseLedgerEntry.LedgerIndex
Namespace: Xrpl.Models.Ledger
Assembly: Xrpl.dll
Syntax
public class LOXChainOwnedClaimID : BaseLedgerEntry

Constructors

| Edit this page View Source

LOXChainOwnedClaimID()

Declaration
public LOXChainOwnedClaimID()

Properties

| Edit this page View Source

Account

The account that owns this claim ID.

Declaration
[JsonPropertyName("Account")]
public string Account { get; init; }
Property Value
Type Description
string
| Edit this page View Source

OtherChainSource

The account that must send the corresponding XChainCommit on the source chain.

Declaration
[JsonPropertyName("OtherChainSource")]
public string OtherChainSource { get; init; }
Property Value
Type Description
string
| Edit this page View Source

OwnerNode

A hint indicating which page of the sender's owner directory links to this object.

Declaration
[JsonPropertyName("OwnerNode")]
public string OwnerNode { get; init; }
Property Value
Type Description
string
| Edit this page View Source

PreviousTxnID

The identifying hash of the transaction that most recently modified this object.

Declaration
[JsonPropertyName("PreviousTxnID")]
public string PreviousTxnID { get; init; }
Property Value
Type Description
string
| Edit this page View Source

PreviousTxnLgrSeq

The index of the ledger that contains the transaction that most recently modified this object.

Declaration
[JsonPropertyName("PreviousTxnLgrSeq")]
public uint? PreviousTxnLgrSeq { get; init; }
Property Value
Type Description
uint?
| Edit this page View Source

SignatureReward

The total amount to be rewarded for providing attestation signatures.

Declaration
[JsonPropertyName("SignatureReward")]
[JsonConverter(typeof(CurrencyConverter))]
public Currency SignatureReward { get; init; }
Property Value
Type Description
Currency
| Edit this page View Source

XChainBridge

The bridge specification.

Declaration
[JsonPropertyName("XChainBridge")]
public XChainBridgeModel XChainBridge { get; init; }
Property Value
Type Description
XChainBridgeModel
| Edit this page View Source

XChainClaimAttestations

Attestations collected from the witness servers.

Declaration
[JsonPropertyName("XChainClaimAttestations")]
public List<XChainClaimAttestationCollectionElement> XChainClaimAttestations { get; init; }
Property Value
Type Description
List<XChainClaimAttestationCollectionElement>
| Edit this page View Source

XChainClaimID

The unique sequence number for the cross-chain claim.

Declaration
[JsonPropertyName("XChainClaimID")]
public string XChainClaimID { get; init; }
Property Value
Type Description
string
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX