Show / Hide Table of Contents

Class LOXChainOwnedCreateAccountClaimID

An XChainOwnedCreateAccountClaimID ledger object represents one cross-chain account create transaction and collects attestations for it.

Inheritance
object
BaseLedgerEntry
LOXChainOwnedCreateAccountClaimID
Inherited Members
BaseLedgerEntry.LedgerEntryType
BaseLedgerEntry.Index
BaseLedgerEntry.LedgerIndex
Namespace: Xrpl.Models.Ledger
Assembly: Xrpl.dll
Syntax
public class LOXChainOwnedCreateAccountClaimID : BaseLedgerEntry

Constructors

| Edit this page View Source

LOXChainOwnedCreateAccountClaimID()

Declaration
public LOXChainOwnedCreateAccountClaimID()

Properties

| Edit this page View Source

Account

The account that owns this object.

Declaration
[JsonPropertyName("Account")]
public string Account { get; init; }
Property Value
Type Description
string
| Edit this page View Source

OwnerNode

A hint indicating which page of the sender's owner directory links to this object.

Declaration
[JsonPropertyName("OwnerNode")]
public string OwnerNode { get; init; }
Property Value
Type Description
string
| Edit this page View Source

PreviousTxnID

The identifying hash of the transaction that most recently modified this object.

Declaration
[JsonPropertyName("PreviousTxnID")]
public string PreviousTxnID { get; init; }
Property Value
Type Description
string
| Edit this page View Source

PreviousTxnLgrSeq

The index of the ledger that contains the transaction that most recently modified this object.

Declaration
[JsonPropertyName("PreviousTxnLgrSeq")]
public uint? PreviousTxnLgrSeq { get; init; }
Property Value
Type Description
uint?
| Edit this page View Source

XChainAccountCreateCount

An integer that determines the order that accounts created through cross-chain transfers must be performed.

Declaration
[JsonPropertyName("XChainAccountCreateCount")]
public string XChainAccountCreateCount { get; init; }
Property Value
Type Description
string
| Edit this page View Source

XChainBridge

The bridge specification.

Declaration
[JsonPropertyName("XChainBridge")]
public XChainBridgeModel XChainBridge { get; init; }
Property Value
Type Description
XChainBridgeModel
| Edit this page View Source

XChainCreateAccountAttestations

Attestations collected from the witness servers for the account creation.

Declaration
[JsonPropertyName("XChainCreateAccountAttestations")]
public List<XChainCreateAccountAttestationCollectionElement> XChainCreateAccountAttestations { get; init; }
Property Value
Type Description
List<XChainCreateAccountAttestationCollectionElement>
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX