Class LedgerEntity
A ledger is a block of transactions and shared state data.
It has a unique header that describes its contents using cryptographic hashes.
Implements
Inherited Members
Namespace: Xrpl.Models.Ledger
Assembly: Xrpl.dll
Syntax
public class LedgerEntity : BaseLedgerEntity, IBaseLedgerEntity
Properties
| Edit this page View SourceAccountHash
The SHA-512Half of this ledger's state tree information.
Declaration
[JsonPropertyName("account_hash")]
public string AccountHash { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
CloseFlags
A bit-map of flags relating to the closing of this ledger.
Declaration
[JsonPropertyName("close_flags")]
public uint CloseFlags { get; set; }
Property Value
| Type | Description |
|---|---|
| uint |
CloseTime
The approximate time this ledger version closed,
as the number of seconds since the Ripple Epoch of 2000-01-01 00:00:00.
This value is rounded based on the close_time_resolution.
Declaration
[JsonPropertyName("close_time")]
[JsonConverter(typeof(RippleDateTimeConverter))]
public DateTime? CloseTime { get; set; }
Property Value
| Type | Description |
|---|---|
| Nullable |
CloseTimeHuman
The approximate time this ledger was closed, in human-readable format.
Always uses the UTC time zone.
Declaration
[JsonPropertyName("close_time_human")]
public string CloseTimeHuman { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
CloseTimeIso
Declaration
[JsonPropertyName("close_time_iso")]
[JsonConverter(typeof(FromStringDateTimeConverter))]
public DateTime? CloseTimeIso { get; set; }
Property Value
| Type | Description |
|---|---|
| Nullable |
CloseTimeResolution
An integer in the range [2,120] indicating the maximum number of seconds by which the close_time could be rounded.
Declaration
[JsonPropertyName("close_time_resolution")]
public int CloseTimeResolution { get; set; }
Property Value
| Type | Description |
|---|---|
| int |
LedgerHash
The SHA-512Half of this ledger version.
This serves as a unique identifier for this ledger and all its contents.
Declaration
[JsonPropertyName("ledger_hash")]
public string LedgerHash { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
LedgerIndex
The ledger index of the ledger.
Some API methods display this as a quoted integer; some display it as a native JSON number.
Declaration
[JsonPropertyName("ledger_index")]
[JsonConverter(typeof(NumberOrStringConverter))]
public string LedgerIndex { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
ParentCloseTime
The approximate time at which the previous ledger was closed.
Declaration
[JsonPropertyName("parent_close_time")]
public uint ParentCloseTime { get; set; }
Property Value
| Type | Description |
|---|---|
| uint |
ParentHash
Unique identifying hash of the ledger that came immediately before this one
Declaration
[JsonPropertyName("parent_hash")]
public string ParentHash { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
TotalCoins
Total number of XRP drops in the network, as a quoted integer.
Declaration
[JsonPropertyName("total_coins")]
public string TotalCoins { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
TransactionHash
Hash of the transaction information included in this ledger, as hex.
Declaration
[JsonPropertyName("transaction_hash")]
public string TransactionHash { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
Transactions
Transactions applied in this ledger version.
By default, members are the transactions' identifying Hash strings.
If the request specified expand as true,
members are full representations of the transactions instead,
in either JSON or binary depending on whether the request specified binary as true.
Declaration
[JsonPropertyName("transactions")]
public List<HashOrTransaction> Transactions { get; set; }
Property Value
| Type | Description |
|---|---|
| List<HashOrTransaction> |