Show / Hide Table of Contents

Enum LedgerIndexType

The rippled server makes a distinction between ledger versions that are open, closed, and validated.
A server has one open ledger, any number of closed but unvalidated ledgers, and an immutable history of validated ledgers.

Namespace: Xrpl.Models.Ledger
Assembly: Xrpl.dll
Syntax
public enum LedgerIndexType

Fields

Name Description
Closed
Current
Validated

Extension Methods

EmumExtensions.DecodeFlags<LedgerIndexType>(LedgerIndexType)
EmumExtensions.FlagsValues<LedgerIndexType>(LedgerIndexType)
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX