Show / Hide Table of Contents

Enum MPTokenFlags

Namespace: Xrpl.Models.Ledger
Assembly: Xrpl.dll
Syntax
[Flags]
public enum MPTokenFlags : uint

Fields

Name Description
lsfMPTAuthorized

(Only applicable for allow-listing) If set, indicates that the issuer has authorized the holder for the MPT.
This flag can be set using a MPTokenAuthorize transaction;
it can also be "un-set" using a MPTokenAuthorize transaction specifying the tfMPTUnauthorize flag.

lsfMPTLocked

If enabled, indicates that the MPT owned by this account is currently locked and cannot be used in any XRP transactions other than sending value back to the issuer.

Extension Methods

EmumExtensions.DecodeFlags<MPTokenFlags>(MPTokenFlags)
EmumExtensions.FlagsValues<MPTokenFlags>(MPTokenFlags)
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX