Show / Hide Table of Contents

Class QueuedTransaction

Each member of the queue_data array represents one transaction in the queue.
Some fields of this object may be omitted because they have not yet been calculated.
https://xrpl.org/ledger.html#response-format

Inheritance
object
QueuedTransaction
Namespace: Xrpl.Models.Ledger
Assembly: Xrpl.dll
Syntax
public class QueuedTransaction

Properties

| Edit this page View Source

Account

The Address of the sender for this queued transaction.

Declaration
[JsonPropertyName("account")]
public string Account { get; set; }
Property Value
Type Description
string
| Edit this page View Source

AuthChange

(May be omitted) Whether this transaction changes this address's ways of authorizing transactions.

Declaration
[JsonPropertyName("auth_change")]
public bool? AuthChange { get; set; }
Property Value
Type Description
bool?
| Edit this page View Source

Fee

(May be omitted) The Transaction Cost of this transaction, in drops of XRP.

Declaration
[JsonPropertyName("fee")]
public string Fee { get; set; }
Property Value
Type Description
string
| Edit this page View Source

FeeLevel

(May be omitted) The transaction cost of this transaction, relative to the minimum cost for this type of transaction, in fee levels.

Declaration
[JsonPropertyName("fee_level")]
public string FeeLevel { get; set; }
Property Value
Type Description
string
| Edit this page View Source

LastResult

May be omitted) If this transaction was left in the queue after getting a retriable (ter) result, this is the exact ter result code it got.

Declaration
[JsonPropertyName("last_result")]
public string LastResult { get; set; }
Property Value
Type Description
string
| Edit this page View Source

MaxSpendDrops

(May be omitted) The maximum amount of XRP, in drops, this transaction could potentially send or destroy.

Declaration
[JsonPropertyName("max_spend_drops")]
public string MaxSpendDrops { get; set; }
Property Value
Type Description
string
| Edit this page View Source

PreflightResult

The tentative result from preliminary transaction checking.
This is always tesSUCCESS.

Declaration
[JsonPropertyName("preflight_result")]
public string PreflightResult { get; set; }
Property Value
Type Description
string
| Edit this page View Source

RetriesRemaining

How many times this transaction can be retried before being dropped.

Declaration
[JsonPropertyName("retries_remaining")]
public uint RetriesRemaining { get; set; }
Property Value
Type Description
uint
| Edit this page View Source

Transaction

By default, this is a String containing the identifying hash of the transaction.
If transactions are expanded in binary format, this is an object whose only field is tx_blob, containing the binary form of the transaction as a decimal string.
If transactions are expanded in JSON format, this is an object containing the transaction object including the transaction's identifying hash in the hash field.

Declaration
[JsonPropertyName("tx")]
[JsonConverter(typeof(QueuedTransactionTxConverter))]
public object Transaction { get; set; }
Property Value
Type Description
object
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX