Show / Hide Table of Contents

Enum VaultVersion

Values of the Vault ledger entry's LEVersion field (rippled VaultVersion).

Namespace: Xrpl.Models.Ledger
Assembly: Xrpl.dll
Syntax
public enum VaultVersion : uint
Remarks

LEVersion stays a plain uint?, matching the other UInt8 fields of this object; these constants name the values the protocol defines so far.

Fields

Name Description
CashBasis

Cash-basis accounting (rippled #7817).

Legacy

Accrual-basis accounting. Vaults created before cash-basis accounting was activated carry no LEVersion at all and are treated as this version implicitly.

Extension Methods

EmumExtensions.DecodeFlags<VaultVersion>(VaultVersion)
EmumExtensions.FlagsValues<VaultVersion>(VaultVersion)
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX