Show / Hide Table of Contents

Enum LedgerEntryType

Each ledger version's state data is a set of ledger objects, sometimes called ledger entries, which collectively represent all settings, balances, and relationships at a given point in time.
To store or retrieve an object in the state data, the protocol uses that object's unique Ledger Object ID.
In the peer protocol, ledger objects have a canonical binary format.In rippled APIs, ledger objects are represented as JSON objects.

Namespace: Xrpl.Models
Assembly: Xrpl.dll
Syntax
public enum LedgerEntryType

Fields

Name Description
AMM

The definition and details of an Automated Market Maker (AMM) instance.

AccountRoot

The settings, XRP balance, and other metadata for one account.

Amendments

The status of enabled and pending amendments.

Bridge

A single cross-chain bridge that connects and enables value to move efficiently between two blockchains.

Check

A check that can be redeemed for money by its destination.

Credential

A credential, which can be used to preauthorize payments or gain access to specific permissioned domains.

DID

A Decentralized Identifier (DID).

Delegate

A record of which permissions have been granted to another account.

DepositPreauth

A record of preauthorization for sending payments to an account that requires authorization.

DirectoryNode

A set of links to other ledger entries, either objects owned by an account or trades in the decentralized exchange.

Escrow

An escrow, which holds funds to be released when certain conditions are met.

FeeSettings

The current base transaction cost and reserve requirements.

LedgerHashes

Lists of prior ledger versions' hashes for history lookup.

MPToken

Multi-Purpose Tokens (MPT) of one issuance held by a specific account.

MPTokenIssuance

Definition of a Multi-Purpose Token (MPT) issuance.

NFTokenOffer

An offer to buy or sell an NFT.

NFTokenPage

A group of up to 32 NFTs, stored together for efficiency.

NegativeUNL

List of validators currently believed to be offline.

Offer

An offer (order) to trade currencies in the decentralized exchange.

Oracle

A record of price information about currency pairs from an outside source.

PayChannel

A payment channel, which allows for rapid, asynchronous payments.

PermissionedDomain

A permissioned domain, which is used to limit access to other features.

RippleState

A trust line, which tracks the net balance of fungible tokens between two accounts.

SignerList

A list of addresses for multi-signing transactions.

Ticket

A ticket, which sets aside a sequence number for use in a future transaction.

Unknown

Unknown ledger entry type (for forward compatibility with future ledger objects).

Vault

Vault object (XLS-xx).

XChainOwnedClaimID

A cross-chain transfer of value.

XChainOwnedCreateAccountClaimID

A record of attestations for creating an account via a cross-chain transfer.

Extension Methods

EmumExtensions.DecodeFlags<LedgerEntryType>(LedgerEntryType)
EmumExtensions.FlagsValues<LedgerEntryType>(LedgerEntryType)
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX