Show / Hide Table of Contents

Class AccountChannels

The expected response from an AccountChannelsRequest .

Inheritance
object
AccountChannels
Namespace: Xrpl.Models.Methods
Assembly: Xrpl.dll
Syntax
public class AccountChannels

Properties

| Edit this page View Source

Account

The address of the source/owner of the payment channels.
This corresponds to the account field of the request.

Declaration
[JsonPropertyName("account")]
public string Account { get; set; }
Property Value
Type Description
string
| Edit this page View Source

Channels

Payment channels owned by this account.

Declaration
[JsonPropertyName("channels")]
public List<Channel> Channels { get; set; }
Property Value
Type Description
List<Channel>
| Edit this page View Source

Limit

The limit to how many channel objects were actually returned by this request.

Declaration
[JsonPropertyName("limit")]
public int? Limit { get; set; }
Property Value
Type Description
int?
| Edit this page View Source

Marker

Server-defined value for pagination.
Pass this to the next call to resume getting results where this call left off.
Omitted when there are no additional pages after this one.

Declaration
[JsonPropertyName("marker")]
public object Marker { get; set; }
Property Value
Type Description
object
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX