Show / Hide Table of Contents

Class AccountChannelsRequest

The account_channels method returns information about an account's Payment Channels.
This includes only channels where the specified account is the channel's source, not the destination.
(A channel's "source" and "owner" are the same.)
All information retrieved is relative to a particular version of the ledger.
Returns an AccountChannels.

Inheritance
object
BaseRequest
BaseLedgerRequest
AccountChannelsRequest
Inherited Members
BaseLedgerRequest.LedgerHash
BaseLedgerRequest.LedgerIndex
BaseRequest.Id
BaseRequest.Command
BaseRequest.ApiVersion
Namespace: Xrpl.Models.Methods
Assembly: Xrpl.dll
Syntax
public class AccountChannelsRequest : BaseLedgerRequest

Constructors

| Edit this page View Source

AccountChannelsRequest(string)

Declaration
public AccountChannelsRequest(string account)
Parameters
Type Name Description
string account

Properties

| Edit this page View Source

Account

The unique identifier of an account, typically the account's address.
The request returns channels where this account is the channel's owner/source.

Declaration
[JsonPropertyName("account")]
public string Account { get; set; }
Property Value
Type Description
string
| Edit this page View Source

DestinationAccount

The unique identifier of an account, typically the account's address.
If provided, filter results to payment channels whose destination is this account.

Declaration
[JsonPropertyName("destination_account")]
public string DestinationAccount { get; set; }
Property Value
Type Description
string
| Edit this page View Source

Limit

Limit the number of transactions to retrieve.
Cannot be less than 10 or more than 400. The default is 200.

Declaration
[JsonPropertyName("limit")]
public int? Limit { get; set; }
Property Value
Type Description
int?
| Edit this page View Source

Marker

Value from a previous paginated response.
Resume retrieving data where that response left off.

Declaration
[JsonPropertyName("marker")]
public object Marker { get; set; }
Property Value
Type Description
object
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX