Show / Hide Table of Contents

Class AccountCurrenciesRequest

The account_currencies command retrieves a list of currencies that an account can send or receive, based on its trust lines. Expects an AccountCurrencies

Inheritance
object
BaseRequest
BaseLedgerRequest
AccountCurrenciesRequest
Inherited Members
BaseLedgerRequest.LedgerHash
BaseLedgerRequest.LedgerIndex
BaseRequest.Id
BaseRequest.Command
BaseRequest.ApiVersion
Namespace: Xrpl.Models.Methods
Assembly: Xrpl.dll
Syntax
public class AccountCurrenciesRequest : BaseLedgerRequest

Constructors

| Edit this page View Source

AccountCurrenciesRequest(string)

Declaration
public AccountCurrenciesRequest(string account)
Parameters
Type Name Description
string account

Properties

| Edit this page View Source

Account

A unique identifier for the account, most commonly the account's address.

Declaration
[JsonPropertyName("account")]
public string Account { get; set; }
Property Value
Type Description
string
| Edit this page View Source

Strict

If true, then the account field only accepts a public key or XRP Ledger address.
Otherwise, account can be a secret or passphrase (not recommended).
The default is false.

Declaration
[JsonPropertyName("strict")]
public bool? Strict { get; set; }
Property Value
Type Description
bool?
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX