Show / Hide Table of Contents

Class AccountInfo

Response expected from an AccountInfoRequest.

Inheritance
object
AccountInfo
Namespace: Xrpl.Models.Methods
Assembly: Xrpl.dll
Syntax
public class AccountInfo

Properties

| Edit this page View Source

AccountData

The AccountRoot ledger object with this account's information, as stored in the ledger.

Declaration
[JsonPropertyName("account_data")]
public LOAccountRoot AccountData { get; set; }
Property Value
Type Description
LOAccountRoot
| Edit this page View Source

AccountFlags

A map of account flags parsed out. This will only be available for rippled nodes 1.11.0 and higher.

Declaration
[JsonPropertyName("account_flags")]
public AccountInfoAccountFlags AccountFlags { get; set; }
Property Value
Type Description
AccountInfoAccountFlags
| Edit this page View Source

LedgerCurrentIndex

The ledger index of the current in-progress ledger, which was used when retrieving this information.

Declaration
[JsonPropertyName("ledger_current_index")]
public int LedgerCurrentIndex { get; set; }
Property Value
Type Description
int
| Edit this page View Source

LedgerIndex

The ledger index of the ledger version used when retrieving this information.The information does not contain any changes from ledger versions newer than this one.

Declaration
[JsonPropertyName("ledger_index")]
public int LedgerIndex { get; set; }
Property Value
Type Description
int
| Edit this page View Source

PseudoAccount

Set or get the pseudo account type of this account. This field is only present if the account is a pseudo account, and is null otherwise.

Declaration
[JsonPropertyName("pseudo_account")]
public PseudoAccountInfo? PseudoAccount { get; set; }
Property Value
Type Description
PseudoAccountInfo
| Edit this page View Source

QueueData

Information about queued transactions sent by this account.
This information describes the state of the local rippled server, which may be different from other servers in the peer-to-peer XRP Ledger network.
Some fields may be omitted because the values are calculated "lazily" by the queuing mechanism.

Declaration
[JsonPropertyName("queue_data")]
public AccountQueueData? QueueData { get; set; }
Property Value
Type Description
AccountQueueData
| Edit this page View Source

SignerLists

If requested, array of SignerList ledger objects associated with this account for Multi-Signing. Since an account can own at most one SignerList, this array must have exactly one member if it is present.

Declaration
[JsonPropertyName("signer_lists")]
public LOSignerList[]? SignerLists { get; set; }
Property Value
Type Description
LOSignerList[]
| Edit this page View Source

Validated

True if this data is from a validated ledger version;
if omitted or set to false, this data is not final.

Declaration
[JsonPropertyName("validated")]
public bool Validated { get; set; }
Property Value
Type Description
bool
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX