Show / Hide Table of Contents

Class AccountInfoAccountFlags

Inheritance
object
AccountInfoAccountFlags
Namespace: Xrpl.Models.Methods
Assembly: Xrpl.dll
Syntax
public sealed class AccountInfoAccountFlags

Properties

| Edit this page View Source

AllowTrustLineClawback

This address can claw back issued IOUs. Once enabled, cannot be disabled.

Declaration
[JsonPropertyName("allowTrustLineClawback")]
public bool AllowTrustLineClawback { get; set; }
Property Value
Type Description
bool
| Edit this page View Source

AllowTrustLineLocking

Declaration
[JsonPropertyName("allowTrustLineLocking")]
public bool AllowTrustLineLocking { get; set; }
Property Value
Type Description
bool
| Edit this page View Source

DefaultRipple

Enable rippling on this address's trust lines by default. Required for issuing addresses; discouraged for others.

Declaration
[JsonPropertyName("defaultRipple")]
public bool DefaultRipple { get; set; }
Property Value
Type Description
bool
| Edit this page View Source

DepositAuth

This account can only receive funds from transactions it sends, and from preauthorized accounts. (DepositAuth enabled.)

Declaration
[JsonPropertyName("depositAuth")]
public bool DepositAuth { get; set; }
Property Value
Type Description
bool
| Edit this page View Source

DisableMasterKey

Disallows use of the master key to sign transactions for this account.

Declaration
[JsonPropertyName("disableMasterKey")]
public bool DisableMasterKey { get; set; }
Property Value
Type Description
bool
| Edit this page View Source

DisallowIncomingCheck

Disallow incoming Checks from other accounts. (DisallowIncoming amendment)

Declaration
[JsonPropertyName("disallowIncomingCheck")]
public bool? DisallowIncomingCheck { get; set; }
Property Value
Type Description
bool?
| Edit this page View Source

DisallowIncomingNFTokenOffer

Disallow incoming NFTOffers from other accounts. (DisallowIncoming amendment)

Declaration
[JsonPropertyName("disallowIncomingNFTokenOffer")]
public bool? DisallowIncomingNFTokenOffer { get; set; }
Property Value
Type Description
bool?
| Edit this page View Source

DisallowIncomingPayChan

Disallow incoming PayChannels from other accounts. (DisallowIncoming amendment)

Declaration
[JsonPropertyName("disallowIncomingPayChan")]
public bool? DisallowIncomingPayChan { get; set; }
Property Value
Type Description
bool?
| Edit this page View Source

DisallowIncomingTrustline

Disallow incoming Trustlines from other accounts. (DisallowIncoming amendment)

Declaration
[JsonPropertyName("disallowIncomingTrustline")]
public bool? DisallowIncomingTrustline { get; set; }
Property Value
Type Description
bool?
| Edit this page View Source

DisallowIncomingXRP

Client applications should not send XRP to this account. Not enforced by rippled.

Declaration
[JsonPropertyName("disallowIncomingXRP")]
public bool DisallowIncomingXRP { get; set; }
Property Value
Type Description
bool
| Edit this page View Source

GlobalFreeze

All assets issued by this address are frozen.

Declaration
[JsonPropertyName("globalFreeze")]
public bool GlobalFreeze { get; set; }
Property Value
Type Description
bool
| Edit this page View Source

NoFreeze

This address cannot freeze trust lines connected to it. Once enabled, cannot be disabled.

Declaration
[JsonPropertyName("noFreeze")]
public bool NoFreeze { get; set; }
Property Value
Type Description
bool
| Edit this page View Source

PasswordSpent

The account has used its free SetRegularKey transaction.

Declaration
[JsonPropertyName("passwordSpent")]
public bool PasswordSpent { get; set; }
Property Value
Type Description
bool
| Edit this page View Source

RequireAuthorization

This account must individually approve other users for those users to hold this account's issued currencies.

Declaration
[JsonPropertyName("requireAuthorization")]
public bool RequireAuthorization { get; set; }
Property Value
Type Description
bool
| Edit this page View Source

RequireDestinationTag

Requires incoming payments to specify a Destination Tag.

Declaration
[JsonPropertyName("requireDestinationTag")]
public bool RequireDestinationTag { get; set; }
Property Value
Type Description
bool
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX