Show / Hide Table of Contents

Class AccountInfoRequest

The account_info command retrieves information about an account, its activity, and its XRP balance.
All information retrieved is relative to a particular version of the ledger. Returns an AccountInfo.

Inheritance
object
BaseRequest
BaseLedgerRequest
AccountInfoRequest
Inherited Members
BaseLedgerRequest.LedgerHash
BaseLedgerRequest.LedgerIndex
BaseRequest.Id
BaseRequest.Command
BaseRequest.ApiVersion
Namespace: Xrpl.Models.Methods
Assembly: Xrpl.dll
Syntax
public class AccountInfoRequest : BaseLedgerRequest

Constructors

| Edit this page View Source

AccountInfoRequest(string)

Declaration
public AccountInfoRequest(string account)
Parameters
Type Name Description
string account

Properties

| Edit this page View Source

Account

A unique identifier for the account, most commonly the account's address.

Declaration
[JsonPropertyName("account")]
public string Account { get; set; }
Property Value
Type Description
string
| Edit this page View Source

Queue

Whether to get info about this account's queued transactions.
Can only be used when querying for the data from the current open ledger.
Not available from servers in Reporting Mode.

Declaration
[JsonPropertyName("queue")]
public bool? Queue { get; set; }
Property Value
Type Description
bool?
| Edit this page View Source

SignerLists

Request SignerList objects associated with this account.

Declaration
[JsonPropertyName("signer_lists")]
public bool? SignerLists { get; set; }
Property Value
Type Description
bool?
| Edit this page View Source

Strict

If true, then the account field only accepts a public key or XRP Ledger address.
Otherwise, account can be a secret or passphrase (not recommended). The default is false.

Declaration
[JsonPropertyName("strict")]
public bool? Strict { get; set; }
Property Value
Type Description
bool?
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX