Show / Hide Table of Contents

Class AccountLines

Response expected from an AccountLinesRequest.

Inheritance
object
AccountLines
Namespace: Xrpl.Models.Methods
Assembly: Xrpl.dll
Syntax
public class AccountLines

Properties

| Edit this page View Source

Account

Unique Address of the account this request corresponds to.
This is the "perspective account" for purpose of the trust lines.

Declaration
[JsonPropertyName("account")]
public string Account { get; set; }
Property Value
Type Description
string
| Edit this page View Source

LedgerCurrentIndex

The ledger index of the current open ledger, which was used when retrieving this information.

Declaration
[JsonPropertyName("ledger_current_index")]
public uint? LedgerCurrentIndex { get; set; }
Property Value
Type Description
uint?
| Edit this page View Source

LedgerHash

The identifying hash the ledger version that was used when retrieving this data.

Declaration
[JsonPropertyName("ledger_hash")]
public string LedgerHash { get; set; }
Property Value
Type Description
string
| Edit this page View Source

LedgerIndex

The ledger index of the ledger version that was used when retrieving this data.

Declaration
[JsonPropertyName("ledger_index")]
public uint? LedgerIndex { get; set; }
Property Value
Type Description
uint?
| Edit this page View Source

Limit

Declaration
[JsonPropertyName("limit")]
public int? Limit { get; set; }
Property Value
Type Description
int?
| Edit this page View Source

Marker

Server-defined value indicating the response is paginated.
Pass this to the next call to resume where this call left off.
Omitted when there are No additional pages after this one.

Declaration
[JsonPropertyName("marker")]
public object Marker { get; set; }
Property Value
Type Description
object
| Edit this page View Source

TrustLines

Array of trust line objects.
If the number of trust lines is large, only returns up to the limit at a time.

Declaration
[JsonPropertyName("lines")]
public List<TrustLine> TrustLines { get; set; }
Property Value
Type Description
List<TrustLine>
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX