Show / Hide Table of Contents

Class AccountNFTs

Response expected from an AccountNFTsRequest.

Inheritance
object
AccountNFTs
Namespace: Xrpl.Models.Methods
Assembly: Xrpl.dll
Syntax
public class AccountNFTs

Properties

| Edit this page View Source

Account

The account requested.

Declaration
[JsonPropertyName("account")]
public string Account { get; set; }
Property Value
Type Description
string
| Edit this page View Source

LedgerCurrentIndex

The ledger index of the current open ledger, which was used when retrieving this information.

Declaration
[JsonPropertyName("ledger_current_index")]
public uint? LedgerCurrentIndex { get; set; }
Property Value
Type Description
uint?
| Edit this page View Source

Limit

The limit that was used to fulfill this request.

Declaration
[JsonPropertyName("limit")]
public int? Limit { get; set; }
Property Value
Type Description
int?
| Edit this page View Source

Marker

Server-defined value indicating the response is paginated.
Pass this to the next call to resume where this call left off.
Omitted when there are No additional pages after this one.

Declaration
[JsonPropertyName("marker")]
public object Marker { get; set; }
Property Value
Type Description
object
| Edit this page View Source

NFTs

A list of NFTs owned by the specified account.

Declaration
[JsonPropertyName("account_nfts")]
public List<NFT> NFTs { get; set; }
Property Value
Type Description
List<NFT>
| Edit this page View Source

Validated

If true, this data comes from a validated ledger.

Declaration
[JsonPropertyName("validated")]
public bool Validated { get; set; }
Property Value
Type Description
bool
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX