Show / Hide Table of Contents

Class AccountObjects

Response expected from an AccountObjectsRequest.

Inheritance
object
AccountObjects
Namespace: Xrpl.Models.Methods
Assembly: Xrpl.dll
Syntax
public class AccountObjects

Properties

| Edit this page View Source

Account

Unique Address of the account this request corresponds to.

Declaration
[JsonPropertyName("account")]
public string Account { get; set; }
Property Value
Type Description
string
| Edit this page View Source

AccountObjectList

Array of objects owned by this account.
Each object is in its raw ledger format.

Declaration
[JsonPropertyName("account_objects")]
public List<BaseLedgerEntry> AccountObjectList { get; set; }
Property Value
Type Description
List<BaseLedgerEntry>
| Edit this page View Source

LedgerCurrentIndex

The ledger index of the current in-progress ledger version, which was used to generate this response.

Declaration
[JsonPropertyName("ledger_current_index")]
public uint? LedgerCurrentIndex { get; set; }
Property Value
Type Description
uint?
| Edit this page View Source

LedgerHash

The identifying hash of the ledger that was used to generate this response.

Declaration
[JsonPropertyName("ledger_hash")]
public string LedgerHash { get; set; }
Property Value
Type Description
string
| Edit this page View Source

LedgerIndex

The ledger index of the ledger version that was used to generate this response.

Declaration
[JsonPropertyName("ledger_index")]
public uint? LedgerIndex { get; set; }
Property Value
Type Description
uint?
| Edit this page View Source

Limit

The limit that was used in this request, if any.

Declaration
[JsonPropertyName("limit")]
public int? Limit { get; set; }
Property Value
Type Description
int?
| Edit this page View Source

Marker

Server-defined value indicating the response is paginated.
Pass this to the next call to resume where this call left off.
Omitted when there are no additional pages after this one.

Declaration
[JsonPropertyName("marker")]
public object Marker { get; set; }
Property Value
Type Description
object
| Edit this page View Source

Validated

If included and set to true, the information in this response comes from a validated ledger version.
Otherwise, the information is subject to change.

Declaration
[JsonPropertyName("validated")]
public bool Validated { get; set; }
Property Value
Type Description
bool
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX