Show / Hide Table of Contents

Class AccountOffers

Response expected from an form an AccountOffersRequest.

Inheritance
object
AccountOffers
Namespace: Xrpl.Models.Methods
Assembly: Xrpl.dll
Syntax
public class AccountOffers

Properties

| Edit this page View Source

Account

Unique Address identifying the account that made the offers.

Declaration
[JsonPropertyName("account")]
public string Account { get; set; }
Property Value
Type Description
string
| Edit this page View Source

LedgerCurrentIndex

The ledger index of the current in-progress ledger version, which was used when retrieving this data.

Declaration
[JsonPropertyName("ledger_current_index")]
public uint? LedgerCurrentIndex { get; set; }
Property Value
Type Description
uint?
| Edit this page View Source

LedgerHash

The identifying hash of the ledger version that was used when retrieving this data.

Declaration
[JsonPropertyName("ledger_hash")]
public string LedgerHash { get; set; }
Property Value
Type Description
string
| Edit this page View Source

LedgerIndex

The ledger index of the ledger version that was used when retrieving this data, as requested.

Declaration
[JsonPropertyName("ledger_index")]
public uint? LedgerIndex { get; set; }
Property Value
Type Description
uint?
| Edit this page View Source

Marker

Server-defined value indicating the response is paginated.
Pass this to the next call to resume where this call left off.
Omitted when there are no pages of information after this one.

Declaration
[JsonPropertyName("marker")]
public object Marker { get; set; }
Property Value
Type Description
object
| Edit this page View Source

Offers

Array of objects, where each object represents an offer made by this account that is outstanding as of the requested ledger version.
If the number of offers is large, only returns up to limit at a time.

Declaration
[JsonPropertyName("offers")]
public List<Offer> Offers { get; set; }
Property Value
Type Description
List<Offer>
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX