Show / Hide Table of Contents

Class AccountQueueData

Information about queued transactions sent by account.
This information describes the state of the local rippled server, which may be different from other servers in the peer-to-peer XRP Ledger network.
Some fields may be omitted because the values are calculated "lazily" by the queuing mechanism.

Inheritance
object
AccountQueueData
Namespace: Xrpl.Models.Methods
Assembly: Xrpl.dll
Syntax
public class AccountQueueData

Properties

| Edit this page View Source

AuthChangeQueued

Whether a transaction in the queue changes this address's ways of authorizing transactions. If true, this address can queue no further transactions until that transaction has been executed or dropped from the queue.

Declaration
[JsonPropertyName("auth_change_queued")]
public bool? AuthChangeQueued { get; set; }
Property Value
Type Description
bool?
| Edit this page View Source

HighestSequence

The highest Sequence Number among transactions queued by this address.

Declaration
[JsonPropertyName("highest_sequence")]
public int? HighestSequence { get; set; }
Property Value
Type Description
int?
| Edit this page View Source

LowestSequence

The lowest Sequence Number among transactions queued by this address.

Declaration
[JsonPropertyName("lowest_sequence")]
public int? LowestSequence { get; set; }
Property Value
Type Description
int?
| Edit this page View Source

MaxSpendDropsTotal

Integer amount of drops of XRP that could be debited from this address if every transaction in the queue consumes the maximum amount of XRP possible.

Declaration
[JsonPropertyName("max_spend_drops_total")]
public string MaxSpendDropsTotal { get; set; }
Property Value
Type Description
string
| Edit this page View Source

Transactions

Information about each queued transaction from this address.

Declaration
[JsonPropertyName("transactions")]
public List<AccountQueueTransaction> Transactions { get; set; }
Property Value
Type Description
List<AccountQueueTransaction>
| Edit this page View Source

TxnCount

Number of queued transactions from this address.

Declaration
[JsonPropertyName("txn_count")]
public int TxnCount { get; set; }
Property Value
Type Description
int
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX