Show / Hide Table of Contents

Class BaseLedgerRequest

Inheritance
object
BaseRequest
BaseLedgerRequest
AMMInfoRequest
AccountChannelsRequest
AccountCurrenciesRequest
AccountInfoRequest
AccountLinesRequest
AccountNFTsRequest
AccountObjectsRequest
AccountOffersRequest
AccountTransactionsRequest
BookOffersRequest
DepositAuthorizedRequest
GatewayBalancesRequest
LedgerDataRequest
LedgerEntryRequest
LedgerRequest
NFTBuyOffersRequest
NFTSellOffersRequest
NoRippleCheckRequest
RipplePathFindRequest
Inherited Members
BaseRequest.Id
BaseRequest.Command
BaseRequest.ApiVersion
Namespace: Xrpl.Models.Methods
Assembly: Xrpl.dll
Syntax
public class BaseLedgerRequest : BaseRequest

Constructors

| Edit this page View Source

BaseLedgerRequest()

Declaration
public BaseLedgerRequest()
| Edit this page View Source

BaseLedgerRequest(Guid)

Declaration
public BaseLedgerRequest(Guid requestId)
Parameters
Type Name Description
Guid requestId

Properties

| Edit this page View Source

LedgerHash

20-byte hex string for the ledger version to use.

Declaration
[JsonPropertyName("ledger_hash")]
public string LedgerHash { get; set; }
Property Value
Type Description
string
| Edit this page View Source

LedgerIndex

The ledger index of the ledger to use, or a shortcut string to choose a ledger automatically.

Declaration
[JsonPropertyName("ledger_index")]
[JsonConverter(typeof(LedgerIndexConverter))]
public LedgerIndex LedgerIndex { get; set; }
Property Value
Type Description
LedgerIndex
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX