Show / Hide Table of Contents

Class BaseRequest

Inheritance
object
BaseRequest
BaseLedgerRequest
ChannelAuthorizeRequest
ChannelVerifyRequest
FeeRequest
LedgerClosedRequest
LedgerCurrentRequest
PathFindCloseRequest
PathFindCreateRequest
PathFindStatusRequest
PingRequest
RandomRequest
ServerFeaturesRequest
ServerInfoRequest
ServerStateRequest
SimulateRequest
SubmitRequest
SubscribeRequest
TxRequest
UnsubscribeRequest
Namespace: Xrpl.Models.Methods
Assembly: Xrpl.dll
Syntax
public class BaseRequest

Constructors

| Edit this page View Source

BaseRequest()

Declaration
public BaseRequest()
| Edit this page View Source

BaseRequest(Guid)

Declaration
public BaseRequest(Guid id)
Parameters
Type Name Description
Guid id

Properties

| Edit this page View Source

ApiVersion

The API version to use.
If omitted, use version 1.

Declaration
[JsonPropertyName("api_version")]
public uint? ApiVersion { get; set; }
Property Value
Type Description
uint?
| Edit this page View Source

Command

Declaration
[JsonPropertyName("command")]
public string Command { get; set; }
Property Value
Type Description
string
| Edit this page View Source

Id

A unique value to identify this request.
The response to this request uses the same id field.
This way, even if responses arrive out of order, you know which request prompted which response.

Declaration
[JsonPropertyName("id")]
public object? Id { get; set; }
Property Value
Type Description
object
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX