Show / Hide Table of Contents

Class BookCurrency

Order book currency

Inheritance
object
BookCurrency
Namespace: Xrpl.Models.Methods
Assembly: Xrpl.dll
Syntax
public class BookCurrency

Properties

| Edit this page View Source

Currency

Currency code

Declaration
[JsonPropertyName("currency")]
public string Currency { get; set; }
Property Value
Type Description
string
| Edit this page View Source

Issuer

Currency Issuer

Declaration
[JsonPropertyName("issuer")]
public string Issuer { get; set; }
Property Value
Type Description
string

Methods

| Edit this page View Source

Equals(object)

Determines whether the specified object is equal to the current object.

Declaration
public override bool Equals(object obj)
Parameters
Type Name Description
object obj

The object to compare with the current object.

Returns
Type Description
bool

true if the specified object is equal to the current object; otherwise, false.

Overrides
object.Equals(object)
| Edit this page View Source

Equals(BookCurrency)

Indicates whether the current object is equal to another object of the same type.

Declaration
public bool Equals(BookCurrency other)
Parameters
Type Name Description
BookCurrency other

An object to compare with this object.

Returns
Type Description
bool

true if the current object is equal to the other parameter; otherwise, false.

| Edit this page View Source

GetHashCode()

Serves as the default hash function.

Declaration
public override int GetHashCode()
Returns
Type Description
int

A hash code for the current object.

Overrides
object.GetHashCode()
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX