Show / Hide Table of Contents

Class Channel

Payment channel owned by account. https://xrpl.org/account_channels.html

Inheritance
object
Channel
Namespace: Xrpl.Models.Methods
Assembly: Xrpl.dll
Syntax
public class Channel

Properties

| Edit this page View Source

Account

The owner of the channel, as an Address.

Declaration
[JsonPropertyName("account")]
public string Account { get; set; }
Property Value
Type Description
string
| Edit this page View Source

Amount

The total amount of XRP, in drops allocated to this channel.

Declaration
[JsonPropertyName("amount")]
public string Amount { get; set; }
Property Value
Type Description
string
| Edit this page View Source

Balance

The total amount of XRP, in drops, paid out from this channel, as of the ledger version used.
(You can calculate the amount of XRP left in the channel by subtracting balance from amount.)

Declaration
[JsonPropertyName("balance")]
public string Balance { get; set; }
Property Value
Type Description
string
| Edit this page View Source

CancelAfter

(May be omitted) Time, in seconds since the Ripple Epoch, of this channel's immutable expiration, if one was specified at channel creation.
If this is before the close time of the most recent validated ledger, the channel is expired.

Declaration
[JsonPropertyName("cancel_after")]
[JsonConverter(typeof(RippleDateTimeConverter))]
public DateTime? CancelAfter { get; set; }
Property Value
Type Description
Nullable
| Edit this page View Source

ChannelId

A unique ID for this channel, as a 64-character hexadecimal string.
This is also the ID of the channel object in the ledger's state data.

Declaration
[JsonPropertyName("channel_id")]
public string ChannelId { get; set; }
Property Value
Type Description
string
| Edit this page View Source

DestinationAccount

The destination account of the channel, as an Address.
Only this account can receive the XRP in the channel while it is open.

Declaration
[JsonPropertyName("destination_account")]
public string DestinationAccount { get; set; }
Property Value
Type Description
string
| Edit this page View Source

DestinationTag

(May be omitted) A 32-bit unsigned integer to use as a destination tag for payments through this channel, if one was specified at channel creation.
This indicates the payment channel's beneficiary or other purpose at the destination account.

Declaration
[JsonPropertyName("destination_tag")]
public uint? DestinationTag { get; set; }
Property Value
Type Description
uint?
| Edit this page View Source

Expiration

(May be omitted) Time, in seconds since the Ripple Epoch, when this channel is set to expire.
This expiration date is mutable.
If this is before the close time of the most recent validated ledger, the channel is expired.

Declaration
[JsonPropertyName("expiration")]
[JsonConverter(typeof(RippleDateTimeConverter))]
public DateTime? Expiration { get; set; }
Property Value
Type Description
Nullable
| Edit this page View Source

PublicKey

(May be omitted) The public key for the payment channel in the XRP Ledger's base58 format.
Signed claims against this channel must be redeemed with the matching key pair.

Declaration
[JsonPropertyName("public_key")]
public string PublicKey { get; set; }
Property Value
Type Description
string
| Edit this page View Source

PublicKeyHex

(May be omitted) The public key for the payment channel in hexadecimal format, if one was specified at channel creation.
Signed claims against this channel must be redeemed with the matching key pair.

Declaration
[JsonPropertyName("public_key_hex")]
public string PublicKeyHex { get; set; }
Property Value
Type Description
string
| Edit this page View Source

SettleDelay

The number of seconds the payment channel must stay open after the owner of the channel requests to close it.

Declaration
[JsonPropertyName("settle_delay")]
public uint SettleDelay { get; set; }
Property Value
Type Description
uint
| Edit this page View Source

SourceTag

(May be omitted) A 32-bit unsigned integer to use as a source tag for payments through this payment channel, if one was specified at channel creation.
This indicates the payment channel's originator or other purpose at the source account.
Conventionally, if you bounce payments from this channel, you should specify this value in the DestinationTag of the return payment.

Declaration
[JsonPropertyName("source_tag")]
public uint? SourceTag { get; set; }
Property Value
Type Description
uint?
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX