Show / Hide Table of Contents

Class ChannelAuthorizeRequest

The channel_authorize method creates a signature that can be used to redeem a specific amount of XRP from a payment channel.
The request must specify exactly one of secret, seed, seed_hex, or passphrase. *** Warning: Do not send secret keys to untrusted servers or through unsecured network connections. ***
(This includes the secret, seed, seed_hex, or passphrase fields of this request.))
You should only use this method on a secure, encrypted network connection to a server you run or fully trust with your funds.
Otherwise, eavesdroppers could use your secret key to sign claims and take all the money from this payment channel and anything else using the same key pair.
See Set Up Secure Signing for instructions.

Inheritance
object
BaseRequest
ChannelAuthorizeRequest
Inherited Members
BaseRequest.Id
BaseRequest.Command
BaseRequest.ApiVersion
Namespace: Xrpl.Models.Methods
Assembly: Xrpl.dll
Syntax
public class ChannelAuthorizeRequest : BaseRequest

Constructors

| Edit this page View Source

ChannelAuthorizeRequest()

Declaration
public ChannelAuthorizeRequest()

Properties

| Edit this page View Source

Amount

Cumulative amount of XRP, in drops, to authorize.
If the destination has already received a lesser amount of XRP from this channel, the signature created by this method can be redeemed for the difference.

Declaration
[JsonPropertyName("amount")]
[JsonConverter(typeof(GenericStringConverter<ulong>))]
public ulong Amount { get; set; }
Property Value
Type Description
ulong
| Edit this page View Source

ChannelId

The unique ID of the payment channel to use.

Declaration
[JsonPropertyName("channel_id")]
public string ChannelId { get; set; }
Property Value
Type Description
string
| Edit this page View Source

KeyType

*** Do not send your secret to a server that you do not control or do not trust. ***
(Optional) The signing algorithm of the cryptographic key pair provided.
Valid types are secp256k1 or ed25519.
The default is secp256k1.

Declaration
[JsonPropertyName("key_type")]
public string KeyType { get; set; }
Property Value
Type Description
string
| Edit this page View Source

Passphrase

*** Do not send your secret to a server that you do not control or do not trust. ***
(Optional) A string passphrase to use to sign the claim.
This must be the same key pair as the public key specified in the channel.
The key derived from this passphrase must match the public key specified in the channel.
If provided, you must also specify the key_type.
Cannot be used with secret, seed, or seed_hex.

Declaration
[JsonPropertyName("passphrase")]
public string Passphrase { get; set; }
Property Value
Type Description
string
| Edit this page View Source

RippleAmount

Declaration
[JsonIgnore]
public double RippleAmount { get; set; }
Property Value
Type Description
double
| Edit this page View Source

Secret

*** Do not send your secret to a server that you do not control or do not trust. ***
(Optional) The secret key to use to sign the claim.
This must be the same key pair as the public key specified in the channel.
Cannot be used with seed, seed_hex, or passphrase.

Declaration
[JsonPropertyName("secret")]
public string Secret { get; set; }
Property Value
Type Description
string
| Edit this page View Source

Seed

*** Do not send your secret to a server that you do not control or do not trust. ***
(Optional) The secret seed to use to sign the claim.
This must be the same key pair as the public key specified in the channel.
Must be in the XRP Ledger's base58 format.
If provided, you must also specify the key_type.
Cannot be used with secret, seed_hex, or passphrase.

Declaration
[JsonPropertyName("seed")]
public string Seed { get; set; }
Property Value
Type Description
string
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX