Show / Hide Table of Contents

Class ChannelVerifyRequest

The channel_verify method checks the validity of a signature that can be used to redeem a specific amount of XRP from a payment channel.
Expects a response in the form of a ChannelVerifyResponse.

Inheritance
object
BaseRequest
ChannelVerifyRequest
Inherited Members
BaseRequest.Id
BaseRequest.Command
BaseRequest.ApiVersion
Namespace: Xrpl.Models.Methods
Assembly: Xrpl.dll
Syntax
public class ChannelVerifyRequest : BaseRequest

Constructors

| Edit this page View Source

ChannelVerifyRequest()

Declaration
public ChannelVerifyRequest()

Properties

| Edit this page View Source

Amount

The amount of XRP, in drops, the provided signature authorizes.

Declaration
[JsonPropertyName("amount")]
[JsonConverter(typeof(GenericStringConverter<ulong>))]
public ulong Amount { get; set; }
Property Value
Type Description
ulong
| Edit this page View Source

ChannelId

The Channel ID of the channel that provides the XRP.
This is a 64-character hexadecimal string.

Declaration
[JsonPropertyName("channel_id")]
public string ChannelId { get; set; }
Property Value
Type Description
string
| Edit this page View Source

PublicKey

The public key of the channel and the key pair that was used to create the signature, in hexadecimal or the XRP Ledger's base58 format.

Declaration
[JsonPropertyName("public_key")]
public string PublicKey { get; set; }
Property Value
Type Description
string
| Edit this page View Source

RippleAmount

Declaration
[JsonIgnore]
public double RippleAmount { get; set; }
Property Value
Type Description
double
| Edit this page View Source

Signature

The signature to verify, in hexadecimal.

Declaration
[JsonPropertyName("signature")]
public string Signature { get; set; }
Property Value
Type Description
string
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX