Show / Hide Table of Contents

Class CredentialQuery

Specify the Credential to retrieve. If a string, must be the ledger entry ID of the entry, as hexadecimal.If an object, requires subject, issuer, and credential_type sub-fields.

Inheritance
object
CredentialQuery
Namespace: Xrpl.Models.Methods
Assembly: Xrpl.dll
Syntax
public class CredentialQuery

Properties

| Edit this page View Source

CredentialType

The type of the credential, as issued.

Declaration
[JsonPropertyName("credential_type")]
public string CredentialType { get; set; }
Property Value
Type Description
string
| Edit this page View Source

Issuer

The account that issued the credential.

Declaration
[JsonPropertyName("issuer")]
public string Issuer { get; set; }
Property Value
Type Description
string
| Edit this page View Source

Subject

The account that is the subject of the credential.

Declaration
[JsonPropertyName("subject")]
public string Subject { get; set; }
Property Value
Type Description
string
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX