Show / Hide Table of Contents

Class DepositAuthorized

Response expected from a DepositAuthorizedRequest.

Inheritance
object
DepositAuthorized
Namespace: Xrpl.Models.Methods
Assembly: Xrpl.dll
Syntax
public class DepositAuthorized

Properties

| Edit this page View Source

Credentials

(Optional, XLS-70) The credentials specified in the request, echoed back.

Declaration
[JsonPropertyName("credentials")]
public List<string> Credentials { get; set; }
Property Value
Type Description
List<string>
| Edit this page View Source

DestinationAccount

The destination account specified in the request.

Declaration
[JsonPropertyName("destination_account")]
public string DestinationAccount { get; set; }
Property Value
Type Description
string
| Edit this page View Source

IsDepositAuthorized

Whether the specified source account is authorized to send payments directly to the destination account. If true, depositing to the destination account is either possible without authorization, the source account has the necessary preauthorization, or the destination account does not require Deposit Authorization.

Declaration
[JsonPropertyName("deposit_authorized")]
public bool IsDepositAuthorized { get; set; }
Property Value
Type Description
bool
| Edit this page View Source

LedgerCurrentIndex

(May be omitted) The ledger index of the current in-progress ledger version, used when no ledger version was specified in the request.

Declaration
[JsonPropertyName("ledger_current_index")]
public uint? LedgerCurrentIndex { get; set; }
Property Value
Type Description
uint?
| Edit this page View Source

LedgerHash

(May be omitted) The hash of the ledger version used to generate this response.

Declaration
[JsonPropertyName("ledger_hash")]
public string LedgerHash { get; set; }
Property Value
Type Description
string
| Edit this page View Source

LedgerIndex

(May be omitted) The ledger index of the ledger version used to generate this response.

Declaration
[JsonPropertyName("ledger_index")]
public uint? LedgerIndex { get; set; }
Property Value
Type Description
uint?
| Edit this page View Source

SourceAccount

The source account specified in the request.

Declaration
[JsonPropertyName("source_account")]
public string SourceAccount { get; set; }
Property Value
Type Description
string
| Edit this page View Source

Validated

(May be omitted) If true, the information comes from a validated ledger version.

Declaration
[JsonPropertyName("validated")]
public bool? Validated { get; set; }
Property Value
Type Description
bool?
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX