Show / Hide Table of Contents

Class Drops

The transaction cost

Inheritance
object
Drops
Namespace: Xrpl.Models.Methods
Assembly: Xrpl.dll
Syntax
public class Drops

Properties

| Edit this page View Source

BaseFee

The transaction cost required for a reference transaction to be included in a ledger under minimum load, represented in drops of XRP.

Declaration
[JsonPropertyName("base_fee")]
[JsonConverter(typeof(GenericStringConverter<uint>))]
public uint BaseFee { get; set; }
Property Value
Type Description
uint
| Edit this page View Source

MedianFee

An approximation of the median transaction cost among transactions.
Included in the previous validated ledger, represented in drops of XRP.

Declaration
[JsonPropertyName("median_fee")]
[JsonConverter(typeof(GenericStringConverter<uint>))]
public uint MedianFee { get; set; }
Property Value
Type Description
uint
| Edit this page View Source

MinimumFee

The minimum transaction cost for a reference transaction to be queued for a later ledger, represented in drops of XRP.
If greater than base_fee, the transaction queue is full.

Declaration
[JsonPropertyName("minimum_fee")]
[JsonConverter(typeof(GenericStringConverter<uint>))]
public uint MinimumFee { get; set; }
Property Value
Type Description
uint
| Edit this page View Source

OpenLedgerFee

The minimum transaction cost that a reference transaction must pay to be included in the current open ledger, represented in drops of XRP.

Declaration
[JsonPropertyName("open_ledger_fee")]
[JsonConverter(typeof(GenericStringConverter<uint>))]
public uint OpenLedgerFee { get; set; }
Property Value
Type Description
uint
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX