Show / Hide Table of Contents

Class FeeRequest

The fee command reports the current state of the open-ledger requirements for the transaction cost.
This requires the FeeEscalation amendment to be enabled.
Expects a response in the form of a Fee.

Inheritance
object
BaseRequest
FeeRequest
Inherited Members
BaseRequest.Id
BaseRequest.Command
BaseRequest.ApiVersion
Namespace: Xrpl.Models.Methods
Assembly: Xrpl.dll
Syntax
public class FeeRequest : BaseRequest

Constructors

| Edit this page View Source

FeeRequest()

Declaration
public FeeRequest()
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX