Show / Hide Table of Contents

Class GatewayBalancesRequest

The gateway_balances command calculates the total balances issued by a given account, optionally excluding amounts held by operational addresses.
Expects a response in the form of a GatewayBalancesResponse.

Inheritance
object
BaseRequest
BaseLedgerRequest
GatewayBalancesRequest
Inherited Members
BaseLedgerRequest.LedgerHash
BaseLedgerRequest.LedgerIndex
BaseRequest.Id
BaseRequest.Command
BaseRequest.ApiVersion
Namespace: Xrpl.Models.Methods
Assembly: Xrpl.dll
Syntax
public class GatewayBalancesRequest : BaseLedgerRequest

Constructors

| Edit this page View Source

GatewayBalancesRequest(string)

Declaration
public GatewayBalancesRequest(string account)
Parameters
Type Name Description
string account

Properties

| Edit this page View Source

Account

The Address to check.
This should be the issuing address.

Declaration
[JsonPropertyName("account")]
public string Account { get; set; }
Property Value
Type Description
string
| Edit this page View Source

HotWallet

An operational address to exclude from the balances issued, or an array of Such addresses.

Declaration
[JsonPropertyName("hotwallet")]
[JsonConverter(typeof(StringOrArrayConverter))]
public object HotWallet { get; set; }
Property Value
Type Description
object
| Edit this page View Source

Strict

If true, only accept an address or public key for the account parameter.
Defaults to false.

Declaration
[JsonPropertyName("strict")]
public bool? Strict { get; set; }
Property Value
Type Description
bool?
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX