Show / Hide Table of Contents

Class GatewayBalancesResponse

Expected response from a GatewayBalancesRequest.

Inheritance
object
GatewayBalancesResponse
Namespace: Xrpl.Models.Methods
Assembly: Xrpl.dll
Syntax
[JsonConverter(typeof(GatewayBalancesResponseConverter))]
public class GatewayBalancesResponse

Properties

| Edit this page View Source

Account

The address of the account that issued the balances.

Declaration
[JsonPropertyName("account")]
public string Account { get; set; }
Property Value
Type Description
string
| Edit this page View Source

Assets

Total amounts held that are issued by others.
In the recommended configuration, the issuing address should have none.

Declaration
[JsonPropertyName("assets")]
public List<Currency> Assets { get; set; }
Property Value
Type Description
List<Currency>
| Edit this page View Source

Balances

Amounts issued to the hotwallet addresses from the request.
The keys are addresses and the values are arrays of currency amounts they hold.

Declaration
[JsonPropertyName("balances")]
public List<Currency> Balances { get; init; }
Property Value
Type Description
List<Currency>
| Edit this page View Source

FrozenBalances

Declaration
[JsonPropertyName("frozen_balances")]
public List<Currency> FrozenBalances { get; init; }
Property Value
Type Description
List<Currency>
| Edit this page View Source

LedgerHash

Declaration
[JsonPropertyName("ledger_hash")]
public string LedgerHash { get; set; }
Property Value
Type Description
string
| Edit this page View Source

LedgerIndex

Declaration
[JsonPropertyName("ledger_index")]
public uint? LedgerIndex { get; set; }
Property Value
Type Description
uint?
| Edit this page View Source

Obligations

Total amounts issued to addresses not excluded, as a map of currencies to the total value issued.

Declaration
[JsonPropertyName("obligations")]
public List<Currency> Obligations { get; init; }
Property Value
Type Description
List<Currency>
| Edit this page View Source

Validated

Declaration
[JsonPropertyName("validated")]
public bool? Validated { get; set; }
Property Value
Type Description
bool?
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX