Show / Hide Table of Contents

Interface IAccountTransaction

Namespace: Xrpl.Models.Methods
Assembly: Xrpl.dll
Syntax
public interface IAccountTransaction

Properties

| Edit this page View Source

CloseTimeIso

The ledger close time represented in ISO 8601 time format.

Declaration
DateTime? CloseTimeIso { get; set; }
Property Value
Type Description
Nullable
| Edit this page View Source

Hash

The unique hash identifier of the transaction.

Declaration
string Hash { get; set; }
Property Value
Type Description
string
| Edit this page View Source

LedgerHash

(Validated transactions only) The identifying hash of the ledger version that includes this transaction

Declaration
string LedgerHash { get; set; }
Property Value
Type Description
string
| Edit this page View Source

LedgerIndex

(Validated transactions only) The ledger index of the ledger version that includes this transaction.

Declaration
ulong? LedgerIndex { get; set; }
Property Value
Type Description
ulong?
| Edit this page View Source

Meta

(Validated transactions only) The transaction metadata, which shows the exact outcome of the transaction in detail.

Declaration
Meta Meta { get; set; }
Property Value
Type Description
Meta
| Edit this page View Source

Transaction

(JSON mode) JSON object defining the transaction.

Declaration
TransactionResponse Transaction { get; }
Property Value
Type Description
TransactionResponse
| Edit this page View Source

Validated

If true, this transaction is included in a validated ledger and its outcome is final.
Responses from the transaction stream should always be validated.

Declaration
bool Validated { get; set; }
Property Value
Type Description
bool
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX