Show / Hide Table of Contents

Class LastClose

Information about the last time the server closed a ledger, including the amount of time it took to reach a consensus and the number of trusted validators participating.

Inheritance
object
LastClose
Namespace: Xrpl.Models.Methods
Assembly: Xrpl.dll
Syntax
public class LastClose

Properties

| Edit this page View Source

ConvergeTimeS

The amount of time it took to reach a consensus on the most recently validated ledger version, in seconds.

Declaration
[JsonPropertyName("converge_time_s")]
public double ConvergeTimeS { get; set; }
Property Value
Type Description
double
| Edit this page View Source

Proposers

How many trusted validators the server considered (including itself,if configured as a validator) in the consensus process for the most recently validated ledger version.

Declaration
[JsonPropertyName("proposers")]
public int Proposers { get; set; }
Property Value
Type Description
int
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX