Show / Hide Table of Contents

Class LedgerClosedRequest

The ledger_closed method returns the unique identifiers of the most recently closed ledger.
Expects a response in the form of a LOBaseLedger.

Inheritance
object
BaseRequest
LedgerClosedRequest
Inherited Members
BaseRequest.Id
BaseRequest.Command
BaseRequest.ApiVersion
Namespace: Xrpl.Models.Methods
Assembly: Xrpl.dll
Syntax
public class LedgerClosedRequest : BaseRequest

Constructors

| Edit this page View Source

LedgerClosedRequest()

Declaration
public LedgerClosedRequest()
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX