Show / Hide Table of Contents

Class LedgerCurrentRequest

The ledger_current method returns the unique identifiers of the current in-progress ledger.
Expects a response in the form of a LOLedgerCurrentIndex

Inheritance
object
BaseRequest
LedgerCurrentRequest
Inherited Members
BaseRequest.Id
BaseRequest.Command
BaseRequest.ApiVersion
Namespace: Xrpl.Models.Methods
Assembly: Xrpl.dll
Syntax
public class LedgerCurrentRequest : BaseRequest

Constructors

| Edit this page View Source

LedgerCurrentRequest()

Declaration
public LedgerCurrentRequest()
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX