Show / Hide Table of Contents

Class LedgerDataRequest

The ledger_data method retrieves contents of the specified ledger.
You can iterate through several calls to retrieve the entire contents of a single ledger version.

Inheritance
object
BaseRequest
BaseLedgerRequest
LedgerDataRequest
Inherited Members
BaseLedgerRequest.LedgerHash
BaseLedgerRequest.LedgerIndex
BaseRequest.Id
BaseRequest.Command
BaseRequest.ApiVersion
Namespace: Xrpl.Models.Methods
Assembly: Xrpl.dll
Syntax
public class LedgerDataRequest : BaseLedgerRequest

Constructors

| Edit this page View Source

LedgerDataRequest()

Declaration
public LedgerDataRequest()

Properties

| Edit this page View Source

Binary

If set to true, return ledger objects as hashed hex strings instead of JSON.

Declaration
[JsonPropertyName("binary")]
public bool? Binary { get; set; }
Property Value
Type Description
bool?
| Edit this page View Source

LedgerEntryType

Filter results to a specific type of ledger entry. This field accepts canonical names of ledger entry types (case insensitive) or short names. If omitted, return ledger entries of all types.

Declaration
[JsonPropertyName("type")]
[JsonConverter(typeof(LedgerEntryTypeConverter))]
public LedgerEntryType? LedgerEntryType { get; set; }
Property Value
Type Description
LedgerEntryType?
| Edit this page View Source

Limit

Limit the number of ledger objects to retrieve.
The server is not required to honor this value.

Declaration
[JsonPropertyName("limit")]
public uint? Limit { get; set; }
Property Value
Type Description
uint?
| Edit this page View Source

Marker

Value from a previous paginated response.
Resume retrieving data where that response left off.

Declaration
[JsonPropertyName("marker")]
public object? Marker { get; set; }
Property Value
Type Description
object
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX