Show / Hide Table of Contents

Class LedgerEntryRequest

The ledger_entry method returns a single ledger object from the XRP Ledger in its raw format.
Expects a response in the form of a LedgerEntryResponse.

Inheritance
object
BaseRequest
BaseLedgerRequest
LedgerEntryRequest
Inherited Members
BaseLedgerRequest.LedgerHash
BaseLedgerRequest.LedgerIndex
BaseRequest.Id
BaseRequest.Command
BaseRequest.ApiVersion
Namespace: Xrpl.Models.Methods
Assembly: Xrpl.dll
Syntax
public class LedgerEntryRequest : BaseLedgerRequest

Constructors

| Edit this page View Source

LedgerEntryRequest()

Declaration
public LedgerEntryRequest()

Properties

| Edit this page View Source

AccountRoot

Retrieve an AccountRoot object by its address.
This is roughly equivalent to the an {@link AccountInfoRequest}.

Declaration
[JsonPropertyName("account_root")]
public string AccountRoot { get; set; }
Property Value
Type Description
string
| Edit this page View Source

Amendments

Retrieve the Amendments entry, which contains a list of all enabled amendments on the network.
The Amendments entry. This value must be 7DB0788C020F02780A673DC74757F23823FA3014C1866E72CC4CD8B226CD6EF4

Declaration
[JsonPropertyName("amendments")]
public string Amendments { get; set; }
Property Value
Type Description
string
| Edit this page View Source

Amm

Retrieve an Automated Market Maker (AMM) object from the ledger. This is similar to amm_info method, but the ledger_entry version returns only the ledger entry as stored.

Declaration
[JsonPropertyName("amm")]
public AmmQuery? Amm { get; set; }
Property Value
Type Description
AmmQuery
| Edit this page View Source

Binary

If true, return the requested ledger object's contents as a hex string in the XRP Ledger's binary format.
Otherwise, return data in JSON format.
The default is false.

Declaration
[JsonPropertyName("binary")]
public bool? Binary { get; set; }
Property Value
Type Description
bool?
| Edit this page View Source

BridgeAccount

Declaration
[JsonPropertyName("bridge_account")]
public string? BridgeAccount { get; set; }
Property Value
Type Description
string
| Edit this page View Source

Check

The object ID of a Check object to retrieve.

Declaration
[JsonPropertyName("check")]
public string? Check { get; set; }
Property Value
Type Description
string
| Edit this page View Source

Credential

The object ID of a Check object to retrieve.

Declaration
[JsonPropertyName("credential")]
public CredentialQuery? Credential { get; set; }
Property Value
Type Description
CredentialQuery
| Edit this page View Source

DID

Retrieve a DID object by the account that owns it.

Declaration
[JsonPropertyName("did")]
public string? DID { get; set; }
Property Value
Type Description
string
| Edit this page View Source

Delegate

Declaration
[JsonPropertyName("delegate")]
public DelegateQuery? Delegate { get; set; }
Property Value
Type Description
DelegateQuery
| Edit this page View Source

DepositPreauth

Specify the DepositPreauth to retrieve. If a string, must be the ledger entry ID of the DepositPreauth entry, as hexadecimal. If an object, requires owner sub-field and either authorized or authorize_credentials sub-field.

Declaration
[JsonPropertyName("deposit_preauth")]
public DepositPreauthQuery? DepositPreauth { get; set; }
Property Value
Type Description
DepositPreauthQuery
| Edit this page View Source

Directory

The DirectoryNode to retrieve. If a string, must be the object ID of the directory, as hexadecimal.If an object, requires either dir_root o Owner as a sub-field, plus optionally a sub_index sub-field.

Declaration
[JsonPropertyName("directory")]
public DirectoryQuery? Directory { get; set; }
Property Value
Type Description
DirectoryQuery
| Edit this page View Source

Escrow

The Escrow object to retrieve. If a string, must be the object ID of the escrow, as hexadecimal. If an object, requires owner and seq sub-fields.

Declaration
[JsonPropertyName("escrow")]
public EscrowQuery? Escrow { get; set; }
Property Value
Type Description
EscrowQuery
| Edit this page View Source

IncludeDeleted

(Clio servers only) If set to true and the queried object has been deleted, return its complete data as it was prior to its deletion.
If set to false or not provided, and the queried object has been deleted, return objectNotFound (current behavior).

Declaration
[JsonPropertyName("include_deleted")]
public bool? IncludeDeleted { get; set; }
Property Value
Type Description
bool?
| Edit this page View Source

Index

Only one of the following properties should be defined in a single request.
org/ledger_entry.
html.
Retrieve any type of ledger object by its unique ID.

Declaration
[JsonPropertyName("index")]
public string Index { get; set; }
Property Value
Type Description
string
| Edit this page View Source

Loan

Specify the Loan to retrieve. If a string, must be the ledger entry ID of the Loan, as hexadecimal. If an object, requires loan_broker_id and loan_seq sub-fields.

Declaration
[JsonPropertyName("loan")]
public LoanQuery? Loan { get; set; }
Property Value
Type Description
LoanQuery
| Edit this page View Source

LoanBroker

Specify the LoanBroker to retrieve. If a string, must be the ledger entry ID of the LoanBroker, as hexadecimal. If an object, requires owner and seq sub-fields.

Declaration
[JsonPropertyName("loan_broker")]
public LoanBrokerQuery? LoanBroker { get; set; }
Property Value
Type Description
LoanBrokerQuery
| Edit this page View Source

MPToken

Object specifying the MPToken object to retrieve.
The mpt_issuance_id and account sub-fields are required.

Declaration
[JsonPropertyName("mptoken")]
public MPTokenQuery? MPToken { get; set; }
Property Value
Type Description
MPTokenQuery
| Edit this page View Source

MptIssuance

Retrieve a MPTokenIssuance object from the ledger.

Declaration
[JsonPropertyName("mpt_issuance")]
public string? MptIssuance { get; set; }
Property Value
Type Description
string
| Edit this page View Source

NftOffer

The ledger entry ID of an NFT offer to retrieve.

Declaration
[JsonPropertyName("nft_offer")]
public string? NftOffer { get; set; }
Property Value
Type Description
string
| Edit this page View Source

NftPage

Must be the object ID of the NFToken page, as hexadecimal

Declaration
[JsonPropertyName("nft_page")]
public string? NftPage { get; set; }
Property Value
Type Description
string
| Edit this page View Source

Offer

The Offer object to retrieve. If a string, interpret as the unique object ID to the Offer.If an object, requires the sub-fields account and seq to uniquely identify the offer.

Declaration
[JsonPropertyName("offer")]
public OfferQuery? Offer { get; set; }
Property Value
Type Description
OfferQuery
| Edit this page View Source

Oracle

The oracle identifier.

Declaration
[JsonPropertyName("oracle")]
public OracleQuery? Oracle { get; set; }
Property Value
Type Description
OracleQuery
| Edit this page View Source

PaymentChannel

The object ID of a PayChannel object to retrieve.

Declaration
[JsonPropertyName("payment_channel")]
public string? PaymentChannel { get; set; }
Property Value
Type Description
string
| Edit this page View Source

PermissionedDomain

Retrieve a PermissionedDomain object by its ID (hash).

Declaration
[JsonPropertyName("permissioned_domain")]
public PermissionedDomainQuery? PermissionedDomain { get; set; }
Property Value
Type Description
PermissionedDomainQuery
| Edit this page View Source

RippleState

Object specifying the RippleState (trust line) object to retrieve.
The accounts and currency sub-fields are required to uniquely specify the rippleState entry to retrieve.

Declaration
[JsonPropertyName("ripple_state")]
public RippleStateQuery RippleState { get; set; }
Property Value
Type Description
RippleStateQuery
| Edit this page View Source

SignerList

The ledger entry ID of the SignerList.

Declaration
[JsonPropertyName("signer_list")]
public string SignerList { get; set; }
Property Value
Type Description
string
| Edit this page View Source

Ticket

The Ticket object to retrieve. If a string, must be the object ID of the Ticket, as hexadecimal.If an object, the owner and ticket_sequence sub-fields are required to uniquely specify the Ticket entry.

Declaration
[JsonPropertyName("ticket")]
public TicketQuery? Ticket { get; set; }
Property Value
Type Description
TicketQuery
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX