Show / Hide Table of Contents

Class LedgerRequest

Retrieve information about the public ledger.
Expects a response in the form.

Inheritance
object
BaseRequest
BaseLedgerRequest
LedgerRequest
Inherited Members
BaseLedgerRequest.LedgerHash
BaseLedgerRequest.LedgerIndex
BaseRequest.Id
BaseRequest.Command
BaseRequest.ApiVersion
Namespace: Xrpl.Models.Methods
Assembly: Xrpl.dll
Syntax
public class LedgerRequest : BaseLedgerRequest

Constructors

| Edit this page View Source

LedgerRequest()

Declaration
public LedgerRequest()

Properties

| Edit this page View Source

Binary

If true, and transactions and expand are both also true, return transaction information in binary format (hexadecimal string) instead of JSON format.

Declaration
[JsonPropertyName("binary")]
public bool? Binary { get; set; }
Property Value
Type Description
bool?
| Edit this page View Source

Expand

Provide full JSON-formatted information for transaction/account information instead of only hashes.
Defaults to false.
Ignored unless you request transactions, accounts, or both.

Declaration
[JsonPropertyName("expand")]
public bool? Expand { get; set; }
Property Value
Type Description
bool?
| Edit this page View Source

OwnerFunds

If true, include owner_funds field in the metadata of OfferCreate transactions in the response.
Defaults to false.
Ignored unless transactions are included and expand is true.

Declaration
[JsonPropertyName("owner_funds")]
public bool? OwnerFunds { get; set; }
Property Value
Type Description
bool?
| Edit this page View Source

Queue

If true, and the command is requesting the current ledger, includes an array of queued transactions in the results.

Declaration
[JsonPropertyName("queue")]
public bool? Queue { get; set; }
Property Value
Type Description
bool?
| Edit this page View Source

Transactions

If true, return information on transactions in the specified ledger version.
Defaults to false.
Ignored if you did not specify a ledger version.

Declaration
[JsonPropertyName("transactions")]
public bool? Transactions { get; set; }
Property Value
Type Description
bool?
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX