Show / Hide Table of Contents

Class Levels

required transaction cost level

Inheritance
object
Levels
Namespace: Xrpl.Models.Methods
Assembly: Xrpl.dll
Syntax
public class Levels

Properties

| Edit this page View Source

MedianLevel

The median transaction cost among transactions in the previous validated ledger, represented in fee levels.

Declaration
[JsonPropertyName("median_level")]
[JsonConverter(typeof(GenericStringConverter<uint>))]
public uint MedianLevel { get; set; }
Property Value
Type Description
uint
| Edit this page View Source

MinimumLevel

The minimum transaction cost required to be queued for a future ledger, represented in fee levels.

Declaration
[JsonPropertyName("minimum_level")]
[JsonConverter(typeof(GenericStringConverter<uint>))]
public uint MinimumLevel { get; set; }
Property Value
Type Description
uint
| Edit this page View Source

OpenLedgerLevel

The minimum transaction cost required to be included in the current open ledger, represented in fee levels.

Declaration
[JsonPropertyName("open_ledger_level")]
[JsonConverter(typeof(GenericStringConverter<uint>))]
public uint OpenLedgerLevel { get; set; }
Property Value
Type Description
uint
| Edit this page View Source

ReferenceLevel

The equivalent of the minimum transaction cost, represented in fee levels.

Declaration
[JsonPropertyName("reference_level")]
[JsonConverter(typeof(GenericStringConverter<uint>))]
public uint ReferenceLevel { get; set; }
Property Value
Type Description
uint
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX