Show / Hide Table of Contents

Class Load

(Admin only) Detailed information about the current load state of the server.

Inheritance
object
Load
Namespace: Xrpl.Models.Methods
Assembly: Xrpl.dll
Syntax
public class Load

Properties

| Edit this page View Source

JobTypes

(Admin only) Information about the rate of different types of jobs the server is doing and how much time it spends on each.

Declaration
[JsonPropertyName("job_types")]
public List<JobType> JobTypes { get; set; }
Property Value
Type Description
List<JobType>
| Edit this page View Source

Threads

(Admin only) The number of threads in the server's main job pool.

Declaration
[JsonPropertyName("threads")]
public int Threads { get; set; }
Property Value
Type Description
int
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX