Show / Hide Table of Contents

Class LoanBrokerQuery

Specify the LoanBroker to retrieve. If a string, must be the ledger entry ID of the LoanBroker, as hexadecimal. If an object, requires owner and seq sub-fields.

Inheritance
object
LoanBrokerQuery
Namespace: Xrpl.Models.Methods
Assembly: Xrpl.dll
Syntax
public class LoanBrokerQuery

Properties

| Edit this page View Source

Owner

The account that controls the LoanBroker.

Declaration
[JsonPropertyName("owner")]
public string? Owner { get; set; }
Property Value
Type Description
string
| Edit this page View Source

Seq

The Sequence Number of the transaction that created the LoanBroker.

Declaration
[JsonPropertyName("seq")]
public uint? Seq { get; set; }
Property Value
Type Description
uint?
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX