Show / Hide Table of Contents

Class NFT

One NFToken that might be returned from an AccountNFTsRequest. https://xrpl.org/account_nfts.html#account_nfts

Inheritance
object
NFT
Namespace: Xrpl.Models.Methods
Assembly: Xrpl.dll
Syntax
public class NFT

Properties

| Edit this page View Source

Account

Declaration
[JsonPropertyName("account")]
public string Account { get; set; }
Property Value
Type Description
string
| Edit this page View Source

Flags

A bit-map of boolean flags enabled for this NFToken.
See NFToken Flags for possible values.

Declaration
[JsonPropertyName("Flags")]
[JsonConverter(typeof(NumberOrStringConverter))]
public string Flags { get; set; }
Property Value
Type Description
string
| Edit this page View Source

Issuer

The account that issued this NFToken.

Declaration
[JsonPropertyName("issuer")]
public string Issuer { get; set; }
Property Value
Type Description
string
| Edit this page View Source

NFTSerial

The token sequence number of this NFToken, which is unique for its issuer

Declaration
[JsonPropertyName("nft_serial")]
[JsonConverter(typeof(NumberOrStringConverter))]
public string NFTSerial { get; set; }
Property Value
Type Description
string
| Edit this page View Source

NFTokenID

The unique identifier of this NFToken, in hexadecimal.

Declaration
[JsonPropertyName("NFTokenID")]
public string NFTokenID { get; set; }
Property Value
Type Description
string
| Edit this page View Source

NFTokenTaxon

The unscrambled version of this token's taxon. Several tokens with the same taxon might represent instances of a limited series.

Declaration
[JsonPropertyName("NFTokenTaxon")]
public uint NFTokenTaxon { get; set; }
Property Value
Type Description
uint
| Edit this page View Source

TransactionFee

Declaration
[JsonPropertyName("transaction_fee")]
public uint TransactionFee { get; set; }
Property Value
Type Description
uint
| Edit this page View Source

TransferFee

The TransferFee value specifies the percentage fee, in units of 1/100,000, charged by the issuer for secondary sales of the token. Valid values for this field are between 0 and 50,000, inclusive. A value of 1 is equivalent to 0.001% or 1/10 of a basis point (bps), allowing transfer rates between 0% and 50%.

Declaration
[JsonPropertyName("TransferFee")]
[JsonConverter(typeof(NumberOrStringConverter))]
public string TransferFee { get; set; }
Property Value
Type Description
string
| Edit this page View Source

URI

The URI data associated with this NFToken, in hexadecimal.

Declaration
[JsonPropertyName("URI")]
public string URI { get; set; }
Property Value
Type Description
string
| Edit this page View Source

URIAsString

Declaration
[JsonIgnore]
public string URIAsString { get; }
Property Value
Type Description
string
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX