Show / Hide Table of Contents

Class NoRippleCheckRequest

The noripple_check command provides a quick way to check the status of th default ripple field for an account and the No Ripple flag of its trust lines, compared with the recommended settings.
Expects a response in the form of an {@link NoRippleCheckResponse}.

Inheritance
object
BaseRequest
BaseLedgerRequest
NoRippleCheckRequest
Inherited Members
BaseLedgerRequest.LedgerHash
BaseLedgerRequest.LedgerIndex
BaseRequest.Id
BaseRequest.Command
BaseRequest.ApiVersion
Namespace: Xrpl.Models.Methods
Assembly: Xrpl.dll
Syntax
public class NoRippleCheckRequest : BaseLedgerRequest

Constructors

| Edit this page View Source

NoRippleCheckRequest(string)

Declaration
public NoRippleCheckRequest(string account)
Parameters
Type Name Description
string account

Properties

| Edit this page View Source

Account

A unique identifier for the account, most commonly the account's address.

Declaration
[JsonPropertyName("account")]
public string Account { get; set; }
Property Value
Type Description
string
| Edit this page View Source

Limit

The maximum number of trust line problems to include in the results.
Defaults to 300.

Declaration
[JsonPropertyName("limit")]
public uint? Limit { get; set; }
Property Value
Type Description
uint?
| Edit this page View Source

Role

Whether the address refers to a gateway or user.
Recommendations depend on the role of the account.
Issuers must have Default Ripple enabled and must disable No Ripple on all trust lines.
Users should have Default Ripple disabled, and should enable No Ripple on all trust lines.

Declaration
[JsonPropertyName("role")]
[JsonConverter(typeof(EnumMemberValueConverter<RoleType>))]
public RoleType Role { get; set; }
Property Value
Type Description
RoleType
| Edit this page View Source

Transactions

If true, include an array of suggested transactions, as JSON objects, that you can sign and submit to fix the problems.
Defaults to false.

Declaration
[JsonPropertyName("transactions")]
public bool? Transactions { get; set; }
Property Value
Type Description
bool?
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX