Show / Hide Table of Contents

Class Offer

offer made by account that is outstanding as of the requested ledger version.

Inheritance
object
Offer
Namespace: Xrpl.Models.Methods
Assembly: Xrpl.dll
Syntax
public class Offer

Properties

| Edit this page View Source

Expiration

A time after which this offer is considered unfunded, as the number of seconds since the Ripple Epoch.
See also: Offer Expiration.

Declaration
[JsonPropertyName("expiration")]
[JsonConverter(typeof(RippleDateTimeConverter))]
public DateTime? Expiration { get; set; }
Property Value
Type Description
Nullable
| Edit this page View Source

Flags

Options set for this offer entry as bit-flags.

Declaration
[JsonPropertyName("flags")]
public uint Flags { get; set; }
Property Value
Type Description
uint
| Edit this page View Source

Quality

The exchange rate of the Offer, as the ratio of the original taker_pays divided by the original taker_gets.
When executing offers, the offer with the most favorable (lowest) quality is consumed first; offers with the same quality are executed from oldest to newest.

Declaration
[JsonPropertyName("quality")]
public string Quality { get; set; }
Property Value
Type Description
string
| Edit this page View Source

Sequence

Sequence number of the transaction that created this entry.

Declaration
[JsonPropertyName("seq")]
public uint Sequence { get; set; }
Property Value
Type Description
uint
| Edit this page View Source

TakerGets

The amount the account placing this Offer receives.

Declaration
[JsonPropertyName("taker_gets")]
[JsonConverter(typeof(CurrencyConverter))]
public Currency TakerGets { get; set; }
Property Value
Type Description
Currency
| Edit this page View Source

TakerPays

The amount the account placing this Offer pays.

Declaration
[JsonPropertyName("taker_pays")]
[JsonConverter(typeof(CurrencyConverter))]
public Currency TakerPays { get; set; }
Property Value
Type Description
Currency
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX