Show / Hide Table of Contents

Class Path

A path set is an array.
Each member of the path set is another array that represents an individual path.
Each member of a path is an object that specifies the step.

Inheritance
object
Path
Namespace: Xrpl.Models.Methods
Assembly: Xrpl.dll
Syntax
public class Path

Properties

| Edit this page View Source

Account

(Optional) If present, this path step represents rippling through the specified address.
MUST NOT be provided if this step specifies the currency or issuer fields.

Declaration
[JsonPropertyName("account")]
public string Account { get; set; }
Property Value
Type Description
string
| Edit this page View Source

CurrencyCode

(Optional) If present, this path step represents changing currencies through an order book.
The currency specified indicates the new currency.
MUST NOT be provided if this step specifies the account field.

Declaration
[JsonPropertyName("currency")]
public string CurrencyCode { get; set; }
Property Value
Type Description
string
| Edit this page View Source

Issuer

(Optional) If present, this path step represents changing currencies and this address defines the issuer of the new currency.
If omitted in a step with a non-XRP currency, a previous step of the path defines the issuer.
If present when currency is omitted, indicates a path step that uses an order book between same-named currencies with different issuers.
MUST be omitted if the currency is XRP.
MUST NOT be provided if this step specifies the account field.

Declaration
[JsonPropertyName("issuer")]
public string Issuer { get; set; }
Property Value
Type Description
string
| Edit this page View Source

Type

(Optional) An integer bitfield indicating which fields are present in this path step.
0x01 = account, 0x10 = currency, 0x20 = issuer.

Declaration
[JsonPropertyName("type")]
public int? Type { get; set; }
Property Value
Type Description
int?
| Edit this page View Source

TypeHex

(Optional) Hex representation of the type field.

Declaration
[JsonPropertyName("type_hex")]
public string TypeHex { get; set; }
Property Value
Type Description
string
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX