Class PathAlternative
Each element in the alternatives array represents a path from one possible source currency to the destination account and currency.
Inherited Members
Namespace: Xrpl.Models.Methods
Assembly: Xrpl.dll
Syntax
public class PathAlternative : BaseMethodResult
Properties
| Edit this page View SourceDestinationAmount
(May be omitted) Currency Amount that the destination would receive along this path.
Only included when the destination_amount from the request was the "-1" special case.
Declaration
[JsonPropertyName("destination_amount")]
[JsonConverter(typeof(CurrencyConverter))]
public Currency DestinationAmount { get; set; }
Property Value
| Type | Description |
|---|---|
| Currency |
PathsCanonical
(Deprecated) Array of arrays of objects defining canonical payment paths.
May be present in server responses but should be disregarded.
Declaration
[JsonPropertyName("paths_canonical")]
public List<List<PathStep>> PathsCanonical { get; set; }
Property Value
| Type | Description |
|---|---|
| List<List<PathStep>> |
PathsComputed
Array of arrays of objects defining payment paths.
Declaration
[JsonPropertyName("paths_computed")]
public List<List<PathStep>> PathsComputed { get; set; }
Property Value
| Type | Description |
|---|---|
| List<List<PathStep>> |
SourceAmount
Currency Amount that the source would have to send along this path for the destination to receive the desired amount.
Declaration
[JsonPropertyName("source_amount")]
[JsonConverter(typeof(CurrencyConverter))]
public Currency SourceAmount { get; set; }
Property Value
| Type | Description |
|---|---|
| Currency |