Show / Hide Table of Contents

Class PathFindCreateRequest

The path_find create sub-command creates an ongoing request to find possible paths along which a payment transaction could be made from one specified account such that another account receives a desired amount of some currency.
WebSocket API only.

Inheritance
object
BaseRequest
PathFindCreateRequest
Inherited Members
BaseRequest.Id
BaseRequest.Command
BaseRequest.ApiVersion
Namespace: Xrpl.Models.Methods
Assembly: Xrpl.dll
Syntax
public class PathFindCreateRequest : BaseRequest

Constructors

| Edit this page View Source

PathFindCreateRequest(string, string, Currency)

Declaration
public PathFindCreateRequest(string sourceAccount, string destinationAccount, Currency destinationAmount)
Parameters
Type Name Description
string sourceAccount
string destinationAccount
Currency destinationAmount

Properties

| Edit this page View Source

DestinationAccount

Unique address of the account to find a path to (the receiver).

Declaration
[JsonPropertyName("destination_account")]
public string DestinationAccount { get; set; }
Property Value
Type Description
string
| Edit this page View Source

DestinationAmount

Currency Amount that the destination account would receive.
Special case: provide -1 as the value to request a path to deliver as much as possible, while spending no more than the amount specified in send_max.

Declaration
[JsonPropertyName("destination_amount")]
[JsonConverter(typeof(CurrencyConverter))]
public Currency DestinationAmount { get; set; }
Property Value
Type Description
Currency
| Edit this page View Source

Paths

(Optional) Array of arrays of objects, representing payment paths to check.
You can use this to keep updated on changes to particular paths you already know about, or to check the overall cost to make a payment along a certain path.

Declaration
[JsonPropertyName("paths")]
public List<List<Path>> Paths { get; set; }
Property Value
Type Description
List<List<Path>>
| Edit this page View Source

SendMax

(Optional) Currency Amount — the maximum amount that would be spent.
Not compatible with source_currencies.

Declaration
[JsonPropertyName("send_max")]
[JsonConverter(typeof(CurrencyConverter))]
public Currency SendMax { get; set; }
Property Value
Type Description
Currency
| Edit this page View Source

SourceAccount

Unique address of the account to find a path from (the sender).

Declaration
[JsonPropertyName("source_account")]
public string SourceAccount { get; set; }
Property Value
Type Description
string
| Edit this page View Source

SubCommand

Use "create" to send the create sub-command.

Declaration
[JsonPropertyName("subcommand")]
public string SubCommand { get; set; }
Property Value
Type Description
string
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX