Show / Hide Table of Contents

Class PathFindResponse

Response expected from a path_find create, close, or status request.

Inheritance
object
PathFindResponse
Namespace: Xrpl.Models.Methods
Assembly: Xrpl.dll
Syntax
public class PathFindResponse

Properties

| Edit this page View Source

Alternatives

Array of objects with suggested paths to take.
If empty, then no paths were found connecting the source and destination accounts.

Declaration
[JsonPropertyName("alternatives")]
public List<PathAlternative> Alternatives { get; set; }
Property Value
Type Description
List<PathAlternative>
| Edit this page View Source

Closed

(path_find close only) The value true indicates this reply is in response to a path_find close command.

Declaration
[JsonPropertyName("closed")]
public bool? Closed { get; set; }
Property Value
Type Description
bool?
| Edit this page View Source

DestinationAccount

Unique address of the account that would receive a payment.

Declaration
[JsonPropertyName("destination_account")]
public string DestinationAccount { get; set; }
Property Value
Type Description
string
| Edit this page View Source

DestinationAmount

Currency Amount that the destination would receive in a transaction.

Declaration
[JsonPropertyName("destination_amount")]
[JsonConverter(typeof(CurrencyConverter))]
public Currency DestinationAmount { get; set; }
Property Value
Type Description
Currency
| Edit this page View Source

FullReply

If false, this is the result of an incomplete search.
If true, then this is the best path found.

Declaration
[JsonPropertyName("full_reply")]
public bool FullReply { get; set; }
Property Value
Type Description
bool
| Edit this page View Source

SourceAccount

Unique address of the account that would send a payment.

Declaration
[JsonPropertyName("source_account")]
public string SourceAccount { get; set; }
Property Value
Type Description
string
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX