Show / Hide Table of Contents

Class PermissionedDomainQuery

Specify the PermissionedDomain to retrieve. If a string, must be the ledger entry ID of the entry, as hexadecimal. If an object, requires account and seq sub-fields.

Inheritance
object
PermissionedDomainQuery
Namespace: Xrpl.Models.Methods
Assembly: Xrpl.dll
Syntax
public class PermissionedDomainQuery

Properties

| Edit this page View Source

Account

The account that owns the PermissionedDomain.

Declaration
[JsonPropertyName("account")]
public string Account { get; set; }
Property Value
Type Description
string
| Edit this page View Source

Seq

The sequence number of the transaction that created the PermissionedDomain.

Declaration
[JsonPropertyName("seq")]
public uint Seq { get; set; }
Property Value
Type Description
uint
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX