Show / Hide Table of Contents

Class PingRequest

The ping command returns an acknowledgement, so that clients can test the connection status and latency.
Expects a response in the form of a PingRequest.

Inheritance
object
BaseRequest
PingRequest
Inherited Members
BaseRequest.Id
BaseRequest.Command
BaseRequest.ApiVersion
Namespace: Xrpl.Models.Methods
Assembly: Xrpl.dll
Syntax
public class PingRequest : BaseRequest

Constructors

| Edit this page View Source

PingRequest()

Declaration
public PingRequest()
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX