Show / Hide Table of Contents

Class RandomRequest

The random command provides a random number to be used as a source of entropy for random number generation by clients.
Expects a response in the form of a RandomResponse.

Inheritance
object
BaseRequest
RandomRequest
Inherited Members
BaseRequest.Id
BaseRequest.Command
BaseRequest.ApiVersion
Namespace: Xrpl.Models.Methods
Assembly: Xrpl.dll
Syntax
public class RandomRequest : BaseRequest

Constructors

| Edit this page View Source

RandomRequest()

Declaration
public RandomRequest()
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX