Show / Hide Table of Contents

Class RipplePathFindResponse

Response expected from a RipplePathFindRequest.

Inheritance
object
RipplePathFindResponse
Namespace: Xrpl.Models.Methods
Assembly: Xrpl.dll
Syntax
public class RipplePathFindResponse

Properties

| Edit this page View Source

Alternatives

Array of objects with possible paths to take.
If empty, then there are no paths connecting the source and destination accounts.

Declaration
[JsonPropertyName("alternatives")]
public List<PathAlternative> Alternatives { get; set; }
Property Value
Type Description
List<PathAlternative>
| Edit this page View Source

DestinationAccount

Unique address of the account that would receive a payment transaction.

Declaration
[JsonPropertyName("destination_account")]
public string DestinationAccount { get; set; }
Property Value
Type Description
string
| Edit this page View Source

DestinationAmount

Currency Amount that the destination would receive in a transaction.

Declaration
[JsonPropertyName("destination_amount")]
[JsonConverter(typeof(CurrencyConverter))]
public Currency DestinationAmount { get; set; }
Property Value
Type Description
Currency
| Edit this page View Source

DestinationCurrencies

Array of strings representing the currencies that the destination accepts, as 3-letter codes like "USD" or as 40-character hex.

Declaration
[JsonPropertyName("destination_currencies")]
public List<string> DestinationCurrencies { get; set; }
Property Value
Type Description
List<string>
| Edit this page View Source

FullReply

If false, this is the result of an incomplete search.
If true, then this is the best path found.

Declaration
[JsonPropertyName("full_reply")]
public bool? FullReply { get; set; }
Property Value
Type Description
bool?
| Edit this page View Source

SourceAccount

Unique address of the account that would send a payment.

Declaration
[JsonPropertyName("source_account")]
public string SourceAccount { get; set; }
Property Value
Type Description
string
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX