Show / Hide Table of Contents

Enum RoleType

Whether the address refers to a gateway or user.
Recommendations depend on the role of the account.
Issuers must have Default Ripple enabled and must disable No Ripple on all trust lines.
Users should have Default Ripple disabled, and should enable No Ripple on all trust lines.

Namespace: Xrpl.Models.Methods
Assembly: Xrpl.dll
Syntax
public enum RoleType

Fields

Name Description
Gateway
User

Extension Methods

EmumExtensions.DecodeFlags<RoleType>(RoleType)
EmumExtensions.FlagsValues<RoleType>(RoleType)
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX