Show / Hide Table of Contents

Class ServerDefinitionsRequest

The server_definitions method retrieves the definition enums used by the server in its binary serialization format. These include field definitions, transaction types, ledger entry types, transaction results, and type codes.

Inheritance
object
BaseRequest
ServerDefinitionsRequest
Inherited Members
BaseRequest.Id
BaseRequest.Command
BaseRequest.ApiVersion
Namespace: Xrpl.Models.Methods
Assembly: Xrpl.dll
Syntax
public class ServerDefinitionsRequest : BaseRequest

Constructors

| Edit this page View Source

ServerDefinitionsRequest()

Declaration
public ServerDefinitionsRequest()

Properties

| Edit this page View Source

Hash

(Optional) A hash value. If the hash matches the server's current definitions, the server returns an empty result, saving bandwidth.

Declaration
[JsonPropertyName("hash")]
public string Hash { get; set; }
Property Value
Type Description
string
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX