Show / Hide Table of Contents

Class ServerInfoRequest

The server_info command asks the server for a human-readable version of various information about the rippled server being queried.
Expects a response in the form of a {@link ServerInfoResponse}.

Inheritance
object
BaseRequest
ServerInfoRequest
Inherited Members
BaseRequest.Id
BaseRequest.Command
BaseRequest.ApiVersion
Namespace: Xrpl.Models.Methods
Assembly: Xrpl.dll
Syntax
public class ServerInfoRequest : BaseRequest

Constructors

| Edit this page View Source

ServerInfoRequest()

Declaration
public ServerInfoRequest()
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX