Show / Hide Table of Contents

Enum ServerStateInner

Depending on how the rippled server is configured, how long it has been running, and other factors, a server may be participating in the global XRP Ledger peer-to-peer network to different degrees.
This is represented as the server_state field in the responses to the server_info method and server_state method.
The possible responses follow a range of ascending interaction, with each later value superseding the previous one.
https://xrpl.org/rippled-server-states.html

Namespace: Xrpl.Models.Methods
Assembly: Xrpl.dll
Syntax
public enum ServerStateInner

Fields

Name Description
Connected

The server believes it is connected to the network.

Disconnected

The server is not connected to the XRP Ledger peer-to-peer network whatsoever.
It may be running in offline mode, or it may not be able to access the network for whatever reason.

Full

The server is fully caught-up with the network and could participate in validation, but is not doing so (possibly because it has not been configured as a validator).

Proposing

The server is participating in validation of the ledger and currently proposing its own version.

Syncing

The server is currently behind on ledger versions.
(It is normal for a server to spend a few minutes catching up after you start it).

Tracking

The server is in agreement with the network.

Validating

The server is currently participating in validation of the ledger.

Extension Methods

EmumExtensions.DecodeFlags<ServerStateInner>(ServerStateInner)
EmumExtensions.FlagsValues<ServerStateInner>(ServerStateInner)
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX