Show / Hide Table of Contents

Class ServerStateRequest

The server_info command asks the server for a human-readable version of various information about the rippled server being queried.
Expects a response in the form of a {@link ServerInfoResponse}.

Inheritance
object
BaseRequest
ServerStateRequest
Inherited Members
BaseRequest.Id
BaseRequest.Command
BaseRequest.ApiVersion
Namespace: Xrpl.Models.Methods
Assembly: Xrpl.dll
Syntax
public class ServerStateRequest : BaseRequest

Constructors

| Edit this page View Source

ServerStateRequest()

Declaration
public ServerStateRequest()
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX