Show / Hide Table of Contents

Class SimulateRequest

The simulate method executes a dry run of any transaction type, enabling you to preview the results and metadata of a transaction without committing them to the XRP Ledger.
Since this command never submits a transaction to the network, it doesn't incur any fees.
Expects a response in the form of a Submit .

Inheritance
object
BaseRequest
SimulateRequest
Inherited Members
BaseRequest.Id
BaseRequest.Command
BaseRequest.ApiVersion
Namespace: Xrpl.Models.Methods
Assembly: Xrpl.dll
Syntax
public class SimulateRequest : BaseRequest

Constructors

| Edit this page View Source

SimulateRequest()

Declaration
public SimulateRequest()

Properties

| Edit this page View Source

Binary

The default value is false, which returns data and metadata in JSON format.
If true, returns data and metadata in binary format, serialized to a hexadecimal string.

Declaration
[JsonPropertyName("binary")]
public bool? Binary { get; set; }
Property Value
Type Description
bool?
| Edit this page View Source

Transaction

The transaction to simulate, in JSON format.
If you include this field, do not also include tx_blob.

Declaration
[JsonPropertyName("tx_json")]
[JsonConverter(typeof(TransactionRequestConverter))]
public ITransactionRequest Transaction { get; set; }
Property Value
Type Description
ITransactionRequest
| Edit this page View Source

TxBlob

The transaction to simulate, in binary format.
If you include this field, do not also include tx_json.

Declaration
[JsonPropertyName("tx_blob")]
public string TxBlob { get; set; }
Property Value
Type Description
string
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX