Show / Hide Table of Contents

Class SimulateResponse

Inheritance
object
SimulateResponse
Namespace: Xrpl.Models.Methods
Assembly: Xrpl.dll
Syntax
public class SimulateResponse

Properties

| Edit this page View Source

Applied

Declaration
[JsonPropertyName("applied")]
public bool Applied { get; set; }
Property Value
Type Description
bool
| Edit this page View Source

Binary

The default value is false, which returns data and metadata in JSON format.
If true, returns data and metadata in binary format, serialized to a hexadecimal string.

Declaration
[JsonPropertyName("binary")]
public bool? Binary { get; set; }
Property Value
Type Description
bool?
| Edit this page View Source

EngineResult

Text result code indicating the preliminary result of the transaction, for example tesSUCCESS.

Declaration
[JsonPropertyName("engine_result")]
public string EngineResult { get; set; }
Property Value
Type Description
string
| Edit this page View Source

EngineResultCode

Numeric version of the result code.

Declaration
[JsonPropertyName("engine_result_code")]
public int EngineResultCode { get; set; }
Property Value
Type Description
int
| Edit this page View Source

EngineResultMessage

Human-readable explanation of the transaction's preliminary result.

Declaration
[JsonPropertyName("engine_result_message")]
public string EngineResultMessage { get; set; }
Property Value
Type Description
string
| Edit this page View Source

LedgerIndex

Declaration
[JsonPropertyName("ledger_index")]
public ulong? LedgerIndex { get; set; }
Property Value
Type Description
ulong?
| Edit this page View Source

Meta

Declaration
[JsonPropertyName("meta")]
public Meta Meta { get; set; }
Property Value
Type Description
Meta
| Edit this page View Source

TxBlob

The transaction to simulate, in binary format.
If you include this field, do not also include tx_json.

Declaration
[JsonPropertyName("tx_blob")]
public string TxBlob { get; set; }
Property Value
Type Description
string
| Edit this page View Source

TxJson

The transaction to simulate, in JSON format.
If you include this field, do not also include tx_blob.

Declaration
[JsonPropertyName("tx_json")]
[JsonConverter(typeof(TransactionRequestConverter))]
public ITransactionRequest TxJson { get; set; }
Property Value
Type Description
ITransactionRequest
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX