Show / Hide Table of Contents

Class SubmitRequest

The submit method applies a transaction and sends it to the network to be confirmed and included in future ledgers.
Expects a response in the form of a Submit .

Inheritance
object
BaseRequest
SubmitRequest
Inherited Members
BaseRequest.Id
BaseRequest.Command
BaseRequest.ApiVersion
Namespace: Xrpl.Models.Methods
Assembly: Xrpl.dll
Syntax
public class SubmitRequest : BaseRequest

Constructors

| Edit this page View Source

SubmitRequest()

Declaration
public SubmitRequest()

Properties

| Edit this page View Source

FailHard

If true, and the transaction fails locally, do not retry or relay the transaction to other servers.
The default is false.

Declaration
[JsonPropertyName("fail_hard")]
public bool? FailHard { get; set; }
Property Value
Type Description
bool?
| Edit this page View Source

TxBlob

The complete transaction in hex string format.

Declaration
[JsonPropertyName("tx_blob")]
public string TxBlob { get; set; }
Property Value
Type Description
string
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX