Show / Hide Table of Contents

Class TakerAmount

Inheritance
object
TakerAmount
Namespace: Xrpl.Models.Methods
Assembly: Xrpl.dll
Syntax
public class TakerAmount

Properties

| Edit this page View Source

Currency

The standard format for currency codes is a three-character string such as USD.
This is intended for use with ISO 4217 Currency Codes
As a 160-bit hexadecimal string, such as "0158415500000000C1F76FF6ECB0BAC600000000".
The following characters are permitted:
all uppercase and lowercase letters, digits, as well as the symbols ? ! @ # $ % ^ * ( ) { } [ ] | and symbols ampersand, less, greater
Currency codes are case-sensitive.

Declaration
[JsonPropertyName("currency")]
public string Currency { get; set; }
Property Value
Type Description
string
| Edit this page View Source

Issuer

Generally, the account that issues this token.
In special cases, this can refer to the account that holds the token instead.

Declaration
[JsonPropertyName("issuer")]
public string Issuer { get; set; }
Property Value
Type Description
string
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX