Show / Hide Table of Contents

Class TicketQuery

The Ticket object to retrieve. If a string, must be the object ID of the Ticket, as hexadecimal.If an object, the owner and ticket_sequence sub-fields are required to uniquely specify the Ticket entry.

Inheritance
object
TicketQuery
Namespace: Xrpl.Models.Methods
Assembly: Xrpl.dll
Syntax
public class TicketQuery

Properties

| Edit this page View Source

Account

The owner of the Ticket object.

Declaration
[JsonPropertyName("account")]
public string Account { get; set; }
Property Value
Type Description
string
| Edit this page View Source

TicketSequence

The Ticket Sequence number of the Ticket entry to retrieve.

Declaration
[JsonPropertyName("ticket_seq")]
public uint TicketSequence { get; set; }
Property Value
Type Description
uint
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX