Show / Hide Table of Contents

Class TransactionEntryRequest

The transaction_entry method retrieves information on a single transaction from a specific ledger version. It differs from the tx method in that it requires you to specify the ledger version to search.

Inheritance
object
BaseRequest
BaseLedgerRequest
TransactionEntryRequest
Inherited Members
BaseLedgerRequest.LedgerHash
BaseLedgerRequest.LedgerIndex
BaseRequest.Id
BaseRequest.Command
BaseRequest.ApiVersion
Namespace: Xrpl.Models.Methods
Assembly: Xrpl.dll
Syntax
public class TransactionEntryRequest : BaseLedgerRequest

Constructors

| Edit this page View Source

TransactionEntryRequest()

Declaration
public TransactionEntryRequest()

Properties

| Edit this page View Source

TxHash

Unique hash of the transaction you are looking up.

Declaration
[JsonPropertyName("tx_hash")]
public string TxHash { get; set; }
Property Value
Type Description
string
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX