Show / Hide Table of Contents

Class TransactionEntryResponse

Response expected from a TransactionEntryRequest.

Inheritance
object
TransactionEntryResponse
Namespace: Xrpl.Models.Methods
Assembly: Xrpl.dll
Syntax
public class TransactionEntryResponse

Properties

| Edit this page View Source

LedgerHash

The identifying hash of the ledger version the transaction was found in.

Declaration
[JsonPropertyName("ledger_hash")]
public string LedgerHash { get; set; }
Property Value
Type Description
string
| Edit this page View Source

LedgerIndex

The ledger index of the ledger version the transaction was found in.

Declaration
[JsonPropertyName("ledger_index")]
public uint? LedgerIndex { get; set; }
Property Value
Type Description
uint?
| Edit this page View Source

Metadata

The transaction metadata, which shows the exact outcome of the transaction.

Declaration
[JsonPropertyName("metadata")]
public JsonElement? Metadata { get; set; }
Property Value
Type Description
JsonElement?
| Edit this page View Source

TxJson

The transaction object in JSON format.

Declaration
[JsonPropertyName("tx_json")]
public JsonElement? TxJson { get; set; }
Property Value
Type Description
JsonElement?
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX