Show / Hide Table of Contents

Class TrustLine

Trust line objects.

Inheritance
object
TrustLine
Namespace: Xrpl.Models.Methods
Assembly: Xrpl.dll
Syntax
public class TrustLine

Properties

| Edit this page View Source

Account

The unique Address of the counterparty to this trust line.

Declaration
[JsonPropertyName("account")]
public string Account { get; set; }
Property Value
Type Description
string
| Edit this page View Source

Authorized

If true, the perspective account has authorized this trust line. The default is false.

Declaration
[JsonPropertyName("authorized")]
public bool? Authorized { get; set; }
Property Value
Type Description
bool?
| Edit this page View Source

Balance

Representation of the numeric balance currently held against this line.
A positive balance means that the perspective account holds value;
a negative Balance means that the perspective account owes value.

Declaration
[JsonPropertyName("balance")]
public string Balance { get; set; }
Property Value
Type Description
string
| Edit this page View Source

BalanceAsNumber

Representation of the numeric balance currently held against this line.
A positive balance means that the perspective account holds value;
a negative Balance means that the perspective account owes value.

Declaration
[JsonIgnore]
public decimal BalanceAsNumber { get; }
Property Value
Type Description
decimal
| Edit this page View Source

Currency

A Currency Code identifying what currency this trust line can hold.

Declaration
[JsonPropertyName("currency")]
public string Currency { get; set; }
Property Value
Type Description
string
| Edit this page View Source

CurrencyValidName

Readable currency name

Declaration
[JsonIgnore]
public string CurrencyValidName { get; }
Property Value
Type Description
string
| Edit this page View Source

DeepFreeze

If true, this account has deep frozen this trust line.
The default is false.

Declaration
[JsonPropertyName("deep_freeze")]
public bool? DeepFreeze { get; set; }
Property Value
Type Description
bool?
| Edit this page View Source

DeepFreezePeer

If true, the peer account has deep frozen this trust line.
The default is false.

Declaration
[JsonPropertyName("deep_freeze_peer")]
public bool? DeepFreezePeer { get; set; }
Property Value
Type Description
bool?
| Edit this page View Source

Freeze

If true, this account has frozen this trust line. The default is false.

Declaration
[JsonPropertyName("freeze")]
public bool? Freeze { get; set; }
Property Value
Type Description
bool?
| Edit this page View Source

FreezePeer

If true, the peer account has frozen this trust line.
The default is false.

Declaration
[JsonPropertyName("freeze_peer")]
public bool? FreezePeer { get; set; }
Property Value
Type Description
bool?
| Edit this page View Source

Limit

The maximum amount of currency that the issuer account is willing to owe the perspective account.

Declaration
[JsonPropertyName("limit")]
public string Limit { get; set; }
Property Value
Type Description
string
| Edit this page View Source

LimitAsNumber

The maximum amount of currency that the issuer account is willing to owe the perspective account.

Declaration
[JsonIgnore]
public double LimitAsNumber { get; }
Property Value
Type Description
double
| Edit this page View Source

LimitPeer

The maximum amount of currency that the issuer account is willing to owe the perspective account.

Declaration
[JsonPropertyName("limit_peer")]
public string LimitPeer { get; set; }
Property Value
Type Description
string
| Edit this page View Source

LimitPeerAsNumber

Declaration
[JsonIgnore]
public double LimitPeerAsNumber { get; }
Property Value
Type Description
double
| Edit this page View Source

NoRipple

If true, this account has enabled the No Ripple flag for this trust line.
If present and false, this account has disabled the No Ripple flag, but, because the account also has the Default Ripple flag enabled, that is not considered the default state.
If omitted, the account has the No Ripple flag disabled for this trust line and Default Ripple disabled.

Declaration
[JsonPropertyName("no_ripple")]
public bool? NoRipple { get; set; }
Property Value
Type Description
bool?
| Edit this page View Source

NoRipplePeer

If true, the peer account has enabled the No Ripple flag for this trust line.
If present and false, this account has disabled the No Ripple flag, but, because the account also has the Default Ripple flag enabled, that is not considered the default state.
If omitted, the account has the No Ripple flag disabled for this trust line and Default Ripple disabled.

Declaration
[JsonPropertyName("no_ripple_peer")]
public bool? NoRipplePeer { get; set; }
Property Value
Type Description
bool?
| Edit this page View Source

PeerAuthorized

If true, the counterparty has authorized this trust line. The default is false.

Declaration
[JsonPropertyName("peer_authorized")]
public bool? PeerAuthorized { get; set; }
Property Value
Type Description
bool?
| Edit this page View Source

QualityIn

Rate at which the account values incoming balances on this trust line, as a ratio of this value per 1 billion units.
(For example, a value of 500 million represents a 0.5:1 ratio.)
As a special case, 0 is treated as a 1:1 ratio.

Declaration
[JsonPropertyName("quality_in")]
public uint QualityIn { get; set; }
Property Value
Type Description
uint
| Edit this page View Source

QualityOut

Rate at which the account values outgoing balances on this trust line, as a ratio of this value per 1 billion units.
(For example, a value of 500 million represents a 0.5:1 ratio.)
As a special case, 0 is treated as a 1:1 ratio.

Declaration
[JsonPropertyName("quality_out")]
public uint QualityOut { get; set; }
Property Value
Type Description
uint

Extension Methods

CurrencyExtensions.IsLpToken(TrustLine)
BalancesSugar.Map(TrustLine)
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX