Show / Hide Table of Contents

Class TxRequest

The tx method retrieves information on a single transaction, by its identifying hash.
Expects a response in the form of a TxResponse.

Inheritance
object
BaseRequest
TxRequest
Inherited Members
BaseRequest.Id
BaseRequest.Command
BaseRequest.ApiVersion
Namespace: Xrpl.Models.Methods
Assembly: Xrpl.dll
Syntax
public class TxRequest : BaseRequest

Constructors

| Edit this page View Source

TxRequest(string)

Declaration
public TxRequest(string hash)
Parameters
Type Name Description
string hash

Properties

| Edit this page View Source

Binary

If true, return transaction data and metadata as binary serialized to hexadecimal strings.
If false, return transaction data and metadata as JSON.
The default is false.

Declaration
[JsonPropertyName("binary")]
public bool? Binary { get; set; }
Property Value
Type Description
bool?
| Edit this page View Source

CtId

The compact transaction identifier of the transaction to look up.
Must use uppercase hexadecimal only.
New in: rippled 1.12.0 (Not supported in Clio v2.0 and earlier)

Declaration
[JsonPropertyName("ctid")]
public string? CtId { get; set; }
Property Value
Type Description
string
| Edit this page View Source

MaxLedger

Use this with min_ledger to specify a range of up to 1000 ledger indexes, ending with this ledger (inclusive).
If the server cannot find the transaction,
it confirms whether it was able to search all the ledgers in the requested range.

Declaration
[JsonPropertyName("max_ledger")]
public uint? MaxLedger { get; set; }
Property Value
Type Description
uint?
| Edit this page View Source

MinLedger

Use this with max_ledger to specify a range of up to 1000 ledger indexes, starting with this ledger (inclusive).
If the server cannot find the transaction,
it confirms whether it was able to search all the ledgers in this range.

Declaration
[JsonPropertyName("min_ledger")]
public uint? MinLedger { get; set; }
Property Value
Type Description
uint?
| Edit this page View Source

Transaction

The 256-bit hash of the transaction to look up, as hexadecimal.

Declaration
[JsonPropertyName("transaction")]
public string? Transaction { get; set; }
Property Value
Type Description
string
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX