Show / Hide Table of Contents

Class UnsubscribeRequest

The unsubscribe command tells the server to stop sending messages for a particular subscription or set of subscriptions.
The parameters in the request are specified almost exactly like the parameters to the subscribe method, except that they are used to define which subscriptions to end instead. The rt_accounts and url parameters, and the rt_transactions stream name, are deprecated and may be removed without further notice.
The response follows the standard format, with a successful result containing no fields.
https://xrpl.org/unsubscribe.html

Inheritance
object
BaseRequest
UnsubscribeRequest
Inherited Members
BaseRequest.Id
BaseRequest.Command
BaseRequest.ApiVersion
Namespace: Xrpl.Models.Methods
Assembly: Xrpl.dll
Syntax
public class UnsubscribeRequest : BaseRequest

Constructors

| Edit this page View Source

UnsubscribeRequest()

Declaration
public UnsubscribeRequest()

Properties

| Edit this page View Source

Accounts

(Optional) Array with the unique addresses of accounts to monitor for validated transactions. The addresses must be in the XRP Ledger's base58 format. The server sends a notification for any transaction that affects at least one of these accounts

Declaration
[JsonPropertyName("accounts")]
public List<string>? Accounts { get; set; }
Property Value
Type Description
List<string>
| Edit this page View Source

AccountsProposed

(Optional) Like accounts, but include transactions that are not yet finalized.

Declaration
[JsonPropertyName("accounts_proposed")]
public List<string>? AccountsProposed { get; set; }
Property Value
Type Description
List<string>
| Edit this page View Source

Books

(Optional) Array of objects defining order books to monitor for updates.

Declaration
[JsonPropertyName("books")]
public List<Book>? Books { get; set; }
Property Value
Type Description
List<Book>
| Edit this page View Source

Streams

Array with the unique addresses of accounts to monitor for validated transactions.The addresses must be in the XRP Ledger's base58 format. The server sends a notification for any transaction that affects at least one of these accounts.

Declaration
[JsonPropertyName("streams")]
[JsonConverter(typeof(StreamTypeListConverter))]
public List<StreamType>? Streams { get; set; }
Property Value
Type Description
List<StreamType>
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX