Show / Hide Table of Contents

Class VaultInfoResponse

Response expected from a VaultInfoRequest.

Inheritance
object
VaultInfoResponse
Namespace: Xrpl.Models.Methods
Assembly: Xrpl.dll
Syntax
public class VaultInfoResponse

Properties

| Edit this page View Source

LedgerHash

The identifying hash of the ledger version used to generate this response.

Declaration
[JsonPropertyName("ledger_hash")]
public string LedgerHash { get; set; }
Property Value
Type Description
string
| Edit this page View Source

LedgerIndex

The ledger index of the ledger version used to generate this response.

Declaration
[JsonPropertyName("ledger_index")]
public uint? LedgerIndex { get; set; }
Property Value
Type Description
uint?
| Edit this page View Source

Validated

If true, the information comes from a validated ledger version.

Declaration
[JsonPropertyName("validated")]
public bool? Validated { get; set; }
Property Value
Type Description
bool?
| Edit this page View Source

Vault

The vault ledger object.

Declaration
[JsonPropertyName("vault")]
public LOVault Vault { get; set; }
Property Value
Type Description
LOVault
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX