Show / Hide Table of Contents

Namespace Xrpl.Models.Subscriptions

Classes

BaseResponse

BaseStream

BookChange

Represents a single order book change in a validated ledger.
Volume and rate values are strings. When the corresponding asset is XRP, values are in drops (1 XRP = 1,000,000 drops).
Rates (high, low, open, close) are expressed as CurrencyA per 1 unit of CurrencyB.

BookChangesStream

The book_changes stream sends a message whenever a new ledger is validated, with a summary of all changes to order books in that ledger. https://xrpl.org/docs/references/http-websocket-apis/public-api-methods/subscription-methods/subscribe#book-changes-stream

ConsensusStream

The consensus stream sends consensusPhase messages when the consensus process changes phase.
The message contains the new phase of consensus the server is in. https://xrpl.org/subscribe.html#consensus-stream

ErrorResponse

ManifestStream

The manifest stream sends a message whenever the server receives a manifest (also called a validator token) from a validator it trusts. https://xrpl.org/docs/references/http-websocket-apis/public-api-methods/subscription-methods/subscribe#manifest-stream

OrderBookStream

When you subscribe to one or more order books with the books field, you get back any transactions that affect those order books. https://xrpl.org/subscribe.html#order-book-streams

PathFindStream

Asynchronous follow-up message from the server for an ongoing path_find request.
These messages have "type": "path_find" and include the id of the original WebSocket request.

PeerStatusStream

The admin-only peer_status stream reports a large amount of information on the activities of other rippled servers to which this server is connected, in particular their status in the consensus process. https://xrpl.org/subscribe.html#peer-status-stream

RippleResponseWarning

When the response contains a warnings array, each member of the array represents a separate warning from the server.

ServerStatusStream

The server stream sends a message whenever the status of the rippled server changes. https://xrpl.org/docs/references/http-websocket-apis/public-api-methods/subscription-methods/subscribe#server-stream

TransactionStream

Many subscriptions result in messages about transactions, including the following: The transactions stream
The transactions_proposed stream
accounts subscriptions
accounts_proposed subscriptions
book (Order Book) subscriptions https://xrpl.org/subscribe.html#transaction-streams

Enums

ResponseStreamType

In this article
Back to top Generated by DocFX