Class BaseResponse
Namespace: Xrpl.Models.Subscriptions
Assembly: Xrpl.dll
Syntax
public class BaseResponse
Properties
| Edit this page View SourceApiVersion
(May be omitted) The api_version specified in the request, if any.
Declaration
[JsonPropertyName("api_version")]
public uint? ApiVersion { get; set; }
Property Value
| Type | Description |
|---|---|
| uint? |
Forwarded
(May be omitted) If true, this request and response have been forwarded from a Reporting Mode
server to a P2P Mode server (and back) because the request requires data that is not available in Reporting Mode.
The default is false.
Declaration
[JsonPropertyName("forwarded")]
public bool? Forwarded { get; set; }
Property Value
| Type | Description |
|---|---|
| bool? |
RawId
The id member exactly as the node sent it.
Declaration
[JsonIgnore]
public RawJson RawId { get; }
Property Value
| Type | Description |
|---|---|
| RawJson |
RawResult
The result member exactly as the node sent it.
Declaration
[JsonIgnore]
public RawJson RawResult { get; }
Property Value
| Type | Description |
|---|---|
| RawJson |
Status
"error" if the request caused an error
Declaration
[JsonPropertyName("status")]
public string Status { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
Type
(WebSocket only) The value response indicates a direct response to an API request.
Asynchronous notifications use a different value such as ledgerClosed or transaction.
Declaration
[JsonPropertyName("type")]
public string Type { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
Warning
(May be omitted) If this field is provided, the value is the string load.
This means the client is approaching the rate limiting threshold where the server will disconnect this client.
Declaration
[JsonPropertyName("warning")]
public string Warning { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
Warnings
May be omitted) If this field is provided, it contains one or more Warnings Objects with important warnings.
For details, see API Warnings (https://xrpl.org/response-formatting.html#api-warnings)
Declaration
[JsonPropertyName("warnings")]
public List<RippleResponseWarning>? Warnings { get; set; }
Property Value
| Type | Description |
|---|---|
| List<RippleResponseWarning> |