Show / Hide Table of Contents

Class BookChangesStream

The book_changes stream sends a message whenever a new ledger is validated, with a summary of all changes to order books in that ledger. https://xrpl.org/docs/references/http-websocket-apis/public-api-methods/subscription-methods/subscribe#book-changes-stream

Inheritance
object
BaseStream
BookChangesStream
Inherited Members
BaseStream.Type
Namespace: Xrpl.Models.Subscriptions
Assembly: Xrpl.dll
Syntax
public class BookChangesStream : BaseStream

Properties

| Edit this page View Source

Changes

A list of book changes in this ledger.

Declaration
[JsonPropertyName("changes")]
public List<BookChange> Changes { get; set; }
Property Value
Type Description
List<BookChange>
| Edit this page View Source

LedgerHash

The identifying hash of the validated ledger.

Declaration
[JsonPropertyName("ledger_hash")]
public string LedgerHash { get; set; }
Property Value
Type Description
string
| Edit this page View Source

LedgerIndex

The ledger index of the validated ledger.

Declaration
[JsonPropertyName("ledger_index")]
public uint LedgerIndex { get; set; }
Property Value
Type Description
uint
| Edit this page View Source

LedgerTime

The close time of the validated ledger.

Declaration
[JsonPropertyName("ledger_time")]
[JsonConverter(typeof(RippleDateTimeConverter))]
public DateTime? LedgerTime { get; set; }
Property Value
Type Description
Nullable
| Edit this page View Source

Validated

If true, this data comes from a validated ledger.

Declaration
[JsonPropertyName("validated")]
public bool? Validated { get; set; }
Property Value
Type Description
bool?
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX