Show / Hide Table of Contents

Class ManifestStream

The manifest stream sends a message whenever the server receives a manifest (also called a validator token) from a validator it trusts. https://xrpl.org/docs/references/http-websocket-apis/public-api-methods/subscription-methods/subscribe#manifest-stream

Inheritance
object
BaseStream
ManifestStream
Inherited Members
BaseStream.Type
Namespace: Xrpl.Models.Subscriptions
Assembly: Xrpl.dll
Syntax
public class ManifestStream : BaseStream

Properties

| Edit this page View Source

Domain

(May be omitted) The domain name associated with this validator, if any.

Declaration
[JsonPropertyName("domain")]
public string Domain { get; set; }
Property Value
Type Description
string
| Edit this page View Source

MasterKey

The master public key of the validator, in the XRP Ledger's base58 format.

Declaration
[JsonPropertyName("master_key")]
public string MasterKey { get; set; }
Property Value
Type Description
string
| Edit this page View Source

MasterSignature

The signature of the manifest data, in hexadecimal.

Declaration
[JsonPropertyName("master_signature")]
public string MasterSignature { get; set; }
Property Value
Type Description
string
| Edit this page View Source

Seq

The sequence number of the manifest. Higher sequence numbers indicate newer manifests.

Declaration
[JsonPropertyName("seq")]
public uint Seq { get; set; }
Property Value
Type Description
uint
| Edit this page View Source

Signature

The signature of the manifest data using the ephemeral key, in hexadecimal.

Declaration
[JsonPropertyName("signature")]
public string Signature { get; set; }
Property Value
Type Description
string
| Edit this page View Source

SigningKey

The ephemeral signing public key for this manifest, in the XRP Ledger's base58 format.

Declaration
[JsonPropertyName("signing_key")]
public string SigningKey { get; set; }
Property Value
Type Description
string
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX