Show / Hide Table of Contents

Class OrderBookStream

When you subscribe to one or more order books with the books field, you get back any transactions that affect those order books. https://xrpl.org/subscribe.html#order-book-streams

Inheritance
object
BaseStream
OrderBookStream
Inherited Members
BaseStream.Type
Namespace: Xrpl.Models.Subscriptions
Assembly: Xrpl.dll
Syntax
public class OrderBookStream : BaseStream

Properties

| Edit this page View Source

EngineResult

String Transaction result code

Declaration
[JsonPropertyName("engine_result")]
public string EngineResult { get; set; }
Property Value
Type Description
string
| Edit this page View Source

EngineResultCode

Numeric transaction response code, if applicable.

Declaration
[JsonPropertyName("engine_result_code")]
public int EngineResultCode { get; set; }
Property Value
Type Description
int
| Edit this page View Source

EngineResultMessage

Human-readable explanation for the transaction response

Declaration
[JsonPropertyName("engine_result_message")]
public string EngineResultMessage { get; set; }
Property Value
Type Description
string
| Edit this page View Source

Meta

(Validated transactions only) The transaction metadata, which shows the exact outcome of the transaction in detail.

Declaration
[JsonPropertyName("meta")]
public Meta Meta { get; set; }
Property Value
Type Description
Meta
| Edit this page View Source

Status

Declaration
[JsonPropertyName("status")]
public string Status { get; set; }
Property Value
Type Description
string
| Edit this page View Source

Transaction

Declaration
[JsonIgnore]
public ITransactionResponse Transaction { get; }
Property Value
Type Description
ITransactionResponse
| Edit this page View Source

TransactionJson

The definition of the transaction in JSON format

Declaration
[JsonPropertyName("transaction")]
public object TransactionJson { get; set; }
Property Value
Type Description
object
| Edit this page View Source

Validated

If true, this transaction is included in a validated ledger and its outcome is final.
Responses from the transaction stream should always be validated.

Declaration
[JsonPropertyName("validated")]
public bool Validated { get; set; }
Property Value
Type Description
bool
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX