Show / Hide Table of Contents

Class PathFindStream

Asynchronous follow-up message from the server for an ongoing path_find request.
These messages have "type": "path_find" and include the id of the original WebSocket request.

Inheritance
object
BaseStream
PathFindStream
Inherited Members
BaseStream.Type
Namespace: Xrpl.Models.Subscriptions
Assembly: Xrpl.dll
Syntax
public class PathFindStream : BaseStream

Properties

| Edit this page View Source

Alternatives

Array of objects with suggested paths to take.
If empty, then no paths were found connecting the source and destination accounts.

Declaration
[JsonPropertyName("alternatives")]
public List<PathAlternative> Alternatives { get; set; }
Property Value
Type Description
List<PathAlternative>
| Edit this page View Source

DestinationAccount

Unique address of the account that would receive a transaction.

Declaration
[JsonPropertyName("destination_account")]
public string DestinationAccount { get; set; }
Property Value
Type Description
string
| Edit this page View Source

DestinationAmount

Currency Amount that the destination would receive in a transaction.

Declaration
[JsonPropertyName("destination_amount")]
[JsonConverter(typeof(CurrencyConverter))]
public Currency DestinationAmount { get; set; }
Property Value
Type Description
Currency
| Edit this page View Source

FullReply

If false, this is the result of an incomplete search. A later reply may have a better path.
If true, then this is the best path found.
Until you close the pathfinding request, rippled continues to send updates each time a new ledger closes.

Declaration
[JsonPropertyName("full_reply")]
public bool FullReply { get; set; }
Property Value
Type Description
bool
| Edit this page View Source

Id

The ID provided in the WebSocket request is included again at this level.

Declaration
[JsonPropertyName("id")]
public object Id { get; set; }
Property Value
Type Description
object
| Edit this page View Source

SendMax

(Optional) Currency Amount that would be spent in the transaction.

Declaration
[JsonPropertyName("send_max")]
[JsonConverter(typeof(CurrencyConverter))]
public Currency SendMax { get; set; }
Property Value
Type Description
Currency
| Edit this page View Source

SourceAccount

Unique address that would send a transaction.

Declaration
[JsonPropertyName("source_account")]
public string SourceAccount { get; set; }
Property Value
Type Description
string
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX