Show / Hide Table of Contents

Class PeerStatusStream

The admin-only peer_status stream reports a large amount of information on the activities of other rippled servers to which this server is connected, in particular their status in the consensus process. https://xrpl.org/subscribe.html#peer-status-stream

Inheritance
object
BaseStream
PeerStatusStream
Inherited Members
BaseStream.Type
Namespace: Xrpl.Models.Subscriptions
Assembly: Xrpl.dll
Syntax
public class PeerStatusStream : BaseStream

Properties

| Edit this page View Source

Action

The type of event that prompted this message. See Peer Status Events for possible values.
possible values:
CLOSING_LEDGER - The peer closed a ledger version with this Ledger Index, which usually means it is about to start consensus.
ACCEPTED_LEDGER - The peer built this ledger version as the result of a consensus round. Note: This ledger is still not certain to become immutably validated.
SWITCHED_LEDGER - The peer concluded it was not following the rest of the network and switched to a different ledger version.
LOST_SYNC - The peer fell behind the rest of the network in tracking which ledger versions are validated and which are undergoing consensus.

Declaration
[JsonPropertyName("action")]
public string Action { get; set; }
Property Value
Type Description
string
| Edit this page View Source

Date

The time this event occurred, in seconds since the Ripple Epoch.

Declaration
[JsonPropertyName("date")]
public ulong Date { get; set; }
Property Value
Type Description
ulong
| Edit this page View Source

LedgerHash

(May be omitted) The identifying Hash of a ledger version to which this message pertains.

Declaration
[JsonPropertyName("ledger_hash")]
public string LedgerHash { get; set; }
Property Value
Type Description
string
| Edit this page View Source

LedgerIndex

(May be omitted) The Ledger Index of a ledger version to which this message pertains.

Declaration
[JsonPropertyName("ledger_index")]
public ulong? LedgerIndex { get; set; }
Property Value
Type Description
ulong?
| Edit this page View Source

ledger_index_max

(May be omitted) The largest Ledger Index the peer has currently available.

Declaration
[JsonPropertyName("ledger_index_max")]
public ulong? ledger_index_max { get; set; }
Property Value
Type Description
ulong?
| Edit this page View Source

ledger_index_min

(May be omitted) The smallest Ledger Index the peer has currently available.

Declaration
[JsonPropertyName("ledger_index_min")]
public ulong? ledger_index_min { get; set; }
Property Value
Type Description
ulong?
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX