Show / Hide Table of Contents

Class RippleResponseWarning

When the response contains a warnings array, each member of the array represents a separate warning from the server.

Inheritance
object
RippleResponseWarning
Namespace: Xrpl.Models.Subscriptions
Assembly: Xrpl.dll
Syntax
public class RippleResponseWarning

Properties

| Edit this page View Source

Details

(May be omitted) Additional information about this warning.
The contents vary depending on the type of warning.

Declaration
[JsonPropertyName("details")]
public Dictionary<string, string>? Details { get; set; }
Property Value
Type Description
Dictionary<string, string>
| Edit this page View Source

Id

A unique numeric code for this warning message.

Declaration
[JsonPropertyName("id")]
public uint Id { get; set; }
Property Value
Type Description
uint
| Edit this page View Source

Message

A human-readable string describing the cause of this message.
Do not write software that relies the contents of this message;
use the id (and details, if applicable) to identify the warning instead.

Declaration
[JsonPropertyName("message")]
public string Message { get; set; }
Property Value
Type Description
string
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX