Show / Hide Table of Contents

Class ServerStatusStream

The server stream sends a message whenever the status of the rippled server changes. https://xrpl.org/docs/references/http-websocket-apis/public-api-methods/subscription-methods/subscribe#server-stream

Inheritance
object
BaseStream
ServerStatusStream
Inherited Members
BaseStream.Type
Namespace: Xrpl.Models.Subscriptions
Assembly: Xrpl.dll
Syntax
public class ServerStatusStream : BaseStream

Properties

| Edit this page View Source

BaseFee

(May be omitted) The minimum base fee, in drops of XRP.

Declaration
[JsonPropertyName("base_fee")]
public uint? BaseFee { get; set; }
Property Value
Type Description
uint?
| Edit this page View Source

LoadBase

The baseline amount of server load used in transaction cost calculations.

Declaration
[JsonPropertyName("load_base")]
public uint LoadBase { get; set; }
Property Value
Type Description
uint
| Edit this page View Source

LoadFactor

The load factor the server is currently enforcing. The ratio between this value and the load_base determines the multiplier for transaction costs.

Declaration
[JsonPropertyName("load_factor")]
public uint LoadFactor { get; set; }
Property Value
Type Description
uint
| Edit this page View Source

LoadFactorFeeEscalation

(May be omitted) The current multiplier to the transaction cost based on load to the server due to fee escalation.

Declaration
[JsonPropertyName("load_factor_fee_escalation")]
public uint? LoadFactorFeeEscalation { get; set; }
Property Value
Type Description
uint?
| Edit this page View Source

LoadFactorFeeQueue

(May be omitted) The current multiplier to the transaction cost being charged to the open ledger based on the open ledger cost.

Declaration
[JsonPropertyName("load_factor_fee_queue")]
public uint? LoadFactorFeeQueue { get; set; }
Property Value
Type Description
uint?
| Edit this page View Source

LoadFactorFeeReference

(May be omitted) The reference load factor for transaction cost calculation.

Declaration
[JsonPropertyName("load_factor_fee_reference")]
public uint? LoadFactorFeeReference { get; set; }
Property Value
Type Description
uint?
| Edit this page View Source

LoadFactorServer

(May be omitted) The load factor the server is enforcing, not including the open ledger cost.

Declaration
[JsonPropertyName("load_factor_server")]
public uint? LoadFactorServer { get; set; }
Property Value
Type Description
uint?
| Edit this page View Source

ReserveBase

(May be omitted) The minimum account reserve, as of the last validated ledger.

Declaration
[JsonPropertyName("reserve_base")]
public uint? ReserveBase { get; set; }
Property Value
Type Description
uint?
| Edit this page View Source

ReserveInc

(May be omitted) The owner reserve per object, as of the last validated ledger.

Declaration
[JsonPropertyName("reserve_inc")]
public uint? ReserveInc { get; set; }
Property Value
Type Description
uint?
| Edit this page View Source

ServerStatus

A string indicating the server's current status. Possible values include "connected", "syncing", "tracking", "full", "validating", and "proposing".

Declaration
[JsonPropertyName("server_status")]
public string ServerStatus { get; set; }
Property Value
Type Description
string
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX