Show / Hide Table of Contents

Class AMMClawBack

Claw back tokens from an Automated Market Maker (AMM) pool. This transaction allows a token issuer to recover tokens that a holder has deposited into an AMM. The issuer must have enabled clawback on their account before issuing any tokens.

Inheritance
object
TransactionRequest
AMMClawBack
Implements
ITransactionRequest
IAMMClawBack
ITransactionCommon
Inherited Members
TransactionRequest.NetworkID
TransactionRequest.Account
TransactionRequest.AccountTxnID
TransactionRequest.Fee
TransactionRequest.Flags
TransactionRequest.LastLedgerSequence
TransactionRequest.Memos
TransactionRequest.Sequence
TransactionRequest.SigningPublicKey
TransactionRequest.Signers
TransactionRequest.TransactionType
TransactionRequest.TransactionSignature
TransactionRequest.ToJson()
TransactionRequest.ToDictionary()
TransactionRequest.SourceTag
TransactionRequest.TicketSequence
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public class AMMClawBack : TransactionRequest, ITransactionRequest, IAMMClawBack, ITransactionCommon

Constructors

| Edit this page View Source

AMMClawBack()

Declaration
public AMMClawBack()

Properties

| Edit this page View Source

Amount

The amount of the asset to claw back from the AMM pool. If not provided, claws back the maximum possible amount.

Declaration
[JsonConverter(typeof(CurrencyConverter))]
public Currency Amount { get; set; }
Property Value
Type Description
Currency
| Edit this page View Source

Asset

Specifies one of the pool assets (XRP or token) of the AMM instance. Together with Asset2, this identifies which AMM pool to claw back from.

Declaration
[JsonConverter(typeof(IssuedCurrencyConverter))]
public Common.IssuedCurrency Asset { get; set; }
Property Value
Type Description
Common.IssuedCurrency
| Edit this page View Source

Asset2

Specifies the other pool asset of the AMM instance. Together with Asset, this identifies which AMM pool to claw back from.

Declaration
[JsonConverter(typeof(IssuedCurrencyConverter))]
public Common.IssuedCurrency Asset2 { get; set; }
Property Value
Type Description
Common.IssuedCurrency
| Edit this page View Source

Holder

The account holding the asset to be clawed back. This is the holder who deposited tokens into the AMM pool.

Declaration
[JsonPropertyName("Holder")]
public string Holder { get; set; }
Property Value
Type Description
string

Implements

ITransactionRequest
IAMMClawBack
ITransactionCommon

Extension Methods

BatchUtils.ToBatchTx(ITransactionRequest)
Utilities.Encode(TransactionRequest)
Utilities.EncodeForMultiSigning(TransactionRequest, string)
Utilities.EncodeForSigning(TransactionRequest)
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX