Show / Hide Table of Contents

Class AMMCreateResponse

AMMCreate is used to create AccountRoot and the corresponding AMM ledger entries. This allows for the creation of only one AMM instance per unique asset pair.

Inheritance
object
BaseTransactionResponse
TransactionResponse
AMMCreateResponse
Implements
ITransactionResponse
IBaseTransactionResponse
IAMMCreate
ITransactionCommon
Inherited Members
TransactionResponse.NetworkID
TransactionResponse.Account
TransactionResponse.AccountTxnID
TransactionResponse.Fee
TransactionResponse.Flags
TransactionResponse.LastLedgerSequence
TransactionResponse.Memos
TransactionResponse.MemoValue
TransactionResponse.Sequence
TransactionResponse.SigningPublicKey
TransactionResponse.Signers
TransactionResponse.TransactionType
TransactionResponse.TransactionSignature
TransactionResponse.Meta
TransactionResponse.ToJson()
TransactionResponse.ToDictionary()
TransactionResponse.SourceTag
TransactionResponse.TicketSequence
BaseTransactionResponse.Date
BaseTransactionResponse.Hash
BaseTransactionResponse.InLedger
BaseTransactionResponse.LedgerIndex
BaseTransactionResponse.Validated
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public class AMMCreateResponse : TransactionResponse, ITransactionResponse, IBaseTransactionResponse, IAMMCreate, ITransactionCommon

Properties

| Edit this page View Source

Amount

Specifies one of the pool assets (XRP or token) of the AMM instance.

Declaration
[JsonConverter(typeof(CurrencyConverter))]
public Currency Amount { get; set; }
Property Value
Type Description
Currency
| Edit this page View Source

Amount2

Specifies the other pool asset of the AMM instance.

Declaration
[JsonConverter(typeof(CurrencyConverter))]
public Currency Amount2 { get; set; }
Property Value
Type Description
Currency
| Edit this page View Source

TradingFee

Specifies the fee, in basis point, to be charged to the traders for the trades executed against the AMM instance. Trading fee is a percentage of the trading volume. Valid values for this field are between 0 and 1000 inclusive. A value of 1 is equivalent to 1/10 bps or 0.001%, allowing trading fee between 0% and 1%.

Declaration
public uint TradingFee { get; set; }
Property Value
Type Description
uint

Implements

ITransactionResponse
IBaseTransactionResponse
IAMMCreate
ITransactionCommon
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX