Show / Hide Table of Contents

Class AMMDeposit

AMMDeposit is the deposit transaction used to add liquidity to the AMM instance pool, thus obtaining some share of the instance's pools in the form of LPTokenOut. The following are the recommended valid combinations:

  • LPTokenOut
  • Amount
  • Amount and Amount2
  • Amount and LPTokenOut
  • Amount and EPrice
Inheritance
object
TransactionRequest
AMMDeposit
Implements
ITransactionRequest
IAMMDeposit
ITransactionCommon
Inherited Members
TransactionRequest.NetworkID
TransactionRequest.Account
TransactionRequest.AccountTxnID
TransactionRequest.Fee
TransactionRequest.LastLedgerSequence
TransactionRequest.Memos
TransactionRequest.Sequence
TransactionRequest.SigningPublicKey
TransactionRequest.Signers
TransactionRequest.TransactionType
TransactionRequest.TransactionSignature
TransactionRequest.ToJson()
TransactionRequest.ToDictionary()
TransactionRequest.SourceTag
TransactionRequest.TicketSequence
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public class AMMDeposit : TransactionRequest, ITransactionRequest, IAMMDeposit, ITransactionCommon

Constructors

| Edit this page View Source

AMMDeposit()

Declaration
public AMMDeposit()

Properties

| Edit this page View Source

Amount

Specifies one of the pool assets (XRP or token) of the AMM instance to deposit more of its value.

Declaration
[JsonConverter(typeof(CurrencyConverter))]
public Currency? Amount { get; set; }
Property Value
Type Description
Currency
| Edit this page View Source

Amount2

Specifies the other pool asset of the AMM instance to deposit more of its value.

Declaration
[JsonConverter(typeof(CurrencyConverter))]
public Currency? Amount2 { get; set; }
Property Value
Type Description
Currency
| Edit this page View Source

Asset

Specifies one of the pool assets (XRP or token) of the AMM instance.

Declaration
[JsonConverter(typeof(IssuedCurrencyConverter))]
public Common.IssuedCurrency Asset { get; set; }
Property Value
Type Description
Common.IssuedCurrency
| Edit this page View Source

Asset2

Specifies the other pool asset of the AMM instance.

Declaration
[JsonConverter(typeof(IssuedCurrencyConverter))]
public Common.IssuedCurrency Asset2 { get; set; }
Property Value
Type Description
Common.IssuedCurrency
| Edit this page View Source

EPrice

Specifies the maximum effective-price that LPTokenOut can be traded out.

Declaration
[JsonConverter(typeof(CurrencyConverter))]
public Currency? EPrice { get; set; }
Property Value
Type Description
Currency
| Edit this page View Source

Flags

Declaration
public AMMDepositFlags? Flags { get; set; }
Property Value
Type Description
AMMDepositFlags?
| Edit this page View Source

LPTokenOut

Specifies the amount of shares of the AMM instance pools that the trader wants to redeem or trade in.

Declaration
[JsonConverter(typeof(CurrencyConverter))]
public Currency? LPTokenOut { get; set; }
Property Value
Type Description
Currency

Implements

ITransactionRequest
IAMMDeposit
ITransactionCommon

Extension Methods

BatchUtils.ToBatchTx(ITransactionRequest)
Utilities.Encode(TransactionRequest)
Utilities.EncodeForMultiSigning(TransactionRequest, string)
Utilities.EncodeForSigning(TransactionRequest)
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX