Show / Hide Table of Contents

Class AMMWithdraw

AMMWithdraw is the withdraw transaction used to remove liquidity from the AMM instance pool, thus redeeming some share of the pools that one owns in the form of LPTokenIn.

Inheritance
object
TransactionRequest
AMMWithdraw
Implements
ITransactionRequest
IAMMWithdraw
ITransactionCommon
Inherited Members
TransactionRequest.NetworkID
TransactionRequest.Account
TransactionRequest.AccountTxnID
TransactionRequest.Fee
TransactionRequest.LastLedgerSequence
TransactionRequest.Memos
TransactionRequest.Sequence
TransactionRequest.SigningPublicKey
TransactionRequest.Signers
TransactionRequest.TransactionType
TransactionRequest.TransactionSignature
TransactionRequest.ToJson()
TransactionRequest.ToDictionary()
TransactionRequest.SourceTag
TransactionRequest.TicketSequence
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public class AMMWithdraw : TransactionRequest, ITransactionRequest, IAMMWithdraw, ITransactionCommon

Constructors

| Edit this page View Source

AMMWithdraw()

Declaration
public AMMWithdraw()

Properties

| Edit this page View Source

Amount

Specifies one of the pools assets that the trader wants to remove. If the asset is XRP, then the Amount is a string specifying the number of drops. Otherwise it is an IssuedCurrencyAmount object.

Declaration
[JsonConverter(typeof(CurrencyConverter))]
public Currency Amount { get; set; }
Property Value
Type Description
Currency
| Edit this page View Source

Amount2

Specifies the other pool asset that the trader wants to remove.

Declaration
[JsonConverter(typeof(CurrencyConverter))]
public Currency Amount2 { get; set; }
Property Value
Type Description
Currency
| Edit this page View Source

Asset

Specifies one of the pool assets (XRP or token) of the AMM instance.

Declaration
[JsonConverter(typeof(IssuedCurrencyConverter))]
public Common.IssuedCurrency Asset { get; set; }
Property Value
Type Description
Common.IssuedCurrency
| Edit this page View Source

Asset2

Specifies the other pool asset of the AMM instance.

Declaration
[JsonConverter(typeof(IssuedCurrencyConverter))]
public Common.IssuedCurrency Asset2 { get; set; }
Property Value
Type Description
Common.IssuedCurrency
| Edit this page View Source

EPrice

Specifies the effective-price of the token out after successful execution of the transaction.

Declaration
[JsonConverter(typeof(CurrencyConverter))]
public Currency EPrice { get; set; }
Property Value
Type Description
Currency
| Edit this page View Source

Flags

Declaration
public AMMWithdrawFlags? Flags { get; set; }
Property Value
Type Description
AMMWithdrawFlags?
| Edit this page View Source

LPTokenIn

Specifies the amount of shares of the AMM instance pools that the trader wants to redeem or trade in.

Declaration
[JsonConverter(typeof(CurrencyConverter))]
public Currency LPTokenIn { get; set; }
Property Value
Type Description
Currency

Implements

ITransactionRequest
IAMMWithdraw
ITransactionCommon

Extension Methods

BatchUtils.ToBatchTx(ITransactionRequest)
Utilities.Encode(TransactionRequest)
Utilities.EncodeForMultiSigning(TransactionRequest, string)
Utilities.EncodeForSigning(TransactionRequest)
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX