Show / Hide Table of Contents

Class AMMWithdrawResponse

AMMWithdraw is the withdraw transaction used to remove liquidity from the AMM instance pool, thus redeeming some share of the pools that one owns in the form of LPTokenIn.

Inheritance
object
BaseTransactionResponse
TransactionResponse
AMMWithdrawResponse
Implements
ITransactionResponse
IBaseTransactionResponse
IAMMWithdraw
ITransactionCommon
Inherited Members
TransactionResponse.NetworkID
TransactionResponse.Account
TransactionResponse.AccountTxnID
TransactionResponse.Fee
TransactionResponse.LastLedgerSequence
TransactionResponse.Memos
TransactionResponse.MemoValue
TransactionResponse.Sequence
TransactionResponse.SigningPublicKey
TransactionResponse.Signers
TransactionResponse.TransactionType
TransactionResponse.TransactionSignature
TransactionResponse.Meta
TransactionResponse.ToJson()
TransactionResponse.ToDictionary()
TransactionResponse.SourceTag
TransactionResponse.TicketSequence
BaseTransactionResponse.Date
BaseTransactionResponse.Hash
BaseTransactionResponse.InLedger
BaseTransactionResponse.LedgerIndex
BaseTransactionResponse.Validated
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public class AMMWithdrawResponse : TransactionResponse, ITransactionResponse, IBaseTransactionResponse, IAMMWithdraw, ITransactionCommon

Properties

| Edit this page View Source

Amount

Specifies one of the pools assets that the trader wants to remove. If the asset is XRP, then the Amount is a string specifying the number of drops. Otherwise it is an IssuedCurrencyAmount object.

Declaration
[JsonConverter(typeof(CurrencyConverter))]
public Currency Amount { get; set; }
Property Value
Type Description
Currency
| Edit this page View Source

Amount2

Specifies the other pool asset that the trader wants to remove.

Declaration
[JsonConverter(typeof(CurrencyConverter))]
public Currency Amount2 { get; set; }
Property Value
Type Description
Currency
| Edit this page View Source

Asset

Specifies one of the pool assets (XRP or token) of the AMM instance.

Declaration
[JsonConverter(typeof(IssuedCurrencyConverter))]
public Common.IssuedCurrency Asset { get; set; }
Property Value
Type Description
Common.IssuedCurrency
| Edit this page View Source

Asset2

Specifies the other pool asset of the AMM instance.

Declaration
[JsonConverter(typeof(IssuedCurrencyConverter))]
public Common.IssuedCurrency Asset2 { get; set; }
Property Value
Type Description
Common.IssuedCurrency
| Edit this page View Source

EPrice

Specifies the effective-price of the token out after successful execution of the transaction.

Declaration
[JsonConverter(typeof(CurrencyConverter))]
public Currency EPrice { get; set; }
Property Value
Type Description
Currency
| Edit this page View Source

Flags

Declaration
public AMMWithdrawFlags? Flags { get; set; }
Property Value
Type Description
AMMWithdrawFlags?
| Edit this page View Source

LPTokenIn

Specifies the amount of shares of the AMM instance pools that the trader wants to redeem or trade in.

Declaration
[JsonConverter(typeof(CurrencyConverter))]
public Currency LPTokenIn { get; set; }
Property Value
Type Description
Currency

Implements

ITransactionResponse
IBaseTransactionResponse
IAMMWithdraw
ITransactionCommon
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX