Show / Hide Table of Contents

Class AccountDelete

An AccountDelete transaction deletes an account and any objects it owns in the XRP Ledger, if possible, sending the account's remaining XRP to a specified destination account.

Inheritance
object
TransactionRequest
AccountDelete
Implements
ITransactionRequest
IAccountDelete
ITransactionCommon
IDestination
Inherited Members
TransactionRequest.NetworkID
TransactionRequest.Account
TransactionRequest.AccountTxnID
TransactionRequest.Fee
TransactionRequest.Flags
TransactionRequest.LastLedgerSequence
TransactionRequest.Memos
TransactionRequest.Sequence
TransactionRequest.SigningPublicKey
TransactionRequest.Signers
TransactionRequest.TransactionType
TransactionRequest.TransactionSignature
TransactionRequest.ToJson()
TransactionRequest.ToDictionary()
TransactionRequest.SourceTag
TransactionRequest.TicketSequence
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public class AccountDelete : TransactionRequest, ITransactionRequest, IAccountDelete, ITransactionCommon, IDestination

Constructors

| Edit this page View Source

AccountDelete()

Declaration
public AccountDelete()

Properties

| Edit this page View Source

CredentialIDs

(Optional) Set of Credentials (object IDs, hex 64-char each) used to authorize delivering the residual XRP when the destination account requires Deposit Authorization with credential-based preauth (XLS-70). Maximum 8 entries.

Declaration
[JsonPropertyName("CredentialIDs")]
[JsonIgnore(Condition = JsonIgnoreCondition.WhenWritingNull)]
public List<string> CredentialIDs { get; set; }
Property Value
Type Description
List<string>
| Edit this page View Source

Destination

The address of an account to receive any leftover XRP after deleting the sending account.
Must be a funded account in the ledger, and must not be.
the sending account.

Declaration
public string Destination { get; set; }
Property Value
Type Description
string
| Edit this page View Source

DestinationTag

Arbitrary destination tag that identifies a hosted recipient or other.
information for the recipient of the deleted account's leftover XRP.

Declaration
public uint? DestinationTag { get; set; }
Property Value
Type Description
uint?

Implements

ITransactionRequest
IAccountDelete
ITransactionCommon
IDestination

Extension Methods

BatchUtils.ToBatchTx(ITransactionRequest)
Utilities.Encode(TransactionRequest)
Utilities.EncodeForMultiSigning(TransactionRequest, string)
Utilities.EncodeForSigning(TransactionRequest)
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX