Show / Hide Table of Contents

Class AccountDeleteResponse

An AccountDelete transaction deletes an account and any objects it owns in the XRP Ledger, if possible, sending the account's remaining XRP to a specified destination account.

Inheritance
object
BaseTransactionResponse
TransactionResponse
AccountDeleteResponse
Implements
ITransactionResponse
IBaseTransactionResponse
IAccountDelete
ITransactionCommon
IDestination
Inherited Members
TransactionResponse.NetworkID
TransactionResponse.Account
TransactionResponse.AccountTxnID
TransactionResponse.Fee
TransactionResponse.Flags
TransactionResponse.LastLedgerSequence
TransactionResponse.Memos
TransactionResponse.MemoValue
TransactionResponse.Sequence
TransactionResponse.SigningPublicKey
TransactionResponse.Signers
TransactionResponse.TransactionType
TransactionResponse.TransactionSignature
TransactionResponse.Meta
TransactionResponse.ToJson()
TransactionResponse.ToDictionary()
TransactionResponse.SourceTag
TransactionResponse.TicketSequence
BaseTransactionResponse.Date
BaseTransactionResponse.Hash
BaseTransactionResponse.InLedger
BaseTransactionResponse.LedgerIndex
BaseTransactionResponse.Validated
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public class AccountDeleteResponse : TransactionResponse, ITransactionResponse, IBaseTransactionResponse, IAccountDelete, ITransactionCommon, IDestination

Properties

| Edit this page View Source

CredentialIDs

(Optional) Set of Credentials (object IDs, hex 64-char each) used to authorize delivering the residual XRP when the destination account requires Deposit Authorization with credential-based preauth (XLS-70). Maximum 8 entries.

Declaration
[JsonPropertyName("CredentialIDs")]
[JsonIgnore(Condition = JsonIgnoreCondition.WhenWritingNull)]
public List<string> CredentialIDs { get; set; }
Property Value
Type Description
List<string>
| Edit this page View Source

Destination

The address of an account to receive any leftover XRP after deleting the sending account.
Must be a funded account in the ledger, and must not be.
the sending account.

Declaration
public string Destination { get; set; }
Property Value
Type Description
string
| Edit this page View Source

DestinationTag

Arbitrary destination tag that identifies a hosted recipient or other.
information for the recipient of the deleted account's leftover XRP.

Declaration
public uint? DestinationTag { get; set; }
Property Value
Type Description
uint?

Implements

ITransactionResponse
IBaseTransactionResponse
IAccountDelete
ITransactionCommon
IDestination
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX