Show / Hide Table of Contents

Class AccountSet

An AccountSet transaction modifies the properties of an account in the XRP Ledger.
The AccountSet transaction type has several "AccountSet Flags" (prefixed asf) that can enable an option when passed as the SetFlag parameter,
or disable an option when passed as the ClearFlag parameter.
Newer options have only this style of flag.
You can enable up to one asf flag per transaction, and disable up to one asf flag per transaction.

Inheritance
object
TransactionRequest
AccountSet
Implements
ITransactionRequest
IAccountSet
ITransactionCommon
Inherited Members
TransactionRequest.NetworkID
TransactionRequest.Account
TransactionRequest.AccountTxnID
TransactionRequest.Fee
TransactionRequest.Flags
TransactionRequest.LastLedgerSequence
TransactionRequest.Memos
TransactionRequest.Sequence
TransactionRequest.SigningPublicKey
TransactionRequest.Signers
TransactionRequest.TransactionType
TransactionRequest.TransactionSignature
TransactionRequest.ToJson()
TransactionRequest.ToDictionary()
TransactionRequest.SourceTag
TransactionRequest.TicketSequence
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public class AccountSet : TransactionRequest, ITransactionRequest, IAccountSet, ITransactionCommon

Constructors

| Edit this page View Source

AccountSet()

Declaration
public AccountSet()
| Edit this page View Source

AccountSet(string)

Declaration
public AccountSet(string account)
Parameters
Type Name Description
string account

Properties

| Edit this page View Source

ClearFlag

Unique identifier of a flag to disable for this account.

Declaration
public AccountSetAsfFlags? ClearFlag { get; set; }
Property Value
Type Description
AccountSetAsfFlags?
| Edit this page View Source

Domain

The domain that owns this account, as a string of hex representing the.
ASCII for the domain in lowercase.

Declaration
public string Domain { get; set; }
Property Value
Type Description
string
| Edit this page View Source

EmailHash

Hash of an email address to be used for generating an avatar image.

Declaration
public string EmailHash { get; set; }
Property Value
Type Description
string
| Edit this page View Source

MessageKey

Public key for sending encrypted messages to this account.

Declaration
public string MessageKey { get; set; }
Property Value
Type Description
string
| Edit this page View Source

NFTokenMinter

Optional) Another account that can mint NFTokens for you.

Declaration
public string NFTokenMinter { get; set; }
Property Value
Type Description
string
| Edit this page View Source

SetFlag

Integer flag to enable for this account.

Declaration
public AccountSetAsfFlags? SetFlag { get; set; }
Property Value
Type Description
AccountSetAsfFlags?
| Edit this page View Source

TickSize

Tick size to use for offers involving a currency issued by this address.
The exchange rates of those offers is rounded to this many significant digits.
Valid values are 3 to 15 inclusive, or 0 to disable.

Declaration
public uint? TickSize { get; set; }
Property Value
Type Description
uint?
| Edit this page View Source

TransferRate

The fee to charge when users transfer this account's issued currencies, represented as billionths of a unit.
Cannot be more than 2000000000 or less than 1000000000, except for the special case 0 meaning no fee.

Declaration
public uint? TransferRate { get; set; }
Property Value
Type Description
uint?

Implements

ITransactionRequest
IAccountSet
ITransactionCommon

Extension Methods

BatchUtils.ToBatchTx(ITransactionRequest)
Utilities.Encode(TransactionRequest)
Utilities.EncodeForMultiSigning(TransactionRequest, string)
Utilities.EncodeForSigning(TransactionRequest)
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX