Show / Hide Table of Contents

Enum AccountSetAsfFlags

Enum for AccountSet Flags.

Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public enum AccountSetAsfFlags : uint

Fields

Name Description
asfAccountTxnID

Track the ID of this account's most recent transaction.
Required for AccountTxnID.

asfAllowTrustLineClawback

Allow account to claw back tokens it has issued. (Requires the Clawback amendment.) Can only be set if the account has an empty owner directory (no trust lines, offers, escrows, payment channels, checks, or signer lists). After you set this flag, it cannot be reverted. The account permanently gains the ability to claw back issued assets on trust lines.

asfAllowTrustLineLocking

Allow Trust Line tokens issued by this account to be held in escrow. If not enabled, tokens issued by this account can't be escrowed. After you enable this flag, it cannot be disabled.

asfAuthorizedNFTokenMinter

Allow another account to mint and burn tokens on behalf of this account.

asfDefaultRipple

Enable rippling on this account's trust lines by default.

asfDepositAuth

Enable Deposit Authorization on this account.

asfDisableMaster

Disallow use of the master key pair.
Can only be enabled if the account has configured another way to sign transactions, such as a Regular Key or a Signer List.

asfDisallowIncomingCheck

Block incoming Checks. (Requires the DisallowIncoming amendment.)

asfDisallowIncomingNFTokenOffer

Block incoming NFTokenOffers. (Requires the DisallowIncoming amendment.)

asfDisallowIncomingPayChan

Block incoming Payment Channels. (Requires the DisallowIncoming amendment.)

asfDisallowIncomingTrustline

Block incoming trust lines. (Requires the DisallowIncoming amendment.)

asfDisallowXRP

XRP should not be sent to this account.

asfGlobalFreeze

Freeze all assets issued by this account.

asfNoFreeze

Permanently give up the ability to freeze individual trust lines or disable Global Freeze.
This flag can never be disabled after being enabled.

asfRequireAuth

Require authorization for users to hold balances issued by this address can only be enabled if the address has no trust lines connected to it.

asfRequireDest

Require a destination tag to send transactions to this account.

tfInnerBatchTxn

batch inner transaction

Extension Methods

EmumExtensions.DecodeFlags<AccountSetAsfFlags>(AccountSetAsfFlags)
EmumExtensions.FlagsValues<AccountSetAsfFlags>(AccountSetAsfFlags)
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX