Show / Hide Table of Contents

Class AffectedNode

The AffectedNodes array contains a complete list of the objects in the ledger that this transaction modified in some way.

Inheritance
object
AffectedNode
Implements
IAffectedNode
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public class AffectedNode : IAffectedNode

Properties

| Edit this page View Source

CreatedNode

indicates that the transaction created a new object in the ledger.

Declaration
public CreatedNode? CreatedNode { get; set; }
Property Value
Type Description
CreatedNode
| Edit this page View Source

DeletedNode

indicates that the transaction removed an object from the ledger.

Declaration
public DeletedNode? DeletedNode { get; set; }
Property Value
Type Description
DeletedNode
| Edit this page View Source

ModifiedNode

indicates that the transaction modified an existing object in the ledger. If the modified ledger object has PreviousTxnID and PreviousTxnLgrSeq fields, the transaction always updates them with the transaction's own identifying hash and the index of the ledger version that included the transaction, but these fields' new value is not listed in the FinalFields of the ModifiedNode object, and their previous values are listed at the top level of the ModifiedNode object rather than in the nested PreviousFields object.

Declaration
public ModifiedNode? ModifiedNode { get; set; }
Property Value
Type Description
ModifiedNode

Implements

IAffectedNode
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX