Show / Hide Table of Contents

Enum BatchFlags

Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
[Flags]
public enum BatchFlags : uint

Fields

Name Description
tfAllOrNothing

In ALLORNOTHING mode, all inner transactions must succeed for any one of them to succeed.

tfIndependent

All transactions are applied, even if one or more of the inner transactions fail.

tfOnlyOne

ONLYONE mode means that the first transaction to succeed is the only one to succeed. All other transactions either failed or were never tried.

tfUntilFailure

UNTILFAILURE applies all transactions until the first failure. All transactions after the first failure are not applied.

Extension Methods

EmumExtensions.DecodeFlags<BatchFlags>(BatchFlags)
EmumExtensions.FlagsValues<BatchFlags>(BatchFlags)
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX