Show / Hide Table of Contents

Class BookOffers

  • Expected response from a BookOffersRequest.
Inheritance
object
BookOffers
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public class BookOffers

Properties

| Edit this page View Source

LedgerCurrentIndex

The ledger index of the current in-progress ledger version, which was used to retrieve this information.

Declaration
[JsonPropertyName("ledger_current_index")]
public uint? LedgerCurrentIndex { get; set; }
Property Value
Type Description
uint?
| Edit this page View Source

LedgerHash

The identifying hash of the ledger version that was used when retrieving this data, as requested.

Declaration
[JsonPropertyName("ledger_hash")]
public string LedgerHash { get; set; }
Property Value
Type Description
string
| Edit this page View Source

LedgerIndex

The ledger index of the ledger version that was used when retrieving this data, as requested.

Declaration
[JsonPropertyName("ledger_index")]
public uint? LedgerIndex { get; set; }
Property Value
Type Description
uint?
| Edit this page View Source

Offers

Array of offer objects, each of which has the fields of an Offer object.

Declaration
[JsonPropertyName("offers")]
public List<Offer> Offers { get; set; }
Property Value
Type Description
List<Offer>
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX