Class CheckCancel
Cancels an unredeemed Check, removing it from the ledger without sending any money.
The source or the destination of the check can cancel a Check at any time using this transaction type.
If the Check has expired, any address can cancel it.
Inherited Members
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public class CheckCancel : TransactionRequest, ITransactionRequest, ICheckCancel, ITransactionCommon
Constructors
| Edit this page View SourceCheckCancel()
Declaration
public CheckCancel()
Properties
| Edit this page View SourceCheckID
The ID of the Check ledger object to cancel as a 64-character hexadecimal string.
Declaration
public string CheckID { get; set; }
Property Value
| Type | Description |
|---|---|
| string |