Show / Hide Table of Contents

Class CheckCancelResponse

Cancels an unredeemed Check, removing it from the ledger without sending any money.
The source or the destination of the check can cancel a Check at any time using this transaction type.
If the Check has expired, any address can cancel it.

Inheritance
object
BaseTransactionResponse
TransactionResponse
CheckCancelResponse
Implements
ITransactionResponse
IBaseTransactionResponse
ICheckCancel
ITransactionCommon
Inherited Members
TransactionResponse.NetworkID
TransactionResponse.Account
TransactionResponse.AccountTxnID
TransactionResponse.Fee
TransactionResponse.Flags
TransactionResponse.LastLedgerSequence
TransactionResponse.Memos
TransactionResponse.MemoValue
TransactionResponse.Sequence
TransactionResponse.SigningPublicKey
TransactionResponse.Signers
TransactionResponse.TransactionType
TransactionResponse.TransactionSignature
TransactionResponse.Meta
TransactionResponse.ToJson()
TransactionResponse.ToDictionary()
TransactionResponse.SourceTag
TransactionResponse.TicketSequence
BaseTransactionResponse.Date
BaseTransactionResponse.Hash
BaseTransactionResponse.InLedger
BaseTransactionResponse.LedgerIndex
BaseTransactionResponse.Validated
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public class CheckCancelResponse : TransactionResponse, ITransactionResponse, IBaseTransactionResponse, ICheckCancel, ITransactionCommon

Properties

| Edit this page View Source

CheckID

The ID of the Check ledger object to cancel as a 64-character hexadecimal string.

Declaration
public string CheckID { get; set; }
Property Value
Type Description
string

Implements

ITransactionResponse
IBaseTransactionResponse
ICheckCancel
ITransactionCommon
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX