Show / Hide Table of Contents

Class CheckCash

Attempts to redeem a Check object in the ledger to receive up to the amount authorized by the corresponding CheckCreate transaction.
Only the Destination address of a Check can cash it with a CheckCash transaction.

Inheritance
object
TransactionRequest
CheckCash
Implements
ITransactionRequest
ICheckCash
ITransactionCommon
Inherited Members
TransactionRequest.NetworkID
TransactionRequest.Account
TransactionRequest.AccountTxnID
TransactionRequest.Fee
TransactionRequest.Flags
TransactionRequest.LastLedgerSequence
TransactionRequest.Memos
TransactionRequest.Sequence
TransactionRequest.SigningPublicKey
TransactionRequest.Signers
TransactionRequest.TransactionType
TransactionRequest.TransactionSignature
TransactionRequest.ToJson()
TransactionRequest.ToDictionary()
TransactionRequest.SourceTag
TransactionRequest.TicketSequence
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public class CheckCash : TransactionRequest, ITransactionRequest, ICheckCash, ITransactionCommon

Constructors

| Edit this page View Source

CheckCash()

Declaration
public CheckCash()

Properties

| Edit this page View Source

Amount

Redeem the Check for exactly this amount, if possible.
The currency must match that of the SendMax of the corresponding CheckCreate transaction.
You.
must provide either this field or DeliverMin.

Declaration
[JsonConverter(typeof(CurrencyConverter))]
public Currency? Amount { get; set; }
Property Value
Type Description
Currency
| Edit this page View Source

CheckID

The ID of the Check ledger object to cash as a 64-character hexadecimal string.

Declaration
public string CheckID { get; set; }
Property Value
Type Description
string
| Edit this page View Source

DeliverMin

Redeem the Check for at least this amount and for as much as possible.
The currency must match that of the SendMax of the corresponding CheckCreate.
transaction.
You must provide either this field or Amount.

Declaration
[JsonConverter(typeof(CurrencyConverter))]
public Currency? DeliverMin { get; set; }
Property Value
Type Description
Currency

Implements

ITransactionRequest
ICheckCash
ITransactionCommon

Extension Methods

BatchUtils.ToBatchTx(ITransactionRequest)
Utilities.Encode(TransactionRequest)
Utilities.EncodeForMultiSigning(TransactionRequest, string)
Utilities.EncodeForSigning(TransactionRequest)
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX