Show / Hide Table of Contents

Class CheckCashResponse

Attempts to redeem a Check object in the ledger to receive up to the amount authorized by the corresponding CheckCreate transaction.
Only the Destination address of a Check can cash it with a CheckCash transaction.

Inheritance
object
BaseTransactionResponse
TransactionResponse
CheckCashResponse
Implements
ITransactionResponse
IBaseTransactionResponse
ICheckCash
ITransactionCommon
Inherited Members
TransactionResponse.NetworkID
TransactionResponse.Account
TransactionResponse.AccountTxnID
TransactionResponse.Fee
TransactionResponse.Flags
TransactionResponse.LastLedgerSequence
TransactionResponse.Memos
TransactionResponse.MemoValue
TransactionResponse.Sequence
TransactionResponse.SigningPublicKey
TransactionResponse.Signers
TransactionResponse.TransactionType
TransactionResponse.TransactionSignature
TransactionResponse.Meta
TransactionResponse.ToJson()
TransactionResponse.ToDictionary()
TransactionResponse.SourceTag
TransactionResponse.TicketSequence
BaseTransactionResponse.Date
BaseTransactionResponse.Hash
BaseTransactionResponse.InLedger
BaseTransactionResponse.LedgerIndex
BaseTransactionResponse.Validated
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public class CheckCashResponse : TransactionResponse, ITransactionResponse, IBaseTransactionResponse, ICheckCash, ITransactionCommon

Properties

| Edit this page View Source

Amount

Redeem the Check for exactly this amount, if possible.
The currency must match that of the SendMax of the corresponding CheckCreate transaction.
You.
must provide either this field or DeliverMin.

Declaration
[JsonConverter(typeof(CurrencyConverter))]
public Currency? Amount { get; set; }
Property Value
Type Description
Currency
| Edit this page View Source

CheckID

The ID of the Check ledger object to cash as a 64-character hexadecimal string.

Declaration
public string CheckID { get; set; }
Property Value
Type Description
string
| Edit this page View Source

DeliverMin

Redeem the Check for at least this amount and for as much as possible.
The currency must match that of the SendMax of the corresponding CheckCreate.
transaction.
You must provide either this field or Amount.

Declaration
[JsonConverter(typeof(CurrencyConverter))]
public Currency? DeliverMin { get; set; }
Property Value
Type Description
Currency

Implements

ITransactionResponse
IBaseTransactionResponse
ICheckCash
ITransactionCommon
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX