Show / Hide Table of Contents

Class CheckCreate

Create a Check object in the ledger, which is a deferred payment that can be cashed by its intended destination.
The sender of this transaction is the sender of the Check.

Inheritance
object
TransactionRequest
CheckCreate
Implements
ITransactionRequest
ICheckCreate
ITransactionCommon
IDestination
Inherited Members
TransactionRequest.NetworkID
TransactionRequest.Account
TransactionRequest.AccountTxnID
TransactionRequest.Fee
TransactionRequest.Flags
TransactionRequest.LastLedgerSequence
TransactionRequest.Memos
TransactionRequest.Sequence
TransactionRequest.SigningPublicKey
TransactionRequest.Signers
TransactionRequest.TransactionType
TransactionRequest.TransactionSignature
TransactionRequest.ToJson()
TransactionRequest.ToDictionary()
TransactionRequest.SourceTag
TransactionRequest.TicketSequence
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public class CheckCreate : TransactionRequest, ITransactionRequest, ICheckCreate, ITransactionCommon, IDestination

Constructors

| Edit this page View Source

CheckCreate()

Declaration
public CheckCreate()

Properties

| Edit this page View Source

Destination

The unique address of the account that can cash the Check.

Declaration
public string Destination { get; set; }
Property Value
Type Description
string
| Edit this page View Source

DestinationTag

Arbitrary tag that identifies the reason for the Check, or a hosted.
recipient to pay.

Declaration
public uint? DestinationTag { get; set; }
Property Value
Type Description
uint?
| Edit this page View Source

Expiration

Time after which the Check is no longer valid, in seconds since the Ripple.
Epoch.

Declaration
public DateTime? Expiration { get; set; }
Property Value
Type Description
Nullable
| Edit this page View Source

InvoiceID

Arbitrary 256-bit hash representing a specific reason or identifier for.
this Check.

Declaration
public uint? InvoiceID { get; set; }
Property Value
Type Description
uint?
| Edit this page View Source

SendMax

Maximum amount of source currency the Check is allowed to debit the sender, including transfer fees on non-XRP currencies.
The Check can only credit the destination with the same currency (from the same issuer, for non-XRP currencies).
For non-XRP amounts, the nested field names MUST be.
lower-case.

Declaration
public Currency SendMax { get; set; }
Property Value
Type Description
Currency

Implements

ITransactionRequest
ICheckCreate
ITransactionCommon
IDestination

Extension Methods

BatchUtils.ToBatchTx(ITransactionRequest)
Utilities.Encode(TransactionRequest)
Utilities.EncodeForMultiSigning(TransactionRequest, string)
Utilities.EncodeForSigning(TransactionRequest)
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX