Show / Hide Table of Contents

Class ClawBack

Claw back tokens issued by your account. Issuers can only claw back trust line tokens if they enabled the Allow Trust Line Clawback setting before issuing any tokens. Issuers can claw back MPTs if the corresponding MPT Issuance has clawback enabled.

Inheritance
object
TransactionRequest
ClawBack
Implements
ITransactionRequest
IClawBack
ITransactionCommon
Inherited Members
TransactionRequest.NetworkID
TransactionRequest.Account
TransactionRequest.AccountTxnID
TransactionRequest.Fee
TransactionRequest.Flags
TransactionRequest.LastLedgerSequence
TransactionRequest.Memos
TransactionRequest.Sequence
TransactionRequest.SigningPublicKey
TransactionRequest.Signers
TransactionRequest.TransactionType
TransactionRequest.TransactionSignature
TransactionRequest.ToJson()
TransactionRequest.ToDictionary()
TransactionRequest.SourceTag
TransactionRequest.TicketSequence
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public class ClawBack : TransactionRequest, ITransactionRequest, IClawBack, ITransactionCommon

Constructors

| Edit this page View Source

ClawBack()

Declaration
public ClawBack()

Properties

| Edit this page View Source

Amount

The amount to claw back. The quantity in the value sub-field must not be zero. If this is more than the current balance, the transaction claws back the entire balance. When clawing back trust line tokens, the issuer sub-field indicates the token holder to claw back tokens from.

Declaration
[JsonConverter(typeof(CurrencyConverter))]
public Currency Amount { get; set; }
Property Value
Type Description
Currency
| Edit this page View Source

Holder

The holder to claw back tokens from, if clawing back MPTs. The holder must have a non-zero balance of the MPT issuance indicated in the Amount field. Required for MPT clawback, must be omitted for trust line token clawback.

Declaration
[JsonPropertyName("Holder")]
public string Holder { get; set; }
Property Value
Type Description
string

Implements

ITransactionRequest
IClawBack
ITransactionCommon

Extension Methods

BatchUtils.ToBatchTx(ITransactionRequest)
Utilities.Encode(TransactionRequest)
Utilities.EncodeForMultiSigning(TransactionRequest, string)
Utilities.EncodeForSigning(TransactionRequest)
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX