Show / Hide Table of Contents

Class ClawBackResponse

Claw back tokens issued by your account. Issuers can only claw back trust line tokens if they enabled the Allow Trust Line Clawback setting before issuing any tokens. Issuers can claw back MPTs if the corresponding MPT Issuance has clawback enabled.

Inheritance
object
BaseTransactionResponse
TransactionResponse
ClawBackResponse
Implements
ITransactionResponse
IBaseTransactionResponse
IClawBack
ITransactionCommon
Inherited Members
TransactionResponse.NetworkID
TransactionResponse.Account
TransactionResponse.AccountTxnID
TransactionResponse.Fee
TransactionResponse.Flags
TransactionResponse.LastLedgerSequence
TransactionResponse.Memos
TransactionResponse.MemoValue
TransactionResponse.Sequence
TransactionResponse.SigningPublicKey
TransactionResponse.Signers
TransactionResponse.TransactionType
TransactionResponse.TransactionSignature
TransactionResponse.Meta
TransactionResponse.ToJson()
TransactionResponse.ToDictionary()
TransactionResponse.SourceTag
TransactionResponse.TicketSequence
BaseTransactionResponse.Date
BaseTransactionResponse.Hash
BaseTransactionResponse.InLedger
BaseTransactionResponse.LedgerIndex
BaseTransactionResponse.Validated
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public class ClawBackResponse : TransactionResponse, ITransactionResponse, IBaseTransactionResponse, IClawBack, ITransactionCommon

Properties

| Edit this page View Source

Amount

The amount to claw back. The quantity in the value sub-field must not be zero. If this is more than the current balance, the transaction claws back the entire balance. When clawing back trust line tokens, the issuer sub-field indicates the token holder to claw back tokens from.

Declaration
[JsonConverter(typeof(CurrencyConverter))]
public Currency Amount { get; set; }
Property Value
Type Description
Currency
| Edit this page View Source

Holder

The holder to claw back tokens from, if clawing back MPTs. The holder must have a non-zero balance of the MPT issuance indicated in the Amount field. Required for MPT clawback, must be omitted for trust line token clawback.

Declaration
[JsonPropertyName("Holder")]
public string Holder { get; set; }
Property Value
Type Description
string

Implements

ITransactionResponse
IBaseTransactionResponse
IClawBack
ITransactionCommon
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX