Show / Hide Table of Contents

Class ConfidentialMPTClawback

Claws back a confidential MPT amount from a holder (issuer only).

Inheritance
object
TransactionRequest
ConfidentialMPTClawback
Implements
ITransactionRequest
IConfidentialMPTClawback
ITransactionCommon
Inherited Members
TransactionRequest.NetworkID
TransactionRequest.Account
TransactionRequest.AccountTxnID
TransactionRequest.Fee
TransactionRequest.Flags
TransactionRequest.LastLedgerSequence
TransactionRequest.Memos
TransactionRequest.Sequence
TransactionRequest.SigningPublicKey
TransactionRequest.Signers
TransactionRequest.TransactionType
TransactionRequest.TransactionSignature
TransactionRequest.ToJson()
TransactionRequest.ToDictionary()
TransactionRequest.SourceTag
TransactionRequest.TicketSequence
TransactionRequest.Sponsor
TransactionRequest.SponsorFlags
TransactionRequest.Delegate
TransactionRequest.OperationLimit
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public class ConfidentialMPTClawback : TransactionRequest, ITransactionRequest, IConfidentialMPTClawback, ITransactionCommon
Remarks

Requires the ConfidentialTransfer amendment. This feature is in draft and subject to change.

Constructors

| Edit this page View Source

ConfidentialMPTClawback()

Declaration
public ConfidentialMPTClawback()

Properties

| Edit this page View Source

Holder

The account the amount is clawed back from.

Declaration
[JsonPropertyName("Holder")]
public string Holder { get; set; }
Property Value
Type Description
string
| Edit this page View Source

MPTAmount

The amount being clawed back, as a decimal string.

Declaration
[JsonPropertyName("MPTAmount")]
public string MPTAmount { get; set; }
Property Value
Type Description
string
| Edit this page View Source

MPTokenIssuanceID

The ID of the MPT issuance the amount is clawed back in.

Declaration
[JsonPropertyName("MPTokenIssuanceID")]
public string MPTokenIssuanceID { get; set; }
Property Value
Type Description
string
| Edit this page View Source

ZKProof

The zero-knowledge proof over the clawed-back amount, hex-encoded.

Declaration
[JsonPropertyName("ZKProof")]
public string ZKProof { get; set; }
Property Value
Type Description
string

Implements

ITransactionRequest
IConfidentialMPTClawback
ITransactionCommon

Extension Methods

BatchUtils.ToBatchTx(ITransactionRequest)
Utilities.Encode(TransactionRequest)
Utilities.EncodeForMultiSigning(TransactionRequest, string)
Utilities.EncodeForSigning(TransactionRequest)
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX