Class ConfidentialMPTConvert
Converts a public MPT balance into a confidential (encrypted) balance.
Inherited Members
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public class ConfidentialMPTConvert : TransactionRequest, ITransactionRequest, IConfidentialMPTConvert, ITransactionCommon
Remarks
Requires the ConfidentialTransfer amendment. This feature is in draft and subject to change.
Constructors
| Edit this page View SourceConfidentialMPTConvert()
Declaration
public ConfidentialMPTConvert()
Properties
| Edit this page View SourceAuditorEncryptedAmount
(Optional) The converted amount encrypted under the auditor's key, hex-encoded.
Declaration
[JsonPropertyName("AuditorEncryptedAmount")]
public string AuditorEncryptedAmount { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
BlindingFactor
The blinding factor of the amount commitment, hex-encoded.
Declaration
[JsonPropertyName("BlindingFactor")]
public string BlindingFactor { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
HolderEncryptedAmount
The converted amount encrypted under the holder's key, hex-encoded.
Declaration
[JsonPropertyName("HolderEncryptedAmount")]
public string HolderEncryptedAmount { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
HolderEncryptionKey
(Optional) The holder's public encryption key, hex-encoded - the key the holder's confidential balances are encrypted under.
Declaration
[JsonPropertyName("HolderEncryptionKey")]
public string HolderEncryptionKey { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
IssuerEncryptedAmount
The converted amount encrypted under the issuer's key, hex-encoded.
Declaration
[JsonPropertyName("IssuerEncryptedAmount")]
public string IssuerEncryptedAmount { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
MPTAmount
The public amount being converted, as a decimal string.
Declaration
[JsonPropertyName("MPTAmount")]
public string MPTAmount { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
MPTokenIssuanceID
The ID of the MPT issuance whose balance is being converted.
Declaration
[JsonPropertyName("MPTokenIssuanceID")]
public string MPTokenIssuanceID { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
ZKProof
(Optional) The zero-knowledge proof over the encrypted amounts, hex-encoded.
Declaration
[JsonPropertyName("ZKProof")]
public string ZKProof { get; set; }
Property Value
| Type | Description |
|---|---|
| string |