Class ConfidentialMPTMergeInboxResponse
Merges the confidential inbox balance into the confidential spending balance.
Inherited Members
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public class ConfidentialMPTMergeInboxResponse : TransactionResponse, ITransactionResponse, IBaseTransactionResponse, ITransactionCommon
Remarks
Requires the ConfidentialTransfer amendment. This feature is in draft and subject to change.
Properties
| Edit this page View SourceMPTokenIssuanceID
Declaration
[JsonPropertyName("MPTokenIssuanceID")]
public string MPTokenIssuanceID { get; set; }
Property Value
| Type | Description |
|---|---|
| string |