Show / Hide Table of Contents

Class CredentialAccept

Accepts a credential that has been provisionally issued to the Account. Once accepted, the credential becomes valid on the ledger and the reserve responsibility transfers from the issuer to the subject (Account). Requires the Credentials amendment.

Inheritance
object
TransactionRequest
CredentialAccept
Implements
ITransactionRequest
ICredentialAccept
ITransactionCommon
Inherited Members
TransactionRequest.NetworkID
TransactionRequest.Account
TransactionRequest.AccountTxnID
TransactionRequest.Fee
TransactionRequest.Flags
TransactionRequest.LastLedgerSequence
TransactionRequest.Memos
TransactionRequest.Sequence
TransactionRequest.SigningPublicKey
TransactionRequest.Signers
TransactionRequest.TransactionType
TransactionRequest.TransactionSignature
TransactionRequest.ToJson()
TransactionRequest.ToDictionary()
TransactionRequest.SourceTag
TransactionRequest.TicketSequence
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public class CredentialAccept : TransactionRequest, ITransactionRequest, ICredentialAccept, ITransactionCommon

Constructors

| Edit this page View Source

CredentialAccept()

Declaration
public CredentialAccept()

Properties

| Edit this page View Source

CredentialType

The type of credential to accept, as a hex-encoded string.

Declaration
[JsonPropertyName("CredentialType")]
public string CredentialType { get; set; }
Property Value
Type Description
string
| Edit this page View Source

CredentialTypeValue

Decoded human-readable value of CredentialType (UTF-8).

Declaration
[JsonIgnore]
public string CredentialTypeValue { get; }
Property Value
Type Description
string
| Edit this page View Source

Issuer

The issuer of the credential to accept.

Declaration
[JsonPropertyName("Issuer")]
public string Issuer { get; set; }
Property Value
Type Description
string

Implements

ITransactionRequest
ICredentialAccept
ITransactionCommon

Extension Methods

BatchUtils.ToBatchTx(ITransactionRequest)
Utilities.Encode(TransactionRequest)
Utilities.EncodeForMultiSigning(TransactionRequest, string)
Utilities.EncodeForSigning(TransactionRequest)
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX