Show / Hide Table of Contents

Class CredentialCreate

Creates a credential on the XRP Ledger. The credential is issued by the transaction sender (Account) to a Subject. The credential is not valid until the Subject accepts it using CredentialAccept. Requires the Credentials amendment.

Inheritance
object
TransactionRequest
CredentialCreate
Implements
ITransactionRequest
ICredentialCreate
ITransactionCommon
Inherited Members
TransactionRequest.NetworkID
TransactionRequest.Account
TransactionRequest.AccountTxnID
TransactionRequest.Fee
TransactionRequest.Flags
TransactionRequest.LastLedgerSequence
TransactionRequest.Memos
TransactionRequest.Sequence
TransactionRequest.SigningPublicKey
TransactionRequest.Signers
TransactionRequest.TransactionType
TransactionRequest.TransactionSignature
TransactionRequest.ToJson()
TransactionRequest.ToDictionary()
TransactionRequest.SourceTag
TransactionRequest.TicketSequence
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public class CredentialCreate : TransactionRequest, ITransactionRequest, ICredentialCreate, ITransactionCommon

Constructors

| Edit this page View Source

CredentialCreate()

Declaration
public CredentialCreate()

Properties

| Edit this page View Source

CredentialType

A value to identify the type of credential, as a hex-encoded string. This must be between 1 and 64 bytes (2 to 128 hex characters).

Declaration
[JsonPropertyName("CredentialType")]
public string CredentialType { get; set; }
Property Value
Type Description
string
| Edit this page View Source

CredentialTypeValue

Decoded human-readable value of CredentialType (UTF-8).

Declaration
[JsonIgnore]
public string CredentialTypeValue { get; }
Property Value
Type Description
string
| Edit this page View Source

Expiration

(Optional) The time after which the credential expires, in seconds since the Ripple Epoch.

Declaration
[JsonConverter(typeof(RippleDateTimeConverter))]
[JsonPropertyName("Expiration")]
public DateTime? Expiration { get; set; }
Property Value
Type Description
Nullable
| Edit this page View Source

Subject

The account that is the subject (recipient) of the credential.

Declaration
[JsonPropertyName("Subject")]
public string Subject { get; set; }
Property Value
Type Description
string
| Edit this page View Source

URI

(Optional) An arbitrary URI reference for additional credential data, as a hex-encoded string. Can be at most 256 bytes (512 hex characters).

Declaration
[JsonPropertyName("URI")]
public string URI { get; set; }
Property Value
Type Description
string
| Edit this page View Source

URIValue

Decoded human-readable value of URI (UTF-8).

Declaration
[JsonIgnore]
public string URIValue { get; }
Property Value
Type Description
string

Implements

ITransactionRequest
ICredentialCreate
ITransactionCommon

Extension Methods

BatchUtils.ToBatchTx(ITransactionRequest)
Utilities.Encode(TransactionRequest)
Utilities.EncodeForMultiSigning(TransactionRequest, string)
Utilities.EncodeForSigning(TransactionRequest)
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX