Show / Hide Table of Contents

Class CredentialCreateResponse

Response for a CredentialCreate transaction.

Inheritance
object
BaseTransactionResponse
TransactionResponse
CredentialCreateResponse
Implements
ITransactionResponse
IBaseTransactionResponse
ICredentialCreate
ITransactionCommon
Inherited Members
TransactionResponse.NetworkID
TransactionResponse.Account
TransactionResponse.AccountTxnID
TransactionResponse.Fee
TransactionResponse.Flags
TransactionResponse.LastLedgerSequence
TransactionResponse.Memos
TransactionResponse.MemoValue
TransactionResponse.Sequence
TransactionResponse.SigningPublicKey
TransactionResponse.Signers
TransactionResponse.TransactionType
TransactionResponse.TransactionSignature
TransactionResponse.Meta
TransactionResponse.ToJson()
TransactionResponse.ToDictionary()
TransactionResponse.SourceTag
TransactionResponse.TicketSequence
BaseTransactionResponse.Date
BaseTransactionResponse.Hash
BaseTransactionResponse.InLedger
BaseTransactionResponse.LedgerIndex
BaseTransactionResponse.Validated
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public class CredentialCreateResponse : TransactionResponse, ITransactionResponse, IBaseTransactionResponse, ICredentialCreate, ITransactionCommon

Properties

| Edit this page View Source

CredentialType

A value to identify the type of credential, as a hex-encoded string. This must be between 1 and 64 bytes (2 to 128 hex characters).

Declaration
[JsonPropertyName("CredentialType")]
public string CredentialType { get; set; }
Property Value
Type Description
string
| Edit this page View Source

CredentialTypeValue

Decoded human-readable value of CredentialType (UTF-8).

Declaration
[JsonIgnore]
public string CredentialTypeValue { get; }
Property Value
Type Description
string
| Edit this page View Source

Expiration

(Optional) The time after which the credential expires, in seconds since the Ripple Epoch.

Declaration
[JsonConverter(typeof(RippleDateTimeConverter))]
[JsonPropertyName("Expiration")]
public DateTime? Expiration { get; set; }
Property Value
Type Description
Nullable
| Edit this page View Source

Subject

The account that is the subject (recipient) of the credential.

Declaration
[JsonPropertyName("Subject")]
public string Subject { get; set; }
Property Value
Type Description
string
| Edit this page View Source

URI

(Optional) An arbitrary URI reference for additional credential data, as a hex-encoded string. Can be at most 256 bytes (512 hex characters).

Declaration
[JsonPropertyName("URI")]
public string URI { get; set; }
Property Value
Type Description
string
| Edit this page View Source

URIValue

Decoded human-readable value of URI (UTF-8).

Declaration
[JsonIgnore]
public string URIValue { get; }
Property Value
Type Description
string

Implements

ITransactionResponse
IBaseTransactionResponse
ICredentialCreate
ITransactionCommon
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX