Show / Hide Table of Contents

Class DIDSetResponse

Creates a new DID ledger entry or updates the fields of an existing one. The DID (Decentralized Identifier) is associated with the sending account.

Inheritance
object
BaseTransactionResponse
TransactionResponse
DIDSetResponse
Implements
ITransactionResponse
IBaseTransactionResponse
IDIDSet
ITransactionCommon
Inherited Members
TransactionResponse.NetworkID
TransactionResponse.Account
TransactionResponse.AccountTxnID
TransactionResponse.Fee
TransactionResponse.Flags
TransactionResponse.LastLedgerSequence
TransactionResponse.Memos
TransactionResponse.MemoValue
TransactionResponse.Sequence
TransactionResponse.SigningPublicKey
TransactionResponse.Signers
TransactionResponse.TransactionType
TransactionResponse.TransactionSignature
TransactionResponse.Meta
TransactionResponse.ToJson()
TransactionResponse.ToDictionary()
TransactionResponse.SourceTag
TransactionResponse.TicketSequence
BaseTransactionResponse.Date
BaseTransactionResponse.Hash
BaseTransactionResponse.InLedger
BaseTransactionResponse.LedgerIndex
BaseTransactionResponse.Validated
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public class DIDSetResponse : TransactionResponse, ITransactionResponse, IBaseTransactionResponse, IDIDSet, ITransactionCommon

Properties

| Edit this page View Source

DIDDocument

The DID document for the DID. This field is encoded as a hexadecimal string and is limited to 256 bytes.

Declaration
[JsonPropertyName("DIDDocument")]
public string DIDDocument { get; set; }
Property Value
Type Description
string
| Edit this page View Source

Data

The public attestations of identity credentials associated with the DID. This field is encoded as a hexadecimal string and is limited to 256 bytes.

Declaration
[JsonPropertyName("Data")]
public string Data { get; set; }
Property Value
Type Description
string
| Edit this page View Source

URI

The Universal Resource Identifier associated with the DID. This field is encoded as a hexadecimal string and is limited to 256 bytes.

Declaration
[JsonPropertyName("URI")]
public string URI { get; set; }
Property Value
Type Description
string

Implements

ITransactionResponse
IBaseTransactionResponse
IDIDSet
ITransactionCommon
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX