Show / Hide Table of Contents

Class DelegateSetResponse

The DelegateSet transaction grants permissions to another account to send transactions on your behalf.

Inheritance
object
BaseTransactionResponse
TransactionResponse
DelegateSetResponse
Implements
ITransactionResponse
IBaseTransactionResponse
IDelegateSet
ITransactionCommon
Inherited Members
TransactionResponse.NetworkID
TransactionResponse.Account
TransactionResponse.AccountTxnID
TransactionResponse.Fee
TransactionResponse.Flags
TransactionResponse.LastLedgerSequence
TransactionResponse.Memos
TransactionResponse.MemoValue
TransactionResponse.Sequence
TransactionResponse.SigningPublicKey
TransactionResponse.Signers
TransactionResponse.TransactionType
TransactionResponse.TransactionSignature
TransactionResponse.Meta
TransactionResponse.ToJson()
TransactionResponse.ToDictionary()
TransactionResponse.SourceTag
TransactionResponse.TicketSequence
BaseTransactionResponse.Date
BaseTransactionResponse.Hash
BaseTransactionResponse.InLedger
BaseTransactionResponse.LedgerIndex
BaseTransactionResponse.Validated
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public class DelegateSetResponse : TransactionResponse, ITransactionResponse, IBaseTransactionResponse, IDelegateSet, ITransactionCommon

Properties

| Edit this page View Source

Delegate

The account to delegate permissions to.

Declaration
[JsonPropertyName("Delegate")]
public string Delegate { get; set; }
Property Value
Type Description
string
| Edit this page View Source

Permissions

An array of permission objects defining which transaction types the delegate can submit.

Declaration
[JsonPropertyName("Permissions")]
public List<PermissionWrapper> Permissions { get; set; }
Property Value
Type Description
List<PermissionWrapper>

Implements

ITransactionResponse
IBaseTransactionResponse
IDelegateSet
ITransactionCommon
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX