Show / Hide Table of Contents

Class DeletedNode

Represents a node that was deleted in a transaction.

Inheritance
object
NodeBase
DeletedNode
Implements
IDeletedNode
Inherited Members
NodeBase.LedgerEntryType
NodeBase.LedgerIndex
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
[JsonConverter(typeof(DeletedNodeConverter))]
public class DeletedNode : NodeBase, IDeletedNode

Properties

| Edit this page View Source

FinalFields

The content fields of the ledger entry immediately before it was deleted. Which fields are present depends on what type of ledger entry was created.

Declaration
[JsonPropertyName("FinalFields")]
public BaseLedgerEntry? FinalFields { get; set; }
Property Value
Type Description
BaseLedgerEntry
| Edit this page View Source

PreviousFields

(May be omitted) Selected fields of the ledger entry before it was deleted. Which fields are present depends on what type of ledger entry was created.

Declaration
[JsonPropertyName("PreviousFields")]
public BaseLedgerEntry? PreviousFields { get; set; }
Property Value
Type Description
BaseLedgerEntry

Methods

| Edit this page View Source

TryGetFinal<T>(out T?)

Declaration
public bool TryGetFinal<T>(out T? value) where T : BaseLedgerEntry
Parameters
Type Name Description
T value
Returns
Type Description
bool
Type Parameters
Name Description
T
| Edit this page View Source

TryGetPrevious<T>(out T?)

Declaration
public bool TryGetPrevious<T>(out T? value) where T : BaseLedgerEntry
Parameters
Type Name Description
T value
Returns
Type Description
bool
Type Parameters
Name Description
T

Implements

IDeletedNode
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX