Show / Hide Table of Contents

Class DepositPreauth

A DepositPreauth transaction gives another account pre-approval to deliver payments to the sender of this transaction.
This is only useful if the sender of this transaction is using (or plans to use) Deposit Authorization.
XLS-70 extends this with credential-based preauthorization via AuthorizeCredentials / UnauthorizeCredentials.

Inheritance
object
TransactionRequest
DepositPreauth
Implements
ITransactionRequest
IDepositPreauth
ITransactionCommon
Inherited Members
TransactionRequest.NetworkID
TransactionRequest.Account
TransactionRequest.AccountTxnID
TransactionRequest.Fee
TransactionRequest.Flags
TransactionRequest.LastLedgerSequence
TransactionRequest.Memos
TransactionRequest.Sequence
TransactionRequest.SigningPublicKey
TransactionRequest.Signers
TransactionRequest.TransactionType
TransactionRequest.TransactionSignature
TransactionRequest.ToJson()
TransactionRequest.ToDictionary()
TransactionRequest.SourceTag
TransactionRequest.TicketSequence
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public class DepositPreauth : TransactionRequest, ITransactionRequest, IDepositPreauth, ITransactionCommon

Constructors

| Edit this page View Source

DepositPreauth()

Declaration
public DepositPreauth()

Properties

| Edit this page View Source

Authorize

The XRP Ledger address of the sender to preauthorize.

Declaration
public string Authorize { get; set; }
Property Value
Type Description
string
| Edit this page View Source

AuthorizeCredentials

(Optional, XLS-70) A set of 1..8 credentials whose holders are preauthorized to deliver payments to the account that submits this transaction. Each entry wraps an AuthorizeCredentialBody with Issuer + CredentialType. Mutually exclusive with Authorize, Unauthorize and UnauthorizeCredentials.

Declaration
[JsonPropertyName("AuthorizeCredentials")]
[JsonIgnore(Condition = JsonIgnoreCondition.WhenWritingNull)]
public List<AuthorizeCredentialEntry> AuthorizeCredentials { get; set; }
Property Value
Type Description
List<AuthorizeCredentialEntry>
| Edit this page View Source

Unauthorize

The XRP Ledger address of a sender whose preauthorization should be revoked.

Declaration
public string Unauthorize { get; set; }
Property Value
Type Description
string
| Edit this page View Source

UnauthorizeCredentials

(Optional, XLS-70) A set of 1..8 credentials to revoke from credential-based preauthorization. Each entry wraps an AuthorizeCredentialBody with Issuer + CredentialType. Mutually exclusive with Authorize, Unauthorize and AuthorizeCredentials.

Declaration
[JsonPropertyName("UnauthorizeCredentials")]
[JsonIgnore(Condition = JsonIgnoreCondition.WhenWritingNull)]
public List<AuthorizeCredentialEntry> UnauthorizeCredentials { get; set; }
Property Value
Type Description
List<AuthorizeCredentialEntry>

Implements

ITransactionRequest
IDepositPreauth
ITransactionCommon

Extension Methods

BatchUtils.ToBatchTx(ITransactionRequest)
Utilities.Encode(TransactionRequest)
Utilities.EncodeForMultiSigning(TransactionRequest, string)
Utilities.EncodeForSigning(TransactionRequest)
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX