Show / Hide Table of Contents

Class DepositPreauthResponse

A DepositPreauth transaction gives another account pre-approval to deliver payments to the sender of this transaction.
This is only useful if the sender of this transaction is using (or plans to use) Deposit Authorization.
XLS-70 extends this with credential-based preauthorization via AuthorizeCredentials / UnauthorizeCredentials.

Inheritance
object
BaseTransactionResponse
TransactionResponse
DepositPreauthResponse
Implements
ITransactionResponse
IBaseTransactionResponse
IDepositPreauth
ITransactionCommon
Inherited Members
TransactionResponse.NetworkID
TransactionResponse.Account
TransactionResponse.AccountTxnID
TransactionResponse.Fee
TransactionResponse.Flags
TransactionResponse.LastLedgerSequence
TransactionResponse.Memos
TransactionResponse.MemoValue
TransactionResponse.Sequence
TransactionResponse.SigningPublicKey
TransactionResponse.Signers
TransactionResponse.TransactionType
TransactionResponse.TransactionSignature
TransactionResponse.Meta
TransactionResponse.ToJson()
TransactionResponse.ToDictionary()
TransactionResponse.SourceTag
TransactionResponse.TicketSequence
BaseTransactionResponse.Date
BaseTransactionResponse.Hash
BaseTransactionResponse.InLedger
BaseTransactionResponse.LedgerIndex
BaseTransactionResponse.Validated
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public class DepositPreauthResponse : TransactionResponse, ITransactionResponse, IBaseTransactionResponse, IDepositPreauth, ITransactionCommon

Properties

| Edit this page View Source

Authorize

The XRP Ledger address of the sender to preauthorize.

Declaration
public string Authorize { get; set; }
Property Value
Type Description
string
| Edit this page View Source

AuthorizeCredentials

(Optional, XLS-70) A set of 1..8 credentials whose holders are preauthorized to deliver payments to the account that submits this transaction. Each entry wraps an AuthorizeCredentialBody with Issuer + CredentialType. Mutually exclusive with Authorize, Unauthorize and UnauthorizeCredentials.

Declaration
[JsonPropertyName("AuthorizeCredentials")]
[JsonIgnore(Condition = JsonIgnoreCondition.WhenWritingNull)]
public List<AuthorizeCredentialEntry> AuthorizeCredentials { get; set; }
Property Value
Type Description
List<AuthorizeCredentialEntry>
| Edit this page View Source

Unauthorize

The XRP Ledger address of a sender whose preauthorization should be revoked.

Declaration
public string Unauthorize { get; set; }
Property Value
Type Description
string
| Edit this page View Source

UnauthorizeCredentials

(Optional, XLS-70) A set of 1..8 credentials to revoke from credential-based preauthorization. Each entry wraps an AuthorizeCredentialBody with Issuer + CredentialType. Mutually exclusive with Authorize, Unauthorize and AuthorizeCredentials.

Declaration
[JsonPropertyName("UnauthorizeCredentials")]
[JsonIgnore(Condition = JsonIgnoreCondition.WhenWritingNull)]
public List<AuthorizeCredentialEntry> UnauthorizeCredentials { get; set; }
Property Value
Type Description
List<AuthorizeCredentialEntry>

Implements

ITransactionResponse
IBaseTransactionResponse
IDepositPreauth
ITransactionCommon
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX