Class EscrowFinish
Deliver XRP or escrowed fungible tokens (IOUs, MPTs) from a held payment to the recipient. Requires the TokenEscrow amendment for fungible token support.
Inherited Members
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public class EscrowFinish : TransactionRequest, ITransactionRequest, IEscrowFinish, ITransactionCommon
Constructors
| Edit this page View SourceEscrowFinish()
Declaration
public EscrowFinish()
EscrowFinish(string, uint, string, string)
Declaration
public EscrowFinish(string owner, uint offerSequence, string condition, string fulfillment)
Parameters
| Type | Name | Description |
|---|---|---|
| string | owner | |
| uint | offerSequence | |
| string | condition | |
| string | fulfillment |
Properties
| Edit this page View SourceCondition
Hex value matching the previously-supplied PREIMAGE-SHA-256.
crypto-condition of the held payment.
Declaration
public string Condition { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
CredentialIDs
(Optional) Set of Credentials (object IDs, hex 64-char each) used to authorize finishing the escrow when the destination account requires Deposit Authorization with credential-based preauth (XLS-70). Maximum 8 entries.
Declaration
[JsonPropertyName("CredentialIDs")]
[JsonIgnore(Condition = JsonIgnoreCondition.WhenWritingNull)]
public List<string> CredentialIDs { get; set; }
Property Value
| Type | Description |
|---|---|
| List<string> |
Fulfillment
Hex value of the PREIMAGE-SHA-256 crypto-condition fulfillment matching.
the held payment's Condition.
Declaration
public string Fulfillment { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
OfferSequence
Transaction sequence of EscrowCreate transaction that created the held.
payment to finish.
Declaration
public uint OfferSequence { get; set; }
Property Value
| Type | Description |
|---|---|
| uint |
Owner
Address of the source account that funded the escrow.
Declaration
public string Owner { get; set; }
Property Value
| Type | Description |
|---|---|
| string |