Show / Hide Table of Contents

Class EscrowFinishResponse

Deliver XRP or escrowed fungible tokens (IOUs, MPTs) from a held payment to the recipient. Requires the TokenEscrow amendment for fungible token support.

Inheritance
object
BaseTransactionResponse
TransactionResponse
EscrowFinishResponse
Implements
ITransactionResponse
IBaseTransactionResponse
IEscrowFinish
ITransactionCommon
Inherited Members
TransactionResponse.NetworkID
TransactionResponse.Account
TransactionResponse.AccountTxnID
TransactionResponse.Fee
TransactionResponse.Flags
TransactionResponse.LastLedgerSequence
TransactionResponse.Memos
TransactionResponse.MemoValue
TransactionResponse.Sequence
TransactionResponse.SigningPublicKey
TransactionResponse.Signers
TransactionResponse.TransactionType
TransactionResponse.TransactionSignature
TransactionResponse.Meta
TransactionResponse.ToJson()
TransactionResponse.ToDictionary()
TransactionResponse.SourceTag
TransactionResponse.TicketSequence
BaseTransactionResponse.Date
BaseTransactionResponse.Hash
BaseTransactionResponse.InLedger
BaseTransactionResponse.LedgerIndex
BaseTransactionResponse.Validated
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public class EscrowFinishResponse : TransactionResponse, ITransactionResponse, IBaseTransactionResponse, IEscrowFinish, ITransactionCommon

Properties

| Edit this page View Source

Condition

Hex value matching the previously-supplied PREIMAGE-SHA-256.
crypto-condition of the held payment.

Declaration
public string Condition { get; set; }
Property Value
Type Description
string
| Edit this page View Source

CredentialIDs

(Optional) Set of Credentials (object IDs, hex 64-char each) used to authorize finishing the escrow when the destination account requires Deposit Authorization with credential-based preauth (XLS-70). Maximum 8 entries.

Declaration
[JsonPropertyName("CredentialIDs")]
[JsonIgnore(Condition = JsonIgnoreCondition.WhenWritingNull)]
public List<string> CredentialIDs { get; set; }
Property Value
Type Description
List<string>
| Edit this page View Source

Fulfillment

Hex value of the PREIMAGE-SHA-256 crypto-condition fulfillment matching.
the held payment's Condition.

Declaration
public string Fulfillment { get; set; }
Property Value
Type Description
string
| Edit this page View Source

OfferSequence

Transaction sequence of EscrowCreate transaction that created the held.
payment to finish.

Declaration
public uint OfferSequence { get; set; }
Property Value
Type Description
uint
| Edit this page View Source

Owner

Address of the source account that funded the escrow.

Declaration
public string Owner { get; set; }
Property Value
Type Description
string

Implements

ITransactionResponse
IBaseTransactionResponse
IEscrowFinish
ITransactionCommon
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX