Show / Hide Table of Contents

Interface IAMMBid

AMMBid is used for submitting a vote for the trading fee of an AMM Instance. Any XRPL account that holds LPToken for an AMM instance may submit this transaction to vote for the trading fee for that instance.

Inherited Members
ITransactionCommon.NetworkID
ITransactionCommon.Account
ITransactionCommon.AccountTxnID
ITransactionCommon.Fee
ITransactionCommon.Flags
ITransactionCommon.LastLedgerSequence
ITransactionCommon.Memos
ITransactionCommon.MemoValue
ITransactionCommon.Sequence
ITransactionCommon.Signers
ITransactionCommon.SigningPublicKey
ITransactionCommon.TransactionSignature
ITransactionCommon.TransactionType
ITransactionCommon.SourceTag
ITransactionCommon.TicketSequence
ITransactionCommon.ToJson()
ITransactionCommon.ToDictionary()
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public interface IAMMBid : ITransactionCommon

Properties

| Edit this page View Source

Asset

Specifies one of the pool assets (XRP or token) of the AMM instance.

Declaration
Common.IssuedCurrency Asset { get; set; }
Property Value
Type Description
Common.IssuedCurrency
| Edit this page View Source

Asset2

Specifies the other pool asset of the AMM instance.

Declaration
Common.IssuedCurrency Asset2 { get; set; }
Property Value
Type Description
Common.IssuedCurrency
| Edit this page View Source

AuthAccounts

This field represents an array of XRPL account IDs that are authorized to trade at the discounted fee against the AMM instance. A maximum of four accounts can be provided.

Declaration
List<AuthAccount> AuthAccounts { get; set; }
Property Value
Type Description
List<AuthAccount>
| Edit this page View Source

BidMax

This field represents the maximum price that the bidder wants to pay for the slot. It is specified in units of LPToken.

Declaration
Currency? BidMax { get; set; }
Property Value
Type Description
Currency
| Edit this page View Source

BidMin

This field represents the minimum price that the bidder wants to pay for the slot. It is specified in units of LPToken.If specified let BidMin be X and let the slot-price computed by price scheduling algorithm be Y, then bidder always pays the max(X, Y).

Declaration
Currency? BidMin { get; set; }
Property Value
Type Description
Currency
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX