Show / Hide Table of Contents

Interface IAMMClawBack

Claw back tokens from an Automated Market Maker (AMM) pool. This transaction allows a token issuer to recover tokens that a holder has deposited into an AMM. The issuer must have enabled clawback on their account before issuing any tokens.

Inherited Members
ITransactionCommon.NetworkID
ITransactionCommon.Account
ITransactionCommon.AccountTxnID
ITransactionCommon.Fee
ITransactionCommon.Flags
ITransactionCommon.LastLedgerSequence
ITransactionCommon.Memos
ITransactionCommon.MemoValue
ITransactionCommon.Sequence
ITransactionCommon.Signers
ITransactionCommon.SigningPublicKey
ITransactionCommon.TransactionSignature
ITransactionCommon.TransactionType
ITransactionCommon.SourceTag
ITransactionCommon.TicketSequence
ITransactionCommon.ToJson()
ITransactionCommon.ToDictionary()
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public interface IAMMClawBack : ITransactionCommon

Properties

| Edit this page View Source

Amount

The amount of the asset to claw back from the AMM pool. If not provided, claws back the maximum possible amount.

Declaration
Currency Amount { get; set; }
Property Value
Type Description
Currency
| Edit this page View Source

Asset

Specifies one of the pool assets (XRP or token) of the AMM instance. Together with Asset2, this identifies which AMM pool to claw back from.

Declaration
Common.IssuedCurrency Asset { get; set; }
Property Value
Type Description
Common.IssuedCurrency
| Edit this page View Source

Asset2

Specifies the other pool asset of the AMM instance. Together with Asset, this identifies which AMM pool to claw back from.

Declaration
Common.IssuedCurrency Asset2 { get; set; }
Property Value
Type Description
Common.IssuedCurrency
| Edit this page View Source

Holder

The account holding the asset to be clawed back. This is the holder who deposited tokens into the AMM pool.

Declaration
string Holder { get; set; }
Property Value
Type Description
string
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX