Show / Hide Table of Contents

Interface IAMMDeposit

AMMDeposit is the deposit transaction used to add liquidity to the AMM instance pool, thus obtaining some share of the instance's pools in the form of LPTokenOut. The following are the recommended valid combinations:

  • LPTokenOut
  • Amount
  • Amount and Amount2
  • Amount and LPTokenOut
  • Amount and EPrice
Inherited Members
ITransactionCommon.NetworkID
ITransactionCommon.Account
ITransactionCommon.AccountTxnID
ITransactionCommon.Fee
ITransactionCommon.LastLedgerSequence
ITransactionCommon.Memos
ITransactionCommon.MemoValue
ITransactionCommon.Sequence
ITransactionCommon.Signers
ITransactionCommon.SigningPublicKey
ITransactionCommon.TransactionSignature
ITransactionCommon.TransactionType
ITransactionCommon.SourceTag
ITransactionCommon.TicketSequence
ITransactionCommon.ToJson()
ITransactionCommon.ToDictionary()
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public interface IAMMDeposit : ITransactionCommon

Properties

| Edit this page View Source

Amount

Specifies one of the pool assets (XRP or token) of the AMM instance to deposit more of its value.

Declaration
Currency? Amount { get; set; }
Property Value
Type Description
Currency
| Edit this page View Source

Amount2

Specifies the other pool asset of the AMM instance to deposit more of its value.

Declaration
Currency? Amount2 { get; set; }
Property Value
Type Description
Currency
| Edit this page View Source

Asset

Specifies one of the pool assets (XRP or token) of the AMM instance.

Declaration
Common.IssuedCurrency Asset { get; set; }
Property Value
Type Description
Common.IssuedCurrency
| Edit this page View Source

Asset2

Specifies the other pool asset of the AMM instance.

Declaration
Common.IssuedCurrency Asset2 { get; set; }
Property Value
Type Description
Common.IssuedCurrency
| Edit this page View Source

EPrice

Specifies the maximum effective-price that LPTokenOut can be traded out.

Declaration
Currency? EPrice { get; set; }
Property Value
Type Description
Currency
| Edit this page View Source

Flags

Declaration
AMMDepositFlags? Flags { get; set; }
Property Value
Type Description
AMMDepositFlags?
| Edit this page View Source

LPTokenOut

Specifies the amount of shares of the AMM instance pools that the trader wants to redeem or trade in.

Declaration
Currency? LPTokenOut { get; set; }
Property Value
Type Description
Currency
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX