Show / Hide Table of Contents

Interface ICheckCancel

Cancels an unredeemed Check, removing it from the ledger without sending any money.
The source or the destination of the check can cancel a Check at any time using this transaction type.
If the Check has expired, any address can cancel it.

Inherited Members
ITransactionCommon.NetworkID
ITransactionCommon.Account
ITransactionCommon.AccountTxnID
ITransactionCommon.Fee
ITransactionCommon.Flags
ITransactionCommon.LastLedgerSequence
ITransactionCommon.Memos
ITransactionCommon.MemoValue
ITransactionCommon.Sequence
ITransactionCommon.Signers
ITransactionCommon.SigningPublicKey
ITransactionCommon.TransactionSignature
ITransactionCommon.TransactionType
ITransactionCommon.SourceTag
ITransactionCommon.TicketSequence
ITransactionCommon.ToJson()
ITransactionCommon.ToDictionary()
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public interface ICheckCancel : ITransactionCommon

Properties

| Edit this page View Source

CheckID

The ID of the Check ledger object to cancel as a 64-character hexadecimal string.

Declaration
string CheckID { get; set; }
Property Value
Type Description
string
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX