Show / Hide Table of Contents

Interface ICheckCash

Attempts to redeem a Check object in the ledger to receive up to the amount authorized by the corresponding CheckCreate transaction.
Only the Destination address of a Check can cash it with a CheckCash transaction.

Inherited Members
ITransactionCommon.NetworkID
ITransactionCommon.Account
ITransactionCommon.AccountTxnID
ITransactionCommon.Fee
ITransactionCommon.Flags
ITransactionCommon.LastLedgerSequence
ITransactionCommon.Memos
ITransactionCommon.MemoValue
ITransactionCommon.Sequence
ITransactionCommon.Signers
ITransactionCommon.SigningPublicKey
ITransactionCommon.TransactionSignature
ITransactionCommon.TransactionType
ITransactionCommon.SourceTag
ITransactionCommon.TicketSequence
ITransactionCommon.ToJson()
ITransactionCommon.ToDictionary()
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public interface ICheckCash : ITransactionCommon

Properties

| Edit this page View Source

Amount

Redeem the Check for exactly this amount, if possible.
The currency must match that of the SendMax of the corresponding CheckCreate transaction.
You.
must provide either this field or DeliverMin.

Declaration
[JsonConverter(typeof(CurrencyConverter))]
Currency? Amount { get; set; }
Property Value
Type Description
Currency
| Edit this page View Source

CheckID

The ID of the Check ledger object to cash as a 64-character hexadecimal string.

Declaration
string CheckID { get; set; }
Property Value
Type Description
string
| Edit this page View Source

DeliverMin

Redeem the Check for at least this amount and for as much as possible.
The currency must match that of the SendMax of the corresponding CheckCreate.
transaction.
You must provide either this field or Amount.

Declaration
[JsonConverter(typeof(CurrencyConverter))]
Currency? DeliverMin { get; set; }
Property Value
Type Description
Currency
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX