Show / Hide Table of Contents

Interface ICheckCreate

Create a Check object in the ledger, which is a deferred payment that can be cashed by its intended destination.
The sender of this transaction is the sender of the Check.

Inherited Members
ITransactionCommon.NetworkID
ITransactionCommon.Account
ITransactionCommon.AccountTxnID
ITransactionCommon.Fee
ITransactionCommon.Flags
ITransactionCommon.LastLedgerSequence
ITransactionCommon.Memos
ITransactionCommon.MemoValue
ITransactionCommon.Sequence
ITransactionCommon.Signers
ITransactionCommon.SigningPublicKey
ITransactionCommon.TransactionSignature
ITransactionCommon.TransactionType
ITransactionCommon.SourceTag
ITransactionCommon.TicketSequence
ITransactionCommon.ToJson()
ITransactionCommon.ToDictionary()
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public interface ICheckCreate : ITransactionCommon

Properties

| Edit this page View Source

Destination

The unique address of the account that can cash the Check.

Declaration
string Destination { get; set; }
Property Value
Type Description
string
| Edit this page View Source

DestinationTag

Arbitrary tag that identifies the reason for the Check, or a hosted.
recipient to pay.

Declaration
uint? DestinationTag { get; set; }
Property Value
Type Description
uint?
| Edit this page View Source

Expiration

Time after which the Check is no longer valid, in seconds since the Ripple.
Epoch.

Declaration
[JsonConverter(typeof(RippleDateTimeConverter))]
DateTime? Expiration { get; set; }
Property Value
Type Description
Nullable
| Edit this page View Source

InvoiceID

Arbitrary 256-bit hash representing a specific reason or identifier for.
this Check.

Declaration
uint? InvoiceID { get; set; }
Property Value
Type Description
uint?
| Edit this page View Source

SendMax

Maximum amount of source currency the Check is allowed to debit the sender, including transfer fees on non-XRP currencies.
The Check can only credit the destination with the same currency (from the same issuer, for non-XRP currencies).
For non-XRP amounts, the nested field names MUST be.
lower-case.

Declaration
Currency SendMax { get; set; }
Property Value
Type Description
Currency
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX