Show / Hide Table of Contents

Interface IClawBack

Claw back tokens issued by your account. Issuers can only claw back trust line tokens if they enabled the Allow Trust Line Clawback setting before issuing any tokens. Issuers can claw back MPTs if the corresponding MPT Issuance has clawback enabled.

Inherited Members
ITransactionCommon.NetworkID
ITransactionCommon.Account
ITransactionCommon.AccountTxnID
ITransactionCommon.Fee
ITransactionCommon.Flags
ITransactionCommon.LastLedgerSequence
ITransactionCommon.Memos
ITransactionCommon.MemoValue
ITransactionCommon.Sequence
ITransactionCommon.Signers
ITransactionCommon.SigningPublicKey
ITransactionCommon.TransactionSignature
ITransactionCommon.TransactionType
ITransactionCommon.SourceTag
ITransactionCommon.TicketSequence
ITransactionCommon.ToJson()
ITransactionCommon.ToDictionary()
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public interface IClawBack : ITransactionCommon

Properties

| Edit this page View Source

Amount

The amount to claw back. The quantity in the value sub-field must not be zero. If this is more than the current balance, the transaction claws back the entire balance. When clawing back trust line tokens, the issuer sub-field indicates the token holder to claw back tokens from.

Declaration
Currency Amount { get; set; }
Property Value
Type Description
Currency
| Edit this page View Source

Holder

The holder to claw back tokens from, if clawing back MPTs. The holder must have a non-zero balance of the MPT issuance indicated in the Amount field. Required for MPT clawback, must be omitted for trust line token clawback.

Declaration
string Holder { get; set; }
Property Value
Type Description
string
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX