Show / Hide Table of Contents

Interface IConfidentialMPTClawback

Claws back a confidential MPT amount from a holder (issuer only).

Inherited Members
ITransactionCommon.NetworkID
ITransactionCommon.Account
ITransactionCommon.AccountTxnID
ITransactionCommon.Fee
ITransactionCommon.Flags
ITransactionCommon.LastLedgerSequence
ITransactionCommon.Memos
ITransactionCommon.MemoValue
ITransactionCommon.Sequence
ITransactionCommon.Signers
ITransactionCommon.SigningPublicKey
ITransactionCommon.TransactionSignature
ITransactionCommon.TransactionType
ITransactionCommon.SourceTag
ITransactionCommon.TicketSequence
ITransactionCommon.Delegate
ITransactionCommon.OperationLimit
ITransactionCommon.Sponsor
ITransactionCommon.SponsorFlags
ITransactionCommon.ToJson()
ITransactionCommon.ToDictionary()
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public interface IConfidentialMPTClawback : ITransactionCommon
Remarks

Requires the ConfidentialTransfer amendment. This feature is in draft and subject to change.

Properties

| Edit this page View Source

Holder

The account the amount is clawed back from.

Declaration
string Holder { get; set; }
Property Value
Type Description
string
| Edit this page View Source

MPTAmount

The amount being clawed back, as a decimal string.

Declaration
string MPTAmount { get; set; }
Property Value
Type Description
string
| Edit this page View Source

MPTokenIssuanceID

The ID of the MPT issuance the amount is clawed back in.

Declaration
string MPTokenIssuanceID { get; set; }
Property Value
Type Description
string
| Edit this page View Source

ZKProof

The zero-knowledge proof over the clawed-back amount, hex-encoded.

Declaration
string ZKProof { get; set; }
Property Value
Type Description
string
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX