Show / Hide Table of Contents

Interface IConfidentialMPTMergeInbox

Merges the confidential inbox balance into the confidential spending balance.

Inherited Members
ITransactionCommon.NetworkID
ITransactionCommon.Account
ITransactionCommon.AccountTxnID
ITransactionCommon.Fee
ITransactionCommon.Flags
ITransactionCommon.LastLedgerSequence
ITransactionCommon.Memos
ITransactionCommon.MemoValue
ITransactionCommon.Sequence
ITransactionCommon.Signers
ITransactionCommon.SigningPublicKey
ITransactionCommon.TransactionSignature
ITransactionCommon.TransactionType
ITransactionCommon.SourceTag
ITransactionCommon.TicketSequence
ITransactionCommon.Delegate
ITransactionCommon.OperationLimit
ITransactionCommon.Sponsor
ITransactionCommon.SponsorFlags
ITransactionCommon.ToJson()
ITransactionCommon.ToDictionary()
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public interface IConfidentialMPTMergeInbox : ITransactionCommon
Remarks

Requires the ConfidentialTransfer amendment. This feature is in draft and subject to change.

Properties

| Edit this page View Source

MPTokenIssuanceID

The ID of the MPT issuance whose inbox balance is merged into the spending balance.

Declaration
string MPTokenIssuanceID { get; set; }
Property Value
Type Description
string
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX