Show / Hide Table of Contents

Interface ICredentialAccept

Accepts a credential that has been provisionally issued to the Account. Once accepted, the credential becomes valid on the ledger and the reserve responsibility transfers from the issuer to the subject (Account). Requires the Credentials amendment.

Inherited Members
ITransactionCommon.NetworkID
ITransactionCommon.Account
ITransactionCommon.AccountTxnID
ITransactionCommon.Fee
ITransactionCommon.Flags
ITransactionCommon.LastLedgerSequence
ITransactionCommon.Memos
ITransactionCommon.MemoValue
ITransactionCommon.Sequence
ITransactionCommon.Signers
ITransactionCommon.SigningPublicKey
ITransactionCommon.TransactionSignature
ITransactionCommon.TransactionType
ITransactionCommon.SourceTag
ITransactionCommon.TicketSequence
ITransactionCommon.ToJson()
ITransactionCommon.ToDictionary()
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public interface ICredentialAccept : ITransactionCommon

Properties

| Edit this page View Source

CredentialType

The type of credential to accept, as a hex-encoded string.

Declaration
string CredentialType { get; set; }
Property Value
Type Description
string
| Edit this page View Source

Issuer

The issuer of the credential to accept.

Declaration
string Issuer { get; set; }
Property Value
Type Description
string
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX