Show / Hide Table of Contents

Interface ICredentialCreate

Creates a credential on the XRP Ledger. The credential is issued by the transaction sender (Account) to a Subject. The credential is not valid until the Subject accepts it using CredentialAccept. Requires the Credentials amendment.

Inherited Members
ITransactionCommon.NetworkID
ITransactionCommon.Account
ITransactionCommon.AccountTxnID
ITransactionCommon.Fee
ITransactionCommon.Flags
ITransactionCommon.LastLedgerSequence
ITransactionCommon.Memos
ITransactionCommon.MemoValue
ITransactionCommon.Sequence
ITransactionCommon.Signers
ITransactionCommon.SigningPublicKey
ITransactionCommon.TransactionSignature
ITransactionCommon.TransactionType
ITransactionCommon.SourceTag
ITransactionCommon.TicketSequence
ITransactionCommon.ToJson()
ITransactionCommon.ToDictionary()
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public interface ICredentialCreate : ITransactionCommon

Properties

| Edit this page View Source

CredentialType

A value to identify the type of credential, as a hex-encoded string. This must be between 1 and 64 bytes (2 to 128 hex characters).

Declaration
string CredentialType { get; set; }
Property Value
Type Description
string
| Edit this page View Source

Expiration

(Optional) The time after which the credential expires, in seconds since the Ripple Epoch.

Declaration
DateTime? Expiration { get; set; }
Property Value
Type Description
Nullable
| Edit this page View Source

Subject

The account that is the subject (recipient) of the credential.

Declaration
string Subject { get; set; }
Property Value
Type Description
string
| Edit this page View Source

URI

(Optional) An arbitrary URI reference for additional credential data, as a hex-encoded string. Can be at most 256 bytes (512 hex characters).

Declaration
string URI { get; set; }
Property Value
Type Description
string
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX