Show / Hide Table of Contents

Interface IDIDSet

Creates a new DID ledger entry or updates the fields of an existing one. The DID (Decentralized Identifier) is associated with the sending account.

Inherited Members
ITransactionCommon.NetworkID
ITransactionCommon.Account
ITransactionCommon.AccountTxnID
ITransactionCommon.Fee
ITransactionCommon.Flags
ITransactionCommon.LastLedgerSequence
ITransactionCommon.Memos
ITransactionCommon.MemoValue
ITransactionCommon.Sequence
ITransactionCommon.Signers
ITransactionCommon.SigningPublicKey
ITransactionCommon.TransactionSignature
ITransactionCommon.TransactionType
ITransactionCommon.SourceTag
ITransactionCommon.TicketSequence
ITransactionCommon.ToJson()
ITransactionCommon.ToDictionary()
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public interface IDIDSet : ITransactionCommon

Properties

| Edit this page View Source

DIDDocument

The DID document for the DID. This field is encoded as a hexadecimal string and is limited to 256 bytes.

Declaration
string DIDDocument { get; set; }
Property Value
Type Description
string
| Edit this page View Source

Data

The public attestations of identity credentials associated with the DID. This field is encoded as a hexadecimal string and is limited to 256 bytes.

Declaration
string Data { get; set; }
Property Value
Type Description
string
| Edit this page View Source

URI

The Universal Resource Identifier associated with the DID. This field is encoded as a hexadecimal string and is limited to 256 bytes.

Declaration
string URI { get; set; }
Property Value
Type Description
string
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX