Show / Hide Table of Contents

Interface IDelegateSet

The DelegateSet transaction grants permissions to another account to send transactions on your behalf.

Inherited Members
ITransactionCommon.NetworkID
ITransactionCommon.Account
ITransactionCommon.AccountTxnID
ITransactionCommon.Fee
ITransactionCommon.Flags
ITransactionCommon.LastLedgerSequence
ITransactionCommon.Memos
ITransactionCommon.MemoValue
ITransactionCommon.Sequence
ITransactionCommon.Signers
ITransactionCommon.SigningPublicKey
ITransactionCommon.TransactionSignature
ITransactionCommon.TransactionType
ITransactionCommon.SourceTag
ITransactionCommon.TicketSequence
ITransactionCommon.ToJson()
ITransactionCommon.ToDictionary()
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public interface IDelegateSet : ITransactionCommon

Properties

| Edit this page View Source

Delegate

The account to delegate permissions to.

Declaration
string Delegate { get; set; }
Property Value
Type Description
string
| Edit this page View Source

Permissions

An array of permission objects defining which transaction types the delegate can submit.

Declaration
List<PermissionWrapper> Permissions { get; set; }
Property Value
Type Description
List<PermissionWrapper>
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX