Show / Hide Table of Contents

Interface IDepositPreauth

A DepositPreauth transaction gives another account pre-approval to deliver payments to the sender of this transaction.
This is only useful if the sender of this transaction is using (or plans to use) Deposit Authorization.
XLS-70 extends this with credential-based preauthorization via AuthorizeCredentials / UnauthorizeCredentials.

Inherited Members
ITransactionCommon.NetworkID
ITransactionCommon.Account
ITransactionCommon.AccountTxnID
ITransactionCommon.Fee
ITransactionCommon.Flags
ITransactionCommon.LastLedgerSequence
ITransactionCommon.Memos
ITransactionCommon.MemoValue
ITransactionCommon.Sequence
ITransactionCommon.Signers
ITransactionCommon.SigningPublicKey
ITransactionCommon.TransactionSignature
ITransactionCommon.TransactionType
ITransactionCommon.SourceTag
ITransactionCommon.TicketSequence
ITransactionCommon.ToJson()
ITransactionCommon.ToDictionary()
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public interface IDepositPreauth : ITransactionCommon

Properties

| Edit this page View Source

Authorize

The XRP Ledger address of the sender to preauthorize.

Declaration
string Authorize { get; set; }
Property Value
Type Description
string
| Edit this page View Source

AuthorizeCredentials

(Optional, XLS-70) A set of 1..8 credentials whose holders are preauthorized to deliver payments to the account that submits this transaction. Each entry wraps an AuthorizeCredentialBody with Issuer + CredentialType. Mutually exclusive with Authorize, Unauthorize and UnauthorizeCredentials.

Declaration
List<AuthorizeCredentialEntry> AuthorizeCredentials { get; set; }
Property Value
Type Description
List<AuthorizeCredentialEntry>
| Edit this page View Source

Unauthorize

The XRP Ledger address of a sender whose preauthorization should be revoked.

Declaration
string Unauthorize { get; set; }
Property Value
Type Description
string
| Edit this page View Source

UnauthorizeCredentials

(Optional, XLS-70) A set of 1..8 credentials to revoke from credential-based preauthorization. Each entry wraps an AuthorizeCredentialBody with Issuer + CredentialType. Mutually exclusive with Authorize, Unauthorize and AuthorizeCredentials.

Declaration
List<AuthorizeCredentialEntry> UnauthorizeCredentials { get; set; }
Property Value
Type Description
List<AuthorizeCredentialEntry>
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX