Show / Hide Table of Contents

Interface IEscrowFinish

Deliver XRP or escrowed fungible tokens (IOUs, MPTs) from a held payment to the recipient. Requires the TokenEscrow amendment for fungible token support.

Inherited Members
ITransactionCommon.NetworkID
ITransactionCommon.Account
ITransactionCommon.AccountTxnID
ITransactionCommon.Fee
ITransactionCommon.Flags
ITransactionCommon.LastLedgerSequence
ITransactionCommon.Memos
ITransactionCommon.MemoValue
ITransactionCommon.Sequence
ITransactionCommon.Signers
ITransactionCommon.SigningPublicKey
ITransactionCommon.TransactionSignature
ITransactionCommon.TransactionType
ITransactionCommon.SourceTag
ITransactionCommon.TicketSequence
ITransactionCommon.ToJson()
ITransactionCommon.ToDictionary()
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public interface IEscrowFinish : ITransactionCommon

Properties

| Edit this page View Source

Condition

Hex value matching the previously-supplied PREIMAGE-SHA-256.
crypto-condition of the held payment.

Declaration
string Condition { get; set; }
Property Value
Type Description
string
| Edit this page View Source

CredentialIDs

(Optional) Set of Credentials (object IDs, hex 64-char each) used to authorize finishing the escrow when the destination account requires Deposit Authorization with credential-based preauth (XLS-70). Maximum 8 entries.

Declaration
List<string> CredentialIDs { get; set; }
Property Value
Type Description
List<string>
| Edit this page View Source

Fulfillment

Hex value of the PREIMAGE-SHA-256 crypto-condition fulfillment matching.
the held payment's Condition.

Declaration
string Fulfillment { get; set; }
Property Value
Type Description
string
| Edit this page View Source

OfferSequence

Transaction sequence of EscrowCreate transaction that created the held.
payment to finish.

Declaration
uint OfferSequence { get; set; }
Property Value
Type Description
uint
| Edit this page View Source

Owner

Address of the source account that funded the escrow.

Declaration
string Owner { get; set; }
Property Value
Type Description
string
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX