Show / Hide Table of Contents

Interface ILoanBrokerCoverClawback

The LoanBrokerCoverClawback transaction claws back cover assets from a loan broker. At least one of LoanBrokerID or Amount must be specified.

Inherited Members
ITransactionCommon.NetworkID
ITransactionCommon.Account
ITransactionCommon.AccountTxnID
ITransactionCommon.Fee
ITransactionCommon.Flags
ITransactionCommon.LastLedgerSequence
ITransactionCommon.Memos
ITransactionCommon.MemoValue
ITransactionCommon.Sequence
ITransactionCommon.Signers
ITransactionCommon.SigningPublicKey
ITransactionCommon.TransactionSignature
ITransactionCommon.TransactionType
ITransactionCommon.SourceTag
ITransactionCommon.TicketSequence
ITransactionCommon.ToJson()
ITransactionCommon.ToDictionary()
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public interface ILoanBrokerCoverClawback : ITransactionCommon
Remarks

Requires the Loan amendment (XLS-66d). This feature is in draft and subject to change.

Properties

| Edit this page View Source

Amount

The amount to claw back. Optional.

Declaration
Currency Amount { get; set; }
Property Value
Type Description
Currency
| Edit this page View Source

LoanBrokerID

The ID of the loan broker to claw back from. Optional.

Declaration
string LoanBrokerID { get; set; }
Property Value
Type Description
string
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX