Show / Hide Table of Contents

Interface ILoanBrokerCoverDeposit

The LoanBrokerCoverDeposit transaction deposits cover assets into a loan broker.

Inherited Members
ITransactionCommon.NetworkID
ITransactionCommon.Account
ITransactionCommon.AccountTxnID
ITransactionCommon.Fee
ITransactionCommon.Flags
ITransactionCommon.LastLedgerSequence
ITransactionCommon.Memos
ITransactionCommon.MemoValue
ITransactionCommon.Sequence
ITransactionCommon.Signers
ITransactionCommon.SigningPublicKey
ITransactionCommon.TransactionSignature
ITransactionCommon.TransactionType
ITransactionCommon.SourceTag
ITransactionCommon.TicketSequence
ITransactionCommon.ToJson()
ITransactionCommon.ToDictionary()
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public interface ILoanBrokerCoverDeposit : ITransactionCommon
Remarks

Requires the Loan amendment (XLS-66d). This feature is in draft and subject to change.

Properties

| Edit this page View Source

Amount

The amount of cover assets to deposit.

Declaration
Currency Amount { get; set; }
Property Value
Type Description
Currency
| Edit this page View Source

LoanBrokerID

The ID of the loan broker to deposit cover assets into.

Declaration
string LoanBrokerID { get; set; }
Property Value
Type Description
string
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX