Interface ILoanBrokerCoverWithdraw
The LoanBrokerCoverWithdraw transaction withdraws cover assets from a loan broker.
Inherited Members
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public interface ILoanBrokerCoverWithdraw : ITransactionCommon
Remarks
Requires the Loan amendment (XLS-66d). This feature is in draft and subject to change.
Properties
| Edit this page View SourceAmount
The amount of cover assets to withdraw.
Declaration
Currency Amount { get; set; }
Property Value
| Type | Description |
|---|---|
| Currency |
Destination
The destination account for the withdrawn assets. Optional.
Declaration
string Destination { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
DestinationTag
An arbitrary tag to identify the destination. Optional.
Declaration
uint? DestinationTag { get; set; }
Property Value
| Type | Description |
|---|---|
| uint? |
LoanBrokerID
The ID of the loan broker to withdraw cover assets from.
Declaration
string LoanBrokerID { get; set; }
Property Value
| Type | Description |
|---|---|
| string |