Show / Hide Table of Contents

Interface ILoanBrokerSet

The LoanBrokerSet transaction creates or modifies a loan broker that manages lending pools. The submitting account must own the Vault specified by VaultID.

Inherited Members
ITransactionCommon.NetworkID
ITransactionCommon.Account
ITransactionCommon.AccountTxnID
ITransactionCommon.Fee
ITransactionCommon.Flags
ITransactionCommon.LastLedgerSequence
ITransactionCommon.Memos
ITransactionCommon.MemoValue
ITransactionCommon.Sequence
ITransactionCommon.Signers
ITransactionCommon.SigningPublicKey
ITransactionCommon.TransactionSignature
ITransactionCommon.TransactionType
ITransactionCommon.SourceTag
ITransactionCommon.TicketSequence
ITransactionCommon.ToJson()
ITransactionCommon.ToDictionary()
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public interface ILoanBrokerSet : ITransactionCommon
Remarks

Requires the Loan amendment (XLS-66d). This feature is in draft and subject to change.

Properties

| Edit this page View Source

CoverRateLiquidation

The cover rate at which liquidation occurs (1/100th of a basis point). Valid range: 0–100000.

Declaration
uint? CoverRateLiquidation { get; set; }
Property Value
Type Description
uint?
| Edit this page View Source

CoverRateMinimum

The minimum cover rate required for loans (1/100th of a basis point). Valid range: 0–100000.

Declaration
uint? CoverRateMinimum { get; set; }
Property Value
Type Description
uint?
| Edit this page View Source

Data

Arbitrary hex-encoded metadata, limited to 256 bytes.

Declaration
string Data { get; set; }
Property Value
Type Description
string
| Edit this page View Source

DebtMaximum

The maximum amount the protocol can owe the Vault. Default 0 means no limit. Must not be negative. (Number type, string representation.)

Declaration
string DebtMaximum { get; set; }
Property Value
Type Description
string
| Edit this page View Source

LoanBrokerID

The ID of an existing LoanBroker object to modify. Optional — omit when creating a new loan broker.

Declaration
string LoanBrokerID { get; set; }
Property Value
Type Description
string
| Edit this page View Source

ManagementFeeRate

The management fee rate charged by the broker (1/10th of a basis point). Valid range: 0–10000.

Declaration
ushort? ManagementFeeRate { get; set; }
Property Value
Type Description
ushort?
| Edit this page View Source

VaultID

The ID of the Vault ledger object that this loan broker is associated with. The account submitting this transaction must own the vault. Required when creating a new loan broker.

Declaration
string VaultID { get; set; }
Property Value
Type Description
string
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX