Show / Hide Table of Contents

Interface ILoanPay

The LoanPay transaction makes a payment on a loan. Flags are mutually exclusive.

Inherited Members
ITransactionCommon.NetworkID
ITransactionCommon.Account
ITransactionCommon.AccountTxnID
ITransactionCommon.Fee
ITransactionCommon.LastLedgerSequence
ITransactionCommon.Memos
ITransactionCommon.MemoValue
ITransactionCommon.Sequence
ITransactionCommon.Signers
ITransactionCommon.SigningPublicKey
ITransactionCommon.TransactionSignature
ITransactionCommon.TransactionType
ITransactionCommon.SourceTag
ITransactionCommon.TicketSequence
ITransactionCommon.ToJson()
ITransactionCommon.ToDictionary()
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public interface ILoanPay : ITransactionCommon
Remarks

Requires the Loan amendment (XLS-66d). This feature is in draft and subject to change.

Properties

| Edit this page View Source

Amount

The amount to pay.

Declaration
Currency Amount { get; set; }
Property Value
Type Description
Currency
| Edit this page View Source

Flags

LoanPay transaction flags.

Declaration
LoanPayFlags? Flags { get; set; }
Property Value
Type Description
LoanPayFlags?
| Edit this page View Source

LoanID

The ID of the loan to make a payment on.

Declaration
string LoanID { get; set; }
Property Value
Type Description
string
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX