Show / Hide Table of Contents

Interface IMPTokenAuthorize

The MPTokenAuthorize transaction is used to allow an account to hold a particular MPT issuance, or by an issuer to authorize or revoke authorization for a holder.

Inherited Members
ITransactionCommon.NetworkID
ITransactionCommon.Account
ITransactionCommon.AccountTxnID
ITransactionCommon.Fee
ITransactionCommon.LastLedgerSequence
ITransactionCommon.Memos
ITransactionCommon.MemoValue
ITransactionCommon.Sequence
ITransactionCommon.Signers
ITransactionCommon.SigningPublicKey
ITransactionCommon.TransactionSignature
ITransactionCommon.TransactionType
ITransactionCommon.SourceTag
ITransactionCommon.TicketSequence
ITransactionCommon.ToJson()
ITransactionCommon.ToDictionary()
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public interface IMPTokenAuthorize : ITransactionCommon

Properties

| Edit this page View Source

Flags

Declaration
MPTokenAuthorizeFlags? Flags { get; set; }
Property Value
Type Description
MPTokenAuthorizeFlags?
| Edit this page View Source

Holder

An optional XRPL Address of an individual token holder balance. If this is set, the Holder field must specify the holder's address. If this is not set, the transaction is assumed to be from the holder directly.

Declaration
string? Holder { get; set; }
Property Value
Type Description
string
| Edit this page View Source

MPTokenIssuanceID

The ID of the MPT to authorize.

Declaration
string MPTokenIssuanceID { get; set; }
Property Value
Type Description
string
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX