Show / Hide Table of Contents

Interface INFTokenBurn

The NFTokenBurn transaction is used to remove an NFToken object from the NFTokenPage in which it is being held, effectively removing the token from the ledger ("burning" it).
If this operation succeeds, the corresponding NFToken is removed.
If this operation empties the NFTokenPage holding the NFToken or results in the consolidation, thus removing an NFTokenPage, the owner’s reserve requirement is reduced by one.

Inherited Members
ITransactionCommon.NetworkID
ITransactionCommon.Account
ITransactionCommon.AccountTxnID
ITransactionCommon.Fee
ITransactionCommon.Flags
ITransactionCommon.LastLedgerSequence
ITransactionCommon.Memos
ITransactionCommon.MemoValue
ITransactionCommon.Sequence
ITransactionCommon.Signers
ITransactionCommon.SigningPublicKey
ITransactionCommon.TransactionSignature
ITransactionCommon.TransactionType
ITransactionCommon.SourceTag
ITransactionCommon.TicketSequence
ITransactionCommon.ToJson()
ITransactionCommon.ToDictionary()
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public interface INFTokenBurn : ITransactionCommon

Properties

| Edit this page View Source

NFTokenID

Identifies the NFToken object to be removed by the transaction.

Declaration
string NFTokenID { get; set; }
Property Value
Type Description
string
| Edit this page View Source

Owner

Indicates which account currently owns the token if it is different than Account.
Only used to burn tokens which have the lsfBurnable flag enabled and are not owned by the signing account.

Declaration
string Owner { get; set; }
Property Value
Type Description
string
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX