Show / Hide Table of Contents

Interface INFTokenModify

NFTokenModify is used to change the URI field of an NFT to point to a different URI in order to update the supporting data for the NFT.
The NFT must have been minted with the tfMutable flag set.
See Dynamic Non-Fungible Tokens.

Inherited Members
ITransactionCommon.NetworkID
ITransactionCommon.Account
ITransactionCommon.AccountTxnID
ITransactionCommon.Fee
ITransactionCommon.Flags
ITransactionCommon.LastLedgerSequence
ITransactionCommon.Memos
ITransactionCommon.MemoValue
ITransactionCommon.Sequence
ITransactionCommon.Signers
ITransactionCommon.SigningPublicKey
ITransactionCommon.TransactionSignature
ITransactionCommon.TransactionType
ITransactionCommon.SourceTag
ITransactionCommon.TicketSequence
ITransactionCommon.ToJson()
ITransactionCommon.ToDictionary()
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public interface INFTokenModify : ITransactionCommon

Properties

| Edit this page View Source

NFTokenID

Identifies the NFTokenID of the NFToken object that the offer references.

Declaration
string NFTokenID { get; set; }
Property Value
Type Description
string
| Edit this page View Source

Owner

Indicates the AccountID of the account that owns the corresponding NFToken. Can be omitted if the owner is the account submitting this transaction.

Declaration
string? Owner { get; set; }
Property Value
Type Description
string
| Edit this page View Source

URI

URI that points to the data and/or metadata associated with the NFT. This must be a hex-encoded string, not an empty string. Can be null or omitted if not used.

Declaration
string? URI { get; set; }
Property Value
Type Description
string
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX