Show / Hide Table of Contents

Interface IOfferCancel

An OfferCancel transaction removes an Offer object from the XRP Ledger.

Inherited Members
ITransactionCommon.NetworkID
ITransactionCommon.Account
ITransactionCommon.AccountTxnID
ITransactionCommon.Fee
ITransactionCommon.Flags
ITransactionCommon.LastLedgerSequence
ITransactionCommon.Memos
ITransactionCommon.MemoValue
ITransactionCommon.Sequence
ITransactionCommon.Signers
ITransactionCommon.SigningPublicKey
ITransactionCommon.TransactionSignature
ITransactionCommon.TransactionType
ITransactionCommon.SourceTag
ITransactionCommon.TicketSequence
ITransactionCommon.ToJson()
ITransactionCommon.ToDictionary()
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public interface IOfferCancel : ITransactionCommon

Properties

| Edit this page View Source

OfferSequence

The sequence number (or Ticket number) of a previous OfferCreate transaction.
If specified, cancel any offer object in the ledger that was created by that transaction.
It is not considered an error if the offer.
specified does not exist.

Declaration
uint OfferSequence { get; set; }
Property Value
Type Description
uint
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX