Show / Hide Table of Contents

Interface IOfferCreate

An OfferCreate transaction is effectively a limit order.
It defines an intent to exchange currencies, and creates an Offer object if not completely.
Fulfilled when placed.
Offers can be partially fulfilled.

Inherited Members
ITransactionCommon.NetworkID
ITransactionCommon.Account
ITransactionCommon.AccountTxnID
ITransactionCommon.Fee
ITransactionCommon.LastLedgerSequence
ITransactionCommon.Memos
ITransactionCommon.MemoValue
ITransactionCommon.Sequence
ITransactionCommon.Signers
ITransactionCommon.SigningPublicKey
ITransactionCommon.TransactionSignature
ITransactionCommon.TransactionType
ITransactionCommon.SourceTag
ITransactionCommon.TicketSequence
ITransactionCommon.ToJson()
ITransactionCommon.ToDictionary()
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public interface IOfferCreate : ITransactionCommon

Properties

| Edit this page View Source

DomainID

The domain that the offer must be a part of. Required for permissioned DEX offers.

Declaration
string DomainID { get; set; }
Property Value
Type Description
string
| Edit this page View Source

Expiration

Time after which the offer is no longer active, in seconds since the.
Ripple Epoch.

Declaration
DateTime? Expiration { get; set; }
Property Value
Type Description
Nullable
| Edit this page View Source

Flags

Transaction Flags for an OfferCreate Transaction.

Declaration
OfferCreateFlags? Flags { get; set; }
Property Value
Type Description
OfferCreateFlags?
| Edit this page View Source

OfferSequence

An offer to delete first, specified in the same way as OfferCancel.

Declaration
uint? OfferSequence { get; set; }
Property Value
Type Description
uint?
| Edit this page View Source

TakerGets

The amount and type of currency being provided by the offer creator.

Declaration
Currency TakerGets { get; set; }
Property Value
Type Description
Currency
| Edit this page View Source

TakerPays

The amount and type of currency being requested by the offer creator.

Declaration
Currency TakerPays { get; set; }
Property Value
Type Description
Currency
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX