Show / Hide Table of Contents

Interface IPaymentChannelClaim

Claim XRP from a payment channel, adjust the payment channel's expiration, or both.

Inherited Members
ITransactionCommon.NetworkID
ITransactionCommon.Account
ITransactionCommon.AccountTxnID
ITransactionCommon.Fee
ITransactionCommon.LastLedgerSequence
ITransactionCommon.Memos
ITransactionCommon.MemoValue
ITransactionCommon.Sequence
ITransactionCommon.Signers
ITransactionCommon.SigningPublicKey
ITransactionCommon.TransactionSignature
ITransactionCommon.TransactionType
ITransactionCommon.SourceTag
ITransactionCommon.TicketSequence
ITransactionCommon.ToJson()
ITransactionCommon.ToDictionary()
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public interface IPaymentChannelClaim : ITransactionCommon

Properties

| Edit this page View Source

Amount

The amount of XRP, in drops, authorized by the Signature.
This must match the amount in the signed message.
This is the cumulative amount of XRP that can be dispensed by the channel, including XRP previously redeemed.

Declaration
string Amount { get; set; }
Property Value
Type Description
string
| Edit this page View Source

Balance

Total amount of XRP, in drops, delivered by this channel after processing this claim.
Required to deliver XRP.
Must be more than the total amount delivered by the channel so far, but not greater than the Amount of the signed claim.
Must be provided except when closing the channel.

Declaration
string Balance { get; set; }
Property Value
Type Description
string
| Edit this page View Source

Channel

The unique ID of the channel as a 64-character hexadecimal string.

Declaration
string Channel { get; set; }
Property Value
Type Description
string
| Edit this page View Source

CredentialIDs

(Optional) Set of Credentials (object IDs, hex 64-char each) used to authorize the claim when the destination account requires Deposit Authorization with credential-based preauth (XLS-70). Maximum 8 entries.

Declaration
List<string> CredentialIDs { get; set; }
Property Value
Type Description
List<string>
| Edit this page View Source

Flags

PaymentChannelClaim transaction flags

Declaration
PaymentChannelClaimFlags? Flags { get; set; }
Property Value
Type Description
PaymentChannelClaimFlags?
| Edit this page View Source

PublicKey

The public key used for the signature, as hexadecimal.
This must match the PublicKey stored in the ledger for the channel.
Required unless the sender of the transaction is the source address of the channel and the Signature field is omitted.

Declaration
string PublicKey { get; set; }
Property Value
Type Description
string
| Edit this page View Source

Signature

The signature of this claim, as hexadecimal.
The signed message contains the channel ID and the amount of the claim.
Required unless the sender of the transaction is the source address of the channel.

Declaration
string Signature { get; set; }
Property Value
Type Description
string
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX