Interface IPermissionedDomainSet
Create a permissioned domain, or modify one that you own. Requires the PermissionedDomains amendment.
Inherited Members
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public interface IPermissionedDomainSet : ITransactionCommon
Properties
| Edit this page View SourceAcceptedCredentials
A list of 1 to 10 AcceptedCredential objects that grant access to this domain. The list does not need to be sorted, but it cannot contain duplicates. When modifying an existing domain, this list replaces the existing list.
Declaration
List<AcceptedCredentialWrapper> AcceptedCredentials { get; set; }
Property Value
| Type | Description |
|---|---|
| List<AcceptedCredentialWrapper> |
DomainID
The ledger entry ID of an existing permissioned domain to modify. If omitted, creates a new permissioned domain.
Declaration
string DomainID { get; set; }
Property Value
| Type | Description |
|---|---|
| string |