Show / Hide Table of Contents

Interface ISetFee

Inherited Members
ITransactionCommon.NetworkID
ITransactionCommon.Account
ITransactionCommon.AccountTxnID
ITransactionCommon.Fee
ITransactionCommon.Flags
ITransactionCommon.LastLedgerSequence
ITransactionCommon.Memos
ITransactionCommon.MemoValue
ITransactionCommon.Sequence
ITransactionCommon.Signers
ITransactionCommon.SigningPublicKey
ITransactionCommon.TransactionSignature
ITransactionCommon.TransactionType
ITransactionCommon.SourceTag
ITransactionCommon.TicketSequence
ITransactionCommon.ToJson()
ITransactionCommon.ToDictionary()
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public interface ISetFee : ITransactionCommon

Properties

| Edit this page View Source

BaseFee

The charge, in drops of XRP, for the reference transaction, as hex.
(This is the transaction cost before scaling for load.)

Declaration
string BaseFee { get; set; }
Property Value
Type Description
string
| Edit this page View Source

LedgerSequence

(Omitted for some historical SetFee pseudo-transactions)
The index of the ledger version where this pseudo-transaction appears.
This distinguishes the pseudo-transaction from other occurrences of the same change.

Declaration
uint LedgerSequence { get; set; }
Property Value
Type Description
uint
| Edit this page View Source

ReferenceFeeUnits

The cost, in fee units, of the reference transaction

Declaration
uint ReferenceFeeUnits { get; set; }
Property Value
Type Description
uint
| Edit this page View Source

ReserveBase

The base reserve, in drops

Declaration
uint ReserveBase { get; set; }
Property Value
Type Description
uint
| Edit this page View Source

ReserveIncrement

The incremental reserve, in drops

Declaration
uint ReserveIncrement { get; set; }
Property Value
Type Description
uint
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX