Show / Hide Table of Contents

Interface ISetRegularKey

A SetRegularKey transaction assigns, changes, or removes the regular key pair associated with an account.

Inherited Members
ITransactionCommon.NetworkID
ITransactionCommon.Account
ITransactionCommon.AccountTxnID
ITransactionCommon.Fee
ITransactionCommon.Flags
ITransactionCommon.LastLedgerSequence
ITransactionCommon.Memos
ITransactionCommon.MemoValue
ITransactionCommon.Sequence
ITransactionCommon.Signers
ITransactionCommon.SigningPublicKey
ITransactionCommon.TransactionSignature
ITransactionCommon.TransactionType
ITransactionCommon.SourceTag
ITransactionCommon.TicketSequence
ITransactionCommon.ToJson()
ITransactionCommon.ToDictionary()
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public interface ISetRegularKey : ITransactionCommon

Properties

| Edit this page View Source

RegularKey

A base-58-encoded Address that indicates the regular key pair to be assigned to the account.
If omitted, removes any existing regular key pair from the account.
Must not match the master key pair for the address.

Declaration
string RegularKey { get; set; }
Property Value
Type Description
string
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX