Show / Hide Table of Contents

Interface ISignerListSet

The SignerListSet transaction creates, replaces, or removes a list of signers that can be used to multi-sign a transaction.

Inherited Members
ITransactionCommon.NetworkID
ITransactionCommon.Account
ITransactionCommon.AccountTxnID
ITransactionCommon.Fee
ITransactionCommon.Flags
ITransactionCommon.LastLedgerSequence
ITransactionCommon.Memos
ITransactionCommon.MemoValue
ITransactionCommon.Sequence
ITransactionCommon.Signers
ITransactionCommon.SigningPublicKey
ITransactionCommon.TransactionSignature
ITransactionCommon.TransactionType
ITransactionCommon.SourceTag
ITransactionCommon.TicketSequence
ITransactionCommon.ToJson()
ITransactionCommon.ToDictionary()
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public interface ISignerListSet : ITransactionCommon

Properties

| Edit this page View Source

SignerEntries

Array of SignerEntry objects, indicating the addresses and weights of signers in this list.
This signer list must have at least 1 member and no more than 32 members.
No address may appear more than once in the list, nor may the Account submitting the transaction appear in the list.

Declaration
List<SignerEntryWrapper> SignerEntries { get; set; }
Property Value
Type Description
List<SignerEntryWrapper>
| Edit this page View Source

SignerQuorum

A target number for the signer weights.
A multi-signature from this list is valid only if the sum weights of the signatures provided is greater than or equal to this value.
To delete a signer list, use the value 0.

Declaration
uint SignerQuorum { get; set; }
Property Value
Type Description
uint
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX