Show / Hide Table of Contents

Interface ISponsorshipSet

The SponsorshipSet transaction creates or updates a Sponsorship relationship, allowing the sponsor to pay transaction fees and/or reserves on behalf of the sponsee.

Inherited Members
ITransactionCommon.NetworkID
ITransactionCommon.Account
ITransactionCommon.AccountTxnID
ITransactionCommon.Fee
ITransactionCommon.Flags
ITransactionCommon.LastLedgerSequence
ITransactionCommon.Memos
ITransactionCommon.MemoValue
ITransactionCommon.Sequence
ITransactionCommon.Signers
ITransactionCommon.SigningPublicKey
ITransactionCommon.TransactionSignature
ITransactionCommon.TransactionType
ITransactionCommon.SourceTag
ITransactionCommon.TicketSequence
ITransactionCommon.Delegate
ITransactionCommon.OperationLimit
ITransactionCommon.Sponsor
ITransactionCommon.SponsorFlags
ITransactionCommon.ToJson()
ITransactionCommon.ToDictionary()
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public interface ISponsorshipSet : ITransactionCommon
Remarks

Requires the Sponsor amendment (XLS-68). This feature is in draft and subject to change.

Properties

| Edit this page View Source

CounterpartySponsor

The sponsoring account. Present when the sponsee submits the transaction (the sponsor then co-signs via SponsorSignature).

Declaration
string CounterpartySponsor { get; set; }
Property Value
Type Description
string
| Edit this page View Source

FeeAmount

The amount of fees the sponsor commits to cover.

Declaration
Currency FeeAmount { get; set; }
Property Value
Type Description
Currency
| Edit this page View Source

MaxFee

The maximum fee per transaction the sponsor is willing to cover.

Declaration
Currency MaxFee { get; set; }
Property Value
Type Description
Currency
| Edit this page View Source

RemainingOwnerCount

The number of owner-reserve slots the sponsor commits to cover.

Declaration
uint? RemainingOwnerCount { get; set; }
Property Value
Type Description
uint?
| Edit this page View Source

Sponsee

The account being sponsored. Present when the sponsor submits the transaction.

Declaration
string Sponsee { get; set; }
Property Value
Type Description
string
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX