Show / Hide Table of Contents

Interface ITransactionCommon

Every transaction has the same set of common fields.

Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public interface ITransactionCommon

Properties

| Edit this page View Source

Account

This is a required field The unique address of the account that initiated the transaction.

Declaration
string Account { get; set; }
Property Value
Type Description
string
| Edit this page View Source

AccountTxnID

Hash value identifying another transaction.
If provided, this transaction is only valid if the sending account's previously-sent transaction matches the provided hash.

Declaration
string AccountTxnID { get; set; }
Property Value
Type Description
string
| Edit this page View Source

Fee

Integer amount of XRP, in drops, to be destroyed as a cost for distributing this transaction to the network.
Some transaction types have different minimum requirements.

Declaration
Currency Fee { get; set; }
Property Value
Type Description
Currency
| Edit this page View Source

Flags

Set of bit-flags for this transaction.
number | GlobalFlags

Declaration
uint? Flags { get; set; }
Property Value
Type Description
uint?
| Edit this page View Source

LastLedgerSequence

Although optional, the LastLedgerSequence is strongly recommended on every transaction to ensure it's validated or rejected promptly.
Highest ledger index this transaction can appear in.
Specifying this field places a strict upper limit on how long the transaction can wait to be validated or rejected.

Declaration
uint? LastLedgerSequence { get; set; }
Property Value
Type Description
uint?
| Edit this page View Source

MemoValue

Declaration
[JsonIgnore]
string MemoValue { get; }
Property Value
Type Description
string
| Edit this page View Source

Memos

Additional arbitrary information used to identify this transaction.

Declaration
List<MemoWrapper> Memos { get; set; }
Property Value
Type Description
List<MemoWrapper>
| Edit this page View Source

NetworkID

Declaration
uint? NetworkID { get; set; }
Property Value
Type Description
uint?
| Edit this page View Source

Sequence

The sequence number of the account sending the transaction.
A transaction is only valid if the Sequence number is exactly 1 greater than the previous transaction from the same account.
The special case 0 means the transaction is using a Ticket instead.

Declaration
uint? Sequence { get; set; }
Property Value
Type Description
uint?
| Edit this page View Source

Signers

Array of objects that represent a multi-signature which authorizes this transaction.

Declaration
List<SignerWrapper> Signers { get; set; }
Property Value
Type Description
List<SignerWrapper>
| Edit this page View Source

SigningPublicKey

Hex representation of the public key that corresponds to the private key used to sign this transaction.
If an empty string, indicates a multi-signature is present in the Signers field instead.

Declaration
string SigningPublicKey { get; set; }
Property Value
Type Description
string
| Edit this page View Source

SourceTag

(Optional) Arbitrary integer used to identify the reason for this payment, or a sender on whose behalf this transaction is made.
Conventionally, a refund should specify the initial payment's SourceTag as the refund payment's DestinationTag.

Declaration
uint? SourceTag { get; set; }
Property Value
Type Description
uint?
| Edit this page View Source

TicketSequence

(Optional) The sequence number of the ticket to use in place of a Sequence number.
If this is provided, Sequence must be 0. Cannot be used with AccountTxnID.

Declaration
uint? TicketSequence { get; set; }
Property Value
Type Description
uint?
| Edit this page View Source

TransactionSignature

The signature that verifies this transaction as originating from the account it says it is from.

Declaration
string TransactionSignature { get; set; }
Property Value
Type Description
string
| Edit this page View Source

TransactionType

The type of transaction.
Valid types include: Payment, OfferCreate, SignerListSet, EscrowCreate, EscrowFinish, EscrowCancel, PaymentChannelCreate, PaymentChannelFund, PaymentChannelClaim, and DepositPreauth.

Declaration
TransactionType TransactionType { get; set; }
Property Value
Type Description
TransactionType

Methods

| Edit this page View Source

ToDictionary()

Declaration
Dictionary<string, object> ToDictionary()
Returns
Type Description
Dictionary<string, object>
| Edit this page View Source

ToJson()

convert transaction to string json value

Declaration
string ToJson()
Returns
Type Description
string
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX