Show / Hide Table of Contents

Interface ITransactionMetadata

Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public interface ITransactionMetadata

Properties

| Edit this page View Source

ActuallyDeliveredAmount

Gets or sets the delivered amount (may be 'unavailable' for transactions before 2014-01-20).

Declaration
[JsonConverter(typeof(CurrencyConverter))]
[JsonPropertyName("delivered_amount")]
Currency ActuallyDeliveredAmount { get; set; }
Property Value
Type Description
Currency
| Edit this page View Source

AffectedNodes

Declaration
List<AffectedNode> AffectedNodes { get; set; }
Property Value
Type Description
List<AffectedNode>
| Edit this page View Source

MptIssuanceId

Shows the MPTokenIssuanceID for the MPTokenIssuance that was created by this transaction. Only present if the transaction is MPTokenIssuanceCreate.

Declaration
[JsonPropertyName("mpt_issuance_id")]
string MptIssuanceId { get; set; }
Property Value
Type Description
string
| Edit this page View Source

NFTokenId

Shows the NFTokenID for the NFToken that changed on the ledger as a result of the transaction. Only present if the transaction is NFTokenMint or NFTokenAcceptOffer

Declaration
[JsonPropertyName("nftoken_id")]
string NFTokenId { get; set; }
Property Value
Type Description
string
| Edit this page View Source

NFTokenIds

Shows all the NFTokenIDs for the NFTokens that changed on the ledger as a result of the transaction. Only present if the transaction is NFTokenCancelOffer.

Declaration
[JsonPropertyName("nftoken_ids")]
string[] NFTokenIds { get; set; }
Property Value
Type Description
string[]
| Edit this page View Source

OfferID

Shows the OfferIDof a new NFTokenOffer in a response from a NFTokenCreateOffer transaction.

Declaration
[JsonPropertyName("offer_id")]
string OfferID { get; set; }
Property Value
Type Description
string
| Edit this page View Source

ParentBatchID

Batch ID of the batch that this transaction belongs to, if any.

Declaration
string? ParentBatchID { get; set; }
Property Value
Type Description
string
| Edit this page View Source

PartialDeliveredAmount

Gets or sets the amount that was actually delivered.

Declaration
[JsonConverter(typeof(CurrencyConverter))]
[JsonPropertyName("DeliveredAmount")]
Currency PartialDeliveredAmount { get; set; }
Property Value
Type Description
Currency
| Edit this page View Source

TransactionIndex

Gets or sets the transaction index.

Declaration
int TransactionIndex { get; set; }
Property Value
Type Description
int
| Edit this page View Source

TransactionResult

Gets or sets the transaction result.

Declaration
string TransactionResult { get; set; }
Property Value
Type Description
string

Extension Methods

AffectedNodeExtensions.GetCreatedNews<T>(ITransactionMetadata)
AffectedNodeExtensions.GetDeletedFinals<T>(ITransactionMetadata)
AffectedNodeExtensions.GetDeletedPrevious<T>(ITransactionMetadata)
AffectedNodeExtensions.GetModifiedFinals<T>(ITransactionMetadata)
AffectedNodeExtensions.GetModifiedPrevious<T>(ITransactionMetadata)
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX