Show / Hide Table of Contents

Interface ITrustSet

Create or modify a trust line linking two accounts.

Inherited Members
ITransactionCommon.NetworkID
ITransactionCommon.Account
ITransactionCommon.AccountTxnID
ITransactionCommon.Fee
ITransactionCommon.LastLedgerSequence
ITransactionCommon.Memos
ITransactionCommon.MemoValue
ITransactionCommon.Sequence
ITransactionCommon.Signers
ITransactionCommon.SigningPublicKey
ITransactionCommon.TransactionSignature
ITransactionCommon.TransactionType
ITransactionCommon.SourceTag
ITransactionCommon.TicketSequence
ITransactionCommon.ToJson()
ITransactionCommon.ToDictionary()
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public interface ITrustSet : ITransactionCommon

Properties

| Edit this page View Source

Flags

ITrustSet transaction flags

Declaration
TrustSetFlags? Flags { get; set; }
Property Value
Type Description
TrustSetFlags?
| Edit this page View Source

LimitAmount

Object defining the trust line to create or modify, in the format of a Currency Amount.

Declaration
Currency LimitAmount { get; set; }
Property Value
Type Description
Currency
| Edit this page View Source

QualityIn

Value incoming balances on this trust line at the ratio of this number per 1,000,000,000 units.
A value of 0 is shorthand for treating balances at face value.

Declaration
uint? QualityIn { get; set; }
Property Value
Type Description
uint?
| Edit this page View Source

QualityOut

Value outgoing balances on this trust line at the ratio of this number per 1,000,000,000 units.
A value of 0 is shorthand for treating balances at face value.

Declaration
uint? QualityOut { get; set; }
Property Value
Type Description
uint?
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX