Show / Hide Table of Contents

Interface IUNLModify

Inherited Members
ITransactionCommon.NetworkID
ITransactionCommon.Account
ITransactionCommon.AccountTxnID
ITransactionCommon.Fee
ITransactionCommon.Flags
ITransactionCommon.LastLedgerSequence
ITransactionCommon.Memos
ITransactionCommon.MemoValue
ITransactionCommon.Sequence
ITransactionCommon.Signers
ITransactionCommon.SigningPublicKey
ITransactionCommon.TransactionSignature
ITransactionCommon.TransactionType
ITransactionCommon.SourceTag
ITransactionCommon.TicketSequence
ITransactionCommon.ToJson()
ITransactionCommon.ToDictionary()
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public interface IUNLModify : ITransactionCommon

Properties

| Edit this page View Source

LedgerSequence

The ledger index where this pseudo-transaction appears.
This distinguishes the pseudo-transaction from other occurrences of the same change.

Declaration
uint LedgerSequence { get; set; }
Property Value
Type Description
uint
| Edit this page View Source

UNLModifyDisabling

If 1, this change represents adding a validator to the Negative UNL.
If 0, this change represents removing a validator from the Negative UNL.
(No other values are allowed.)

Declaration
uint UNLModifyDisabling { get; set; }
Property Value
Type Description
uint
| Edit this page View Source

UNLModifyValidator

The validator to add or remove, as identified by its master public key.

Declaration
string UNLModifyValidator { get; set; }
Property Value
Type Description
string
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX