Show / Hide Table of Contents

Interface IVaultSet

The VaultSet transaction modifies the settings of an existing vault.

Inherited Members
ITransactionCommon.NetworkID
ITransactionCommon.Account
ITransactionCommon.AccountTxnID
ITransactionCommon.Fee
ITransactionCommon.Flags
ITransactionCommon.LastLedgerSequence
ITransactionCommon.Memos
ITransactionCommon.MemoValue
ITransactionCommon.Sequence
ITransactionCommon.Signers
ITransactionCommon.SigningPublicKey
ITransactionCommon.TransactionSignature
ITransactionCommon.TransactionType
ITransactionCommon.SourceTag
ITransactionCommon.TicketSequence
ITransactionCommon.ToJson()
ITransactionCommon.ToDictionary()
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public interface IVaultSet : ITransactionCommon
Remarks

Requires the Vault amendment (XLS-65d). This feature is in draft and subject to change.

Properties

| Edit this page View Source

AssetsMaximum

The maximum asset amount that can be held in the vault. STNumber type (12 bytes: int64 mantissa + int32 exponent), serialized as string in JSON.

Declaration
string AssetsMaximum { get; set; }
Property Value
Type Description
string
| Edit this page View Source

Data

Arbitrary hex-encoded data associated with the vault, limited to 256 bytes.

Declaration
string Data { get; set; }
Property Value
Type Description
string
| Edit this page View Source

DomainID

The ID of a permissioned domain to associate with the vault.

Declaration
string DomainID { get; set; }
Property Value
Type Description
string
| Edit this page View Source

VaultID

The ID of the vault to modify.

Declaration
string VaultID { get; set; }
Property Value
Type Description
string
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX