Show / Hide Table of Contents

Interface IXChainAccountCreateCommit

The XChainAccountCreateCommit transaction creates a new account for a witness's account on one of the chains a bridge connects. This transaction can only be used for XRP-XRP bridges.

Inherited Members
ITransactionCommon.NetworkID
ITransactionCommon.Account
ITransactionCommon.AccountTxnID
ITransactionCommon.Fee
ITransactionCommon.Flags
ITransactionCommon.LastLedgerSequence
ITransactionCommon.Memos
ITransactionCommon.MemoValue
ITransactionCommon.Sequence
ITransactionCommon.Signers
ITransactionCommon.SigningPublicKey
ITransactionCommon.TransactionSignature
ITransactionCommon.TransactionType
ITransactionCommon.SourceTag
ITransactionCommon.TicketSequence
ITransactionCommon.ToJson()
ITransactionCommon.ToDictionary()
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public interface IXChainAccountCreateCommit : ITransactionCommon

Properties

| Edit this page View Source

Amount

The amount, in XRP, to use for account creation. This must be greater than or equal to the MinAccountCreateAmount specified in the Bridge ledger object.

Declaration
Currency Amount { get; set; }
Property Value
Type Description
Currency
| Edit this page View Source

Destination

The destination account on the destination chain.

Declaration
string Destination { get; set; }
Property Value
Type Description
string
| Edit this page View Source

SignatureReward

The amount, in XRP, to be used to reward the witness servers for providing signatures. This must match the amount on the Bridge ledger object.

Declaration
Currency SignatureReward { get; set; }
Property Value
Type Description
Currency
| Edit this page View Source

XChainBridge

The bridge to create accounts for.

Declaration
XChainBridgeModel XChainBridge { get; set; }
Property Value
Type Description
XChainBridgeModel
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX