Show / Hide Table of Contents

Interface IXChainAddAccountCreateAttestation

The XChainAddAccountCreateAttestation transaction provides an attestation from a witness server that an XChainAccountCreateCommit transaction occurred on the other chain.

Inherited Members
ITransactionCommon.NetworkID
ITransactionCommon.Account
ITransactionCommon.AccountTxnID
ITransactionCommon.Fee
ITransactionCommon.Flags
ITransactionCommon.LastLedgerSequence
ITransactionCommon.Memos
ITransactionCommon.MemoValue
ITransactionCommon.Sequence
ITransactionCommon.Signers
ITransactionCommon.SigningPublicKey
ITransactionCommon.TransactionSignature
ITransactionCommon.TransactionType
ITransactionCommon.SourceTag
ITransactionCommon.TicketSequence
ITransactionCommon.ToJson()
ITransactionCommon.ToDictionary()
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public interface IXChainAddAccountCreateAttestation : ITransactionCommon

Properties

| Edit this page View Source

Amount

The amount committed by the XChainAccountCreateCommit transaction on the source chain.

Declaration
Currency Amount { get; set; }
Property Value
Type Description
Currency
| Edit this page View Source

AttestationRewardAccount

The account that should receive this signer's share of the SignatureReward.

Declaration
string AttestationRewardAccount { get; set; }
Property Value
Type Description
string
| Edit this page View Source

AttestationSignerAccount

The account on the door account's signer list that is signing the transaction.

Declaration
string AttestationSignerAccount { get; set; }
Property Value
Type Description
string
| Edit this page View Source

Destination

The destination account for the funds on the destination chain.

Declaration
string Destination { get; set; }
Property Value
Type Description
string
| Edit this page View Source

OtherChainSource

The account on the source chain that submitted the XChainAccountCreateCommit transaction that triggered the event associated with the attestation.

Declaration
string OtherChainSource { get; set; }
Property Value
Type Description
string
| Edit this page View Source

PublicKey

The public key used to verify the signature.

Declaration
string PublicKey { get; set; }
Property Value
Type Description
string
| Edit this page View Source

Signature

The signature attesting to the event on the other chain.

Declaration
string Signature { get; set; }
Property Value
Type Description
string
| Edit this page View Source

SignatureReward

The amount, in XRP, to be used to reward the witness servers for providing signatures.

Declaration
Currency SignatureReward { get; set; }
Property Value
Type Description
Currency
| Edit this page View Source

WasLockingChainSend

A boolean representing the chain where the event occurred. 0 represents the issuing chain, 1 represents the locking chain.

Declaration
byte WasLockingChainSend { get; set; }
Property Value
Type Description
byte
| Edit this page View Source

XChainAccountCreateCount

An integer that represents the order that the claim must be processed in.

Declaration
string XChainAccountCreateCount { get; set; }
Property Value
Type Description
string
| Edit this page View Source

XChainBridge

The bridge associated with the attestation.

Declaration
XChainBridgeModel XChainBridge { get; set; }
Property Value
Type Description
XChainBridgeModel
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX