Show / Hide Table of Contents

Interface IXChainClaim

The XChainClaim transaction completes a cross-chain transfer of value. It allows a user to claim the value on the destination chain — the equivalent of the value locked on the source chain.

Inherited Members
ITransactionCommon.NetworkID
ITransactionCommon.Account
ITransactionCommon.AccountTxnID
ITransactionCommon.Fee
ITransactionCommon.Flags
ITransactionCommon.LastLedgerSequence
ITransactionCommon.Memos
ITransactionCommon.MemoValue
ITransactionCommon.Sequence
ITransactionCommon.Signers
ITransactionCommon.SigningPublicKey
ITransactionCommon.TransactionSignature
ITransactionCommon.TransactionType
ITransactionCommon.SourceTag
ITransactionCommon.TicketSequence
ITransactionCommon.ToJson()
ITransactionCommon.ToDictionary()
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public interface IXChainClaim : ITransactionCommon

Properties

| Edit this page View Source

Amount

The amount to claim on the destination chain. This must match the amount attested to on the attestations associated with this claim ID.

Declaration
Currency Amount { get; set; }
Property Value
Type Description
Currency
| Edit this page View Source

Destination

The destination account on the destination chain. It must exist or the transaction will fail.

Declaration
string Destination { get; set; }
Property Value
Type Description
string
| Edit this page View Source

DestinationTag

An integer destination tag.

Declaration
uint? DestinationTag { get; set; }
Property Value
Type Description
uint?
| Edit this page View Source

XChainBridge

The bridge to use for the claim.

Declaration
XChainBridgeModel XChainBridge { get; set; }
Property Value
Type Description
XChainBridgeModel
| Edit this page View Source

XChainClaimID

The unique integer ID for the cross-chain claim.

Declaration
string XChainClaimID { get; set; }
Property Value
Type Description
string
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX