Show / Hide Table of Contents

Interface IXChainCommit

The XChainCommit transaction is the second step in a cross-chain transfer. It puts assets into trust on the locking chain so that they can be wrapped on the issuing chain, or burns wrapped assets on the issuing chain so that they can be returned on the locking chain.

Inherited Members
ITransactionCommon.NetworkID
ITransactionCommon.Account
ITransactionCommon.AccountTxnID
ITransactionCommon.Fee
ITransactionCommon.Flags
ITransactionCommon.LastLedgerSequence
ITransactionCommon.Memos
ITransactionCommon.MemoValue
ITransactionCommon.Sequence
ITransactionCommon.Signers
ITransactionCommon.SigningPublicKey
ITransactionCommon.TransactionSignature
ITransactionCommon.TransactionType
ITransactionCommon.SourceTag
ITransactionCommon.TicketSequence
ITransactionCommon.ToJson()
ITransactionCommon.ToDictionary()
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public interface IXChainCommit : ITransactionCommon

Properties

| Edit this page View Source

Amount

The amount to transfer.

Declaration
Currency Amount { get; set; }
Property Value
Type Description
Currency
| Edit this page View Source

OtherChainDestination

The destination account on the destination chain. If this is not specified, the account that submitted the XChainCreateClaimID transaction on the destination chain will need to submit an XChainClaim transaction.

Declaration
string OtherChainDestination { get; set; }
Property Value
Type Description
string
| Edit this page View Source

XChainBridge

The bridge to use for the transfer.

Declaration
XChainBridgeModel XChainBridge { get; set; }
Property Value
Type Description
XChainBridgeModel
| Edit this page View Source

XChainClaimID

The unique integer ID for the cross-chain claim.

Declaration
string XChainClaimID { get; set; }
Property Value
Type Description
string
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX