Show / Hide Table of Contents

Interface IXChainCreateBridge

The XChainCreateBridge transaction creates a new Bridge ledger object and defines a cross-chain bridge between a locking chain and an issuing chain.

Inherited Members
ITransactionCommon.NetworkID
ITransactionCommon.Account
ITransactionCommon.AccountTxnID
ITransactionCommon.Fee
ITransactionCommon.Flags
ITransactionCommon.LastLedgerSequence
ITransactionCommon.Memos
ITransactionCommon.MemoValue
ITransactionCommon.Sequence
ITransactionCommon.Signers
ITransactionCommon.SigningPublicKey
ITransactionCommon.TransactionSignature
ITransactionCommon.TransactionType
ITransactionCommon.SourceTag
ITransactionCommon.TicketSequence
ITransactionCommon.ToJson()
ITransactionCommon.ToDictionary()
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public interface IXChainCreateBridge : ITransactionCommon

Properties

| Edit this page View Source

MinAccountCreateAmount

The minimum amount, in XRP, required for an XChainAccountCreateCommit transaction. If this is not present, the XChainAccountCreateCommit transaction will fail.

Declaration
Currency MinAccountCreateAmount { get; set; }
Property Value
Type Description
Currency
| Edit this page View Source

SignatureReward

The signature reward split between the witnesses for submitting attestations.

Declaration
Currency SignatureReward { get; set; }
Property Value
Type Description
Currency
| Edit this page View Source

XChainBridge

The bridge (door accounts and brided assets) to create.

Declaration
XChainBridgeModel XChainBridge { get; set; }
Property Value
Type Description
XChainBridgeModel
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX