Show / Hide Table of Contents

Interface IXChainCreateClaimID

The XChainCreateClaimID transaction creates a new cross-chain claim ID that is used for a cross-chain transfer. A cross-chain claim ID represents one cross-chain transfer of value.

Inherited Members
ITransactionCommon.NetworkID
ITransactionCommon.Account
ITransactionCommon.AccountTxnID
ITransactionCommon.Fee
ITransactionCommon.Flags
ITransactionCommon.LastLedgerSequence
ITransactionCommon.Memos
ITransactionCommon.MemoValue
ITransactionCommon.Sequence
ITransactionCommon.Signers
ITransactionCommon.SigningPublicKey
ITransactionCommon.TransactionSignature
ITransactionCommon.TransactionType
ITransactionCommon.SourceTag
ITransactionCommon.TicketSequence
ITransactionCommon.ToJson()
ITransactionCommon.ToDictionary()
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public interface IXChainCreateClaimID : ITransactionCommon

Properties

| Edit this page View Source

OtherChainSource

The account that must send the corresponding XChainCommit on the source chain.

Declaration
string OtherChainSource { get; set; }
Property Value
Type Description
string
| Edit this page View Source

SignatureReward

The amount, in XRP, to reward the witness servers for providing signatures. This must match the amount on the Bridge ledger object.

Declaration
Currency SignatureReward { get; set; }
Property Value
Type Description
Currency
| Edit this page View Source

XChainBridge

The bridge to create the claim ID for.

Declaration
XChainBridgeModel XChainBridge { get; set; }
Property Value
Type Description
XChainBridgeModel
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX