Show / Hide Table of Contents

Interface IXChainModifyBridge

The XChainModifyBridge transaction allows bridge managers to modify the parameters of an existing bridge.

Inherited Members
ITransactionCommon.NetworkID
ITransactionCommon.Account
ITransactionCommon.AccountTxnID
ITransactionCommon.Fee
ITransactionCommon.LastLedgerSequence
ITransactionCommon.Memos
ITransactionCommon.MemoValue
ITransactionCommon.Sequence
ITransactionCommon.Signers
ITransactionCommon.SigningPublicKey
ITransactionCommon.TransactionSignature
ITransactionCommon.TransactionType
ITransactionCommon.SourceTag
ITransactionCommon.TicketSequence
ITransactionCommon.ToJson()
ITransactionCommon.ToDictionary()
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public interface IXChainModifyBridge : ITransactionCommon

Properties

| Edit this page View Source

Flags

Declaration
XChainModifyBridgeFlags? Flags { get; set; }
Property Value
Type Description
XChainModifyBridgeFlags?
| Edit this page View Source

MinAccountCreateAmount

The minimum amount, in XRP, required for an XChainAccountCreateCommit transaction.

Declaration
Currency MinAccountCreateAmount { get; set; }
Property Value
Type Description
Currency
| Edit this page View Source

SignatureReward

The signature reward split between the witnesses for submitting attestations.

Declaration
Currency SignatureReward { get; set; }
Property Value
Type Description
Currency
| Edit this page View Source

XChainBridge

The bridge to modify.

Declaration
XChainBridgeModel XChainBridge { get; set; }
Property Value
Type Description
XChainBridgeModel
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX