Show / Hide Table of Contents

Class InnerSigner

The Signers field contains a multi-signature, which has signatures from up to 8 key pairs, that together should authorize the transaction.

Inheritance
object
InnerSigner
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public class InnerSigner

Properties

| Edit this page View Source

Account

The address associated with this signature, as it appears in the signer list.

Declaration
public string Account { get; set; }
Property Value
Type Description
string
| Edit this page View Source

SigningPublicKey

The public key used to create this signature.

Declaration
[JsonPropertyName("SigningPubKey")]
public string SigningPublicKey { get; set; }
Property Value
Type Description
string
| Edit this page View Source

TransactionSignature

A signature for this transaction, verifiable using the SigningPubKey.

Declaration
[JsonPropertyName("TxnSignature")]
public string TransactionSignature { get; set; }
Property Value
Type Description
string
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX