Class LoanBrokerCoverClawback
The LoanBrokerCoverClawback transaction claws back cover assets from a loan broker. At least one of LoanBrokerID or Amount must be specified.
Inherited Members
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public class LoanBrokerCoverClawback : TransactionRequest, ITransactionRequest, ILoanBrokerCoverClawback, ITransactionCommon
Remarks
Requires the Loan amendment (XLS-66d). This feature is in draft and subject to change.
Constructors
| Edit this page View SourceLoanBrokerCoverClawback()
Declaration
public LoanBrokerCoverClawback()
Properties
| Edit this page View SourceAmount
The amount to claw back. Optional.
Declaration
[JsonPropertyName("Amount")]
[JsonConverter(typeof(CurrencyConverter))]
public Currency Amount { get; set; }
Property Value
| Type | Description |
|---|---|
| Currency |
LoanBrokerID
The ID of the loan broker to claw back from. Optional.
Declaration
[JsonPropertyName("LoanBrokerID")]
public string LoanBrokerID { get; set; }
Property Value
| Type | Description |
|---|---|
| string |