Class LoanBrokerCoverDeposit
The LoanBrokerCoverDeposit transaction deposits cover assets into a loan broker.
Inherited Members
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public class LoanBrokerCoverDeposit : TransactionRequest, ITransactionRequest, ILoanBrokerCoverDeposit, ITransactionCommon
Remarks
Requires the Loan amendment (XLS-66d). This feature is in draft and subject to change.
Constructors
| Edit this page View SourceLoanBrokerCoverDeposit()
Declaration
public LoanBrokerCoverDeposit()
Properties
| Edit this page View SourceAmount
The amount of cover assets to deposit.
Declaration
[JsonPropertyName("Amount")]
[JsonConverter(typeof(CurrencyConverter))]
public Currency Amount { get; set; }
Property Value
| Type | Description |
|---|---|
| Currency |
LoanBrokerID
The ID of the loan broker to deposit cover assets into.
Declaration
[JsonPropertyName("LoanBrokerID")]
public string LoanBrokerID { get; set; }
Property Value
| Type | Description |
|---|---|
| string |