Show / Hide Table of Contents

Class LoanBrokerCoverWithdrawResponse

The LoanBrokerCoverWithdraw transaction withdraws cover assets from a loan broker.

Inheritance
object
BaseTransactionResponse
TransactionResponse
LoanBrokerCoverWithdrawResponse
Implements
ITransactionResponse
IBaseTransactionResponse
ILoanBrokerCoverWithdraw
ITransactionCommon
Inherited Members
TransactionResponse.NetworkID
TransactionResponse.Account
TransactionResponse.AccountTxnID
TransactionResponse.Fee
TransactionResponse.Flags
TransactionResponse.LastLedgerSequence
TransactionResponse.Memos
TransactionResponse.MemoValue
TransactionResponse.Sequence
TransactionResponse.SigningPublicKey
TransactionResponse.Signers
TransactionResponse.TransactionType
TransactionResponse.TransactionSignature
TransactionResponse.Meta
TransactionResponse.ToJson()
TransactionResponse.ToDictionary()
TransactionResponse.SourceTag
TransactionResponse.TicketSequence
BaseTransactionResponse.Date
BaseTransactionResponse.Hash
BaseTransactionResponse.InLedger
BaseTransactionResponse.LedgerIndex
BaseTransactionResponse.Validated
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public class LoanBrokerCoverWithdrawResponse : TransactionResponse, ITransactionResponse, IBaseTransactionResponse, ILoanBrokerCoverWithdraw, ITransactionCommon
Remarks

Requires the Loan amendment (XLS-66d). This feature is in draft and subject to change.

Properties

| Edit this page View Source

Amount

The amount of cover assets to withdraw.

Declaration
[JsonPropertyName("Amount")]
[JsonConverter(typeof(CurrencyConverter))]
public Currency Amount { get; set; }
Property Value
Type Description
Currency
| Edit this page View Source

Destination

The destination account for the withdrawn assets. Optional.

Declaration
[JsonPropertyName("Destination")]
public string Destination { get; set; }
Property Value
Type Description
string
| Edit this page View Source

DestinationTag

An arbitrary tag to identify the destination. Optional.

Declaration
[JsonPropertyName("DestinationTag")]
public uint? DestinationTag { get; set; }
Property Value
Type Description
uint?
| Edit this page View Source

LoanBrokerID

The ID of the loan broker to withdraw cover assets from.

Declaration
[JsonPropertyName("LoanBrokerID")]
public string LoanBrokerID { get; set; }
Property Value
Type Description
string

Implements

ITransactionResponse
IBaseTransactionResponse
ILoanBrokerCoverWithdraw
ITransactionCommon
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX