Show / Hide Table of Contents

Class LoanPayResponse

The LoanPay transaction makes a payment on a loan. Flags are mutually exclusive.

Inheritance
object
BaseTransactionResponse
TransactionResponse
LoanPayResponse
Implements
ITransactionResponse
IBaseTransactionResponse
ILoanPay
ITransactionCommon
Inherited Members
TransactionResponse.NetworkID
TransactionResponse.Account
TransactionResponse.AccountTxnID
TransactionResponse.Fee
TransactionResponse.LastLedgerSequence
TransactionResponse.Memos
TransactionResponse.MemoValue
TransactionResponse.Sequence
TransactionResponse.SigningPublicKey
TransactionResponse.Signers
TransactionResponse.TransactionType
TransactionResponse.TransactionSignature
TransactionResponse.Meta
TransactionResponse.ToJson()
TransactionResponse.ToDictionary()
TransactionResponse.SourceTag
TransactionResponse.TicketSequence
BaseTransactionResponse.Date
BaseTransactionResponse.Hash
BaseTransactionResponse.InLedger
BaseTransactionResponse.LedgerIndex
BaseTransactionResponse.Validated
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public class LoanPayResponse : TransactionResponse, ITransactionResponse, IBaseTransactionResponse, ILoanPay, ITransactionCommon
Remarks

Requires the Loan amendment (XLS-66d). This feature is in draft and subject to change.

Properties

| Edit this page View Source

Amount

The amount to pay.

Declaration
[JsonPropertyName("Amount")]
[JsonConverter(typeof(CurrencyConverter))]
public Currency Amount { get; set; }
Property Value
Type Description
Currency
| Edit this page View Source

Flags

LoanPay transaction flags.

Declaration
public LoanPayFlags? Flags { get; set; }
Property Value
Type Description
LoanPayFlags?
| Edit this page View Source

LoanID

The ID of the loan to make a payment on.

Declaration
[JsonPropertyName("LoanID")]
public string LoanID { get; set; }
Property Value
Type Description
string

Implements

ITransactionResponse
IBaseTransactionResponse
ILoanPay
ITransactionCommon
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX