Show / Hide Table of Contents

Class MPTokenAuthorize

The MPTokenAuthorize transaction authorizes an account to hold an MPT.

Inheritance
object
TransactionRequest
MPTokenAuthorize
Implements
ITransactionRequest
IMPTokenAuthorize
ITransactionCommon
Inherited Members
TransactionRequest.NetworkID
TransactionRequest.Account
TransactionRequest.AccountTxnID
TransactionRequest.Fee
TransactionRequest.LastLedgerSequence
TransactionRequest.Memos
TransactionRequest.Sequence
TransactionRequest.SigningPublicKey
TransactionRequest.Signers
TransactionRequest.TransactionType
TransactionRequest.TransactionSignature
TransactionRequest.ToJson()
TransactionRequest.ToDictionary()
TransactionRequest.SourceTag
TransactionRequest.TicketSequence
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public class MPTokenAuthorize : TransactionRequest, ITransactionRequest, IMPTokenAuthorize, ITransactionCommon

Constructors

| Edit this page View Source

MPTokenAuthorize()

Initializes a new instance of the MPTokenAuthorize class.

Declaration
public MPTokenAuthorize()

Properties

| Edit this page View Source

Flags

Declaration
public MPTokenAuthorizeFlags? Flags { get; set; }
Property Value
Type Description
MPTokenAuthorizeFlags?
| Edit this page View Source

Holder

An optional XRPL Address of an individual token holder balance. If this is set, the Holder field must specify the holder's address. If this is not set, the transaction is assumed to be from the holder directly.

Declaration
[JsonPropertyName("Holder")]
public string? Holder { get; set; }
Property Value
Type Description
string
| Edit this page View Source

MPTokenIssuanceID

The ID of the MPT to authorize.

Declaration
[JsonPropertyName("MPTokenIssuanceID")]
public string MPTokenIssuanceID { get; set; }
Property Value
Type Description
string

Implements

ITransactionRequest
IMPTokenAuthorize
ITransactionCommon

Extension Methods

BatchUtils.ToBatchTx(ITransactionRequest)
Utilities.Encode(TransactionRequest)
Utilities.EncodeForMultiSigning(TransactionRequest, string)
Utilities.EncodeForSigning(TransactionRequest)
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX