Show / Hide Table of Contents

Enum MPTokenAuthorizeFlags

Enum representing flags for MPTokenAuthorize transactions.

Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
[Flags]
public enum MPTokenAuthorizeFlags : uint

Fields

Name Description
tfMPTUnauthorize

When the holder enables this flag, if their balance of the given MPT is zero,
it revokes their willingness to hold this MPT and deletes their MPToken entry.
If their balance is non-zero, the transaction fails.
When an issuer enables this flag, it revokes permission for the specified holder to hold this MPT;
the transaction fails if the MPT does not use allow-listing.

Extension Methods

EmumExtensions.DecodeFlags<MPTokenAuthorizeFlags>(MPTokenAuthorizeFlags)
EmumExtensions.FlagsValues<MPTokenAuthorizeFlags>(MPTokenAuthorizeFlags)
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX