Show / Hide Table of Contents

Class MPTokenAuthorizeResponse

The MPTokenAuthorize transaction is used to allow an account to hold a particular MPT issuance, or by an issuer to authorize or revoke authorization for a holder.

Inheritance
object
BaseTransactionResponse
TransactionResponse
MPTokenAuthorizeResponse
Implements
ITransactionResponse
IBaseTransactionResponse
IMPTokenAuthorize
ITransactionCommon
Inherited Members
TransactionResponse.NetworkID
TransactionResponse.Account
TransactionResponse.AccountTxnID
TransactionResponse.Fee
TransactionResponse.LastLedgerSequence
TransactionResponse.Memos
TransactionResponse.MemoValue
TransactionResponse.Sequence
TransactionResponse.SigningPublicKey
TransactionResponse.Signers
TransactionResponse.TransactionType
TransactionResponse.TransactionSignature
TransactionResponse.Meta
TransactionResponse.ToJson()
TransactionResponse.ToDictionary()
TransactionResponse.SourceTag
TransactionResponse.TicketSequence
BaseTransactionResponse.Date
BaseTransactionResponse.Hash
BaseTransactionResponse.InLedger
BaseTransactionResponse.LedgerIndex
BaseTransactionResponse.Validated
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public class MPTokenAuthorizeResponse : TransactionResponse, ITransactionResponse, IBaseTransactionResponse, IMPTokenAuthorize, ITransactionCommon

Properties

| Edit this page View Source

Flags

Declaration
public MPTokenAuthorizeFlags? Flags { get; set; }
Property Value
Type Description
MPTokenAuthorizeFlags?
| Edit this page View Source

Holder

An optional XRPL Address of an individual token holder balance. If this is set, the Holder field must specify the holder's address. If this is not set, the transaction is assumed to be from the holder directly.

Declaration
[JsonPropertyName("Holder")]
public string? Holder { get; set; }
Property Value
Type Description
string
| Edit this page View Source

MPTokenIssuanceID

The ID of the MPT to authorize.

Declaration
[JsonPropertyName("MPTokenIssuanceID")]
public string MPTokenIssuanceID { get; set; }
Property Value
Type Description
string

Implements

ITransactionResponse
IBaseTransactionResponse
IMPTokenAuthorize
ITransactionCommon
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX