Show / Hide Table of Contents

Class MPTokenIssuanceCreate

The MPTokenIssuanceCreate transaction creates an MPTokenIssuance object.

Inheritance
object
TransactionRequest
MPTokenIssuanceCreate
Implements
ITransactionRequest
IMPTokenIssuanceCreate
ITransactionCommon
Inherited Members
TransactionRequest.NetworkID
TransactionRequest.Account
TransactionRequest.AccountTxnID
TransactionRequest.Fee
TransactionRequest.LastLedgerSequence
TransactionRequest.Memos
TransactionRequest.Sequence
TransactionRequest.SigningPublicKey
TransactionRequest.Signers
TransactionRequest.TransactionType
TransactionRequest.TransactionSignature
TransactionRequest.ToJson()
TransactionRequest.ToDictionary()
TransactionRequest.SourceTag
TransactionRequest.TicketSequence
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public class MPTokenIssuanceCreate : TransactionRequest, ITransactionRequest, IMPTokenIssuanceCreate, ITransactionCommon

Constructors

| Edit this page View Source

MPTokenIssuanceCreate()

Initializes a new instance of the MPTokenIssuanceCreate class.

Declaration
public MPTokenIssuanceCreate()

Properties

| Edit this page View Source

AssetScale

An asset scale is the difference, in orders of magnitude, between a standard unit and a corresponding fractional unit.More formally, the asset scale is a non-negative integer (0, 1, 2, …) such that one standard unit equals 10^(-scale) of a corresponding fractional unit.If the fractional unit equals the standard unit, then the asset scale is 0. Note that this value is optional, and will default to 0 if not supplied.

Declaration
[JsonPropertyName("AssetScale")]
public uint? AssetScale { get; set; }
Property Value
Type Description
uint?
| Edit this page View Source

Flags

Declaration
public MPTokenIssuanceCreateFlags? Flags { get; set; }
Property Value
Type Description
MPTokenIssuanceCreateFlags?
| Edit this page View Source

MPTokenMetadata

Arbitrary metadata about this issuance, in hex format. The limit for this field is 1024 bytes.

Declaration
[JsonPropertyName("MPTokenMetadata")]
public string? MPTokenMetadata { get; set; }
Property Value
Type Description
string
| Edit this page View Source

MPTokenMetadataRow

Declaration
[JsonIgnore]
public string? MPTokenMetadataRow { get; }
Property Value
Type Description
string
| Edit this page View Source

MaximumAmount

Specifies the maximum asset amount of this token that should ever be issued. Valid values for this field are between 0 and 9223372036854775807 (the maximum signed 64-bit integer). If this value is not specified, the issuance does not have a limit.

Declaration
[JsonPropertyName("MaximumAmount")]
public string? MaximumAmount { get; set; }
Property Value
Type Description
string
| Edit this page View Source

Metadata

Parsed metadata object conforming to the XLS-89 Multi-Purpose Token Metadata Schema. Setting this property automatically serializes the schema to the MPTokenMetadata hex field.

Declaration
[JsonIgnore]
public MPTokenMetadataSchema? Metadata { get; set; }
Property Value
Type Description
MPTokenMetadataSchema
| Edit this page View Source

TransferFee

The value specifies the fee to charged by the issuer for secondary sales of the token, if such sales are allowed. Valid values for this field are between 0 and 50000 inclusive, allowing transfer rates of between 0.00% and 50.00% in increments of 0.001.

Declaration
[JsonPropertyName("TransferFee")]
public ushort? TransferFee { get; set; }
Property Value
Type Description
ushort?

Implements

ITransactionRequest
IMPTokenIssuanceCreate
ITransactionCommon

Extension Methods

BatchUtils.ToBatchTx(ITransactionRequest)
Utilities.Encode(TransactionRequest)
Utilities.EncodeForMultiSigning(TransactionRequest, string)
Utilities.EncodeForSigning(TransactionRequest)
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX