Show / Hide Table of Contents

Class MPTokenIssuanceDestroyResponse

The MPTokenIssuanceDestroy transaction is used to remove an MPTokenIssuance object from the directory node in which it is being held, effectively removing the token from the ledger.

Inheritance
object
BaseTransactionResponse
TransactionResponse
MPTokenIssuanceDestroyResponse
Implements
ITransactionResponse
IBaseTransactionResponse
IMPTokenIssuanceDestroy
ITransactionCommon
Inherited Members
TransactionResponse.NetworkID
TransactionResponse.Account
TransactionResponse.AccountTxnID
TransactionResponse.Fee
TransactionResponse.Flags
TransactionResponse.LastLedgerSequence
TransactionResponse.Memos
TransactionResponse.MemoValue
TransactionResponse.Sequence
TransactionResponse.SigningPublicKey
TransactionResponse.Signers
TransactionResponse.TransactionType
TransactionResponse.TransactionSignature
TransactionResponse.Meta
TransactionResponse.ToJson()
TransactionResponse.ToDictionary()
TransactionResponse.SourceTag
TransactionResponse.TicketSequence
BaseTransactionResponse.Date
BaseTransactionResponse.Hash
BaseTransactionResponse.InLedger
BaseTransactionResponse.LedgerIndex
BaseTransactionResponse.Validated
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public class MPTokenIssuanceDestroyResponse : TransactionResponse, ITransactionResponse, IBaseTransactionResponse, IMPTokenIssuanceDestroy, ITransactionCommon

Properties

| Edit this page View Source

MPTokenIssuanceID

Identifies the MPTokenIssuance object to be removed by the transaction.

Declaration
[JsonPropertyName("MPTokenIssuanceID")]
public string MPTokenIssuanceID { get; set; }
Property Value
Type Description
string

Implements

ITransactionResponse
IBaseTransactionResponse
IMPTokenIssuanceDestroy
ITransactionCommon
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX