Show / Hide Table of Contents

Class Memo

The Memos field includes arbitrary messaging data with the transaction.

Inheritance
object
Memo
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public class Memo

Properties

| Edit this page View Source

MemoData

Arbitrary hex value, conventionally containing the content of the memo.

Declaration
public string MemoData { get; set; }
Property Value
Type Description
string
| Edit this page View Source

MemoDataAsText

Content of the memo.

Declaration
[JsonIgnore]
public string MemoDataAsText { get; }
Property Value
Type Description
string
| Edit this page View Source

MemoFormat

Hex value representing characters allowed in URLs.
Conventionally containing information on how the memo is encoded, for example as a MIME type.

Declaration
public string MemoFormat { get; set; }
Property Value
Type Description
string
| Edit this page View Source

MemoFormatAsText

Conventionally containing information on how the memo is encoded, for example as a MIME type.

Declaration
[JsonIgnore]
public string MemoFormatAsText { get; }
Property Value
Type Description
string
| Edit this page View Source

MemoType

Hex value representing characters allowed in URLs.
Conventionally, a unique relation (according to RFC 5988 ) that defines the format of this memo.

Declaration
public string MemoType { get; set; }
Property Value
Type Description
string
| Edit this page View Source

MemoTypeAsText

Conventionally, a unique relation (according to RFC 5988 ) that defines the format of this memo.

Declaration
[JsonIgnore]
public string MemoTypeAsText { get; }
Property Value
Type Description
string
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX