Show / Hide Table of Contents

Class Meta

Transaction metadata is a section of data that gets added to a transaction after it is processed.
Any transaction that gets included in a ledger has metadata, regardless of whether it is successful.
The transaction metadata describes the outcome of the transaction in detail.
Warning: The changes described in transaction metadata are only final if the transaction is in a validated ledger version.

Inheritance
object
Meta
Implements
ITransactionMetadata
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public class Meta : ITransactionMetadata

Properties

| Edit this page View Source

ActuallyDeliveredAmount

(Omitted for non-Payment transactions) The Currency Amount actually received by the Destination account.
Use this field to determine how much was delivered, regardless of whether the transaction is a partial payment.
See this description for details.

Declaration
[JsonConverter(typeof(CurrencyConverter))]
[JsonPropertyName("delivered_amount")]
public Currency ActuallyDeliveredAmount { get; set; }
Property Value
Type Description
Currency
| Edit this page View Source

AffectedNodes

List of ledger objects that were created, deleted, or modified by this transaction, and specific changes to each.

Declaration
public List<AffectedNode> AffectedNodes { get; set; }
Property Value
Type Description
List<AffectedNode>
| Edit this page View Source

MetaBlob

Declaration
public string MetaBlob { get; set; }
Property Value
Type Description
string
| Edit this page View Source

MptIssuanceId

Shows the MPTokenIssuanceID for the MPTokenIssuance that was created by this transaction. Only present if the transaction is MPTokenIssuanceCreate.

Declaration
[JsonPropertyName("mpt_issuance_id")]
public string MptIssuanceId { get; set; }
Property Value
Type Description
string
| Edit this page View Source

NFTokenId

Shows the NFTokenID for the NFToken that changed on the ledger as a result of the transaction. Only present if the transaction is NFTokenMint or NFTokenAcceptOffer

Declaration
[JsonPropertyName("nftoken_id")]
public string NFTokenId { get; set; }
Property Value
Type Description
string
| Edit this page View Source

NFTokenIds

Shows all the NFTokenIDs for the NFTokens that changed on the ledger as a result of the transaction. Only present if the transaction is NFTokenCancelOffer.

Declaration
[JsonPropertyName("nftoken_ids")]
public string[] NFTokenIds { get; set; }
Property Value
Type Description
string[]
| Edit this page View Source

OfferID

Shows the OfferIDof a new NFTokenOffer in a response from a NFTokenCreateOffer transaction.

Declaration
[JsonPropertyName("offer_id")]
public string OfferID { get; set; }
Property Value
Type Description
string
| Edit this page View Source

ParentBatchID

Batch ID of the batch that this transaction belongs to, if any.

Declaration
public string? ParentBatchID { get; set; }
Property Value
Type Description
string
| Edit this page View Source

PartialDeliveredAmount

(May be omitted) For a partial payment, this field records the amount of currency actually delivered to the destination.
To avoid errors when reading transactions, instead use the delivered_amount field, which is provided for all Payment transactions, partial or not.

Declaration
[JsonConverter(typeof(CurrencyConverter))]
[JsonPropertyName("DeliveredAmount")]
public Currency PartialDeliveredAmount { get; set; }
Property Value
Type Description
Currency
| Edit this page View Source

TransactionIndex

The transaction's position within the ledger that included it.
This is zero-indexed.
(For example, the value 2 means it was the 3rd transaction in that ledger.)

Declaration
public int TransactionIndex { get; set; }
Property Value
Type Description
int
| Edit this page View Source

TransactionResult

A result code indicating whether the transaction succeeded or how it failed.

Declaration
public string TransactionResult { get; set; }
Property Value
Type Description
string

Implements

ITransactionMetadata

Extension Methods

AffectedNodeExtensions.GetCreatedNews<T>(ITransactionMetadata)
AffectedNodeExtensions.GetDeletedFinals<T>(ITransactionMetadata)
AffectedNodeExtensions.GetDeletedPrevious<T>(ITransactionMetadata)
AffectedNodeExtensions.GetModifiedFinals<T>(ITransactionMetadata)
AffectedNodeExtensions.GetModifiedPrevious<T>(ITransactionMetadata)
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX