Show / Hide Table of Contents

Class NFTokenAcceptOfferResponse

The NFTokenOfferAccept transaction is used to accept offers to buy or sell an NFToken.
It can either:
1.
Allow one offer to be accepted.
This is called direct mode.
2.
Allow two distinct offers, one offering to buy a given NFToken and the other offering to sell the same NFToken, to be accepted in an atomic fashion.
This is called brokered mode.
To indicate direct mode, use either the sell_offer or buy_offer fields, but not both.
To indicate brokered mode, use both the sell_offer and buy_offer fields.
If you use neither sell_offer nor buy_offer, the transaction is invalid.

Inheritance
object
BaseTransactionResponse
TransactionResponse
NFTokenAcceptOfferResponse
Implements
ITransactionResponse
IBaseTransactionResponse
INFTokenAcceptOffer
ITransactionCommon
Inherited Members
TransactionResponse.NetworkID
TransactionResponse.Account
TransactionResponse.AccountTxnID
TransactionResponse.Fee
TransactionResponse.Flags
TransactionResponse.LastLedgerSequence
TransactionResponse.Memos
TransactionResponse.MemoValue
TransactionResponse.Sequence
TransactionResponse.SigningPublicKey
TransactionResponse.Signers
TransactionResponse.TransactionType
TransactionResponse.TransactionSignature
TransactionResponse.Meta
TransactionResponse.ToJson()
TransactionResponse.ToDictionary()
TransactionResponse.SourceTag
TransactionResponse.TicketSequence
BaseTransactionResponse.Date
BaseTransactionResponse.Hash
BaseTransactionResponse.InLedger
BaseTransactionResponse.LedgerIndex
BaseTransactionResponse.Validated
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public class NFTokenAcceptOfferResponse : TransactionResponse, ITransactionResponse, IBaseTransactionResponse, INFTokenAcceptOffer, ITransactionCommon

Properties

| Edit this page View Source

NFTokenBrokerFee

This field is only valid in brokered mode.
It specifies the amount that the broker will keep as part of their fee for bringing the two offers together; the remaining amount will be sent to the seller of the NFToken being bought.
If specified, the fee must be such that, prior to accounting for the transfer fee charged by the issuer, the amount that the seller would receive is at least as much as the amount indicated in the sell offer.
This functionality is intended to allow the owner of an NFToken to offer their token for sale to a third party broker, who may then attempt to sell the NFToken on for a larger amount, without the broker having to own the NFToken or custody funds.
Note: in brokered mode, the offers referenced by NFTokenBuyOffer and NFTokenSellOffer must both specify the same NFTokenID; that is, both must be for the same NFToken.

Declaration
[JsonConverter(typeof(CurrencyConverter))]
public Currency NFTokenBrokerFee { get; set; }
Property Value
Type Description
Currency
| Edit this page View Source

NFTokenBuyOffer

Identifies the NFTokenOffer that offers to buy the NFToken.
In direct mode this field is optional, but either NFTokenSellOffer or NFTokenBuyOffer must be specified.
In brokered mode, both NFTokenSellOffer and NFTokenBuyOffer must be specified.

Declaration
public string NFTokenBuyOffer { get; set; }
Property Value
Type Description
string
| Edit this page View Source

NFTokenID

Declaration
public string NFTokenID { get; set; }
Property Value
Type Description
string
| Edit this page View Source

NFTokenSellOffer

Identifies the NFTokenOffer that offers to sell the NFToken.
In direct mode this field is optional, but either NFTokenSellOffer or NFTokenBuyOffer must be specified.
In brokered mode, both NFTokenSellOffer and NFTokenBuyOffer must be specified.

Declaration
public string NFTokenSellOffer { get; set; }
Property Value
Type Description
string

Implements

ITransactionResponse
IBaseTransactionResponse
INFTokenAcceptOffer
ITransactionCommon
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX