Show / Hide Table of Contents

Class NFTokenBurn

The NFTokenBurn transaction is used to remove an NFToken object from the NFTokenPage in which it is being held, effectively removing the token from the ledger ("burning" it).
If this operation succeeds, the corresponding NFToken is removed.
If this operation empties the NFTokenPage holding the NFToken or results in the consolidation, thus removing an NFTokenPage, the owner’s reserve requirement is reduced by one.

Inheritance
object
TransactionRequest
NFTokenBurn
Implements
ITransactionRequest
INFTokenBurn
ITransactionCommon
Inherited Members
TransactionRequest.NetworkID
TransactionRequest.Account
TransactionRequest.AccountTxnID
TransactionRequest.Fee
TransactionRequest.Flags
TransactionRequest.LastLedgerSequence
TransactionRequest.Memos
TransactionRequest.Sequence
TransactionRequest.SigningPublicKey
TransactionRequest.Signers
TransactionRequest.TransactionType
TransactionRequest.TransactionSignature
TransactionRequest.ToJson()
TransactionRequest.ToDictionary()
TransactionRequest.SourceTag
TransactionRequest.TicketSequence
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public class NFTokenBurn : TransactionRequest, ITransactionRequest, INFTokenBurn, ITransactionCommon

Constructors

| Edit this page View Source

NFTokenBurn()

Declaration
public NFTokenBurn()

Properties

| Edit this page View Source

NFTokenID

Identifies the NFToken object to be removed by the transaction.

Declaration
public string NFTokenID { get; set; }
Property Value
Type Description
string
| Edit this page View Source

Owner

Indicates which account currently owns the token if it is different than Account.
Only used to burn tokens which have the lsfBurnable flag enabled and are not owned by the signing account.

Declaration
public string Owner { get; set; }
Property Value
Type Description
string

Implements

ITransactionRequest
INFTokenBurn
ITransactionCommon

Extension Methods

BatchUtils.ToBatchTx(ITransactionRequest)
Utilities.Encode(TransactionRequest)
Utilities.EncodeForMultiSigning(TransactionRequest, string)
Utilities.EncodeForSigning(TransactionRequest)
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX