Show / Hide Table of Contents

Class NFTokenBurnResponse

The NFTokenBurn transaction is used to remove an NFToken object from the NFTokenPage in which it is being held, effectively removing the token from the ledger ("burning" it).
If this operation succeeds, the corresponding NFToken is removed.
If this operation empties the NFTokenPage holding the NFToken or results in the consolidation, thus removing an NFTokenPage, the owner’s reserve requirement is reduced by one.

Inheritance
object
BaseTransactionResponse
TransactionResponse
NFTokenBurnResponse
Implements
ITransactionResponse
IBaseTransactionResponse
INFTokenBurn
ITransactionCommon
Inherited Members
TransactionResponse.NetworkID
TransactionResponse.Account
TransactionResponse.AccountTxnID
TransactionResponse.Fee
TransactionResponse.Flags
TransactionResponse.LastLedgerSequence
TransactionResponse.Memos
TransactionResponse.MemoValue
TransactionResponse.Sequence
TransactionResponse.SigningPublicKey
TransactionResponse.Signers
TransactionResponse.TransactionType
TransactionResponse.TransactionSignature
TransactionResponse.Meta
TransactionResponse.ToJson()
TransactionResponse.ToDictionary()
TransactionResponse.SourceTag
TransactionResponse.TicketSequence
BaseTransactionResponse.Date
BaseTransactionResponse.Hash
BaseTransactionResponse.InLedger
BaseTransactionResponse.LedgerIndex
BaseTransactionResponse.Validated
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public class NFTokenBurnResponse : TransactionResponse, ITransactionResponse, IBaseTransactionResponse, INFTokenBurn, ITransactionCommon

Properties

| Edit this page View Source

NFTokenID

Identifies the NFToken object to be removed by the transaction.

Declaration
public string NFTokenID { get; set; }
Property Value
Type Description
string
| Edit this page View Source

Owner

Indicates which account currently owns the token if it is different than Account.
Only used to burn tokens which have the lsfBurnable flag enabled and are not owned by the signing account.

Declaration
public string Owner { get; set; }
Property Value
Type Description
string

Implements

ITransactionResponse
IBaseTransactionResponse
INFTokenBurn
ITransactionCommon
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX