Show / Hide Table of Contents

Class NFTokenCancelOfferResponse

The NFTokenCancelOffer transaction deletes existing NFTokenOffer objects.
It is useful if you want to free up space on your account to lower your reserve requirement.
The transaction can be executed by the account that originally created the NFTokenOffer, the account in the Recipient field of the NFTokenOffer (if present), or any account if the NFTokenOffer has an Expiration and the NFTokenOffer has already expired.

Inheritance
object
BaseTransactionResponse
TransactionResponse
NFTokenCancelOfferResponse
Implements
ITransactionResponse
IBaseTransactionResponse
INFTokenCancelOffer
ITransactionCommon
Inherited Members
TransactionResponse.NetworkID
TransactionResponse.Account
TransactionResponse.AccountTxnID
TransactionResponse.Fee
TransactionResponse.Flags
TransactionResponse.LastLedgerSequence
TransactionResponse.Memos
TransactionResponse.MemoValue
TransactionResponse.Sequence
TransactionResponse.SigningPublicKey
TransactionResponse.Signers
TransactionResponse.TransactionType
TransactionResponse.TransactionSignature
TransactionResponse.Meta
TransactionResponse.ToJson()
TransactionResponse.ToDictionary()
TransactionResponse.SourceTag
TransactionResponse.TicketSequence
BaseTransactionResponse.Date
BaseTransactionResponse.Hash
BaseTransactionResponse.InLedger
BaseTransactionResponse.LedgerIndex
BaseTransactionResponse.Validated
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public class NFTokenCancelOfferResponse : TransactionResponse, ITransactionResponse, IBaseTransactionResponse, INFTokenCancelOffer, ITransactionCommon

Properties

| Edit this page View Source

NFTokenOffers

An array of identifiers of NFTokenOffer objects that should be cancelled by this transaction.
It is an error if an entry in this list points to an object that is not an NFTokenOffer object.
It is not an error if an entry in this list points to an object that does not exist.
This field is required.

Declaration
public string[] NFTokenOffers { get; set; }
Property Value
Type Description
string[]

Implements

ITransactionResponse
IBaseTransactionResponse
INFTokenCancelOffer
ITransactionCommon
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX