Show / Hide Table of Contents

Class NFTokenCreateOffer

The NFTokenCreateOffer transaction creates either an offer to buy an NFT the submitting account does not own, or an offer to sell an NFT the submitting account does own.

Inheritance
object
TransactionRequest
NFTokenCreateOffer
Implements
ITransactionRequest
INFTokenCreateOffer
ITransactionCommon
IDestination
Inherited Members
TransactionRequest.NetworkID
TransactionRequest.Account
TransactionRequest.AccountTxnID
TransactionRequest.Fee
TransactionRequest.LastLedgerSequence
TransactionRequest.Memos
TransactionRequest.Sequence
TransactionRequest.SigningPublicKey
TransactionRequest.Signers
TransactionRequest.TransactionType
TransactionRequest.TransactionSignature
TransactionRequest.ToJson()
TransactionRequest.ToDictionary()
TransactionRequest.SourceTag
TransactionRequest.TicketSequence
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public class NFTokenCreateOffer : TransactionRequest, ITransactionRequest, INFTokenCreateOffer, ITransactionCommon, IDestination

Constructors

| Edit this page View Source

NFTokenCreateOffer()

Declaration
public NFTokenCreateOffer()

Properties

| Edit this page View Source

Amount

Indicates the amount expected or offered for the Token.
The amount must be non-zero, except when this is a sell offer and the asset is XRP.
This would indicate that the current owner of the token is giving it away free, either to anyone at all, or to the account identified by the Destination field.

Declaration
[JsonConverter(typeof(CurrencyConverter))]
public Currency Amount { get; set; }
Property Value
Type Description
Currency
| Edit this page View Source

Destination

If present, indicates that this offer may only be accepted by the specified account.
Attempts by other accounts to accept this offer MUST fail.

Declaration
public string Destination { get; set; }
Property Value
Type Description
string
| Edit this page View Source

Expiration

Indicates the time after which the offer will no longer be valid.
The value is the number of seconds since the Ripple Epoch.

Declaration
[JsonConverter(typeof(RippleDateTimeConverter))]
public DateTime? Expiration { get; set; }
Property Value
Type Description
Nullable
| Edit this page View Source

Flags

If set, indicates that the offer is a sell offer.
Otherwise, it is a buy offer.

Declaration
public NFTokenCreateOfferFlags? Flags { get; set; }
Property Value
Type Description
NFTokenCreateOfferFlags?
| Edit this page View Source

NFTokenID

Identifies the NFTokenID of the NFToken object that the offer references.

Declaration
public string NFTokenID { get; set; }
Property Value
Type Description
string
| Edit this page View Source

Owner

Indicates the AccountID of the account that owns the corresponding NFToken.
If the offer is to buy a token, this field must be present and it must be different than Account (since an offer to buy a token one already holds is meaningless).
If the offer is to sell a token, this field must not be present, as the owner is, implicitly, the same as Account (since an offer to sell a token one doesn't already hold is meaningless).

Declaration
public string Owner { get; set; }
Property Value
Type Description
string

Implements

ITransactionRequest
INFTokenCreateOffer
ITransactionCommon
IDestination

Extension Methods

BatchUtils.ToBatchTx(ITransactionRequest)
Utilities.Encode(TransactionRequest)
Utilities.EncodeForMultiSigning(TransactionRequest, string)
Utilities.EncodeForSigning(TransactionRequest)
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX