Show / Hide Table of Contents

Class NFTokenMint

The NFTokenMint transaction creates an NFToken object and adds it to the relevant NFTokenPage object of the minter.
If the transaction is successful, the newly minted token will be owned by the minter account specified by the transaction.

Inheritance
object
TransactionRequest
NFTokenMint
Implements
ITransactionRequest
INFTokenMint
ITransactionCommon
Inherited Members
TransactionRequest.NetworkID
TransactionRequest.Account
TransactionRequest.AccountTxnID
TransactionRequest.Fee
TransactionRequest.LastLedgerSequence
TransactionRequest.Memos
TransactionRequest.Sequence
TransactionRequest.SigningPublicKey
TransactionRequest.Signers
TransactionRequest.TransactionType
TransactionRequest.TransactionSignature
TransactionRequest.ToJson()
TransactionRequest.ToDictionary()
TransactionRequest.SourceTag
TransactionRequest.TicketSequence
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public class NFTokenMint : TransactionRequest, ITransactionRequest, INFTokenMint, ITransactionCommon

Constructors

| Edit this page View Source

NFTokenMint()

Declaration
public NFTokenMint()

Properties

| Edit this page View Source

Flags

Declaration
public NFTokenMintFlags? Flags { get; set; }
Property Value
Type Description
NFTokenMintFlags?
| Edit this page View Source

Issuer

Indicates the account that should be the issuer of this token.
This value is optional and should only be specified if the account executing the transaction is not the Issuer of the NFToken object.
If it is present, the MintAccount field in the AccountRoot of the Issuer field must match the Account, otherwise the transaction will fail.

Declaration
public string Issuer { get; set; }
Property Value
Type Description
string
| Edit this page View Source

NFTokenTaxon

Indicates the taxon associated with this token.
The taxon is generally a value chosen by the minter of the token and a given taxon may be used for multiple tokens.
The implementation reserves taxon identifiers greater than or equal to 2147483648 (0x80000000).
If you have no use for this field, set it to 0.

Declaration
public uint NFTokenTaxon { get; set; }
Property Value
Type Description
uint
| Edit this page View Source

TransferFee

Specifies the fee charged by the issuer for secondary sales of the Token, if such sales are allowed.
Valid values for this field are between 0 and 50000 inclusive, allowing transfer rates between 0.000% and 50.000% in increments of 0.001%.
This field must NOT be present if the tfTransferable flag is not set.

Declaration
public uint? TransferFee { get; set; }
Property Value
Type Description
uint?
| Edit this page View Source

URI

URI that points to the data and/or metadata associated with the NFT.
This field need not be an HTTP or HTTPS URL; it could be an IPFS URI, a magnet link, immediate data encoded as an RFC2379 "data" URL, or even an opaque issuer-specific encoding.
The URI is NOT checked for validity, but the field is limited to a maximum length of 256 bytes.
This field must be hex-encoded.
You can use convertStringToHex to convert this field to the proper encoding.

Declaration
public string URI { get; set; }
Property Value
Type Description
string

Implements

ITransactionRequest
INFTokenMint
ITransactionCommon

Extension Methods

BatchUtils.ToBatchTx(ITransactionRequest)
Utilities.Encode(TransactionRequest)
Utilities.EncodeForMultiSigning(TransactionRequest, string)
Utilities.EncodeForSigning(TransactionRequest)
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX