Show / Hide Table of Contents

Enum NFTokenMintFlags

Transaction Flags for an NFTokenMint Transaction.

Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
[Flags]
public enum NFTokenMintFlags : uint

Fields

Name Description
tfBurnable

If set, indicates that the minted token may be burned by the issuer even if the issuer does not currently hold the token.
The current holder of the token may always burn it.

tfInnerBatchTxn

batch inner transaction

tfMutable
tfOnlyXRP

If set, indicates that the token may only be offered or sold for XRP.

tfTransferable

If set, indicates that this NFT can be transferred.
This flag has no effect if the token is being transferred from the issuer or to the issuer.

tfTrustLine

If set, indicates that the issuer wants a trustline to be automatically created.

Extension Methods

EmumExtensions.DecodeFlags<NFTokenMintFlags>(NFTokenMintFlags)
EmumExtensions.FlagsValues<NFTokenMintFlags>(NFTokenMintFlags)
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX