Show / Hide Table of Contents

Class NFTokenModify

NFTokenModify is used to change the URI field of an NFT to point to a different URI in order to update the supporting data for the NFT.
The NFT must have been minted with the tfMutable flag set.
See Dynamic Non-Fungible Tokens.

Inheritance
object
TransactionRequest
NFTokenModify
Implements
ITransactionRequest
INFTokenModify
ITransactionCommon
Inherited Members
TransactionRequest.NetworkID
TransactionRequest.Account
TransactionRequest.AccountTxnID
TransactionRequest.Fee
TransactionRequest.Flags
TransactionRequest.LastLedgerSequence
TransactionRequest.Memos
TransactionRequest.Sequence
TransactionRequest.SigningPublicKey
TransactionRequest.Signers
TransactionRequest.TransactionType
TransactionRequest.TransactionSignature
TransactionRequest.ToJson()
TransactionRequest.ToDictionary()
TransactionRequest.SourceTag
TransactionRequest.TicketSequence
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public class NFTokenModify : TransactionRequest, ITransactionRequest, INFTokenModify, ITransactionCommon

Constructors

| Edit this page View Source

NFTokenModify()

Declaration
public NFTokenModify()

Properties

| Edit this page View Source

NFTokenID

Identifies the NFTokenID of the NFToken object that the offer references.

Declaration
public string NFTokenID { get; set; }
Property Value
Type Description
string
| Edit this page View Source

Owner

Indicates the AccountID of the account that owns the corresponding NFToken. Can be omitted if the owner is the account submitting this transaction.

Declaration
public string? Owner { get; set; }
Property Value
Type Description
string
| Edit this page View Source

URI

URI that points to the data and/or metadata associated with the NFT. This must be a hex-encoded string, not an empty string. Can be null or omitted if not used.

Declaration
public string? URI { get; set; }
Property Value
Type Description
string

Implements

ITransactionRequest
INFTokenModify
ITransactionCommon

Extension Methods

BatchUtils.ToBatchTx(ITransactionRequest)
Utilities.Encode(TransactionRequest)
Utilities.EncodeForMultiSigning(TransactionRequest, string)
Utilities.EncodeForSigning(TransactionRequest)
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX