Show / Hide Table of Contents

Class NFTokenModifyResponse

NFTokenModify is used to change the URI field of an NFT to point to a different URI in order to update the supporting data for the NFT.
The NFT must have been minted with the tfMutable flag set.
See Dynamic Non-Fungible Tokens.

Inheritance
object
BaseTransactionResponse
TransactionResponse
NFTokenModifyResponse
Implements
ITransactionResponse
IBaseTransactionResponse
INFTokenModify
ITransactionCommon
Inherited Members
TransactionResponse.NetworkID
TransactionResponse.Account
TransactionResponse.AccountTxnID
TransactionResponse.Fee
TransactionResponse.Flags
TransactionResponse.LastLedgerSequence
TransactionResponse.Memos
TransactionResponse.MemoValue
TransactionResponse.Sequence
TransactionResponse.SigningPublicKey
TransactionResponse.Signers
TransactionResponse.TransactionType
TransactionResponse.TransactionSignature
TransactionResponse.Meta
TransactionResponse.ToJson()
TransactionResponse.ToDictionary()
TransactionResponse.SourceTag
TransactionResponse.TicketSequence
BaseTransactionResponse.Date
BaseTransactionResponse.Hash
BaseTransactionResponse.InLedger
BaseTransactionResponse.LedgerIndex
BaseTransactionResponse.Validated
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public class NFTokenModifyResponse : TransactionResponse, ITransactionResponse, IBaseTransactionResponse, INFTokenModify, ITransactionCommon

Properties

| Edit this page View Source

NFTokenID

Identifies the NFTokenID of the NFToken object that the offer references.

Declaration
public string NFTokenID { get; set; }
Property Value
Type Description
string
| Edit this page View Source

Owner

Indicates the AccountID of the account that owns the corresponding NFToken. Can be omitted if the owner is the account submitting this transaction.

Declaration
public string? Owner { get; set; }
Property Value
Type Description
string
| Edit this page View Source

URI

URI that points to the data and/or metadata associated with the NFT. This must be a hex-encoded string, not an empty string. Can be null or omitted if not used.

Declaration
public string? URI { get; set; }
Property Value
Type Description
string

Implements

ITransactionResponse
IBaseTransactionResponse
INFTokenModify
ITransactionCommon
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX