Show / Hide Table of Contents

Class NodeInfo

transaction object

Inheritance
object
NodeInfo
Implements
ICreatedNode
IModifiedNode
IDeletedNode
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public class NodeInfo : ICreatedNode, IModifiedNode, IDeletedNode

Properties

| Edit this page View Source

FinalFields

The content fields of the ledger object, read differently depending on the node type.

Declaration
public BaseLedgerEntry? FinalFields { get; set; }
Property Value
Type Description
BaseLedgerEntry
Remarks

DeletedNode: the fields as they were immediately before the object was deleted. Which fields are present depends on what type of ledger object it was.

ModifiedNode: the fields after applying any changes from this transaction. Which fields are present depends on the object type, and this omits PreviousTxnID and PreviousTxnLgrSeq even though most types of ledger object carry them.

| Edit this page View Source

LedgerEntryType

The type of ledger object

Declaration
[JsonConverter(typeof(LedgerEntryTypeConverter))]
public LedgerEntryType LedgerEntryType { get; set; }
Property Value
Type Description
LedgerEntryType
| Edit this page View Source

LedgerIndex

The ID of this ledger object in the ledger's state tree.
Note: This is not the same as a ledger index, even though the field name is very similar.

Declaration
public string LedgerIndex { get; set; }
Property Value
Type Description
string
| Edit this page View Source

NewFields

CreatedNode
The content fields of the newly-created ledger object.
Which fields are present depends on what type of ledger object was created.

Declaration
public BaseLedgerEntry? NewFields { get; set; }
Property Value
Type Description
BaseLedgerEntry
| Edit this page View Source

PreviousFields

JSON ModifiedNode
The previous values for all fields of the object that were changed as a result of this transaction.
If the transaction only added fields to the object, this field is an empty object.

Declaration
public BaseLedgerEntry? PreviousFields { get; set; }
Property Value
Type Description
BaseLedgerEntry
| Edit this page View Source

PreviousTxnID

ModifiedNode
(May be omitted) The identifying hash of the previous transaction to modify this ledger object.
Omitted for ledger object types that do not have a PreviousTxnID field.

Declaration
[JsonPropertyName("PreviousTxnID")]
public string PreviousTxnID { get; set; }
Property Value
Type Description
string
| Edit this page View Source

PreviousTxnLgrSeq

ModifiedNode
(May be omitted) The Ledger Index of the ledger version containing the previous transaction to modify this ledger object.
Omitted for ledger object types that do not have a PreviousTxnLgrSeq field.

Declaration
[JsonPropertyName("PreviousTxnLgrSeq")]
public uint? PreviousTxnLgrSeq { get; set; }
Property Value
Type Description
uint?

Implements

ICreatedNode
IModifiedNode
IDeletedNode
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX