Class OfferCancel
An OfferCancel transaction removes an Offer object from the XRP Ledger.
Inherited Members
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public class OfferCancel : TransactionRequest, ITransactionRequest, IOfferCancel, ITransactionCommon
Constructors
| Edit this page View SourceOfferCancel()
Declaration
public OfferCancel()
Properties
| Edit this page View SourceOfferSequence
The sequence number (or Ticket number) of a previous OfferCreate transaction.
If specified, cancel any offer object in the ledger that was created by that transaction.
It is not considered an error if the offer.
specified does not exist.
Declaration
public uint OfferSequence { get; set; }
Property Value
| Type | Description |
|---|---|
| uint |