Show / Hide Table of Contents

Class OfferCancelResponse

An OfferCancel transaction removes an Offer object from the XRP Ledger.

Inheritance
object
BaseTransactionResponse
TransactionResponse
OfferCancelResponse
Implements
ITransactionResponse
IBaseTransactionResponse
IOfferCancel
ITransactionCommon
Inherited Members
TransactionResponse.NetworkID
TransactionResponse.Account
TransactionResponse.AccountTxnID
TransactionResponse.Fee
TransactionResponse.Flags
TransactionResponse.LastLedgerSequence
TransactionResponse.Memos
TransactionResponse.MemoValue
TransactionResponse.Sequence
TransactionResponse.SigningPublicKey
TransactionResponse.Signers
TransactionResponse.TransactionType
TransactionResponse.TransactionSignature
TransactionResponse.Meta
TransactionResponse.ToJson()
TransactionResponse.ToDictionary()
TransactionResponse.SourceTag
TransactionResponse.TicketSequence
BaseTransactionResponse.Date
BaseTransactionResponse.Hash
BaseTransactionResponse.InLedger
BaseTransactionResponse.LedgerIndex
BaseTransactionResponse.Validated
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public class OfferCancelResponse : TransactionResponse, ITransactionResponse, IBaseTransactionResponse, IOfferCancel, ITransactionCommon

Properties

| Edit this page View Source

OfferSequence

The sequence number (or Ticket number) of a previous OfferCreate transaction.
If specified, cancel any offer object in the ledger that was created by that transaction.
It is not considered an error if the offer.
specified does not exist.

Declaration
public uint OfferSequence { get; set; }
Property Value
Type Description
uint

Implements

ITransactionResponse
IBaseTransactionResponse
IOfferCancel
ITransactionCommon
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX