Show / Hide Table of Contents

Class OfferCreate

An OfferCreate transaction is effectively a limit order.
It defines an intent to exchange currencies, and creates an Offer object if not completely.
Fulfilled when placed.
Offers can be partially fulfilled.

Inheritance
object
TransactionRequest
OfferCreate
Implements
ITransactionRequest
IOfferCreate
ITransactionCommon
Inherited Members
TransactionRequest.NetworkID
TransactionRequest.Account
TransactionRequest.AccountTxnID
TransactionRequest.Fee
TransactionRequest.LastLedgerSequence
TransactionRequest.Memos
TransactionRequest.Sequence
TransactionRequest.SigningPublicKey
TransactionRequest.Signers
TransactionRequest.TransactionType
TransactionRequest.TransactionSignature
TransactionRequest.ToJson()
TransactionRequest.ToDictionary()
TransactionRequest.SourceTag
TransactionRequest.TicketSequence
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public class OfferCreate : TransactionRequest, ITransactionRequest, IOfferCreate, ITransactionCommon

Constructors

| Edit this page View Source

OfferCreate()

Declaration
public OfferCreate()

Properties

| Edit this page View Source

DomainID

The domain that the offer must be a part of. Required for permissioned DEX offers.

Declaration
public string DomainID { get; set; }
Property Value
Type Description
string
| Edit this page View Source

Expiration

Time after which the offer is no longer active, in seconds since the.
Ripple Epoch.

Declaration
[JsonConverter(typeof(RippleDateTimeConverter))]
public DateTime? Expiration { get; set; }
Property Value
Type Description
Nullable
| Edit this page View Source

Flags

Transaction Flags for an OfferCreate Transaction.

Declaration
public OfferCreateFlags? Flags { get; set; }
Property Value
Type Description
OfferCreateFlags?
| Edit this page View Source

OfferSequence

An offer to delete first, specified in the same way as OfferCancel.

Declaration
public uint? OfferSequence { get; set; }
Property Value
Type Description
uint?
| Edit this page View Source

TakerGets

The amount and type of currency being provided by the offer creator.

Declaration
[JsonConverter(typeof(CurrencyConverter))]
public Currency TakerGets { get; set; }
Property Value
Type Description
Currency
| Edit this page View Source

TakerPays

The amount and type of currency being requested by the offer creator.

Declaration
[JsonConverter(typeof(CurrencyConverter))]
public Currency TakerPays { get; set; }
Property Value
Type Description
Currency

Implements

ITransactionRequest
IOfferCreate
ITransactionCommon

Extension Methods

BatchUtils.ToBatchTx(ITransactionRequest)
Utilities.Encode(TransactionRequest)
Utilities.EncodeForMultiSigning(TransactionRequest, string)
Utilities.EncodeForSigning(TransactionRequest)
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX