Enum OfferCreateFlags
Transaction Flags for an OfferCreate Transaction.
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
[Flags]
public enum OfferCreateFlags : uint
Fields
| Name | Description |
|---|---|
| tfFillOrKill | Treat the offer as a Fill or Kill order. |
| tfHybrid | Make this a hybrid offer that can use both a permissioned DEX and the open DEX. The DomainID field must be provided when using this flag. 1048576 |
| tfImmediateOrCancel | Treat the offer as an Immediate or Cancel order. |
| tfInnerBatchTxn | batch inner transaction |
| tfPassive | If enabled, the offer does not consume offers that exactly match it, and instead becomes an Offer object in the ledger. |
| tfSell | Exchange the entire TakerGets amount, even if it means obtaining more than the TakerPays amount in exchange. 524288 |