Show / Hide Table of Contents

Class OfferCreateResponse

An OfferCreate transaction is effectively a limit order.
It defines an intent to exchange currencies, and creates an Offer object if not completely.
Fulfilled when placed.
Offers can be partially fulfilled.

Inheritance
object
BaseTransactionResponse
TransactionResponse
OfferCreateResponse
Implements
ITransactionResponse
IBaseTransactionResponse
IOfferCreate
ITransactionCommon
Inherited Members
TransactionResponse.NetworkID
TransactionResponse.Account
TransactionResponse.AccountTxnID
TransactionResponse.Fee
TransactionResponse.LastLedgerSequence
TransactionResponse.Memos
TransactionResponse.MemoValue
TransactionResponse.Sequence
TransactionResponse.SigningPublicKey
TransactionResponse.Signers
TransactionResponse.TransactionType
TransactionResponse.TransactionSignature
TransactionResponse.Meta
TransactionResponse.ToJson()
TransactionResponse.ToDictionary()
TransactionResponse.SourceTag
TransactionResponse.TicketSequence
BaseTransactionResponse.Date
BaseTransactionResponse.Hash
BaseTransactionResponse.InLedger
BaseTransactionResponse.LedgerIndex
BaseTransactionResponse.Validated
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public class OfferCreateResponse : TransactionResponse, ITransactionResponse, IBaseTransactionResponse, IOfferCreate, ITransactionCommon

Properties

| Edit this page View Source

DomainID

The domain that the offer must be a part of. Required for permissioned DEX offers.

Declaration
public string DomainID { get; set; }
Property Value
Type Description
string
| Edit this page View Source

Expiration

Time after which the offer is no longer active, in seconds since the.
Ripple Epoch.

Declaration
[JsonConverter(typeof(RippleDateTimeConverter))]
public DateTime? Expiration { get; set; }
Property Value
Type Description
Nullable
| Edit this page View Source

Flags

Transaction Flags for an OfferCreate Transaction.

Declaration
public OfferCreateFlags? Flags { get; set; }
Property Value
Type Description
OfferCreateFlags?
| Edit this page View Source

OfferSequence

An offer to delete first, specified in the same way as OfferCancel.

Declaration
public uint? OfferSequence { get; set; }
Property Value
Type Description
uint?
| Edit this page View Source

TakerGets

The amount and type of currency being provided by the offer creator.

Declaration
[JsonConverter(typeof(CurrencyConverter))]
public Currency TakerGets { get; set; }
Property Value
Type Description
Currency
| Edit this page View Source

TakerPays

The amount and type of currency being requested by the offer creator.

Declaration
[JsonConverter(typeof(CurrencyConverter))]
public Currency TakerPays { get; set; }
Property Value
Type Description
Currency

Implements

ITransactionResponse
IBaseTransactionResponse
IOfferCreate
ITransactionCommon
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX