Show / Hide Table of Contents

Enum OfferFlags

There are several options which can be either enabled or disabled when an OfferCreate transaction creates an offer object.
In the ledger, flags are represented as binary values that can be combined with bitwise-or operations.
The bit values for the flags in the ledger are different than the values used to enable or disable those flags in a transaction.
Ledger flags have names that begin with lsf.

Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
[Flags]
public enum OfferFlags : uint

Fields

Name Description
lsfHybrid

The offer was placed as a hybrid

lsfPassive

The object was placed as a passive offer. This has no effect on the object in the ledger.

lsfSell

The object was placed as a sell offer.
This has no effect on the object in the ledger (because tfSell only matters if you get a better rate than you asked for, which cannot happen after the object enters the ledger).

tfInnerBatchTxn

batch inner transaction

Extension Methods

EmumExtensions.DecodeFlags<OfferFlags>(OfferFlags)
EmumExtensions.FlagsValues<OfferFlags>(OfferFlags)
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX