Show / Hide Table of Contents

Class OracleDeleteResponse

Deletes an Oracle ledger entry. Only the owner of the price oracle can send this transaction.

Inheritance
object
BaseTransactionResponse
TransactionResponse
OracleDeleteResponse
Implements
ITransactionResponse
IBaseTransactionResponse
IOracleDelete
ITransactionCommon
Inherited Members
TransactionResponse.NetworkID
TransactionResponse.Account
TransactionResponse.AccountTxnID
TransactionResponse.Fee
TransactionResponse.Flags
TransactionResponse.LastLedgerSequence
TransactionResponse.Memos
TransactionResponse.MemoValue
TransactionResponse.Sequence
TransactionResponse.SigningPublicKey
TransactionResponse.Signers
TransactionResponse.TransactionType
TransactionResponse.TransactionSignature
TransactionResponse.Meta
TransactionResponse.ToJson()
TransactionResponse.ToDictionary()
TransactionResponse.SourceTag
TransactionResponse.TicketSequence
BaseTransactionResponse.Date
BaseTransactionResponse.Hash
BaseTransactionResponse.InLedger
BaseTransactionResponse.LedgerIndex
BaseTransactionResponse.Validated
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public class OracleDeleteResponse : TransactionResponse, ITransactionResponse, IBaseTransactionResponse, IOracleDelete, ITransactionCommon

Properties

| Edit this page View Source

OracleDocumentID

A unique identifier of the price oracle for the Account.

Declaration
[JsonPropertyName("OracleDocumentID")]
public uint OracleDocumentID { get; set; }
Property Value
Type Description
uint

Implements

ITransactionResponse
IBaseTransactionResponse
IOracleDelete
ITransactionCommon
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX