Show / Hide Table of Contents

Class PaymentChannelCreate

Create a unidirectional channel and fund it with XRP.
The address sending this transaction becomes the "source address" of the payment channel.

Inheritance
object
TransactionRequest
PaymentChannelCreate
Implements
ITransactionRequest
IPaymentChannelCreate
ITransactionCommon
IDestination
Inherited Members
TransactionRequest.NetworkID
TransactionRequest.Account
TransactionRequest.AccountTxnID
TransactionRequest.Fee
TransactionRequest.Flags
TransactionRequest.LastLedgerSequence
TransactionRequest.Memos
TransactionRequest.Sequence
TransactionRequest.SigningPublicKey
TransactionRequest.Signers
TransactionRequest.TransactionType
TransactionRequest.TransactionSignature
TransactionRequest.ToJson()
TransactionRequest.ToDictionary()
TransactionRequest.TicketSequence
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public class PaymentChannelCreate : TransactionRequest, ITransactionRequest, IPaymentChannelCreate, ITransactionCommon, IDestination

Constructors

| Edit this page View Source

PaymentChannelCreate()

Declaration
public PaymentChannelCreate()

Properties

| Edit this page View Source

Amount

Amount of XRP, in drops, to deduct from the sender's balance and set aside in this channel.
While the channel is open, the XRP can only go to the Destination address.
When the channel closes, any unclaimed XRP is returned to the source address's balance.

Declaration
public string Amount { get; set; }
Property Value
Type Description
string
| Edit this page View Source

CancelAfter

The time, in seconds since the Ripple Epoch, when this channel expires.
Any transaction that would modify the channel after this time closes the channel without otherwise affecting it.
This value is immutable; the channel can be closed earlier than this time but cannot remain open after this time.

Declaration
[JsonConverter(typeof(RippleDateTimeConverter))]
public DateTime? CancelAfter { get; set; }
Property Value
Type Description
Nullable
| Edit this page View Source

Destination

Address to receive XRP claims against this channel.
This is also known as the "destination address" for the channel.

Declaration
public string Destination { get; set; }
Property Value
Type Description
string
| Edit this page View Source

DestinationTag

Arbitrary tag to further specify the destination for this payment channel, such as a hosted recipient at the destination address.

Declaration
public uint? DestinationTag { get; set; }
Property Value
Type Description
uint?
| Edit this page View Source

PublicKey

The public key of the key pair the source will use to sign claims against this channel in hexadecimal.
This can be any secp256k1 or ed25519 public key.

Declaration
public string PublicKey { get; set; }
Property Value
Type Description
string
| Edit this page View Source

SettleDelay

Amount of time the source address must wait before closing the channel if it has unclaimed XRP.

Declaration
public uint SettleDelay { get; set; }
Property Value
Type Description
uint
| Edit this page View Source

SourceTag

(Optional) Arbitrary integer used to identify the reason for this payment, or a sender on whose behalf this transaction is made.
Conventionally, a refund should specify the initial payment's SourceTag as the refund payment's DestinationTag.

Declaration
public uint? SourceTag { get; set; }
Property Value
Type Description
uint?

Implements

ITransactionRequest
IPaymentChannelCreate
ITransactionCommon
IDestination

Extension Methods

BatchUtils.ToBatchTx(ITransactionRequest)
Utilities.Encode(TransactionRequest)
Utilities.EncodeForMultiSigning(TransactionRequest, string)
Utilities.EncodeForSigning(TransactionRequest)
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX