Show / Hide Table of Contents

Class PaymentChannelFund

Add additional XRP to an open payment channel, and optionally update the expiration time of the channel.
Only the source address of the channel can use this transaction.

Inheritance
object
TransactionRequest
PaymentChannelFund
Implements
ITransactionRequest
IPaymentChannelFund
ITransactionCommon
Inherited Members
TransactionRequest.NetworkID
TransactionRequest.Account
TransactionRequest.AccountTxnID
TransactionRequest.Fee
TransactionRequest.Flags
TransactionRequest.LastLedgerSequence
TransactionRequest.Memos
TransactionRequest.Sequence
TransactionRequest.SigningPublicKey
TransactionRequest.Signers
TransactionRequest.TransactionType
TransactionRequest.TransactionSignature
TransactionRequest.ToJson()
TransactionRequest.ToDictionary()
TransactionRequest.SourceTag
TransactionRequest.TicketSequence
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public class PaymentChannelFund : TransactionRequest, ITransactionRequest, IPaymentChannelFund, ITransactionCommon

Constructors

| Edit this page View Source

PaymentChannelFund()

Declaration
public PaymentChannelFund()

Properties

| Edit this page View Source

Amount

Amount of XRP in drops to add to the channel.
Must be a positive amount of XRP.

Declaration
public string Amount { get; set; }
Property Value
Type Description
string
| Edit this page View Source

Channel

The unique ID of the channel to fund as a 64-character hexadecimal string.

Declaration
public string Channel { get; set; }
Property Value
Type Description
string
| Edit this page View Source

Expiration

New Expiration time to set for the channel in seconds since the Ripple Epoch.
This must be later than either the current time plus the SettleDelay of the channel, or the existing Expiration of the channel.
After the Expiration time, any transaction that would access the channel closes the channel without taking its normal action.
Any unspent XRP is returned to the source address when the channel closes.
(Expiration is separate from the channel's immutable CancelAfter time.)
For more information, see the PayChannel ledger object type.

Declaration
[JsonConverter(typeof(RippleDateTimeConverter))]
public DateTime? Expiration { get; set; }
Property Value
Type Description
Nullable

Implements

ITransactionRequest
IPaymentChannelFund
ITransactionCommon

Extension Methods

BatchUtils.ToBatchTx(ITransactionRequest)
Utilities.Encode(TransactionRequest)
Utilities.EncodeForMultiSigning(TransactionRequest, string)
Utilities.EncodeForSigning(TransactionRequest)
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX