Show / Hide Table of Contents

Class PaymentChannelFundResponse

Add additional XRP to an open payment channel, and optionally update the expiration time of the channel.
Only the source address of the channel can use this transaction.

Inheritance
object
BaseTransactionResponse
TransactionResponse
PaymentChannelFundResponse
Implements
ITransactionResponse
IBaseTransactionResponse
IPaymentChannelFund
ITransactionCommon
Inherited Members
TransactionResponse.NetworkID
TransactionResponse.Account
TransactionResponse.AccountTxnID
TransactionResponse.Fee
TransactionResponse.Flags
TransactionResponse.LastLedgerSequence
TransactionResponse.Memos
TransactionResponse.MemoValue
TransactionResponse.Sequence
TransactionResponse.SigningPublicKey
TransactionResponse.Signers
TransactionResponse.TransactionType
TransactionResponse.TransactionSignature
TransactionResponse.Meta
TransactionResponse.ToJson()
TransactionResponse.ToDictionary()
TransactionResponse.SourceTag
TransactionResponse.TicketSequence
BaseTransactionResponse.Date
BaseTransactionResponse.Hash
BaseTransactionResponse.InLedger
BaseTransactionResponse.LedgerIndex
BaseTransactionResponse.Validated
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public class PaymentChannelFundResponse : TransactionResponse, ITransactionResponse, IBaseTransactionResponse, IPaymentChannelFund, ITransactionCommon

Properties

| Edit this page View Source

Amount

Amount of XRP in drops to add to the channel.
Must be a positive amount of XRP.

Declaration
public string Amount { get; set; }
Property Value
Type Description
string
| Edit this page View Source

Channel

The unique ID of the channel to fund as a 64-character hexadecimal string.

Declaration
public string Channel { get; set; }
Property Value
Type Description
string
| Edit this page View Source

Expiration

New Expiration time to set for the channel in seconds since the Ripple Epoch.
This must be later than either the current time plus the SettleDelay of the channel, or the existing Expiration of the channel.
After the Expiration time, any transaction that would access the channel closes the channel without taking its normal action.
Any unspent XRP is returned to the source address when the channel closes.
(Expiration is separate from the channel's immutable CancelAfter time.)
For more information, see the PayChannel ledger object type.

Declaration
[JsonConverter(typeof(RippleDateTimeConverter))]
public DateTime? Expiration { get; set; }
Property Value
Type Description
Nullable

Implements

ITransactionResponse
IBaseTransactionResponse
IPaymentChannelFund
ITransactionCommon
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX