Enum PaymentFlags
Enum representing values for Payment Transaction Flags.
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
[Flags]
public enum PaymentFlags : uint
Fields
| Name | Description |
|---|---|
| tfInnerBatchTxn | batch inner transaction |
| tfLimitQuality | Only take paths where all the conversions have an input:output ratio that is equal or better than the ratio of Amount:SendMax. |
| tfNoDirectRipple | Do not use the default path; |
| tfPartialPayment | If the specified Amount cannot be sent without spending more than SendMax, reduce the received amount instead of failing outright. |
| tfSponsorCreatedAccount | The sponsor covers the reserve of an account this payment creates (XLS-68). |