Show / Hide Table of Contents

Class PermissionedDomainSetResponse

Response for a PermissionedDomainSet transaction.

Inheritance
object
BaseTransactionResponse
TransactionResponse
PermissionedDomainSetResponse
Implements
ITransactionResponse
IBaseTransactionResponse
IPermissionedDomainSet
ITransactionCommon
Inherited Members
TransactionResponse.NetworkID
TransactionResponse.Account
TransactionResponse.AccountTxnID
TransactionResponse.Fee
TransactionResponse.Flags
TransactionResponse.LastLedgerSequence
TransactionResponse.Memos
TransactionResponse.MemoValue
TransactionResponse.Sequence
TransactionResponse.SigningPublicKey
TransactionResponse.Signers
TransactionResponse.TransactionType
TransactionResponse.TransactionSignature
TransactionResponse.Meta
TransactionResponse.ToJson()
TransactionResponse.ToDictionary()
TransactionResponse.SourceTag
TransactionResponse.TicketSequence
BaseTransactionResponse.Date
BaseTransactionResponse.Hash
BaseTransactionResponse.InLedger
BaseTransactionResponse.LedgerIndex
BaseTransactionResponse.Validated
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public class PermissionedDomainSetResponse : TransactionResponse, ITransactionResponse, IBaseTransactionResponse, IPermissionedDomainSet, ITransactionCommon

Properties

| Edit this page View Source

AcceptedCredentials

A list of 1 to 10 AcceptedCredential objects that grant access to this domain. The list does not need to be sorted, but it cannot contain duplicates. When modifying an existing domain, this list replaces the existing list.

Declaration
[JsonPropertyName("AcceptedCredentials")]
public List<AcceptedCredentialWrapper> AcceptedCredentials { get; set; }
Property Value
Type Description
List<AcceptedCredentialWrapper>
| Edit this page View Source

DomainID

The ledger entry ID of an existing permissioned domain to modify. If omitted, creates a new permissioned domain.

Declaration
[JsonPropertyName("DomainID")]
public string DomainID { get; set; }
Property Value
Type Description
string

Implements

ITransactionResponse
IBaseTransactionResponse
IPermissionedDomainSet
ITransactionCommon
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX