Show / Hide Table of Contents

Class SetFeeResponse

Inheritance
object
BaseTransactionResponse
TransactionResponse
SetFeeResponse
Implements
ITransactionResponse
IBaseTransactionResponse
ISetFee
ITransactionCommon
Inherited Members
TransactionResponse.NetworkID
TransactionResponse.Account
TransactionResponse.AccountTxnID
TransactionResponse.Fee
TransactionResponse.Flags
TransactionResponse.LastLedgerSequence
TransactionResponse.Memos
TransactionResponse.MemoValue
TransactionResponse.Sequence
TransactionResponse.SigningPublicKey
TransactionResponse.Signers
TransactionResponse.TransactionType
TransactionResponse.TransactionSignature
TransactionResponse.Meta
TransactionResponse.Sponsor
TransactionResponse.SponsorFlags
TransactionResponse.Delegate
TransactionResponse.OperationLimit
TransactionResponse.ToJson()
TransactionResponse.ToDictionary()
TransactionResponse.SourceTag
TransactionResponse.TicketSequence
BaseTransactionResponse.CloseTimeIso
BaseTransactionResponse.Ctid
BaseTransactionResponse.Date
BaseTransactionResponse.Hash
BaseTransactionResponse.InLedger
BaseTransactionResponse.LedgerIndex
BaseTransactionResponse.Validated
BaseTransactionResponse.UnknownFields
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public class SetFeeResponse : TransactionResponse, ITransactionResponse, IBaseTransactionResponse, ISetFee, ITransactionCommon

Properties

| Edit this page View Source

BaseFee

The charge, in drops of XRP, for the reference transaction, as hex.
(This is the transaction cost before scaling for load.)

Declaration
public string BaseFee { get; set; }
Property Value
Type Description
string
| Edit this page View Source

BaseFeeDrops

XRPFees: base fee in drops.

Declaration
[JsonConverter(typeof(CurrencyConverter))]
public Currency BaseFeeDrops { get; set; }
Property Value
Type Description
Currency
| Edit this page View Source

LedgerSequence

(Omitted for some historical SetFee pseudo-transactions)
The index of the ledger version where this pseudo-transaction appears.
This distinguishes the pseudo-transaction from other occurrences of the same change.

Declaration
public uint? LedgerSequence { get; set; }
Property Value
Type Description
uint?
| Edit this page View Source

ReferenceFeeUnits

The cost, in fee units, of the reference transaction

Declaration
public uint? ReferenceFeeUnits { get; set; }
Property Value
Type Description
uint?
| Edit this page View Source

ReserveBase

The base reserve, in drops

Declaration
public uint? ReserveBase { get; set; }
Property Value
Type Description
uint?
| Edit this page View Source

ReserveBaseDrops

XRPFees: account reserve in drops.

Declaration
[JsonConverter(typeof(CurrencyConverter))]
public Currency ReserveBaseDrops { get; set; }
Property Value
Type Description
Currency
| Edit this page View Source

ReserveIncrement

The incremental reserve, in drops

Declaration
public uint? ReserveIncrement { get; set; }
Property Value
Type Description
uint?
| Edit this page View Source

ReserveIncrementDrops

XRPFees: owner reserve increment in drops.

Declaration
[JsonConverter(typeof(CurrencyConverter))]
public Currency ReserveIncrementDrops { get; set; }
Property Value
Type Description
Currency

Implements

ITransactionResponse
IBaseTransactionResponse
ISetFee
ITransactionCommon
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX