Show / Hide Table of Contents

Class SetRegularKeyResponse

A SetRegularKey transaction assigns, changes, or removes the regular key pair associated with an account.

Inheritance
object
BaseTransactionResponse
TransactionResponse
SetRegularKeyResponse
Implements
ITransactionResponse
IBaseTransactionResponse
ISetRegularKey
ITransactionCommon
Inherited Members
TransactionResponse.NetworkID
TransactionResponse.Account
TransactionResponse.AccountTxnID
TransactionResponse.Fee
TransactionResponse.Flags
TransactionResponse.LastLedgerSequence
TransactionResponse.Memos
TransactionResponse.MemoValue
TransactionResponse.Sequence
TransactionResponse.SigningPublicKey
TransactionResponse.Signers
TransactionResponse.TransactionType
TransactionResponse.TransactionSignature
TransactionResponse.Meta
TransactionResponse.ToJson()
TransactionResponse.ToDictionary()
TransactionResponse.SourceTag
TransactionResponse.TicketSequence
BaseTransactionResponse.Date
BaseTransactionResponse.Hash
BaseTransactionResponse.InLedger
BaseTransactionResponse.LedgerIndex
BaseTransactionResponse.Validated
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public class SetRegularKeyResponse : TransactionResponse, ITransactionResponse, IBaseTransactionResponse, ISetRegularKey, ITransactionCommon

Properties

| Edit this page View Source

RegularKey

A base-58-encoded Address that indicates the regular key pair to be assigned to the account.
If omitted, removes any existing regular key pair from the account.
Must not match the master key pair for the address.

Declaration
public string RegularKey { get; set; }
Property Value
Type Description
string

Implements

ITransactionResponse
IBaseTransactionResponse
ISetRegularKey
ITransactionCommon
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX