Show / Hide Table of Contents

Class SignerListSet

The SignerListSet transaction creates, replaces, or removes a list of signers that can be used to multi-sign a transaction.

Inheritance
object
TransactionRequest
SignerListSet
Implements
ITransactionRequest
ISignerListSet
ITransactionCommon
Inherited Members
TransactionRequest.NetworkID
TransactionRequest.Account
TransactionRequest.AccountTxnID
TransactionRequest.Fee
TransactionRequest.Flags
TransactionRequest.LastLedgerSequence
TransactionRequest.Memos
TransactionRequest.Sequence
TransactionRequest.SigningPublicKey
TransactionRequest.Signers
TransactionRequest.TransactionType
TransactionRequest.TransactionSignature
TransactionRequest.ToJson()
TransactionRequest.ToDictionary()
TransactionRequest.SourceTag
TransactionRequest.TicketSequence
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public class SignerListSet : TransactionRequest, ITransactionRequest, ISignerListSet, ITransactionCommon

Constructors

| Edit this page View Source

SignerListSet()

Declaration
public SignerListSet()

Properties

| Edit this page View Source

SignerEntries

Array of SignerEntry objects, indicating the addresses and weights of signers in this list.
This signer list must have at least 1 member and no more than 32 members.
No address may appear more than once in the list, nor may the Account submitting the transaction appear in the list.

Declaration
public List<SignerEntryWrapper> SignerEntries { get; set; }
Property Value
Type Description
List<SignerEntryWrapper>
| Edit this page View Source

SignerQuorum

A target number for the signer weights.
A multi-signature from this list is valid only if the sum weights of the signatures provided is greater than or equal to this value.
To delete a signer list, use the value 0.

Declaration
public uint SignerQuorum { get; set; }
Property Value
Type Description
uint

Implements

ITransactionRequest
ISignerListSet
ITransactionCommon

Extension Methods

BatchUtils.ToBatchTx(ITransactionRequest)
Utilities.Encode(TransactionRequest)
Utilities.EncodeForMultiSigning(TransactionRequest, string)
Utilities.EncodeForSigning(TransactionRequest)
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX