Show / Hide Table of Contents

Class SignerListSetResponse

The SignerListSet transaction creates, replaces, or removes a list of signers that can be used to multi-sign a transaction.

Inheritance
object
BaseTransactionResponse
TransactionResponse
SignerListSetResponse
Implements
ITransactionResponse
IBaseTransactionResponse
ISignerListSet
ITransactionCommon
Inherited Members
TransactionResponse.NetworkID
TransactionResponse.Account
TransactionResponse.AccountTxnID
TransactionResponse.Fee
TransactionResponse.Flags
TransactionResponse.LastLedgerSequence
TransactionResponse.Memos
TransactionResponse.MemoValue
TransactionResponse.Sequence
TransactionResponse.SigningPublicKey
TransactionResponse.Signers
TransactionResponse.TransactionType
TransactionResponse.TransactionSignature
TransactionResponse.Meta
TransactionResponse.ToJson()
TransactionResponse.ToDictionary()
TransactionResponse.SourceTag
TransactionResponse.TicketSequence
BaseTransactionResponse.Date
BaseTransactionResponse.Hash
BaseTransactionResponse.InLedger
BaseTransactionResponse.LedgerIndex
BaseTransactionResponse.Validated
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public class SignerListSetResponse : TransactionResponse, ITransactionResponse, IBaseTransactionResponse, ISignerListSet, ITransactionCommon

Properties

| Edit this page View Source

SignerEntries

Array of SignerEntry objects, indicating the addresses and weights of signers in this list.
This signer list must have at least 1 member and no more than 32 members.
No address may appear more than once in the list, nor may the Account submitting the transaction appear in the list.

Declaration
public List<SignerEntryWrapper> SignerEntries { get; set; }
Property Value
Type Description
List<SignerEntryWrapper>
| Edit this page View Source

SignerQuorum

A target number for the signer weights.
A multi-signature from this list is valid only if the sum weights of the signatures provided is greater than or equal to this value.
To delete a signer list, use the value 0.

Declaration
public uint SignerQuorum { get; set; }
Property Value
Type Description
uint

Implements

ITransactionResponse
IBaseTransactionResponse
ISignerListSet
ITransactionCommon
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX