Show / Hide Table of Contents

Class TicketCreateResponse

A TicketCreate transaction sets aside one or more sequence numbers as Tickets.

Inheritance
object
BaseTransactionResponse
TransactionResponse
TicketCreateResponse
Implements
ITransactionResponse
IBaseTransactionResponse
ITicketCreate
ITransactionCommon
Inherited Members
TransactionResponse.NetworkID
TransactionResponse.Account
TransactionResponse.AccountTxnID
TransactionResponse.Fee
TransactionResponse.Flags
TransactionResponse.LastLedgerSequence
TransactionResponse.Memos
TransactionResponse.MemoValue
TransactionResponse.Sequence
TransactionResponse.SigningPublicKey
TransactionResponse.Signers
TransactionResponse.TransactionType
TransactionResponse.TransactionSignature
TransactionResponse.Meta
TransactionResponse.ToJson()
TransactionResponse.ToDictionary()
TransactionResponse.SourceTag
TransactionResponse.TicketSequence
BaseTransactionResponse.Date
BaseTransactionResponse.Hash
BaseTransactionResponse.InLedger
BaseTransactionResponse.LedgerIndex
BaseTransactionResponse.Validated
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public class TicketCreateResponse : TransactionResponse, ITransactionResponse, IBaseTransactionResponse, ITicketCreate, ITransactionCommon

Properties

| Edit this page View Source

TicketCount

How many Tickets to create.
This must be a positive number and cannot cause the account to own more than 250 Tickets after executing this transaction.

Declaration
public uint TicketCount { get; set; }
Property Value
Type Description
uint

Implements

ITransactionResponse
IBaseTransactionResponse
ITicketCreate
ITransactionCommon
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX