Show / Hide Table of Contents

Class TransactionRequest

Supports all classes in the .NET class hierarchy and provides low-level services to derived classes. This is the ultimate base class of all .NET classes; it is the root of the type hierarchy.

Inheritance
object
TransactionRequest
AMMBid
AMMClawBack
AMMCreate
AMMDelete
AMMDeposit
AMMVote
AMMWithdraw
AccountDelete
AccountSet
Batch
CheckCancel
CheckCash
CheckCreate
ClawBack
CredentialAccept
CredentialCreate
CredentialDelete
DIDDelete
DIDSet
DepositPreauth
EnableAmendment
EscrowCancel
EscrowCreate
EscrowFinish
MPTokenAuthorize
MPTokenIssuanceCreate
MPTokenIssuanceDestroy
MPTokenIssuanceSet
NFTokenAcceptOffer
NFTokenBurn
NFTokenCancelOffer
NFTokenCreateOffer
NFTokenMint
NFTokenModify
OfferCancel
OfferCreate
OracleDelete
OracleSet
Payment
PaymentChannelClaim
PaymentChannelCreate
PaymentChannelFund
PermissionedDomainDelete
PermissionedDomainSet
SetFee
SetRegularKey
SignerListSet
TicketCreate
TrustSet
UNLModify
Implements
ITransactionRequest
ITransactionCommon
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
[JsonConverter(typeof(TransactionRequestConverter))]
public abstract class TransactionRequest : ITransactionRequest, ITransactionCommon

Properties

| Edit this page View Source

Account

This is a required field The unique address of the account that initiated the transaction.

Declaration
public string Account { get; set; }
Property Value
Type Description
string
| Edit this page View Source

AccountTxnID

Hash value identifying another transaction.
If provided, this transaction is only valid if the sending account's previously-sent transaction matches the provided hash.

Declaration
public string AccountTxnID { get; set; }
Property Value
Type Description
string
| Edit this page View Source

Fee

Integer amount of XRP, in drops, to be destroyed as a cost for distributing this transaction to the network.
Some transaction types have different minimum requirements.

Declaration
[JsonConverter(typeof(CurrencyConverter))]
public Currency Fee { get; set; }
Property Value
Type Description
Currency
| Edit this page View Source

Flags

Set of bit-flags for this transaction.
number | GlobalFlags

Declaration
public uint? Flags { get; set; }
Property Value
Type Description
uint?
| Edit this page View Source

LastLedgerSequence

Although optional, the LastLedgerSequence is strongly recommended on every transaction to ensure it's validated or rejected promptly.
Highest ledger index this transaction can appear in.
Specifying this field places a strict upper limit on how long the transaction can wait to be validated or rejected.

Declaration
public uint? LastLedgerSequence { get; set; }
Property Value
Type Description
uint?
| Edit this page View Source

Memos

Additional arbitrary information used to identify this transaction.

Declaration
public List<MemoWrapper> Memos { get; set; }
Property Value
Type Description
List<MemoWrapper>
| Edit this page View Source

NetworkID

Declaration
public uint? NetworkID { get; set; }
Property Value
Type Description
uint?
| Edit this page View Source

Sequence

The sequence number of the account sending the transaction.
A transaction is only valid if the Sequence number is exactly 1 greater than the previous transaction from the same account.
The special case 0 means the transaction is using a Ticket instead.

Declaration
public uint? Sequence { get; set; }
Property Value
Type Description
uint?
| Edit this page View Source

Signers

Array of objects that represent a multi-signature which authorizes this transaction.

Declaration
public List<SignerWrapper> Signers { get; set; }
Property Value
Type Description
List<SignerWrapper>
| Edit this page View Source

SigningPublicKey

Hex representation of the public key that corresponds to the private key used to sign this transaction.
If an empty string, indicates a multi-signature is present in the Signers field instead.

Declaration
[JsonPropertyName("SigningPubKey")]
public string SigningPublicKey { get; set; }
Property Value
Type Description
string
| Edit this page View Source

SourceTag

(Optional) Arbitrary integer used to identify the reason for this payment, or a sender on whose behalf this transaction is made.
Conventionally, a refund should specify the initial payment's SourceTag as the refund payment's DestinationTag.

Declaration
public uint? SourceTag { get; set; }
Property Value
Type Description
uint?
| Edit this page View Source

TicketSequence

(Optional) The sequence number of the ticket to use in place of a Sequence number.
If this is provided, Sequence must be 0. Cannot be used with AccountTxnID.

Declaration
public uint? TicketSequence { get; set; }
Property Value
Type Description
uint?
| Edit this page View Source

TransactionSignature

The signature that verifies this transaction as originating from the account it says it is from.

Declaration
[JsonPropertyName("TxnSignature")]
public string TransactionSignature { get; set; }
Property Value
Type Description
string
| Edit this page View Source

TransactionType

The type of transaction.
Valid types include: Payment, OfferCreate, SignerListSet, EscrowCreate, EscrowFinish, EscrowCancel, PaymentChannelCreate, PaymentChannelFund, PaymentChannelClaim, and DepositPreauth.

Declaration
[JsonConverter(typeof(TransactionTypeConverter))]
public TransactionType TransactionType { get; set; }
Property Value
Type Description
TransactionType

Methods

| Edit this page View Source

ToDictionary()

Declaration
public Dictionary<string, object> ToDictionary()
Returns
Type Description
Dictionary<string, object>
| Edit this page View Source

ToJson()

convert transaction to string json value

Declaration
public string ToJson()
Returns
Type Description
string

Implements

ITransactionRequest
ITransactionCommon

Extension Methods

BatchUtils.ToBatchTx(ITransactionRequest)
Utilities.Encode(TransactionRequest)
Utilities.EncodeForMultiSigning(TransactionRequest, string)
Utilities.EncodeForSigning(TransactionRequest)
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX