Class TrustSet
Create or modify a trust line linking two accounts.
Inherited Members
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public class TrustSet : TransactionRequest, ITransactionRequest, ITrustSet, ITransactionCommon
Constructors
| Edit this page View SourceTrustSet()
Declaration
public TrustSet()
Properties
| Edit this page View SourceFlags
ITrustSet transaction flags
Declaration
public TrustSetFlags? Flags { get; set; }
Property Value
| Type | Description |
|---|---|
| TrustSetFlags? |
LimitAmount
Object defining the trust line to create or modify, in the format of a Currency Amount.
Declaration
[JsonConverter(typeof(CurrencyConverter))]
public Currency LimitAmount { get; set; }
Property Value
| Type | Description |
|---|---|
| Currency |
QualityIn
Value incoming balances on this trust line at the ratio of this number per 1,000,000,000 units.
A value of 0 is shorthand for treating balances at face value.
Declaration
public uint? QualityIn { get; set; }
Property Value
| Type | Description |
|---|---|
| uint? |
QualityOut
Value outgoing balances on this trust line at the ratio of this number per 1,000,000,000 units.
A value of 0 is shorthand for treating balances at face value.
Declaration
public uint? QualityOut { get; set; }
Property Value
| Type | Description |
|---|---|
| uint? |