Show / Hide Table of Contents

Class TrustSetResponse

Create or modify a trust line linking two accounts.

Inheritance
object
BaseTransactionResponse
TransactionResponse
TrustSetResponse
Implements
ITransactionResponse
IBaseTransactionResponse
ITrustSet
ITransactionCommon
Inherited Members
TransactionResponse.NetworkID
TransactionResponse.Account
TransactionResponse.AccountTxnID
TransactionResponse.Fee
TransactionResponse.LastLedgerSequence
TransactionResponse.Memos
TransactionResponse.MemoValue
TransactionResponse.Sequence
TransactionResponse.SigningPublicKey
TransactionResponse.Signers
TransactionResponse.TransactionType
TransactionResponse.TransactionSignature
TransactionResponse.Meta
TransactionResponse.ToJson()
TransactionResponse.ToDictionary()
TransactionResponse.SourceTag
TransactionResponse.TicketSequence
BaseTransactionResponse.Date
BaseTransactionResponse.Hash
BaseTransactionResponse.InLedger
BaseTransactionResponse.LedgerIndex
BaseTransactionResponse.Validated
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public class TrustSetResponse : TransactionResponse, ITransactionResponse, IBaseTransactionResponse, ITrustSet, ITransactionCommon

Properties

| Edit this page View Source

Flags

ITrustSet transaction flags

Declaration
public TrustSetFlags? Flags { get; set; }
Property Value
Type Description
TrustSetFlags?
| Edit this page View Source

LimitAmount

Object defining the trust line to create or modify, in the format of a Currency Amount.

Declaration
[JsonConverter(typeof(CurrencyConverter))]
public Currency LimitAmount { get; set; }
Property Value
Type Description
Currency
| Edit this page View Source

QualityIn

Value incoming balances on this trust line at the ratio of this number per 1,000,000,000 units.
A value of 0 is shorthand for treating balances at face value.

Declaration
public uint? QualityIn { get; set; }
Property Value
Type Description
uint?
| Edit this page View Source

QualityOut

Value outgoing balances on this trust line at the ratio of this number per 1,000,000,000 units.
A value of 0 is shorthand for treating balances at face value.

Declaration
public uint? QualityOut { get; set; }
Property Value
Type Description
uint?

Implements

ITransactionResponse
IBaseTransactionResponse
ITrustSet
ITransactionCommon
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX