Show / Hide Table of Contents

Class UNLModify

Inheritance
object
TransactionRequest
UNLModify
Implements
ITransactionRequest
IUNLModify
ITransactionCommon
Inherited Members
TransactionRequest.NetworkID
TransactionRequest.Account
TransactionRequest.AccountTxnID
TransactionRequest.Fee
TransactionRequest.Flags
TransactionRequest.LastLedgerSequence
TransactionRequest.Memos
TransactionRequest.Sequence
TransactionRequest.SigningPublicKey
TransactionRequest.Signers
TransactionRequest.TransactionType
TransactionRequest.TransactionSignature
TransactionRequest.ToJson()
TransactionRequest.ToDictionary()
TransactionRequest.SourceTag
TransactionRequest.TicketSequence
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public class UNLModify : TransactionRequest, ITransactionRequest, IUNLModify, ITransactionCommon

Constructors

| Edit this page View Source

UNLModify()

Declaration
public UNLModify()

Properties

| Edit this page View Source

LedgerSequence

The ledger index where this pseudo-transaction appears.
This distinguishes the pseudo-transaction from other occurrences of the same change.

Declaration
public uint LedgerSequence { get; set; }
Property Value
Type Description
uint
| Edit this page View Source

UNLModifyDisabling

If 1, this change represents adding a validator to the Negative UNL.
If 0, this change represents removing a validator from the Negative UNL.
(No other values are allowed.)

Declaration
public uint UNLModifyDisabling { get; set; }
Property Value
Type Description
uint
| Edit this page View Source

UNLModifyValidator

The validator to add or remove, as identified by its master public key.

Declaration
public string UNLModifyValidator { get; set; }
Property Value
Type Description
string

Implements

ITransactionRequest
IUNLModify
ITransactionCommon

Extension Methods

BatchUtils.ToBatchTx(ITransactionRequest)
Utilities.Encode(TransactionRequest)
Utilities.EncodeForMultiSigning(TransactionRequest, string)
Utilities.EncodeForSigning(TransactionRequest)
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX