Show / Hide Table of Contents

Class UNLModifyResponse

Inheritance
object
BaseTransactionResponse
TransactionResponse
UNLModifyResponse
Implements
ITransactionResponse
IBaseTransactionResponse
IUNLModify
ITransactionCommon
Inherited Members
TransactionResponse.NetworkID
TransactionResponse.Account
TransactionResponse.AccountTxnID
TransactionResponse.Fee
TransactionResponse.Flags
TransactionResponse.LastLedgerSequence
TransactionResponse.Memos
TransactionResponse.MemoValue
TransactionResponse.Sequence
TransactionResponse.SigningPublicKey
TransactionResponse.Signers
TransactionResponse.TransactionType
TransactionResponse.TransactionSignature
TransactionResponse.Meta
TransactionResponse.ToJson()
TransactionResponse.ToDictionary()
TransactionResponse.SourceTag
TransactionResponse.TicketSequence
BaseTransactionResponse.Date
BaseTransactionResponse.Hash
BaseTransactionResponse.InLedger
BaseTransactionResponse.LedgerIndex
BaseTransactionResponse.Validated
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public class UNLModifyResponse : TransactionResponse, ITransactionResponse, IBaseTransactionResponse, IUNLModify, ITransactionCommon

Properties

| Edit this page View Source

LedgerSequence

The ledger index where this pseudo-transaction appears.
This distinguishes the pseudo-transaction from other occurrences of the same change.

Declaration
public uint LedgerSequence { get; set; }
Property Value
Type Description
uint
| Edit this page View Source

UNLModifyDisabling

If 1, this change represents adding a validator to the Negative UNL.
If 0, this change represents removing a validator from the Negative UNL.
(No other values are allowed.)

Declaration
public uint UNLModifyDisabling { get; set; }
Property Value
Type Description
uint
| Edit this page View Source

UNLModifyValidator

The validator to add or remove, as identified by its master public key.

Declaration
public string UNLModifyValidator { get; set; }
Property Value
Type Description
string

Implements

ITransactionResponse
IBaseTransactionResponse
IUNLModify
ITransactionCommon
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX