Show / Hide Table of Contents

Class VaultClawbackResponse

The VaultClawback transaction allows an issuer to claw back assets from a vault.

Inheritance
object
BaseTransactionResponse
TransactionResponse
VaultClawbackResponse
Implements
ITransactionResponse
IBaseTransactionResponse
IVaultClawback
ITransactionCommon
Inherited Members
TransactionResponse.NetworkID
TransactionResponse.Account
TransactionResponse.AccountTxnID
TransactionResponse.Fee
TransactionResponse.Flags
TransactionResponse.LastLedgerSequence
TransactionResponse.Memos
TransactionResponse.MemoValue
TransactionResponse.Sequence
TransactionResponse.SigningPublicKey
TransactionResponse.Signers
TransactionResponse.TransactionType
TransactionResponse.TransactionSignature
TransactionResponse.Meta
TransactionResponse.ToJson()
TransactionResponse.ToDictionary()
TransactionResponse.SourceTag
TransactionResponse.TicketSequence
BaseTransactionResponse.Date
BaseTransactionResponse.Hash
BaseTransactionResponse.InLedger
BaseTransactionResponse.LedgerIndex
BaseTransactionResponse.Validated
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public class VaultClawbackResponse : TransactionResponse, ITransactionResponse, IBaseTransactionResponse, IVaultClawback, ITransactionCommon
Remarks

Requires the Vault amendment (XLS-65d). This feature is in draft and subject to change.

Properties

| Edit this page View Source

Amount

The amount to claw back. If omitted, claws back all available assets.

Declaration
[JsonPropertyName("Amount")]
[JsonConverter(typeof(CurrencyConverter))]
public Currency Amount { get; set; }
Property Value
Type Description
Currency
| Edit this page View Source

Holder

The holder account to claw back from.

Declaration
[JsonPropertyName("Holder")]
public string Holder { get; set; }
Property Value
Type Description
string
| Edit this page View Source

VaultID

The ID of the vault to claw back from.

Declaration
[JsonPropertyName("VaultID")]
public string VaultID { get; set; }
Property Value
Type Description
string

Implements

ITransactionResponse
IBaseTransactionResponse
IVaultClawback
ITransactionCommon
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX