Show / Hide Table of Contents

Class VaultCreate

The VaultCreate transaction creates a new Vault ledger object for holding pooled assets.

Inheritance
object
TransactionRequest
VaultCreate
Implements
ITransactionRequest
IVaultCreate
ITransactionCommon
Inherited Members
TransactionRequest.NetworkID
TransactionRequest.Account
TransactionRequest.AccountTxnID
TransactionRequest.Fee
TransactionRequest.Flags
TransactionRequest.LastLedgerSequence
TransactionRequest.Memos
TransactionRequest.Sequence
TransactionRequest.SigningPublicKey
TransactionRequest.Signers
TransactionRequest.TransactionType
TransactionRequest.TransactionSignature
TransactionRequest.ToJson()
TransactionRequest.ToDictionary()
TransactionRequest.SourceTag
TransactionRequest.TicketSequence
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public class VaultCreate : TransactionRequest, ITransactionRequest, IVaultCreate, ITransactionCommon
Remarks

Requires the Vault amendment (XLS-65d). This feature is in draft and subject to change.

Constructors

| Edit this page View Source

VaultCreate()

Declaration
public VaultCreate()

Properties

| Edit this page View Source

Amount

The initial deposit amount.

Declaration
[JsonPropertyName("Amount")]
public Currency Amount { get; set; }
Property Value
Type Description
Currency
| Edit this page View Source

Asset

The asset held by the vault.

Declaration
[JsonPropertyName("Asset")]
[JsonConverter(typeof(IssuedCurrencyConverter))]
public Common.IssuedCurrency Asset { get; set; }
Property Value
Type Description
Common.IssuedCurrency
| Edit this page View Source

AssetsMaximum

The maximum asset amount that can be held in the vault. STNumber type (12 bytes: int64 mantissa + int32 exponent), serialized as string in JSON.

Declaration
[JsonPropertyName("AssetsMaximum")]
public string AssetsMaximum { get; set; }
Property Value
Type Description
string
| Edit this page View Source

Data

Arbitrary hex-encoded data associated with the vault, limited to 256 bytes.

Declaration
[JsonPropertyName("Data")]
public string Data { get; set; }
Property Value
Type Description
string
| Edit this page View Source

DomainID

The ID of a permissioned domain to associate with the vault.

Declaration
[JsonPropertyName("DomainID")]
public string DomainID { get; set; }
Property Value
Type Description
string
| Edit this page View Source

MPTokenMetadata

Arbitrary metadata for the vault shares (MPToken), limited in size. Hex-encoded string.

Declaration
[JsonPropertyName("MPTokenMetadata")]
public string MPTokenMetadata { get; set; }
Property Value
Type Description
string
| Edit this page View Source

Scale

The scale (decimal precision) for the vault shares.

Declaration
[JsonPropertyName("Scale")]
public uint? Scale { get; set; }
Property Value
Type Description
uint?
| Edit this page View Source

WithdrawalPolicy

The withdrawal policy for the vault. Defines how withdrawals are handled.

Declaration
[JsonPropertyName("WithdrawalPolicy")]
public uint? WithdrawalPolicy { get; set; }
Property Value
Type Description
uint?

Implements

ITransactionRequest
IVaultCreate
ITransactionCommon

Extension Methods

BatchUtils.ToBatchTx(ITransactionRequest)
Utilities.Encode(TransactionRequest)
Utilities.EncodeForMultiSigning(TransactionRequest, string)
Utilities.EncodeForSigning(TransactionRequest)
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX