Show / Hide Table of Contents

Class VaultSetResponse

The VaultSet transaction modifies the settings of an existing vault.

Inheritance
object
BaseTransactionResponse
TransactionResponse
VaultSetResponse
Implements
ITransactionResponse
IBaseTransactionResponse
IVaultSet
ITransactionCommon
Inherited Members
TransactionResponse.NetworkID
TransactionResponse.Account
TransactionResponse.AccountTxnID
TransactionResponse.Fee
TransactionResponse.Flags
TransactionResponse.LastLedgerSequence
TransactionResponse.Memos
TransactionResponse.MemoValue
TransactionResponse.Sequence
TransactionResponse.SigningPublicKey
TransactionResponse.Signers
TransactionResponse.TransactionType
TransactionResponse.TransactionSignature
TransactionResponse.Meta
TransactionResponse.ToJson()
TransactionResponse.ToDictionary()
TransactionResponse.SourceTag
TransactionResponse.TicketSequence
BaseTransactionResponse.Date
BaseTransactionResponse.Hash
BaseTransactionResponse.InLedger
BaseTransactionResponse.LedgerIndex
BaseTransactionResponse.Validated
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public class VaultSetResponse : TransactionResponse, ITransactionResponse, IBaseTransactionResponse, IVaultSet, ITransactionCommon
Remarks

Requires the Vault amendment (XLS-65d). This feature is in draft and subject to change.

Properties

| Edit this page View Source

AssetsMaximum

The maximum asset amount that can be held in the vault. STNumber type (12 bytes: int64 mantissa + int32 exponent), serialized as string in JSON.

Declaration
[JsonPropertyName("AssetsMaximum")]
public string AssetsMaximum { get; set; }
Property Value
Type Description
string
| Edit this page View Source

Data

Arbitrary hex-encoded data associated with the vault, limited to 256 bytes.

Declaration
[JsonPropertyName("Data")]
public string Data { get; set; }
Property Value
Type Description
string
| Edit this page View Source

DomainID

The ID of a permissioned domain to associate with the vault.

Declaration
[JsonPropertyName("DomainID")]
public string DomainID { get; set; }
Property Value
Type Description
string
| Edit this page View Source

VaultID

The ID of the vault to modify.

Declaration
[JsonPropertyName("VaultID")]
public string VaultID { get; set; }
Property Value
Type Description
string

Implements

ITransactionResponse
IBaseTransactionResponse
IVaultSet
ITransactionCommon
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX