Show / Hide Table of Contents

Class VaultWithdraw

The VaultWithdraw transaction withdraws assets from a vault.

Inheritance
object
TransactionRequest
VaultWithdraw
Implements
ITransactionRequest
IVaultWithdraw
ITransactionCommon
Inherited Members
TransactionRequest.NetworkID
TransactionRequest.Account
TransactionRequest.AccountTxnID
TransactionRequest.Fee
TransactionRequest.Flags
TransactionRequest.LastLedgerSequence
TransactionRequest.Memos
TransactionRequest.Sequence
TransactionRequest.SigningPublicKey
TransactionRequest.Signers
TransactionRequest.TransactionType
TransactionRequest.TransactionSignature
TransactionRequest.ToJson()
TransactionRequest.ToDictionary()
TransactionRequest.SourceTag
TransactionRequest.TicketSequence
TransactionRequest.Sponsor
TransactionRequest.SponsorFlags
TransactionRequest.Delegate
TransactionRequest.OperationLimit
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public class VaultWithdraw : TransactionRequest, ITransactionRequest, IVaultWithdraw, ITransactionCommon
Remarks

Requires the Vault amendment (XLS-65d). This feature is in draft and subject to change.

Constructors

| Edit this page View Source

VaultWithdraw()

Declaration
public VaultWithdraw()

Properties

| Edit this page View Source

Amount

The exact amount of vault asset to withdraw or vault share to redeem.

Declaration
[JsonPropertyName("Amount")]
[JsonConverter(typeof(CurrencyConverter))]
public Currency Amount { get; set; }
Property Value
Type Description
Currency
| Edit this page View Source

CredentialIDs

Credentials (object IDs, 64 hex characters each) authorizing the withdrawal when the Destination requires deposit authorization with credential-based preauth (XLS-70). Maximum 8 entries.

Declaration
[JsonPropertyName("CredentialIDs")]
[JsonIgnore(Condition = JsonIgnoreCondition.WhenWritingNull)]
public List<string> CredentialIDs { get; set; }
Property Value
Type Description
List<string>
| Edit this page View Source

Destination

An account to receive the assets. This account must be able to receive the vault asset or the transaction fails.

Declaration
[JsonPropertyName("Destination")]
public string Destination { get; set; }
Property Value
Type Description
string
| Edit this page View Source

DestinationTag

Arbitrary tag identifying the reason for the withdrawal to the destination.

Declaration
[JsonPropertyName("DestinationTag")]
public uint? DestinationTag { get; set; }
Property Value
Type Description
uint?
| Edit this page View Source

VaultID

The ID of the vault to withdraw from.

Declaration
[JsonPropertyName("VaultID")]
public string VaultID { get; set; }
Property Value
Type Description
string

Implements

ITransactionRequest
IVaultWithdraw
ITransactionCommon

Extension Methods

BatchUtils.ToBatchTx(ITransactionRequest)
Utilities.Encode(TransactionRequest)
Utilities.EncodeForMultiSigning(TransactionRequest, string)
Utilities.EncodeForSigning(TransactionRequest)
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX