Show / Hide Table of Contents

Class VaultWithdrawResponse

The VaultWithdraw transaction withdraws assets from a vault.

Inheritance
object
BaseTransactionResponse
TransactionResponse
VaultWithdrawResponse
Implements
ITransactionResponse
IBaseTransactionResponse
IVaultWithdraw
ITransactionCommon
Inherited Members
TransactionResponse.NetworkID
TransactionResponse.Account
TransactionResponse.AccountTxnID
TransactionResponse.Fee
TransactionResponse.Flags
TransactionResponse.LastLedgerSequence
TransactionResponse.Memos
TransactionResponse.MemoValue
TransactionResponse.Sequence
TransactionResponse.SigningPublicKey
TransactionResponse.Signers
TransactionResponse.TransactionType
TransactionResponse.TransactionSignature
TransactionResponse.Meta
TransactionResponse.ToJson()
TransactionResponse.ToDictionary()
TransactionResponse.SourceTag
TransactionResponse.TicketSequence
BaseTransactionResponse.Date
BaseTransactionResponse.Hash
BaseTransactionResponse.InLedger
BaseTransactionResponse.LedgerIndex
BaseTransactionResponse.Validated
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public class VaultWithdrawResponse : TransactionResponse, ITransactionResponse, IBaseTransactionResponse, IVaultWithdraw, ITransactionCommon
Remarks

Requires the Vault amendment (XLS-65d). This feature is in draft and subject to change.

Properties

| Edit this page View Source

Amount

The exact amount of vault asset to withdraw or vault share to redeem.

Declaration
[JsonPropertyName("Amount")]
[JsonConverter(typeof(CurrencyConverter))]
public Currency Amount { get; set; }
Property Value
Type Description
Currency
| Edit this page View Source

Destination

An account to receive the assets. This account must be able to receive the vault asset or the transaction fails.

Declaration
[JsonPropertyName("Destination")]
public string Destination { get; set; }
Property Value
Type Description
string
| Edit this page View Source

DestinationTag

Arbitrary tag identifying the reason for the withdrawal to the destination.

Declaration
[JsonPropertyName("DestinationTag")]
public uint? DestinationTag { get; set; }
Property Value
Type Description
uint?
| Edit this page View Source

VaultID

The ID of the vault to withdraw from.

Declaration
[JsonPropertyName("VaultID")]
public string VaultID { get; set; }
Property Value
Type Description
string

Implements

ITransactionResponse
IBaseTransactionResponse
IVaultWithdraw
ITransactionCommon
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX