Show / Hide Table of Contents

Class XChainAccountCreateCommit

The XChainAccountCreateCommit transaction creates a new account for a witness's account on one of the chains a bridge connects. This transaction can only be used for XRP-XRP bridges.

Inheritance
object
TransactionRequest
XChainAccountCreateCommit
Implements
ITransactionRequest
IXChainAccountCreateCommit
ITransactionCommon
Inherited Members
TransactionRequest.NetworkID
TransactionRequest.Account
TransactionRequest.AccountTxnID
TransactionRequest.Fee
TransactionRequest.Flags
TransactionRequest.LastLedgerSequence
TransactionRequest.Memos
TransactionRequest.Sequence
TransactionRequest.SigningPublicKey
TransactionRequest.Signers
TransactionRequest.TransactionType
TransactionRequest.TransactionSignature
TransactionRequest.ToJson()
TransactionRequest.ToDictionary()
TransactionRequest.SourceTag
TransactionRequest.TicketSequence
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public class XChainAccountCreateCommit : TransactionRequest, ITransactionRequest, IXChainAccountCreateCommit, ITransactionCommon

Constructors

| Edit this page View Source

XChainAccountCreateCommit()

Declaration
public XChainAccountCreateCommit()

Properties

| Edit this page View Source

Amount

The amount, in XRP, to use for account creation. This must be greater than or equal to the MinAccountCreateAmount specified in the Bridge ledger object.

Declaration
[JsonPropertyName("Amount")]
[JsonConverter(typeof(CurrencyConverter))]
public Currency Amount { get; set; }
Property Value
Type Description
Currency
| Edit this page View Source

Destination

The destination account on the destination chain.

Declaration
[JsonPropertyName("Destination")]
public string Destination { get; set; }
Property Value
Type Description
string
| Edit this page View Source

SignatureReward

The amount, in XRP, to be used to reward the witness servers for providing signatures. This must match the amount on the Bridge ledger object.

Declaration
[JsonPropertyName("SignatureReward")]
[JsonConverter(typeof(CurrencyConverter))]
public Currency SignatureReward { get; set; }
Property Value
Type Description
Currency
| Edit this page View Source

XChainBridge

The bridge to create accounts for.

Declaration
[JsonPropertyName("XChainBridge")]
public XChainBridgeModel XChainBridge { get; set; }
Property Value
Type Description
XChainBridgeModel

Implements

ITransactionRequest
IXChainAccountCreateCommit
ITransactionCommon

Extension Methods

BatchUtils.ToBatchTx(ITransactionRequest)
Utilities.Encode(TransactionRequest)
Utilities.EncodeForMultiSigning(TransactionRequest, string)
Utilities.EncodeForSigning(TransactionRequest)
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX