Show / Hide Table of Contents

Class XChainAddAccountCreateAttestation

The XChainAddAccountCreateAttestation transaction provides an attestation from a witness server that an XChainAccountCreateCommit transaction occurred on the other chain.

Inheritance
object
TransactionRequest
XChainAddAccountCreateAttestation
Implements
ITransactionRequest
IXChainAddAccountCreateAttestation
ITransactionCommon
Inherited Members
TransactionRequest.NetworkID
TransactionRequest.Account
TransactionRequest.AccountTxnID
TransactionRequest.Fee
TransactionRequest.Flags
TransactionRequest.LastLedgerSequence
TransactionRequest.Memos
TransactionRequest.Sequence
TransactionRequest.SigningPublicKey
TransactionRequest.Signers
TransactionRequest.TransactionType
TransactionRequest.TransactionSignature
TransactionRequest.ToJson()
TransactionRequest.ToDictionary()
TransactionRequest.SourceTag
TransactionRequest.TicketSequence
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public class XChainAddAccountCreateAttestation : TransactionRequest, ITransactionRequest, IXChainAddAccountCreateAttestation, ITransactionCommon

Constructors

| Edit this page View Source

XChainAddAccountCreateAttestation()

Declaration
public XChainAddAccountCreateAttestation()

Properties

| Edit this page View Source

Amount

The amount committed by the XChainAccountCreateCommit transaction on the source chain.

Declaration
[JsonPropertyName("Amount")]
[JsonConverter(typeof(CurrencyConverter))]
public Currency Amount { get; set; }
Property Value
Type Description
Currency
| Edit this page View Source

AttestationRewardAccount

The account that should receive this signer's share of the SignatureReward.

Declaration
[JsonPropertyName("AttestationRewardAccount")]
public string AttestationRewardAccount { get; set; }
Property Value
Type Description
string
| Edit this page View Source

AttestationSignerAccount

The account on the door account's signer list that is signing the transaction.

Declaration
[JsonPropertyName("AttestationSignerAccount")]
public string AttestationSignerAccount { get; set; }
Property Value
Type Description
string
| Edit this page View Source

Destination

The destination account for the funds on the destination chain.

Declaration
[JsonPropertyName("Destination")]
public string Destination { get; set; }
Property Value
Type Description
string
| Edit this page View Source

OtherChainSource

The account on the source chain that submitted the XChainAccountCreateCommit transaction that triggered the event associated with the attestation.

Declaration
[JsonPropertyName("OtherChainSource")]
public string OtherChainSource { get; set; }
Property Value
Type Description
string
| Edit this page View Source

PublicKey

The public key used to verify the signature.

Declaration
[JsonPropertyName("PublicKey")]
public string PublicKey { get; set; }
Property Value
Type Description
string
| Edit this page View Source

Signature

The signature attesting to the event on the other chain.

Declaration
[JsonPropertyName("Signature")]
public string Signature { get; set; }
Property Value
Type Description
string
| Edit this page View Source

SignatureReward

The amount, in XRP, to be used to reward the witness servers for providing signatures.

Declaration
[JsonPropertyName("SignatureReward")]
[JsonConverter(typeof(CurrencyConverter))]
public Currency SignatureReward { get; set; }
Property Value
Type Description
Currency
| Edit this page View Source

WasLockingChainSend

A boolean representing the chain where the event occurred. 0 represents the issuing chain, 1 represents the locking chain.

Declaration
[JsonPropertyName("WasLockingChainSend")]
public byte WasLockingChainSend { get; set; }
Property Value
Type Description
byte
| Edit this page View Source

XChainAccountCreateCount

An integer that represents the order that the claim must be processed in.

Declaration
[JsonPropertyName("XChainAccountCreateCount")]
public string XChainAccountCreateCount { get; set; }
Property Value
Type Description
string
| Edit this page View Source

XChainBridge

The bridge associated with the attestation.

Declaration
[JsonPropertyName("XChainBridge")]
public XChainBridgeModel XChainBridge { get; set; }
Property Value
Type Description
XChainBridgeModel

Implements

ITransactionRequest
IXChainAddAccountCreateAttestation
ITransactionCommon

Extension Methods

BatchUtils.ToBatchTx(ITransactionRequest)
Utilities.Encode(TransactionRequest)
Utilities.EncodeForMultiSigning(TransactionRequest, string)
Utilities.EncodeForSigning(TransactionRequest)
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX