Show / Hide Table of Contents

Class XChainAddClaimAttestation

The XChainAddClaimAttestation transaction provides proof from a witness server, attesting to an XChainCommit transaction.

Inheritance
object
TransactionRequest
XChainAddClaimAttestation
Implements
ITransactionRequest
IXChainAddClaimAttestation
ITransactionCommon
Inherited Members
TransactionRequest.NetworkID
TransactionRequest.Account
TransactionRequest.AccountTxnID
TransactionRequest.Fee
TransactionRequest.Flags
TransactionRequest.LastLedgerSequence
TransactionRequest.Memos
TransactionRequest.Sequence
TransactionRequest.SigningPublicKey
TransactionRequest.Signers
TransactionRequest.TransactionType
TransactionRequest.TransactionSignature
TransactionRequest.ToJson()
TransactionRequest.ToDictionary()
TransactionRequest.SourceTag
TransactionRequest.TicketSequence
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public class XChainAddClaimAttestation : TransactionRequest, ITransactionRequest, IXChainAddClaimAttestation, ITransactionCommon

Constructors

| Edit this page View Source

XChainAddClaimAttestation()

Declaration
public XChainAddClaimAttestation()

Properties

| Edit this page View Source

Amount

The amount committed by the XChainCommit transaction on the source chain.

Declaration
[JsonPropertyName("Amount")]
[JsonConverter(typeof(CurrencyConverter))]
public Currency Amount { get; set; }
Property Value
Type Description
Currency
| Edit this page View Source

AttestationRewardAccount

The account that should receive this signer's share of the SignatureReward.

Declaration
[JsonPropertyName("AttestationRewardAccount")]
public string AttestationRewardAccount { get; set; }
Property Value
Type Description
string
| Edit this page View Source

AttestationSignerAccount

The account on the door account's signer list that is signing the transaction.

Declaration
[JsonPropertyName("AttestationSignerAccount")]
public string AttestationSignerAccount { get; set; }
Property Value
Type Description
string
| Edit this page View Source

Destination

The destination account for the funds on the destination chain.

Declaration
[JsonPropertyName("Destination")]
public string Destination { get; set; }
Property Value
Type Description
string
| Edit this page View Source

OtherChainSource

The account on the source chain that submitted the XChainCommit transaction that triggered the event associated with the attestation.

Declaration
[JsonPropertyName("OtherChainSource")]
public string OtherChainSource { get; set; }
Property Value
Type Description
string
| Edit this page View Source

PublicKey

The public key used to verify the signature.

Declaration
[JsonPropertyName("PublicKey")]
public string PublicKey { get; set; }
Property Value
Type Description
string
| Edit this page View Source

Signature

The signature attesting to the event on the other chain.

Declaration
[JsonPropertyName("Signature")]
public string Signature { get; set; }
Property Value
Type Description
string
| Edit this page View Source

WasLockingChainSend

A boolean representing the chain where the event occurred. 0 represents the issuing chain, 1 represents the locking chain.

Declaration
[JsonPropertyName("WasLockingChainSend")]
public byte WasLockingChainSend { get; set; }
Property Value
Type Description
byte
| Edit this page View Source

XChainBridge

The bridge to attest to.

Declaration
[JsonPropertyName("XChainBridge")]
public XChainBridgeModel XChainBridge { get; set; }
Property Value
Type Description
XChainBridgeModel
| Edit this page View Source

XChainClaimID

The XChainClaimID associated with the transfer, which was included in the XChainCommit transaction.

Declaration
[JsonPropertyName("XChainClaimID")]
public string XChainClaimID { get; set; }
Property Value
Type Description
string

Implements

ITransactionRequest
IXChainAddClaimAttestation
ITransactionCommon

Extension Methods

BatchUtils.ToBatchTx(ITransactionRequest)
Utilities.Encode(TransactionRequest)
Utilities.EncodeForMultiSigning(TransactionRequest, string)
Utilities.EncodeForSigning(TransactionRequest)
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX