Show / Hide Table of Contents

Class XChainClaim

The XChainClaim transaction completes a cross-chain transfer of value. It allows a user to claim the value on the destination chain — the equivalent of the value locked on the source chain.

Inheritance
object
TransactionRequest
XChainClaim
Implements
ITransactionRequest
IXChainClaim
ITransactionCommon
Inherited Members
TransactionRequest.NetworkID
TransactionRequest.Account
TransactionRequest.AccountTxnID
TransactionRequest.Fee
TransactionRequest.Flags
TransactionRequest.LastLedgerSequence
TransactionRequest.Memos
TransactionRequest.Sequence
TransactionRequest.SigningPublicKey
TransactionRequest.Signers
TransactionRequest.TransactionType
TransactionRequest.TransactionSignature
TransactionRequest.ToJson()
TransactionRequest.ToDictionary()
TransactionRequest.SourceTag
TransactionRequest.TicketSequence
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public class XChainClaim : TransactionRequest, ITransactionRequest, IXChainClaim, ITransactionCommon

Constructors

| Edit this page View Source

XChainClaim()

Declaration
public XChainClaim()

Properties

| Edit this page View Source

Amount

The amount to claim on the destination chain. This must match the amount attested to on the attestations associated with this claim ID.

Declaration
[JsonPropertyName("Amount")]
[JsonConverter(typeof(CurrencyConverter))]
public Currency Amount { get; set; }
Property Value
Type Description
Currency
| Edit this page View Source

Destination

The destination account on the destination chain. It must exist or the transaction will fail.

Declaration
[JsonPropertyName("Destination")]
public string Destination { get; set; }
Property Value
Type Description
string
| Edit this page View Source

DestinationTag

An integer destination tag.

Declaration
[JsonPropertyName("DestinationTag")]
public uint? DestinationTag { get; set; }
Property Value
Type Description
uint?
| Edit this page View Source

XChainBridge

The bridge to use for the claim.

Declaration
[JsonPropertyName("XChainBridge")]
public XChainBridgeModel XChainBridge { get; set; }
Property Value
Type Description
XChainBridgeModel
| Edit this page View Source

XChainClaimID

The unique integer ID for the cross-chain claim.

Declaration
[JsonPropertyName("XChainClaimID")]
public string XChainClaimID { get; set; }
Property Value
Type Description
string

Implements

ITransactionRequest
IXChainClaim
ITransactionCommon

Extension Methods

BatchUtils.ToBatchTx(ITransactionRequest)
Utilities.Encode(TransactionRequest)
Utilities.EncodeForMultiSigning(TransactionRequest, string)
Utilities.EncodeForSigning(TransactionRequest)
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX