Show / Hide Table of Contents

Class XChainClaimResponse

The XChainClaim transaction completes a cross-chain transfer of value. It allows a user to claim the value on the destination chain — the equivalent of the value locked on the source chain.

Inheritance
object
BaseTransactionResponse
TransactionResponse
XChainClaimResponse
Implements
ITransactionResponse
IBaseTransactionResponse
IXChainClaim
ITransactionCommon
Inherited Members
TransactionResponse.NetworkID
TransactionResponse.Account
TransactionResponse.AccountTxnID
TransactionResponse.Fee
TransactionResponse.Flags
TransactionResponse.LastLedgerSequence
TransactionResponse.Memos
TransactionResponse.MemoValue
TransactionResponse.Sequence
TransactionResponse.SigningPublicKey
TransactionResponse.Signers
TransactionResponse.TransactionType
TransactionResponse.TransactionSignature
TransactionResponse.Meta
TransactionResponse.ToJson()
TransactionResponse.ToDictionary()
TransactionResponse.SourceTag
TransactionResponse.TicketSequence
BaseTransactionResponse.Date
BaseTransactionResponse.Hash
BaseTransactionResponse.InLedger
BaseTransactionResponse.LedgerIndex
BaseTransactionResponse.Validated
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public class XChainClaimResponse : TransactionResponse, ITransactionResponse, IBaseTransactionResponse, IXChainClaim, ITransactionCommon

Properties

| Edit this page View Source

Amount

The amount to claim on the destination chain. This must match the amount attested to on the attestations associated with this claim ID.

Declaration
[JsonPropertyName("Amount")]
[JsonConverter(typeof(CurrencyConverter))]
public Currency Amount { get; set; }
Property Value
Type Description
Currency
| Edit this page View Source

Destination

The destination account on the destination chain. It must exist or the transaction will fail.

Declaration
[JsonPropertyName("Destination")]
public string Destination { get; set; }
Property Value
Type Description
string
| Edit this page View Source

DestinationTag

An integer destination tag.

Declaration
[JsonPropertyName("DestinationTag")]
public uint? DestinationTag { get; set; }
Property Value
Type Description
uint?
| Edit this page View Source

XChainBridge

The bridge to use for the claim.

Declaration
[JsonPropertyName("XChainBridge")]
public XChainBridgeModel XChainBridge { get; set; }
Property Value
Type Description
XChainBridgeModel
| Edit this page View Source

XChainClaimID

The unique integer ID for the cross-chain claim.

Declaration
[JsonPropertyName("XChainClaimID")]
public string XChainClaimID { get; set; }
Property Value
Type Description
string

Implements

ITransactionResponse
IBaseTransactionResponse
IXChainClaim
ITransactionCommon
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX