Show / Hide Table of Contents

Class XChainCommitResponse

The XChainCommit transaction is the second step in a cross-chain transfer. It puts assets into trust on the locking chain so that they can be wrapped on the issuing chain, or burns wrapped assets on the issuing chain so that they can be returned on the locking chain.

Inheritance
object
BaseTransactionResponse
TransactionResponse
XChainCommitResponse
Implements
ITransactionResponse
IBaseTransactionResponse
IXChainCommit
ITransactionCommon
Inherited Members
TransactionResponse.NetworkID
TransactionResponse.Account
TransactionResponse.AccountTxnID
TransactionResponse.Fee
TransactionResponse.Flags
TransactionResponse.LastLedgerSequence
TransactionResponse.Memos
TransactionResponse.MemoValue
TransactionResponse.Sequence
TransactionResponse.SigningPublicKey
TransactionResponse.Signers
TransactionResponse.TransactionType
TransactionResponse.TransactionSignature
TransactionResponse.Meta
TransactionResponse.ToJson()
TransactionResponse.ToDictionary()
TransactionResponse.SourceTag
TransactionResponse.TicketSequence
BaseTransactionResponse.Date
BaseTransactionResponse.Hash
BaseTransactionResponse.InLedger
BaseTransactionResponse.LedgerIndex
BaseTransactionResponse.Validated
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public class XChainCommitResponse : TransactionResponse, ITransactionResponse, IBaseTransactionResponse, IXChainCommit, ITransactionCommon

Properties

| Edit this page View Source

Amount

The amount to transfer.

Declaration
[JsonPropertyName("Amount")]
[JsonConverter(typeof(CurrencyConverter))]
public Currency Amount { get; set; }
Property Value
Type Description
Currency
| Edit this page View Source

OtherChainDestination

The destination account on the destination chain. If this is not specified, the account that submitted the XChainCreateClaimID transaction on the destination chain will need to submit an XChainClaim transaction.

Declaration
[JsonPropertyName("OtherChainDestination")]
public string OtherChainDestination { get; set; }
Property Value
Type Description
string
| Edit this page View Source

XChainBridge

The bridge to use for the transfer.

Declaration
[JsonPropertyName("XChainBridge")]
public XChainBridgeModel XChainBridge { get; set; }
Property Value
Type Description
XChainBridgeModel
| Edit this page View Source

XChainClaimID

The unique integer ID for the cross-chain claim.

Declaration
[JsonPropertyName("XChainClaimID")]
public string XChainClaimID { get; set; }
Property Value
Type Description
string

Implements

ITransactionResponse
IBaseTransactionResponse
IXChainCommit
ITransactionCommon
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX