Show / Hide Table of Contents

Class XChainCreateBridgeResponse

The XChainCreateBridge transaction creates a new Bridge ledger object and defines a cross-chain bridge between a locking chain and an issuing chain.

Inheritance
object
BaseTransactionResponse
TransactionResponse
XChainCreateBridgeResponse
Implements
ITransactionResponse
IBaseTransactionResponse
IXChainCreateBridge
ITransactionCommon
Inherited Members
TransactionResponse.NetworkID
TransactionResponse.Account
TransactionResponse.AccountTxnID
TransactionResponse.Fee
TransactionResponse.Flags
TransactionResponse.LastLedgerSequence
TransactionResponse.Memos
TransactionResponse.MemoValue
TransactionResponse.Sequence
TransactionResponse.SigningPublicKey
TransactionResponse.Signers
TransactionResponse.TransactionType
TransactionResponse.TransactionSignature
TransactionResponse.Meta
TransactionResponse.ToJson()
TransactionResponse.ToDictionary()
TransactionResponse.SourceTag
TransactionResponse.TicketSequence
BaseTransactionResponse.Date
BaseTransactionResponse.Hash
BaseTransactionResponse.InLedger
BaseTransactionResponse.LedgerIndex
BaseTransactionResponse.Validated
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public class XChainCreateBridgeResponse : TransactionResponse, ITransactionResponse, IBaseTransactionResponse, IXChainCreateBridge, ITransactionCommon

Properties

| Edit this page View Source

MinAccountCreateAmount

The minimum amount, in XRP, required for an XChainAccountCreateCommit transaction. If this is not present, the XChainAccountCreateCommit transaction will fail.

Declaration
[JsonPropertyName("MinAccountCreateAmount")]
[JsonConverter(typeof(CurrencyConverter))]
public Currency MinAccountCreateAmount { get; set; }
Property Value
Type Description
Currency
| Edit this page View Source

SignatureReward

The signature reward split between the witnesses for submitting attestations.

Declaration
[JsonPropertyName("SignatureReward")]
[JsonConverter(typeof(CurrencyConverter))]
public Currency SignatureReward { get; set; }
Property Value
Type Description
Currency
| Edit this page View Source

XChainBridge

The bridge (door accounts and brided assets) to create.

Declaration
[JsonPropertyName("XChainBridge")]
public XChainBridgeModel XChainBridge { get; set; }
Property Value
Type Description
XChainBridgeModel

Implements

ITransactionResponse
IBaseTransactionResponse
IXChainCreateBridge
ITransactionCommon
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX