Show / Hide Table of Contents

Class XChainCreateClaimIDResponse

The XChainCreateClaimID transaction creates a new cross-chain claim ID that is used for a cross-chain transfer. A cross-chain claim ID represents one cross-chain transfer of value.

Inheritance
object
BaseTransactionResponse
TransactionResponse
XChainCreateClaimIDResponse
Implements
ITransactionResponse
IBaseTransactionResponse
IXChainCreateClaimID
ITransactionCommon
Inherited Members
TransactionResponse.NetworkID
TransactionResponse.Account
TransactionResponse.AccountTxnID
TransactionResponse.Fee
TransactionResponse.Flags
TransactionResponse.LastLedgerSequence
TransactionResponse.Memos
TransactionResponse.MemoValue
TransactionResponse.Sequence
TransactionResponse.SigningPublicKey
TransactionResponse.Signers
TransactionResponse.TransactionType
TransactionResponse.TransactionSignature
TransactionResponse.Meta
TransactionResponse.ToJson()
TransactionResponse.ToDictionary()
TransactionResponse.SourceTag
TransactionResponse.TicketSequence
BaseTransactionResponse.Date
BaseTransactionResponse.Hash
BaseTransactionResponse.InLedger
BaseTransactionResponse.LedgerIndex
BaseTransactionResponse.Validated
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public class XChainCreateClaimIDResponse : TransactionResponse, ITransactionResponse, IBaseTransactionResponse, IXChainCreateClaimID, ITransactionCommon

Properties

| Edit this page View Source

OtherChainSource

The account that must send the corresponding XChainCommit on the source chain.

Declaration
[JsonPropertyName("OtherChainSource")]
public string OtherChainSource { get; set; }
Property Value
Type Description
string
| Edit this page View Source

SignatureReward

The amount, in XRP, to reward the witness servers for providing signatures. This must match the amount on the Bridge ledger object.

Declaration
[JsonPropertyName("SignatureReward")]
[JsonConverter(typeof(CurrencyConverter))]
public Currency SignatureReward { get; set; }
Property Value
Type Description
Currency
| Edit this page View Source

XChainBridge

The bridge to create the claim ID for.

Declaration
[JsonPropertyName("XChainBridge")]
public XChainBridgeModel XChainBridge { get; set; }
Property Value
Type Description
XChainBridgeModel

Implements

ITransactionResponse
IBaseTransactionResponse
IXChainCreateClaimID
ITransactionCommon
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX