Show / Hide Table of Contents

Class BatchSignStatusExtensions

Inheritance
object
BatchSignStatusExtensions
Namespace: Xrpl.Models.Utils
Assembly: Xrpl.dll
Syntax
public static class BatchSignStatusExtensions

Methods

| Edit this page View Source

GetBatchSignStatus(Dictionary<string, object>)

Builds the signing status of a batch transaction from a tx dictionary.

Declaration
public static BatchSignStatus GetBatchSignStatus(this Dictionary<string, object> tx)
Parameters
Type Name Description
Dictionary<string, object> tx
Returns
Type Description
BatchSignStatus
| Edit this page View Source

GetBatchSignStatus(string)

Convenience helper for the status of a hex blob (tx_blob).

Declaration
public static BatchSignStatus GetBatchSignStatus(this string txBlob)
Parameters
Type Name Description
string txBlob
Returns
Type Description
BatchSignStatus
| Edit this page View Source

GetBatchSignStatus(SignatureResult)

Convenience helper for the status of a SignatureResult.

Declaration
public static BatchSignStatus GetBatchSignStatus(this SignatureResult signed)
Parameters
Type Name Description
SignatureResult signed
Returns
Type Description
BatchSignStatus
| Edit this page View Source

IsFullySignedBatch(Dictionary<string, object>, bool)

Quickly check whether a batch is fully signed, over the inner accounts and optionally the root.

Declaration
public static bool IsFullySignedBatch(this Dictionary<string, object> tx, bool requireRoot = false)
Parameters
Type Name Description
Dictionary<string, object> tx
bool requireRoot
Returns
Type Description
bool
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX