Show / Hide Table of Contents

Class Index

Inheritance
object
Index
Namespace: Xrpl.Models.Utils
Assembly: Xrpl.dll
Syntax
public static class Index

Methods

| Edit this page View Source

IsFlagEnabled(uint, uint)

Declaration
public static bool IsFlagEnabled(this uint Flags, uint checkFlag)
Parameters
Type Name Description
uint Flags
uint checkFlag
Returns
Type Description
bool
| Edit this page View Source

IsHex(string)

Check if string is in hex format.

Declaration
public static bool IsHex(this string str)
Parameters
Type Name Description
string str

The string to check if it's in hex format.

Returns
Type Description
bool

True if string is in hex format

| Edit this page View Source

OnlyHasFields(Dictionary<string, object>, string[])

Verify that all fields of an object are in fields.

Declaration
public static bool OnlyHasFields(this Dictionary<string, object> obj, string[] fields)
Parameters
Type Name Description
Dictionary<string, object> obj

Object to verify fields.

string[] fields

Fields to verify

Returns
Type Description
bool

True if keys in object are all in fields.

  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX