Show / Hide Table of Contents

Class AutofillSugar

Inheritance
object
AutofillSugar
Namespace: Xrpl.Sugar
Assembly: Xrpl.dll
Syntax
public static class AutofillSugar

Methods

| Edit this page View Source

Autofill(IXrplClient, Dictionary<string, object>, int?, CancellationToken)

Autofills fields in a transaction. This will set Sequence, Fee, lastLedgerSequence according to the current state of the server this Client is connected to. It also converts all X-Addresses to classic addresses and flags interfaces into numbers.

Declaration
public static Task<Dictionary<string, object>> Autofill(this IXrplClient client, Dictionary<string, object> transaction, int? signersCount, CancellationToken cancellationToken = default)
Parameters
Type Name Description
IXrplClient client

A client.

Dictionary<string, object> transaction

A {@link Transaction} in JSON format

int? signersCount

The expected number of signers for this transaction. Only used for multisigned transactions.

CancellationToken cancellationToken
Returns
Type Description
Task<Dictionary<string, object>>

The autofilled transaction.

| Edit this page View Source

CalculateFeePerTransactionType(IXrplClient, Dictionary<string, object>, int, CancellationToken)

Declaration
public static Task CalculateFeePerTransactionType(this IXrplClient client, Dictionary<string, object> tx, int signersCount = 0, CancellationToken cancellationToken = default)
Parameters
Type Name Description
IXrplClient client
Dictionary<string, object> tx
int signersCount
CancellationToken cancellationToken
Returns
Type Description
Task
| Edit this page View Source

CheckAccountDeleteBlockers(IXrplClient, Dictionary<string, object>, CancellationToken)

Declaration
public static Task CheckAccountDeleteBlockers(this IXrplClient client, Dictionary<string, object> tx, CancellationToken cancellationToken = default)
Parameters
Type Name Description
IXrplClient client
Dictionary<string, object> tx
CancellationToken cancellationToken
Returns
Type Description
Task
| Edit this page View Source

ConvertToClassicAddress(Dictionary<string, object>, string)

Declaration
public static void ConvertToClassicAddress(this Dictionary<string, object> tx, string fieldName)
Parameters
Type Name Description
Dictionary<string, object> tx
string fieldName
| Edit this page View Source

FetchReserveFee(IXrplClient, CancellationToken)

Declaration
public static Task<BigInteger> FetchReserveFee(this IXrplClient client, CancellationToken cancellationToken = default)
Parameters
Type Name Description
IXrplClient client
CancellationToken cancellationToken
Returns
Type Description
Task<BigInteger>
| Edit this page View Source

GetClassicAccountAndTag(string, uint?)

Declaration
public static AddressNTag GetClassicAccountAndTag(this string account, uint? expectedTag)
Parameters
Type Name Description
string account
uint? expectedTag
Returns
Type Description
AddressNTag
| Edit this page View Source

ScaleValueDecimal(string, decimal)

Declaration
public static decimal ScaleValueDecimal(string value, decimal multiplier)
Parameters
Type Name Description
string value
decimal multiplier
Returns
Type Description
decimal
| Edit this page View Source

SetLatestValidatedLedgerSequence(IXrplClient, Dictionary<string, object>, CancellationToken)

Declaration
public static Task SetLatestValidatedLedgerSequence(this IXrplClient client, Dictionary<string, object> tx, CancellationToken cancellationToken = default)
Parameters
Type Name Description
IXrplClient client
Dictionary<string, object> tx
CancellationToken cancellationToken
Returns
Type Description
Task
| Edit this page View Source

SetNextValidSequenceNumber(IXrplClient, Dictionary<string, object>, CancellationToken)

Declaration
public static Task<uint> SetNextValidSequenceNumber(this IXrplClient client, Dictionary<string, object> tx, CancellationToken cancellationToken = default)
Parameters
Type Name Description
IXrplClient client
Dictionary<string, object> tx
CancellationToken cancellationToken
Returns
Type Description
Task<uint>
| Edit this page View Source

SetValidAddresses(Dictionary<string, object>)

Declaration
public static void SetValidAddresses(this Dictionary<string, object> tx)
Parameters
Type Name Description
Dictionary<string, object> tx
| Edit this page View Source

ValidateAccountAddress(Dictionary<string, object>, string, string)

Declaration
public static void ValidateAccountAddress(this Dictionary<string, object> tx, string accountField, string tagField)
Parameters
Type Name Description
Dictionary<string, object> tx
string accountField
string tagField
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX