Show / Hide Table of Contents

Class DomainCredentialStatus

Status of a single credential held by the account that matches one of the domain's accepted (issuer, credential_type) pairs but is not currently valid.

Inheritance
object
DomainCredentialStatus
Namespace: Xrpl.Sugar
Assembly: Xrpl.dll
Syntax
public class DomainCredentialStatus

Properties

| Edit this page View Source

Accepted

True if the subject account has accepted the credential.

Declaration
public bool Accepted { get; set; }
Property Value
Type Description
bool
| Edit this page View Source

CredentialType

The credential type, as hexadecimal.

Declaration
public string CredentialType { get; set; }
Property Value
Type Description
string
| Edit this page View Source

Expired

True if the credential is past its Expiration at the checked ledger's close time.

Declaration
public bool Expired { get; set; }
Property Value
Type Description
bool
| Edit this page View Source

Issuer

The account that issued the credential.

Declaration
public string Issuer { get; set; }
Property Value
Type Description
string
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX