Show / Hide Table of Contents

Class Derive

Inheritance
object
Derive
Namespace: Xrpl.Utils
Assembly: Xrpl.dll
Syntax
public static class Derive

Methods

| Edit this page View Source

DeriveXAddress(string, uint?, bool)

Derive an X-Address from a public key and a destination tag.
Options - Public key and destination tag to encode as an X-Address.

Declaration
public static string DeriveXAddress(string publicKey, uint? tag, bool test)
Parameters
Type Name Description
string publicKey

The public key corresponding to an address.

uint? tag

A destination tag to encode into an X-address. False indicates no destination tag.

bool test

Whether this address is for use in Testnet.

Returns
Type Description
string

X-Address.

  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX