Show / Hide Table of Contents

Namespace Xrpl.Utils.Hashes

Classes

HashLedger

Hashes

Sha512HalfUtil

Interfaces

HashLedgerHeaderOptions

Enums

HashPrefix

Prefix for hashing functions.
These prefixes are inserted before the source material used to generate various hashes.This is done to put each hash in its own "space."
This way, two different types of objects with the same binary data will produce different hashes.
Each prefix is a 4-byte value with the last byte set to zero and the first three bytes formed from the ASCII equivalent of some arbitrary string.
For example "TXN".

LedgerSpace

XRP Ledger namespace prefixes. The XRP Ledger is a key-value store.In order to avoid name collisions, names are partitioned into namespaces. Each namespace is just a single character prefix. SeeLedgerNameSpace enum.

In this article
Back to top Generated by DocFX