Show / Hide Table of Contents

Enum HashPrefix

Prefix for hashing functions.
These prefixes are inserted before the source material used to generate various hashes.This is done to put each hash in its own "space."
This way, two different types of objects with the same binary data will produce different hashes.
Each prefix is a 4-byte value with the last byte set to zero and the first three bytes formed from the ASCII equivalent of some arbitrary string.
For example "TXN".

Namespace: Xrpl.Utils.Hashes
Assembly: Xrpl.dll
Syntax
public enum HashPrefix

Fields

Name Description
BATCH
INNER_NODE
LEAF_NODE
LEDGER
TRANSACTION_ID
TRANSACTION_MULTISIGN
TRANSACTION_NODE
TRANSACTION_SIGN
TRANSACTION_SIGN_TESTNET

Extension Methods

EmumExtensions.DecodeFlags<HashPrefix>(HashPrefix)
EmumExtensions.FlagsValues<HashPrefix>(HashPrefix)
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX