Show / Hide Table of Contents

Class Hashes

Inheritance
object
Hashes
Namespace: Xrpl.Utils.Hashes
Assembly: Xrpl.dll
Syntax
public static class Hashes

Methods

| Edit this page View Source

AddressToHex(string)

Declaration
public static string AddressToHex(this string address)
Parameters
Type Name Description
string address
Returns
Type Description
string
| Edit this page View Source

CurrencyToHex(string)

checks and generates a token code for transmission to the network

Declaration
public static string CurrencyToHex(this string currency)
Parameters
Type Name Description
string currency

Currency code

Returns
Type Description
string
Exceptions
Type Condition
ArgumentException

If Currency code length more than 40 characters

| Edit this page View Source

HashAccountRoot(string)

Declaration
public static string HashAccountRoot(this string address)
Parameters
Type Name Description
string address
Returns
Type Description
string
| Edit this page View Source

HashCredential(string, string, string)

Compute the ledger object index (object ID) for an XLS-70 Credential ledger entry. Mirrors rippled's keylet::credential(subject, issuer, credentialType): sha512Half(uint16(LedgerNameSpace::CREDENTIAL) || subject(20) || issuer(20) || credentialType).

Declaration
public static string HashCredential(string subject, string issuer, string credentialTypeHex)
Parameters
Type Name Description
string subject

Classic XRPL address of the credential subject.

string issuer

Classic XRPL address of the credential issuer.

string credentialTypeHex

Credential type as an uppercase hexadecimal string (1..64 bytes -> 2..128 hex chars).

Returns
Type Description
string

The 64-character (32-byte) hexadecimal object ID of the credential ledger entry.

Exceptions
Type Condition
ArgumentException

Thrown when arguments are missing or malformed.

| Edit this page View Source

HashEscrow(string, int)

Declaration
public static string HashEscrow(string address, int sequence)
Parameters
Type Name Description
string address
int sequence
Returns
Type Description
string
| Edit this page View Source

HashOfferId(string, int)

Declaration
public static string HashOfferId(string address, int sequence)
Parameters
Type Name Description
string address
int sequence
Returns
Type Description
string
| Edit this page View Source

HashPaymentChannel(string, string, int)

Declaration
public static string HashPaymentChannel(string address, string dstAddress, int sequence)
Parameters
Type Name Description
string address
string dstAddress
int sequence
Returns
Type Description
string
| Edit this page View Source

HashSignerListId(string)

Declaration
public static string HashSignerListId(this string address)
Parameters
Type Name Description
string address
Returns
Type Description
string
| Edit this page View Source

HashTX(string)

Declaration
public static string HashTX(this string txBlobHex)
Parameters
Type Name Description
string txBlobHex
Returns
Type Description
string
| Edit this page View Source

HashTrustline(string, string, string)

Declaration
public static string HashTrustline(string address1, string address2, string currency)
Parameters
Type Name Description
string address1
string address2
string currency
Returns
Type Description
string
| Edit this page View Source

HashTx(string)

Hash the given binary transaction data with the single-signing prefix.
See Serialization Format.

Declaration
public static string HashTx(this string txBlobHex)
Parameters
Type Name Description
string txBlobHex

The binary transaction blob as a hexadecimal string.

Returns
Type Description
string

The hash to sign.

| Edit this page View Source

IsHexCurrencyCode(string)

check currency code for HEX

Declaration
public static bool IsHexCurrencyCode(this string code)
Parameters
Type Name Description
string code

currency code

Returns
Type Description
bool
| Edit this page View Source

LedgerSpaceHex(string)

Declaration
public static string LedgerSpaceHex(string name)
Parameters
Type Name Description
string name
Returns
Type Description
string
| Edit this page View Source

LedgerSpaceHex(LedgerSpace)

Declaration
public static string LedgerSpaceHex(this LedgerSpace name)
Parameters
Type Name Description
LedgerSpace name
Returns
Type Description
string
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX