Class B58
Assembly: Xrpl.AddressCodec.dll
Syntax
Constructors
|
Edit this page
B58(string)
Declaration
public B58(string alphabet)
Parameters
| Type |
Name |
Description |
| string |
alphabet |
|
Methods
|
Edit this page
Decode(string)
Declaration
public byte[] Decode(string input)
Parameters
| Type |
Name |
Description |
| string |
input |
Base58Check-encoded string to decode
|
Returns
|
Edit this page
Decode(string, Version)
Declaration
public byte[] Decode(string input, B58.Version version)
Parameters
| Type |
Name |
Description |
| string |
input |
Base58Check-encoded string to decode
|
| B58.Version |
version |
Options object including the version byte(s) and the expected length of the data after decoding
|
Returns
|
Edit this page
Decode(string, Versions)
Declaration
public B58.Decoded Decode(string input, B58.Versions versions)
Parameters
| Type |
Name |
Description |
| string |
input |
Base58Check-encoded string to decode
|
| B58.Versions |
versions |
Options object including the version byte(s) and the expected length of the data after decoding
|
Returns
|
Edit this page
Encode(byte[], string, Versions)
Declaration
public string Encode(byte[] buffer, string versionName, B58.Versions versions)
Parameters
| Type |
Name |
Description |
| byte[] |
buffer |
Buffer of data to encode.
|
| string |
versionName |
|
| B58.Versions |
versions |
Options object including the version bytes and the expected length of the data to encode.
|
Returns
|
Edit this page
Encode(byte[], Version)
Declaration
public string Encode(byte[] buffer, B58.Version version)
Parameters
| Type |
Name |
Description |
| byte[] |
buffer |
|
| B58.Version |
version |
|
Returns
|
Edit this page
EncodeToBytes(byte[])
Encodes the given bytes in base58. No checksum is appended.
Declaration
public byte[] EncodeToBytes(byte[] input)
Parameters
| Type |
Name |
Description |
| byte[] |
input |
|
Returns
|
Edit this page
EncodeToBytesChecked(byte[], byte[])
Declaration
public byte[] EncodeToBytesChecked(byte[] input, byte[] version)
Parameters
| Type |
Name |
Description |
| byte[] |
input |
|
| byte[] |
version |
|
Returns
|
Edit this page
EncodeToBytesChecked(byte[], int)
Declaration
public byte[] EncodeToBytesChecked(byte[] input, int version)
Parameters
| Type |
Name |
Description |
| byte[] |
input |
|
| int |
version |
|
Returns
|
Edit this page
EncodeToString(byte[])
Encodes the given bytes in base58. No checksum is appended.
Declaration
public string EncodeToString(byte[] input)
Parameters
| Type |
Name |
Description |
| byte[] |
input |
|
Returns
| Type |
Description |
| string |
ASCII string
|
|
Edit this page
EncodeToStringChecked(byte[], byte[])
Declaration
public string EncodeToStringChecked(byte[] input, byte[] version)
Parameters
| Type |
Name |
Description |
| byte[] |
input |
|
| byte[] |
version |
|
Returns
|
Edit this page
EncodeToStringChecked(byte[], int)
Declaration
public string EncodeToStringChecked(byte[] input, int version)
Parameters
| Type |
Name |
Description |
| byte[] |
input |
|
| int |
version |
|
Returns
|
Edit this page
FindPrefix(int, string)
Declaration
public byte[] FindPrefix(int payLoadLength, string desiredPrefix)
Parameters
| Type |
Name |
Description |
| int |
payLoadLength |
|
| string |
desiredPrefix |
|
Returns
|
Edit this page
IsValid(string, Version)
Declaration
public bool IsValid(string input, B58.Version version)
Parameters
| Type |
Name |
Description |
| string |
input |
|
| B58.Version |
version |
|
Returns
|
Edit this page
IsValid(string, Versions)
Declaration
public bool IsValid(string input, B58.Versions version)
Parameters
| Type |
Name |
Description |
| string |
input |
|
| B58.Versions |
version |
|
Returns