Class XrplAddressCodec
Inheritance
object
XrplAddressCodec
Assembly: Xrpl.AddressCodec.dll
Syntax
public class XrplAddressCodec
Fields
|
Edit this page
Alphabet
Declaration
public const string Alphabet = "rpshnaf39wBUDNEGHJKLM4PQRST7VWXYZ2bcdeCg65jkm8oFqi1tuvAxyz"
Field Value
Methods
|
Edit this page
ClassicAddressToXAddress(string, uint?, bool)
Returns the X-Address representation of the data.
Declaration
public static string ClassicAddressToXAddress(string classicAddress, uint? tag, bool isTest)
Parameters
| Type |
Name |
Description |
| string |
classicAddress |
|
| uint? |
tag |
|
| bool |
isTest |
|
Returns
| Type |
Description |
| string |
The X-Address representation of the data.
|
|
Edit this page
DecodeXAddress(string)
Declaration
public static XrplAddressCodec.CodecAccountID DecodeXAddress(string xAddress)
Parameters
| Type |
Name |
Description |
| string |
xAddress |
|
Returns
|
Edit this page
EncodeXAddress(byte[], uint?, bool)
Encode account ID, tag, and network ID to X-address
Declaration
public static string EncodeXAddress(byte[] accountId, uint? tag, bool isTest)
Parameters
| Type |
Name |
Description |
| byte[] |
accountId |
|
| uint? |
tag |
|
| bool |
isTest |
|
Returns
Exceptions
|
Edit this page
IsTestAddress(byte[])
Returns whether a decoded X-Address is a test address.
Declaration
public static bool IsTestAddress(byte[] buf)
Parameters
| Type |
Name |
Description |
| byte[] |
buf |
|
Returns
| Type |
Description |
| bool |
Whether a decoded X-Address is a test address.
|
|
Edit this page
IsValidXAddress(string)
Returns whether xAddress is a valid X-Address.
Declaration
public static bool IsValidXAddress(string xAddress)
Parameters
| Type |
Name |
Description |
| string |
xAddress |
|
Returns
| Type |
Description |
| bool |
Whether xAddress is a valid X-Address.
|
|
Edit this page
TagFromBuffer(byte[])
Returns the destination tag extracted from the suffix of the X-Address.
Declaration
public static uint? TagFromBuffer(byte[] buf)
Parameters
| Type |
Name |
Description |
| byte[] |
buf |
|
Returns
| Type |
Description |
| uint? |
The destination tag extracted from the suffix of the X-Address.
|
|
Edit this page
XAddressToClassicAddress(string)
Returns a tuple containing the classic address, tag, and whether the address
is on a test network for an X-Address.
Declaration
public static XrplAddressCodec.CodecAddress XAddressToClassicAddress(string xAddress)
Parameters
| Type |
Name |
Description |
| string |
xAddress |
|
Returns
| Type |
Description |
| XrplAddressCodec.CodecAddress |
A dict containing: classicAddress: the base58 classic address, tag: the destination tag, isTest: whether the address is on the test network (or main)
|