Namespace Xrpl.BinaryCodec.Enums
Classes
AccountIdField
AmountField
BlobField
CurrencyField
Represents a Currency field used for Oracle price data (BaseAsset, QuoteAsset).
DelegatablePermissions
Maps a Delegate permission between the name rippled reports and the number it serializes.
EngineResult
EngineResult.EngineResultValues
EngineResultField
EnumItem
Enumeration<T>
Field
FieldType
Hash128Field
Hash160Field
Hash192Field
Hash256Field
Int32Field
Int64Field
IssueField
LedgerEntryType
LedgerEntryType.Enumeration
LedgerEntryTypeField
NumberField
PathSetField
SerializedEnumItem<TOrd>
SerializedEnumeration<TEnum, TOrd>
StArrayField
StObjectField
TransactionTypeField
Uint16Field
Uint32Field
Uint64Field
Uint8Field
Vector256Field
XChainBridgeField
Enums
GranularPermission
A granular permission: the right to perform part of a transaction type rather than all of
it, granted to a delegate through DelegateSet.