Class LedgerEntryType
Inheritance
object
LedgerEntryType
Assembly: Xrpl.BinaryCodec.dll
Syntax
public class LedgerEntryType : SerializedEnumItem<ushort>, ISerializedType
Fields
|
Edit this page
AMM
Declaration
public static readonly LedgerEntryType AMM
Field Value
|
Edit this page
AccountRoot
Declaration
public static readonly LedgerEntryType AccountRoot
Field Value
|
Edit this page
Amendments
Declaration
public static readonly LedgerEntryType Amendments
Field Value
|
Edit this page
Bridge
Declaration
public static readonly LedgerEntryType Bridge
Field Value
|
Edit this page
Check
Declaration
public static readonly LedgerEntryType Check
Field Value
|
Edit this page
Contract
Declaration
[Obsolete("Contract is deprecated and no longer used in the protocol.")]
public static readonly LedgerEntryType Contract
Field Value
|
Edit this page
Credential
Declaration
public static readonly LedgerEntryType Credential
Field Value
|
Edit this page
DID
Declaration
public static readonly LedgerEntryType DID
Field Value
|
Edit this page
Delegate
Declaration
public static readonly LedgerEntryType Delegate
Field Value
|
Edit this page
DepositPreauth
Declaration
public static readonly LedgerEntryType DepositPreauth
Field Value
|
Edit this page
DirectoryNode
Declaration
public static readonly LedgerEntryType DirectoryNode
Field Value
|
Edit this page
Escrow
Declaration
public static readonly LedgerEntryType Escrow
Field Value
|
Edit this page
FeeSettings
Declaration
public static readonly LedgerEntryType FeeSettings
Field Value
|
Edit this page
GeneratorMap
Declaration
[Obsolete("GeneratorMap is deprecated and no longer used in the protocol.")]
public static readonly LedgerEntryType GeneratorMap
Field Value
|
Edit this page
Invalid
Declaration
public static readonly LedgerEntryType Invalid
Field Value
|
Edit this page
LedgerHashes
Declaration
public static readonly LedgerEntryType LedgerHashes
Field Value
|
Edit this page
Loan
Declaration
public static readonly LedgerEntryType Loan
Field Value
|
Edit this page
LoanBroker
Declaration
public static readonly LedgerEntryType LoanBroker
Field Value
|
Edit this page
MPToken
Declaration
public static readonly LedgerEntryType MPToken
Field Value
|
Edit this page
MPTokenIssuance
Declaration
public static readonly LedgerEntryType MPTokenIssuance
Field Value
|
Edit this page
NFTokenOffer
Declaration
public static readonly LedgerEntryType NFTokenOffer
Field Value
|
Edit this page
NFTokenPage
Declaration
public static readonly LedgerEntryType NFTokenPage
Field Value
|
Edit this page
NegativeUNL
Declaration
public static readonly LedgerEntryType NegativeUNL
Field Value
|
Edit this page
Offer
Declaration
public static readonly LedgerEntryType Offer
Field Value
|
Edit this page
Oracle
Declaration
public static readonly LedgerEntryType Oracle
Field Value
|
Edit this page
PayChannel
Declaration
public static readonly LedgerEntryType PayChannel
Field Value
|
Edit this page
PermissionedDomain
Declaration
public static readonly LedgerEntryType PermissionedDomain
Field Value
|
Edit this page
RippleState
Declaration
public static readonly LedgerEntryType RippleState
Field Value
|
Edit this page
SignerList
Declaration
public static readonly LedgerEntryType SignerList
Field Value
|
Edit this page
Ticket
Declaration
public static readonly LedgerEntryType Ticket
Field Value
|
Edit this page
Values
Declaration
public static LedgerEntryType.Enumeration Values
Field Value
|
Edit this page
Vault
Declaration
public static readonly LedgerEntryType Vault
Field Value
|
Edit this page
XChainOwnedClaimID
Declaration
public static readonly LedgerEntryType XChainOwnedClaimID
Field Value
|
Edit this page
XChainOwnedCreateAccountClaimID
Declaration
public static readonly LedgerEntryType XChainOwnedCreateAccountClaimID
Field Value
Properties
|
Edit this page
EnabledAmendments
Declaration
[Obsolete("Use Amendments instead. EnabledAmendments is the legacy name.")]
public static LedgerEntryType EnabledAmendments { get; }
Property Value
Methods
|
Edit this page
FromJson(JsonNode)
Declaration
public static LedgerEntryType FromJson(JsonNode jToken)
Parameters
| Type |
Name |
Description |
| JsonNode |
jToken |
|
Returns
Implements
Extension Methods