Namespace Xrpl.BinaryCodec.Types
Classes
AccountId
Class defining how to encode and decode an AccountID
The unique identifier for an account.
Amount
AmountValue
Blob
The Blob type is a length-prefixed field with arbitrary data.
Two common fields that use this type are SigningPubKey and TxnSignature, which contain (respectively)
the public key and signature that authorize a transaction to be executed.
Blob fields have no further structure to their contents, so they consist of
exactly the amount of bytes indicated in the variable-length encoding, after the Field ID and length prefixes.
Variable length encoded type
Comparable
Currency
Class defining how to encode and decode Currencies
Hash
The XRP Ledger has several "hash" types: Hash128, Hash160, and Hash256.
These fields contain arbitrary binary data of the given number of bits, which may or may not represent the result of a hash operation.
All such fields are serialized as the specific number of bits, with no length indicator, in big-endian byte order.
Base class defining how to encode and decode hashes
Hash128
Hash with a width of 128 bits
Hash160
Hash with a width of 160 bits
Hash192
Represents a 192-bit (24-byte) hash (e.g., MPTokenIssuanceID).
Hash256
Hash with a width of 256 bits
InvalidAmountValueException
IouValue
Issue
Represents an Issue (currency + optional issuer), similar to ripple-binary-codec/src/types/issue.ts
MptAmount
Path
Class for serializing/deserializing Paths
PathHop
The object representation of a Hop, an issuer AccountID, an account AccountID, and a Currency
PathSet
Deserialize and Serialize the PathSet type
PrecisionException
SerializedType
StArray
Class for serializing and deserializing Arrays of Objects
StExtensions
extension for ISerializedType
StObject
Class for Serializing/Deserializing objects
StReader
TransactionType
TransactionType.Enumeration
Uint16
Derived UInt class for serializing/deserializing 16 bit UInt
Uint32
Derived UInt class for serializing/deserializing 32 bit UInt
Uint64
Derived UInt class for serializing/deserializing 64 bit UInt
Uint8
Derived UInt class for serializing/deserializing 8 bit UInt
Uint<T>
Base class for serializing and deserializing unsigned integers.
Vector256
Class for serializing and deserializing vectors of Hash256