Class PathHop
The object representation of a Hop, an issuer AccountID, an account AccountID, and a Currency or an MPTokenIssuanceID
Inheritance
Namespace: Xrpl.BinaryCodec.Types
Assembly: Xrpl.BinaryCodec.dll
Syntax
public class PathHop
Constructors
| Edit this page View SourcePathHop(AccountId, AccountId, Currency)
Create a Hop
Declaration
public PathHop(AccountId account, AccountId issuer, Currency currency)
Parameters
| Type | Name | Description |
|---|---|---|
| AccountId | account | account AccountID |
| AccountId | issuer | issuer AccountID |
| Currency | currency | Currency |
PathHop(AccountId, AccountId, Currency, Hash192)
Create a Hop
Declaration
public PathHop(AccountId account, AccountId issuer, Currency currency, Hash192 mptIssuanceId)
Parameters
| Type | Name | Description |
|---|---|---|
| AccountId | account | account AccountID |
| AccountId | issuer | issuer AccountID |
| Currency | currency | Currency, mutually exclusive with mptIssuanceId |
| Hash192 | mptIssuanceId | MPTokenIssuanceID, mutually exclusive with currency |
Fields
| Edit this page View SourceAccount
account AccountID
Declaration
public readonly AccountId Account
Field Value
| Type | Description |
|---|---|
| AccountId |
Currency
Currency
Declaration
public readonly Currency Currency
Field Value
| Type | Description |
|---|---|
| Currency |
Issuer
issuer AccountID
Declaration
public readonly AccountId Issuer
Field Value
| Type | Description |
|---|---|
| AccountId |
MptIssuanceId
MPTokenIssuanceID, mutually exclusive with Currency
Declaration
public readonly Hash192 MptIssuanceId
Field Value
| Type | Description |
|---|---|
| Hash192 |
Type
Hop type byte, synthesized from the fields present
Declaration
public readonly byte Type
Field Value
| Type | Description |
|---|---|
| byte |
TypeAccount
TypeAccount const byte
Declaration
public const byte TypeAccount = 1
Field Value
| Type | Description |
|---|---|
| byte |
TypeAll
Every bit a hop type byte is allowed to carry
Declaration
public const byte TypeAll = 113
Field Value
| Type | Description |
|---|---|
| byte |
TypeCurrency
TypeCurrency const byte
Declaration
public const byte TypeCurrency = 16
Field Value
| Type | Description |
|---|---|
| byte |
TypeIssuer
type issuer const byte
Declaration
public const byte TypeIssuer = 32
Field Value
| Type | Description |
|---|---|
| byte |
TypeMpt
MPTokenIssuanceID const byte (rippled 3.2.0+, MPTokensV2 amendment)
Declaration
public const byte TypeMpt = 64
Field Value
| Type | Description |
|---|---|
| byte |
Methods
| Edit this page View SourceFromJson(JsonNode)
Declaration
public static PathHop FromJson(JsonNode json)
Parameters
| Type | Name | Description |
|---|---|---|
| JsonNode | json |
Returns
| Type | Description |
|---|---|
| PathHop |
HasAccount()
check that hop has account AccountID
Declaration
public bool HasAccount()
Returns
| Type | Description |
|---|---|
| bool |
HasCurrency()
check that hop has currency
Declaration
public bool HasCurrency()
Returns
| Type | Description |
|---|---|
| bool |
HasIssuer()
check that hop has issuer AccountID
Declaration
public bool HasIssuer()
Returns
| Type | Description |
|---|---|
| bool |
HasMpt()
check that hop has MPTokenIssuanceID
Declaration
public bool HasMpt()
Returns
| Type | Description |
|---|---|
| bool |
SynthesizeType()
generate type for current hop
Declaration
public byte SynthesizeType()
Returns
| Type | Description |
|---|---|
| byte |
ToJson()
Serialize Hop
Declaration
public JsonObject ToJson()
Returns
| Type | Description |
|---|---|
| JsonObject |