Class TransactionType
Inheritance
object
TransactionType
Assembly: Xrpl.BinaryCodec.dll
Syntax
public class TransactionType : SerializedEnumItem<ushort>, ISerializedType
Fields
|
Edit this page
AMMBid
Declaration
public static readonly TransactionType AMMBid
Field Value
|
Edit this page
AMMClawback
Claw back tokens from an Automated Market Maker (AMM) pool.
Declaration
public static readonly TransactionType AMMClawback
Field Value
|
Edit this page
AMMCreate
Declaration
public static readonly TransactionType AMMCreate
Field Value
|
Edit this page
AMMDelete
Declaration
public static readonly TransactionType AMMDelete
Field Value
|
Edit this page
AMMDeposit
Declaration
public static readonly TransactionType AMMDeposit
Field Value
|
Edit this page
AMMVote
Declaration
public static readonly TransactionType AMMVote
Field Value
|
Edit this page
AMMWithdraw
Declaration
public static readonly TransactionType AMMWithdraw
Field Value
|
Edit this page
AccountDelete
This transaction type deletes an existing account.
Declaration
public static readonly TransactionType AccountDelete
Field Value
|
Edit this page
AccountSet
This transaction type adjusts various account settings.
Declaration
public static readonly TransactionType AccountSet
Field Value
|
Edit this page
Batch
Batch Transactions let you package multiple transactions together and execute them as a single unit.
It eliminates the risk of partial completion and unexpected outcomes,
giving you a more reliable and predictable experience for complex operations.
Up to eight transactions can be submitted in a single batch.
For details, see: https://xrpl.org/docs/concepts/transactions/batch-transactions
Declaration
public static readonly TransactionType Batch
Field Value
|
Edit this page
CheckCancel
This transaction type cancels an existing check.
Declaration
public static readonly TransactionType CheckCancel
Field Value
|
Edit this page
CheckCash
This transaction type cashes an existing check.
Declaration
public static readonly TransactionType CheckCash
Field Value
|
Edit this page
CheckCreate
This transaction type creates a new check.
Declaration
public static readonly TransactionType CheckCreate
Field Value
|
Edit this page
Clawback
Claw back tokens issued by your account from a holder.
Declaration
public static readonly TransactionType Clawback
Field Value
|
Edit this page
CredentialAccept
Accepts a provisionally-issued credential, making it valid.
Declaration
public static readonly TransactionType CredentialAccept
Field Value
|
Edit this page
CredentialCreate
Creates a new credential issued to a subject account.
Declaration
public static readonly TransactionType CredentialCreate
Field Value
|
Edit this page
CredentialDelete
Deletes (revokes) a credential from the ledger.
Declaration
public static readonly TransactionType CredentialDelete
Field Value
|
Edit this page
DIDDelete
Deletes the DID associated with the sending account.
Declaration
public static readonly TransactionType DIDDelete
Field Value
|
Edit this page
DIDSet
Creates or updates a Decentralized Identifier (DID) associated with the sending account.
Declaration
public static readonly TransactionType DIDSet
Field Value
|
Edit this page
DepositPreauth
This transaction type grants or revokes authorization to transfer funds.
Declaration
public static readonly TransactionType DepositPreauth
Field Value
|
Edit this page
EnableAmendment
Declaration
public static readonly TransactionType EnableAmendment
Field Value
|
Edit this page
EscrowCancel
This transaction type cancels an existing escrow.
Declaration
public static readonly TransactionType EscrowCancel
Field Value
|
Edit this page
EscrowCreate
This transaction type creates an escrow object.
Declaration
public static readonly TransactionType EscrowCreate
Field Value
|
Edit this page
EscrowFinish
This transaction type completes an existing escrow.
Declaration
public static readonly TransactionType EscrowFinish
Field Value
|
Edit this page
HookSet
This transaction type installs a hook.
NOTE*: maybe_unused
Declaration
public static readonly TransactionType HookSet
Field Value
|
Edit this page
Invalid
Declaration
public static readonly TransactionType Invalid
Field Value
|
Edit this page
MPTokenAuthorize
This transaction authorizes or unauthorizes a holder for an MPT.
Declaration
public static readonly TransactionType MPTokenAuthorize
Field Value
|
Edit this page
MPTokenIssuanceCreate
This transaction creates a new Multi-Purpose Token (MPT) issuance.
Declaration
public static readonly TransactionType MPTokenIssuanceCreate
Field Value
|
Edit this page
MPTokenIssuanceDestroy
This transaction destroys an existing MPT issuance.
Declaration
public static readonly TransactionType MPTokenIssuanceDestroy
Field Value
|
Edit this page
MPTokenIssuanceSet
This transaction modifies settings of an existing MPT issuance.
Declaration
public static readonly TransactionType MPTokenIssuanceSet
Field Value
|
Edit this page
NFTokenAcceptOffer
This transaction accepts an existing offer to buy or sell an existing NFT.
Declaration
public static readonly TransactionType NFTokenAcceptOffer
Field Value
|
Edit this page
NFTokenBurn
This transaction burns (i.e. destroys) an existing NFT.
Declaration
public static readonly TransactionType NFTokenBurn
Field Value
|
Edit this page
NFTokenCancelOffer
This transaction cancels an existing offer to buy or sell an existing NFT.
Declaration
public static readonly TransactionType NFTokenCancelOffer
Field Value
|
Edit this page
NFTokenCreateOffer
This transaction creates a new offer to buy or sell an NFT.
Declaration
public static readonly TransactionType NFTokenCreateOffer
Field Value
|
Edit this page
NFTokenMint
This transaction mints a new NFT
Declaration
public static readonly TransactionType NFTokenMint
Field Value
|
Edit this page
NFTokenModify
Declaration
public static readonly TransactionType NFTokenModify
Field Value
|
Edit this page
OfferCancel
This transaction type cancels existing offers to trade one asset for another.
Declaration
public static readonly TransactionType OfferCancel
Field Value
|
Edit this page
OfferCreate
This transaction type creates an offer to trade one asset for another.
Declaration
public static readonly TransactionType OfferCreate
Field Value
|
Edit this page
OracleDelete
Deletes a price oracle from the ledger.
Declaration
public static readonly TransactionType OracleDelete
Field Value
|
Edit this page
OracleSet
Creates or updates a price oracle on the ledger.
Declaration
public static readonly TransactionType OracleSet
Field Value
|
Edit this page
Payment
This transaction type executes a payment
Declaration
public static readonly TransactionType Payment
Field Value
|
Edit this page
PaymentChannelClaim
This transaction type submits a claim against an existing unidirectional payment channel.
Declaration
public static readonly TransactionType PaymentChannelClaim
Field Value
|
Edit this page
PaymentChannelCreate
This transaction type creates a new unidirectional XRP payment channel.
Declaration
public static readonly TransactionType PaymentChannelCreate
Field Value
|
Edit this page
PaymentChannelFund
This transaction type funds an existing unidirectional XRP payment channel.
Declaration
public static readonly TransactionType PaymentChannelFund
Field Value
|
Edit this page
PermissionedDomainDelete
Delete a permissioned domain that you own.
Declaration
public static readonly TransactionType PermissionedDomainDelete
Field Value
|
Edit this page
PermissionedDomainSet
Create a permissioned domain, or modify one that you own.
Declaration
public static readonly TransactionType PermissionedDomainSet
Field Value
|
Edit this page
SetFee
Declaration
public static readonly TransactionType SetFee
Field Value
|
Edit this page
SetRegularKey
This transaction type sets or clears an account's "regular key"
Declaration
public static readonly TransactionType SetRegularKey
Field Value
|
Edit this page
SignerListSet
This transaction type modifies the signer list associated with an account.
Declaration
public static readonly TransactionType SignerListSet
Field Value
|
Edit this page
TicketCreate
This transaction type creates a new set of tickets.
Declaration
public static readonly TransactionType TicketCreate
Field Value
|
Edit this page
TrustSet
This transaction type modifies a trustline between two accounts.
Declaration
public static readonly TransactionType TrustSet
Field Value
|
Edit this page
UNLModify
Declaration
public static readonly TransactionType UNLModify
Field Value
|
Edit this page
Values
Declaration
public static TransactionType.Enumeration Values
Field Value
Implements
Extension Methods