Show / Hide Table of Contents

Class XrplBinaryCodec

Inheritance
object
XrplBinaryCodec
Namespace: Xrpl.BinaryCodec
Assembly: Xrpl.BinaryCodec.dll
Syntax
public class XrplBinaryCodec

Methods

| Edit this page View Source

Decode(string)

Decode a hex string into a JsonNode representing the transaction/object.

Declaration
public static JsonNode Decode(string binary)
Parameters
Type Name Description
string binary
Returns
Type Description
JsonNode

JsonNode

| Edit this page View Source

Encode(object)

Encode an object into binary hex string.

Declaration
public static string Encode(object json)
Parameters
Type Name Description
object json
Returns
Type Description
string

string

| Edit this page View Source

Encode(JsonNode)

Encode a JsonNode into binary hex string.

Declaration
public static string Encode(JsonNode token)
Parameters
Type Name Description
JsonNode token
Returns
Type Description
string

string

| Edit this page View Source

EncodeForMultiSigning(object, string)

Encode a transaction into binary format in preparation for providing one signature towards a multi-signed transaction. (Only encodes fields that are intended to be signed.)

Declaration
public static string EncodeForMultiSigning(object json, string signingAccount)
Parameters
Type Name Description
object json
string signingAccount
Returns
Type Description
string

string

| Edit this page View Source

EncodeForSigning(object)

Encode a transaction into binary format in preparation for signing. (Only encodes fields that are intended to be signed.)

Declaration
public static string EncodeForSigning(object json)
Parameters
Type Name Description
object json
Returns
Type Description
string

string

| Edit this page View Source

EncodeForSigningBatch(uint, IEnumerable<string>, uint?)

Encode a multi transaction - Batch

Declaration
public static byte[] EncodeForSigningBatch(uint flags, IEnumerable<string> txIDs, uint? networkId = null)
Parameters
Type Name Description
uint flags

Batch flags.

IEnumerable<string> txIDs

Collection of inner transaction IDs.

uint? networkId

Optional network ID for cross‑chain replay protection.

Returns
Type Description
byte[]
Exceptions
Type Condition
ArgumentNullException
ArgumentException
| Edit this page View Source

EncodeForSigningClaim(object)

Encode a payment channel <a href="https://xrpl.org/payment-channels.html">here</a>_ Claim to be signed.

Declaration
public static string EncodeForSigningClaim(object obj)
Parameters
Type Name Description
object obj
Returns
Type Description
string

string

| Edit this page View Source

SerializeJson(JsonNode, byte[]?, byte[]?, bool)

Declaration
public static string SerializeJson(JsonNode json, byte[]? prefix = null, byte[]? suffix = null, bool signingOnly = false)
Parameters
Type Name Description
JsonNode json
byte[] prefix
byte[] suffix
bool signingOnly
Returns
Type Description
string

string

  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX