Namespace Xrpl.Client
Classes
AdminCredentials
rippled's admin_user/admin_password port-stanza credentials. They are carried
inside the JSON body of each request, which is the only mechanism rippled accepts for
admin commands over ws/wss.
Connection
Connection.ConnectionOptions
ConnectionManager
ConnectionStatusInfo
ReconnectInfo
RequestManager
Manage all the requests made to the websocket, and their async responses that come in from the WebSocket.Responses come in over the WS connection after-the-fact, so this manager will tie that response to resolve the original request.