Show / Hide Table of Contents

Namespace Xrpl.Client

Classes

Connection

Connection.ConnectionOptions

Connection.Trace

ConnectionManager

ConnectionStatusInfo

ReconnectInfo

RequestManager

Manage all the requests made to the websocket, and their async responses that come in from the WebSocket.Responses come in over the WS connection after-the-fact, so this manager will tie that response to resolve the original request.

RequestManager.XrplGRequest

RequestManager.XrplRequest

TaskInfo

WebSocketClient

XrplClient

XrplClient.ClientOptions

Interfaces

IXrplClient

Enums

ConnectionCloseSeverity

RequestFailurePolicy

SocketFailureReason

XrpConnectionState

Delegates

OnConnected

OnConsensusPhase

OnDisconnect

OnError

OnLedgerClosed

OnManifestReceived

OnPathFind

OnPeerStatusChange

OnPing

OnServerWarning

OnTransaction

OnWarning

In this article
Back to top Generated by DocFX