Show / Hide Table of Contents

Namespace Xrpl.Client.Exceptions

Classes

ConnectionException

Exception thrown when xrpl.js has an Exception with connection to rippled.

DisconnectedException

Exception thrown when xrpl.js has disconnected from rippled server.

NotConnectedException

Exception thrown when xrpl.js is not connected to rippled server.

NotFoundException

Exception thrown when xrpl.js cannot retrieve a transaction, ledger, account, etc. From rippled.

ResponseFormatException

Exception thrown when xrpl.js sees a response in the wrong format.

RippleException

RippledErrorParser

RippledException

Exception thrown when rippled responds with an Exception.

RippledNotInitializedException

Exception thrown when rippled is not initialized.

TimeoutException

Exception thrown when a request to rippled times out.

IMPORTANT: this is Xrpl.Client.Exceptions.TimeoutException, NOT System.TimeoutException. It derives from XrplException, so a catch (System.TimeoutException) will NOT catch it. Catch this type (or its base XrplException) explicitly; if both using System; and using Xrpl.Client.Exceptions; are in scope, fully-qualify the type to avoid catching the wrong one.

UnexpectedException

Exception thrown when xrpl.js cannot specify Exception type.

ValidationException

Exception thrown when xrpl.js sees a malformed transaction.

XRPLFaucetException

Exception thrown when a client cannot generate a wallet from the testnet/devnet faucets, or when the client cannot infer the faucet URL(i.e.when the Client is connected to mainnet).

XrplErrorClassifier

XrplErrorCodes

XrplErrorInfo

XrplException

Enums

XrplErrorCategory

XrplErrorSubject

In this article
Back to top Generated by DocFX