Namespace Xrpl.Client.Exceptions
Classes
ConnectionException
Exception thrown when xrpl.js has an Exception with connection to rippled.
DisconnectedException
Exception thrown when xrpl.js has disconnected from rippled server.
NotConnectedException
Exception thrown when xrpl.js is not connected to rippled server.
NotFoundException
Exception thrown when xrpl.js cannot retrieve a transaction, ledger, account, etc. From rippled.
ResponseFormatException
Exception thrown when xrpl.js sees a response in the wrong format.
RippleException
RippledErrorParser
RippledException
Exception thrown when rippled responds with an Exception.
RippledNotInitializedException
Exception thrown when rippled is not initialized.
TimeoutException
Exception thrown when xrpl.js times out.
UnexpectedException
Exception thrown when xrpl.js cannot specify Exception type.
ValidationException
Exception thrown when xrpl.js sees a malformed transaction.
XRPLFaucetException
Exception thrown when a client cannot generate a wallet from the testnet/devnet faucets, or when the client cannot infer the faucet URL(i.e.when the Client is connected to mainnet).