Show / Hide Table of Contents

Class XRPLFaucetException

Exception thrown when a client cannot generate a wallet from the testnet/devnet faucets, or when the client cannot infer the faucet URL(i.e.when the Client is connected to mainnet).

Inheritance
object
Exception
XrplException
XRPLFaucetException
Namespace: Xrpl.Client.Exceptions
Assembly: Xrpl.dll
Syntax
public class XRPLFaucetException : XrplException

Constructors

| Edit this page View Source

XRPLFaucetException(string)

Declaration
public XRPLFaucetException(string message = null)
Parameters
Type Name Description
string message

Extension Methods

XrplErrorClassifier.Classify(Exception)
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX