Class XRPLFaucetException
Exception thrown when a client cannot generate a wallet from the testnet/devnet faucets, or when the client cannot infer the faucet URL(i.e.when the Client is connected to mainnet).
Namespace: Xrpl.Client.Exceptions
Assembly: Xrpl.dll
Syntax
public class XRPLFaucetException : XrplException
Constructors
| Edit this page View SourceXRPLFaucetException(string)
Declaration
public XRPLFaucetException(string message = null)
Parameters
| Type | Name | Description |
|---|---|---|
| string | message |