Class NumberOrStringConverter
Reads a JSON value that may be either a number or a string and always returns it as a string.
Useful for fields like ledger_index which some API methods return as a quoted integer
and others return as a native JSON number.
Inheritance
object
JsonConverter
JsonConverter<string>
NumberOrStringConverter
Namespace: Xrpl.Client.Json.Converters
Assembly: Xrpl.dll
Syntax
public class NumberOrStringConverter : JsonConverter<string>
Methods
| Edit this page View SourceRead(ref Utf8JsonReader, Type, JsonSerializerOptions)
Reads and converts the JSON to type string.
Declaration
public override string Read(ref Utf8JsonReader reader, Type typeToConvert, JsonSerializerOptions options)
Parameters
| Type | Name | Description |
|---|---|---|
| Utf8JsonReader | reader | The reader. |
| Type | typeToConvert | The type to convert. |
| JsonSerializerOptions | options | An object that specifies serialization options to use. |
Returns
| Type | Description |
|---|---|
| string | The converted value. |
Overrides
System.Text.Json.Serialization.JsonConverter<string>.Read(ref System.Text.Json.Utf8JsonReader, System.Type, System.Text.Json.JsonSerializerOptions)
|
Edit this page
Write(Utf8JsonWriter, string, JsonSerializerOptions)
Writes a specified value as JSON.
Declaration
public override void Write(Utf8JsonWriter writer, string value, JsonSerializerOptions options)
Parameters
| Type | Name | Description |
|---|---|---|
| Utf8JsonWriter | writer | The writer to write to. |
| string | value | The value to convert to JSON. |
| JsonSerializerOptions | options | An object that specifies serialization options to use. |
Overrides
System.Text.Json.Serialization.JsonConverter<string>.Write(System.Text.Json.Utf8JsonWriter, string, System.Text.Json.JsonSerializerOptions)