Class RequestManager
Manage all the requests made to the websocket, and their async responses
that come in from the WebSocket.Responses come in over the WS connection
after-the-fact, so this manager will tie that response to resolve the
original request.
Inheritance
object
RequestManager
Assembly: Xrpl.dll
Syntax
public class RequestManager
Constructors
|
Edit this page
RequestManager()
Declaration
Methods
|
Edit this page
CreateGRequest<T, R>(R, TimeSpan, CancellationToken)
Declaration
public RequestManager.XrplGRequest CreateGRequest<T, R>(R request, TimeSpan timeout, CancellationToken cancellationToken = default)
Parameters
| Type |
Name |
Description |
| R |
request |
|
| TimeSpan |
timeout |
|
| CancellationToken |
cancellationToken |
|
Returns
Type Parameters
|
Edit this page
CreateRequest(Dictionary<string, object>, TimeSpan, CancellationToken)
Declaration
public RequestManager.XrplRequest CreateRequest(Dictionary<string, object> request, TimeSpan timeout, CancellationToken cancellationToken = default)
Parameters
| Type |
Name |
Description |
| Dictionary<string, object> |
request |
|
| TimeSpan |
timeout |
|
| CancellationToken |
cancellationToken |
|
Returns
|
Edit this page
DeletePromise(Guid, TaskInfo)
Declaration
public void DeletePromise(Guid id, TaskInfo taskInfo)
Parameters
| Type |
Name |
Description |
| Guid |
id |
|
| TaskInfo |
taskInfo |
|
|
Edit this page
HandleResponse(string)
Handles an incoming response message. Returns a tuple of (response, handled).
handled=true means the message was matched to a pending request (resolved or rejected).
handled=false means the id was not found among pending requests — the caller
should treat the message as a stream/follow-up (e.g. path_find async updates).
Declaration
public (BaseResponse Response, bool Handled) HandleResponse(string message)
Parameters
| Type |
Name |
Description |
| string |
message |
|
Returns
|
Edit this page
RejectAll(Exception)
Rejects all pending requests with the specified exception.
Declaration
public void RejectAll(Exception error)
Parameters
| Type |
Name |
Description |
| Exception |
error |
|
|
Edit this page
RejectAllWithCancellation()
Rejects all pending requests with OperationCanceledException.
Used for intentional disconnects to avoid logging as Critical errors.
Declaration
public void RejectAllWithCancellation()
|
Edit this page
Reject<T>(Guid, T)
Rejects a pending request with the specified exception.
Safe to call even if the promise no longer exists (e.g., already resolved).
The exception is automatically "observed" to prevent UnobservedTaskException
from being raised in consuming applications like DaddyWallet.
Declaration
public void Reject<T>(Guid id, T error) where T : Exception
Parameters
| Type |
Name |
Description |
| Guid |
id |
|
| T |
error |
|
Type Parameters
|
Edit this page
Resolve(Guid, BaseResponse)
Declaration
public void Resolve(Guid id, BaseResponse response)
Parameters