Show / Hide Table of Contents

Namespace Xrpl.Models.Common

Classes

Common

common class

Common.IssuedCurrency

currency with issuer

Common.IssuedCurrencyAmount

currency with amount and issuer

Common.MPTAmount

Represents a Multi-Purpose Token (MPT) amount with value.

Common.MPTCurrency

Represents a Multi-Purpose Token (MPT) currency identifier.

Common.XRP

is XRP currency

Currency

The XRP Ledger has two kinds of digital asset: XRP and tokens.
Both types have high precision, although their formats are different

CurrencyExtensions

LedgerIndex

MPTokenIssuanceIdData

Decoded components of an MPTokenIssuanceID (XLS-33).

NFTokenIdData

PriceData

Represents the price information for a single asset pair in a price oracle.

PriceDataWrapper

Represents price information for a token pair in a price oracle.

In this article
Back to top Generated by DocFX