Show / Hide Table of Contents

Class PermissionEntry

Represents a single permission granted to a delegate account.

Inheritance
object
PermissionEntry
Namespace: Xrpl.Models.Common
Assembly: Xrpl.dll
Syntax
public class PermissionEntry

Properties

| Edit this page View Source

PermissionValue

A bit-flag value representing the specific permission granted. Each bit corresponds to a particular transaction type or capability.

Declaration
[JsonPropertyName("PermissionValue")]
public uint PermissionValue { get; set; }
Property Value
Type Description
uint
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX