Class XChainBridgeModel
Represents the XChainBridge field, which identifies a cross-chain bridge. The bridge is defined by the door accounts and issued currencies on both chains.
Inheritance
object
XChainBridgeModel
Namespace: Xrpl.Models.Common
Assembly: Xrpl.dll
Syntax
public class XChainBridgeModel
Properties
| Edit this page View SourceIssuingChainDoor
The door account on the locking chain.
Declaration
[JsonPropertyName("IssuingChainDoor")]
public string IssuingChainDoor { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
IssuingChainIssue
The asset that is locked and unlocked on the locking chain.
Declaration
[JsonPropertyName("IssuingChainIssue")]
[JsonConverter(typeof(IssuedCurrencyConverter))]
public Common.IssuedCurrency IssuingChainIssue { get; set; }
Property Value
| Type | Description |
|---|---|
| Common.IssuedCurrency |
LockingChainDoor
The door account on the issuing chain. For an XRP-XRP bridge, this must be the genesis account (the account that is created when the network is first started, which contains all of the XRP).
Declaration
[JsonPropertyName("LockingChainDoor")]
public string LockingChainDoor { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
LockingChainIssue
The asset that is minted and burned on the issuing chain. For an IOU-IOU bridge, the issuer of the asset must be the door account on the issuing chain, to avoid supply issues.
Declaration
[JsonPropertyName("LockingChainIssue")]
[JsonConverter(typeof(IssuedCurrencyConverter))]
public Common.IssuedCurrency LockingChainIssue { get; set; }
Property Value
| Type | Description |
|---|---|
| Common.IssuedCurrency |