Namespace Xrpl.Models.Ledger
Classes
AuctionSlot
Details of the current owner of the auction slot.
AuthAccount
AuthorizeCredentialBody
Body of a single credential reference inside a credential-based DepositPreauth entry.
AuthorizeCredentialEntry
Wrapper element used inside AuthorizeCredentials.
rippled serializes each credential reference as a single-property object: { "Credential": { ... } }.
BaseLedgerEntity
BaseLedgerEntry
BookReference
Represents a reference to an order book directory page for hybrid offers. Used in AdditionalBooks array for offers that participate in multiple order books.
BookWrapper
Wrapper for Book reference in AdditionalBooks array. Each element in AdditionalBooks contains a Book object.
DisabledValidator
HashOrTransaction
LOAccountRoot
The AccountRoot object type describes a single account, its settings, and XRP balance.
LOAmendments
The Amendments object type contains a list of Amendments that are currently active.
LOAmm
LOBaseLedger
base ledger fields
LOCheck
A Check object describes a check, similar to a paper personal check, which can be cashed by its destination to get money from its sender.
LOCredential
A Credential ledger entry represents a verifiable credential issued by one account (the issuer) to another (the subject). Credentials are used for on-chain identity verification and permissioned domain access control on the XRP Ledger.
LODID
A DID ledger entry holds references to, or data associated with, a single DID (Decentralized Identifier).
LODepositPreauth
A DepositPreauth object tracks a preauthorization from one account to another.
DepositPreauth transactions create these objects.
Preauthorization can be granted either to a specific account (Authorize)
or to any account that holds a matching set of credentials (AuthorizeCredentials, XLS-70).
Exactly one of these two fields is populated per ledger entry.
LODirectoryNode
The DirectoryNode object type provides a list of links to other objects in the ledger's state tree.
LOEscrow
The Escrow object type represents a held payment of XRP or fungible tokens (IOUs, MPTs) waiting to be executed or canceled.
LOFeeSettings
The FeeSettings object type contains the current base transaction cost and reserve amounts as determined by fee voting.
LOLedger
Response expected from a LedgerRequest. https://github.com/XRPLF/xrpl.js/blob/b20c05c3680d80344006d20c44b4ae1c3b0ffcac/packages/xrpl/src/models/methods/ledger.ts#L113
LOLedgerCurrentIndex
Response expected from a {@link LedgerCurrentRequest}.
LOLedgerData
The response expected from a LedgerDataRequest.
LOLedgerHashes
The LedgerHashes objects exist to make it possible to look up a previous ledger's hash with only the current ledger version and at most one lookup of a previous ledger version.
LOMPToken
The MPToken object represents an amount of an MPT held by an account that is not the issuer.
LOMPTokenIssuance
The MPTokenIssuance object represents a Multi-Purpose Token (MPT) issuance.
LONegativeUNL
The NegativeUNL object type contains the current status of the Negative UNL, a list of trusted validators currently believed to be offline.
LOOffer
LOOracle
An Oracle ledger entry holds data associated with a single price oracle, which can store information on up to 10 asset pairs.
LOPayChannel
The PayChannel object type represents a payment channel.
Payment channels enable small, rapid off-ledger payments of XRP that can be later reconciled with the consensus ledger.
A payment channel holds a balance of XRP that can only be paid out to a specific destination address until the channel is closed.
LOPermissionedDomain
A PermissionedDomain ledger entry describes a single permissioned domain instance. You can create a permissioned domain by sending a PermissionedDomainSet transaction. Requires the PermissionedDomains amendment.
LORippleState
The RippleState object type connects two accounts in a single currency.
LOSignerList
The SignerList object type represents a list of parties that, as a group,
are authorized to sign a transaction in place of an individual account.
You can create, replace, or remove a signer list using a SignerListSet transaction.
LOTicket
The Ticket object type represents a Ticket, which tracks an account sequence number that has been set aside for future use.
You can create new tickets with a TicketCreate transaction.
LedgerBinaryEntity
LedgerEntity
A ledger is a block of transactions and shared state data.
It has a unique header that describes its contents using cryptographic hashes.
LedgerEntryResponse
LedgerTransaction
Majority
QueuedTransaction
Each member of the queue_data array represents one transaction in the queue.
Some fields of this object may be omitted because they have not yet been calculated.
https://xrpl.org/ledger.html#response-format
SignerEntry
The object that describes the signer in SignerEntries.
SignerEntryWrapper
VoteEntry
Interfaces
IAuthAccount
IBaseLedgerEntity
IDisabledValidator
IVoteEntry
Enums
AccountRootFlags
There are several options which can be either enabled or disabled for an account.
These options can be changed with an AccountSet transaction.
In the ledger, flags are represented as binary values that can be combined with bitwise-or operations.
The bit values for the flags in the ledger are different than the values used to enable or disable those flags in a transaction.
CredentialFlags
Flags for the Credential ledger entry.
EnableAmendmentFlags
LedgerIndexType
The rippled server makes a distinction between ledger versions that are open, closed, and validated.
A server has one open ledger, any number of closed but unvalidated ledgers, and an immutable history of validated ledgers.
MPTokenFlags
MPTokenIssuanceFlags
RippleStateFlags
There are several options which can be either enabled or disabled for a trust line.
These options can be changed with a TrustSet transaction.
In the ledger, flags are represented as binary values that can be combined with bitwise-or operations.
The bit values for the flags in the ledger are different than the values used to enable or disable those flags in a transaction.
Ledger flags have names that begin with lsf.