Class AuctionSlot
Details of the current owner of the auction slot.
Inheritance
Namespace: Xrpl.Models.Ledger
Assembly: Xrpl.dll
Syntax
public class AuctionSlot
Properties
| Edit this page View SourceAccount
The current owner of this auction slot.
Declaration
[JsonPropertyName("account")]
public string Account { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
AuthAccounts
A list of at most 4 additional accounts that are authorized to trade at the discounted fee for this AMM instance.
Declaration
[JsonPropertyName("auth_accounts")]
public List<AuthAccount> AuthAccounts { get; set; }
Property Value
| Type | Description |
|---|---|
| List<AuthAccount> |
DiscountedFee
The trading fee to be charged to the auction owner, in the same format as TradingFee.
By default this is 0, meaning that the auction owner can trade at no fee instead of the standard fee for this AMM.
Declaration
[JsonPropertyName("discounted_fee")]
public uint DiscountedFee { get; set; }
Property Value
| Type | Description |
|---|---|
| uint |
Expiration
The time when this slot expires, in seconds since the Ripple Epoch.
Declaration
[JsonPropertyName("expiration")]
[JsonConverter(typeof(FromStringDateTimeConverter))]
public DateTime? Expiration { get; set; }
Property Value
| Type | Description |
|---|---|
| Nullable |
Price
The amount the auction owner paid to win this slot, in LPTokens.
Declaration
[JsonPropertyName("price")]
[JsonConverter(typeof(CurrencyConverter))]
public Currency Price { get; set; }
Property Value
| Type | Description |
|---|---|
| Currency |
TimeInterval
The current 72-minute time interval this auction slot is in, from 0 to 19. The auction slot expires after 24 hours (20 intervals of 72 minutes) and affects the cost to outbid the current holder and how much the current holder is refunded if someone outbids them.
Declaration
[JsonPropertyName("time_interval")]
public uint TimeInterval { get; set; }
Property Value
| Type | Description |
|---|---|
| uint |