Class BaseLedgerEntry
Inheritance
object
BaseLedgerEntry
Namespace: Xrpl.Models.Ledger
Assembly: Xrpl.dll
Syntax
public class BaseLedgerEntry
Properties
| Edit this page View SourceIndex
The unique ID for this ledger entry.
In JSON, this field is represented with different names depending on the context and API method.
(Note, even though this is specified as "optional" in the code, every ledger entry should have one unless it's legacy data from very early in the XRP Ledger's history.)
Declaration
[JsonPropertyName("index")]
public string Index { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
LedgerEntryType
Declaration
[JsonConverter(typeof(LedgerEntryTypeConverter))]
public LedgerEntryType LedgerEntryType { get; set; }
Property Value
| Type | Description |
|---|---|
| LedgerEntryType |
LedgerIndex
Declaration
[JsonPropertyName("LedgerIndex")]
public string LedgerIndex { get; set; }
Property Value
| Type | Description |
|---|---|
| string |