Class LOAmendments
The Amendments object type contains a list of Amendments that are currently active.
Inherited Members
Namespace: Xrpl.Models.Ledger
Assembly: Xrpl.dll
Syntax
public class LOAmendments : BaseLedgerEntry
Properties
| Edit this page View SourceAmendments
Array of 256-bit amendment IDs for all currently-enabled amendments.
If omitted, there are no enabled amendments.
Declaration
public List<string> Amendments { get; set; }
Property Value
| Type | Description |
|---|---|
| List<string> |
Flags
A bit-map of boolean flags.
No flags are defined for the Amendments object type, so this value is always 0.
Declaration
public uint? Flags { get; set; }
Property Value
| Type | Description |
|---|---|
| uint? |
Majorities
Array of objects describing the status of amendments that have majority support but are not yet enabled.
If omitted, there are no pending amendments with majority support.
Declaration
public List<Majority> Majorities { get; set; }
Property Value
| Type | Description |
|---|---|
| List<Majority> |
PreviousTxnID
The identifying hash of the transaction that most recently modified this object.
Declaration
[JsonPropertyName("PreviousTxnID")]
public string PreviousTxnID { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
PreviousTxnLgrSeq
The index of the ledger that contains the transaction that most recently modified this object.
Declaration
[JsonPropertyName("PreviousTxnLgrSeq")]
public uint? PreviousTxnLgrSeq { get; set; }
Property Value
| Type | Description |
|---|---|
| uint? |