Show / Hide Table of Contents

Class LOAmendments

The Amendments object type contains a list of Amendments that are currently active.

Inheritance
object
BaseLedgerEntry
LOAmendments
Inherited Members
BaseLedgerEntry.LedgerEntryType
BaseLedgerEntry.Index
BaseLedgerEntry.LedgerIndex
Namespace: Xrpl.Models.Ledger
Assembly: Xrpl.dll
Syntax
public class LOAmendments : BaseLedgerEntry

Constructors

| Edit this page View Source

LOAmendments()

Declaration
public LOAmendments()

Properties

| Edit this page View Source

Amendments

Array of 256-bit amendment IDs for all currently-enabled amendments.
If omitted, there are no enabled amendments.

Declaration
public List<string> Amendments { get; set; }
Property Value
Type Description
List<string>
| Edit this page View Source

Flags

A bit-map of boolean flags.
No flags are defined for the Amendments object type, so this value is always 0.

Declaration
public uint Flags { get; set; }
Property Value
Type Description
uint
| Edit this page View Source

Majorities

Array of objects describing the status of amendments that have majority support but are not yet enabled.
If omitted, there are no pending amendments with majority support.

Declaration
public List<Majority> Majorities { get; set; }
Property Value
Type Description
List<Majority>
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX