Class LOAmm
Namespace: Xrpl.Models.Ledger
Assembly: Xrpl.dll
Syntax
public class LOAmm : BaseLedgerEntry
Constructors
| Edit this page View SourceLOAmm()
Declaration
public LOAmm()
Properties
| Edit this page View SourceAMMAccount
The account that tracks the balance of LPTokens between the AMM instance via Trustline.
Declaration
public string AMMAccount { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
Asset
Specifies one of the pool assets (XRP or token) of the AMM instance.
Declaration
[JsonConverter(typeof(CurrencyConverter))]
public Currency Asset { get; set; }
Property Value
| Type | Description |
|---|---|
| Currency |
Asset2
Specifies the other pool asset of the AMM instance.
Declaration
[JsonConverter(typeof(CurrencyConverter))]
public Currency Asset2 { get; set; }
Property Value
| Type | Description |
|---|---|
| Currency |
AuctionSlot
Details of the current owner of the auction slot.
Declaration
public AuctionSlot AuctionSlot { get; set; }
Property Value
| Type | Description |
|---|---|
| AuctionSlot |
LPTokenBalance
The total outstanding balance of liquidity provider tokens from this AMM instance.
The holders of these tokens can vote on the AMM's trading fee in proportion to their holdings,
or redeem the tokens for a share of the AMM's assets which grows with the trading fees collected.
Declaration
[JsonConverter(typeof(CurrencyConverter))]
public Currency LPTokenBalance { get; set; }
Property Value
| Type | Description |
|---|---|
| Currency |
LedgerCurrentIndex
The ledger index of the current in-progress ledger, which was used when retrieving this information.
Declaration
public int? LedgerCurrentIndex { get; set; }
Property Value
| Type | Description |
|---|---|
| int? |
TradingFee
Specifies the fee, in basis point, to be charged to the traders for the trades
executed against the AMM instance.
Trading fee is a percentage of the trading volume.
Valid values for this field are between 0 and 1000 inclusive.
A value of 1 is equivalent to 1/10 bps or 0.001%, allowing trading fee
between 0% and 1%.
This field is required.
Declaration
public uint TradingFee { get; set; }
Property Value
| Type | Description |
|---|---|
| uint |
Validated
True if this data is from a validated ledger version;
if omitted or set to false, this data is not final.
Declaration
public bool? Validated { get; set; }
Property Value
| Type | Description |
|---|---|
| bool? |
VoteSlots
A list of vote objects, representing votes on the pool's trading fee..
Declaration
public List<VoteEntry> VoteSlots { get; set; }
Property Value
| Type | Description |
|---|---|
| List<VoteEntry> |