Class LOBridge
A Bridge ledger object represents a single cross-chain bridge that connects and enables value to move efficiently between two blockchains.
Namespace: Xrpl.Models.Ledger
Assembly: Xrpl.dll
Syntax
public class LOBridge : BaseLedgerEntry
Constructors
| Edit this page View SourceLOBridge()
Declaration
public LOBridge()
Properties
| Edit this page View SourceAccount
The account that owns this bridge on this chain.
Declaration
[JsonPropertyName("Account")]
public string Account { get; init; }
Property Value
| Type | Description |
|---|---|
| string |
MinAccountCreateAmount
The minimum amount, in XRP, required for an XChainAccountCreateCommit transaction.
Declaration
[JsonPropertyName("MinAccountCreateAmount")]
[JsonConverter(typeof(CurrencyConverter))]
public Currency MinAccountCreateAmount { get; init; }
Property Value
| Type | Description |
|---|---|
| Currency |
OwnerNode
A hint indicating which page of the sender's owner directory links to this object.
Declaration
[JsonPropertyName("OwnerNode")]
public string OwnerNode { get; init; }
Property Value
| Type | Description |
|---|---|
| string |
PreviousTxnID
The identifying hash of the transaction that most recently modified this object.
Declaration
[JsonPropertyName("PreviousTxnID")]
public string PreviousTxnID { get; init; }
Property Value
| Type | Description |
|---|---|
| string |
PreviousTxnLgrSeq
The index of the ledger that contains the transaction that most recently modified this object.
Declaration
[JsonPropertyName("PreviousTxnLgrSeq")]
public uint? PreviousTxnLgrSeq { get; init; }
Property Value
| Type | Description |
|---|---|
| uint? |
SignatureReward
The total amount, in XRP, to be rewarded for providing a signature for cross-chain transfer or account creation.
Declaration
[JsonPropertyName("SignatureReward")]
[JsonConverter(typeof(CurrencyConverter))]
public Currency SignatureReward { get; init; }
Property Value
| Type | Description |
|---|---|
| Currency |
XChainAccountClaimCount
A counter representing the next account create count expected to be claimed.
Declaration
[JsonPropertyName("XChainAccountClaimCount")]
public string XChainAccountClaimCount { get; init; }
Property Value
| Type | Description |
|---|---|
| string |
XChainAccountCreateCount
A counter used to order the creation of new accounts.
Declaration
[JsonPropertyName("XChainAccountCreateCount")]
public string XChainAccountCreateCount { get; init; }
Property Value
| Type | Description |
|---|---|
| string |
XChainBridge
The bridge specification (door accounts and issued currencies).
Declaration
[JsonPropertyName("XChainBridge")]
public XChainBridgeModel XChainBridge { get; init; }
Property Value
| Type | Description |
|---|---|
| XChainBridgeModel |
XChainClaimID
A counter used to order the creation of new claim IDs.
Declaration
[JsonPropertyName("XChainClaimID")]
public string XChainClaimID { get; init; }
Property Value
| Type | Description |
|---|---|
| string |