Class LOCheck
A Check object describes a check, similar to a paper personal check, which can be cashed by its destination to get money from its sender.
Implements
Namespace: Xrpl.Models.Ledger
Assembly: Xrpl.dll
Syntax
public class LOCheck : BaseLedgerEntry, IDestination
Constructors
| Edit this page View SourceLOCheck()
Declaration
public LOCheck()
Properties
| Edit this page View SourceAccount
The sender of the Check. Cashing the Check debits this address's balance.
Declaration
public string Account { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
Destination
The intended recipient of the Check.Only this address can cash the Check, using a CheckCash transaction.
Declaration
public string Destination { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
DestinationNode
A hint indicating which page of the destination's owner directory links to this object, in case the directory consists of multiple pages.
Declaration
public string DestinationNode { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
DestinationTag
An arbitrary tag to further specify the destination for this Check, such as a hosted recipient at the destination address.
Declaration
public uint? DestinationTag { get; set; }
Property Value
| Type | Description |
|---|---|
| uint? |
Expiration
Indicates the time after which this Check is considered expired.
Declaration
[JsonConverter(typeof(RippleDateTimeConverter))]
public DateTime? Expiration { get; set; }
Property Value
| Type | Description |
|---|---|
| Nullable |
Flags
A bit-map of boolean flags.
No flags are defined for Checks, so this value is always 0.
Declaration
[JsonConverter(typeof(NumberOrStringConverter))]
public string Flags { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
InvoiceID
Arbitrary 256-bit hash provided by the sender as a specific reason or identifier for this Check.
Declaration
public string InvoiceID { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
OwnerNode
A hint indicating which page of the sender's owner directory links to this object, in case the directory consists of multiple pages.
Declaration
public string OwnerNode { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
PreviousTxnID
The identifying hash of the transaction that most recently modified this object.
Declaration
public string PreviousTxnID { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
PreviousTxnLgrSeq
The index of the ledger that contains the transaction that most recently modified this object.
Declaration
public uint PreviousTxnLgrSeq { get; set; }
Property Value
| Type | Description |
|---|---|
| uint |
SendMax
The maximum amount of currency this Check can debit the sender.
If the Check is successfully cashed,
the destination is credited in the same currency for up to this amount.
Declaration
[JsonConverter(typeof(CurrencyConverter))]
public Currency SendMax { get; set; }
Property Value
| Type | Description |
|---|---|
| Currency |
Sequence
The sequence number of the CheckCreate transaction that created this check.
Declaration
public uint Sequence { get; set; }
Property Value
| Type | Description |
|---|---|
| uint |
SourceTag
An arbitrary tag to further specify the source for this Check, such as a hosted recipient at the sender's address.
Declaration
public string SourceTag { get; set; }
Property Value
| Type | Description |
|---|---|
| string |