Class LOCredential
A Credential ledger entry represents a verifiable credential issued by one account (the issuer) to another (the subject). Credentials are used for on-chain identity verification and permissioned domain access control on the XRP Ledger.
Namespace: Xrpl.Models.Ledger
Assembly: Xrpl.dll
Syntax
public class LOCredential : BaseLedgerEntry
Constructors
| Edit this page View SourceLOCredential()
Declaration
public LOCredential()
Properties
| Edit this page View SourceCredentialType
A value identifying the type of credential, stored as a hex-encoded string. Automatically normalizes text input to hex on assignment.
Declaration
[JsonPropertyName("CredentialType")]
public string CredentialType { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
CredentialTypeValue
Decoded human-readable value of CredentialType (UTF-8, trimmed by 0x00).
Declaration
[JsonIgnore]
public string CredentialTypeValue { get; }
Property Value
| Type | Description |
|---|---|
| string |
Expiration
The time after which the credential expires, in seconds since the Ripple Epoch.
Declaration
[JsonPropertyName("Expiration")]
[JsonConverter(typeof(RippleDateTimeConverter))]
public DateTime? Expiration { get; set; }
Property Value
| Type | Description |
|---|---|
| Nullable |
Flags
A bit-map of boolean flags. See CredentialFlags.
Declaration
[JsonPropertyName("Flags")]
public uint Flags { get; set; }
Property Value
| Type | Description |
|---|---|
| uint |
Issuer
The account that issued the credential.
Declaration
[JsonPropertyName("Issuer")]
public string Issuer { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
IssuerNode
A hint indicating which page of the issuer's owner directory links to this entry.
Declaration
[JsonPropertyName("IssuerNode")]
public string IssuerNode { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
OwnerNode
A hint indicating which page of the owner directory links to this entry.
Declaration
[JsonPropertyName("OwnerNode")]
public string OwnerNode { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
PreviousTxnID
The identifying hash of the transaction that most recently modified this entry.
Declaration
[JsonPropertyName("PreviousTxnID")]
public string PreviousTxnID { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
PreviousTxnLgrSeq
The index of the ledger that contains the transaction that most recently modified this entry.
Declaration
[JsonPropertyName("PreviousTxnLgrSeq")]
public uint PreviousTxnLgrSeq { get; set; }
Property Value
| Type | Description |
|---|---|
| uint |
Subject
The account that is the subject (holder) of the credential.
Declaration
[JsonPropertyName("Subject")]
public string Subject { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
SubjectNode
A hint indicating which page of the subject's owner directory links to this entry.
Declaration
[JsonPropertyName("SubjectNode")]
public string SubjectNode { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
URI
An arbitrary URI reference for additional credential data, stored as a hex-encoded string. Automatically normalizes text input to hex on assignment.
Declaration
[JsonPropertyName("URI")]
public string URI { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
URIValue
Decoded human-readable value of URI (UTF-8, trimmed by 0x00).
Declaration
[JsonIgnore]
public string URIValue { get; }
Property Value
| Type | Description |
|---|---|
| string |