Show / Hide Table of Contents

Class LODelegate

A Delegate ledger object records which permissions have been granted by one account to another.

Inheritance
object
BaseLedgerEntry
LODelegate
Inherited Members
BaseLedgerEntry.LedgerEntryType
BaseLedgerEntry.Index
BaseLedgerEntry.LedgerIndex
Namespace: Xrpl.Models.Ledger
Assembly: Xrpl.dll
Syntax
public class LODelegate : BaseLedgerEntry

Constructors

| Edit this page View Source

LODelegate()

Declaration
public LODelegate()

Properties

| Edit this page View Source

Account

The account that granted the permissions.

Declaration
[JsonPropertyName("Account")]
public string Account { get; init; }
Property Value
Type Description
string
| Edit this page View Source

Delegate

The account that received the permissions.

Declaration
[JsonPropertyName("Delegate")]
public string Delegate { get; init; }
Property Value
Type Description
string
| Edit this page View Source

OwnerNode

A hint indicating which page of the owner's directory links to this object.

Declaration
[JsonPropertyName("OwnerNode")]
public string OwnerNode { get; init; }
Property Value
Type Description
string
| Edit this page View Source

Permissions

The permissions granted to the delegate.

Declaration
[JsonPropertyName("Permissions")]
public List<PermissionWrapper> Permissions { get; init; }
Property Value
Type Description
List<PermissionWrapper>
| Edit this page View Source

PreviousTxnID

The identifying hash of the transaction that most recently modified this object.

Declaration
[JsonPropertyName("PreviousTxnID")]
public string PreviousTxnID { get; init; }
Property Value
Type Description
string
| Edit this page View Source

PreviousTxnLgrSeq

The index of the ledger that contains the transaction that most recently modified this object.

Declaration
[JsonPropertyName("PreviousTxnLgrSeq")]
public uint? PreviousTxnLgrSeq { get; init; }
Property Value
Type Description
uint?
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX