Class LODelegate
A Delegate ledger object records which permissions have been granted by one account to another.
Namespace: Xrpl.Models.Ledger
Assembly: Xrpl.dll
Syntax
public class LODelegate : BaseLedgerEntry
Constructors
| Edit this page View SourceLODelegate()
Declaration
public LODelegate()
Properties
| Edit this page View SourceAccount
The account that granted the permissions.
Declaration
[JsonPropertyName("Account")]
public string Account { get; init; }
Property Value
| Type | Description |
|---|---|
| string |
Delegate
The account that received the permissions.
Declaration
[JsonPropertyName("Delegate")]
public string Delegate { get; init; }
Property Value
| Type | Description |
|---|---|
| string |
OwnerNode
A hint indicating which page of the owner's directory links to this object.
Declaration
[JsonPropertyName("OwnerNode")]
public string OwnerNode { get; init; }
Property Value
| Type | Description |
|---|---|
| string |
Permissions
The permissions granted to the delegate.
Declaration
[JsonPropertyName("Permissions")]
public List<PermissionWrapper> Permissions { get; init; }
Property Value
| Type | Description |
|---|---|
| List<PermissionWrapper> |
PreviousTxnID
The identifying hash of the transaction that most recently modified this object.
Declaration
[JsonPropertyName("PreviousTxnID")]
public string PreviousTxnID { get; init; }
Property Value
| Type | Description |
|---|---|
| string |
PreviousTxnLgrSeq
The index of the ledger that contains the transaction that most recently modified this object.
Declaration
[JsonPropertyName("PreviousTxnLgrSeq")]
public uint? PreviousTxnLgrSeq { get; init; }
Property Value
| Type | Description |
|---|---|
| uint? |