Show / Hide Table of Contents

Class LODirectoryNode

The DirectoryNode object type provides a list of links to other objects in the ledger's state tree.

Inheritance
object
BaseLedgerEntry
LODirectoryNode
Inherited Members
BaseLedgerEntry.LedgerEntryType
BaseLedgerEntry.Index
BaseLedgerEntry.LedgerIndex
Namespace: Xrpl.Models.Ledger
Assembly: Xrpl.dll
Syntax
public class LODirectoryNode : BaseLedgerEntry

Constructors

| Edit this page View Source

LODirectoryNode()

Declaration
public LODirectoryNode()

Properties

| Edit this page View Source

Flags

A bit-map of boolean flags enabled for this directory.Currently, the protocol defines no flags for DirectoryNode objects.

Declaration
public uint Flags { get; set; }
Property Value
Type Description
uint
| Edit this page View Source

IndexNext

If this Directory consists of multiple pages, this ID links to the next object in the chain, wrapping around at the end.

Declaration
public string IndexNext { get; set; }
Property Value
Type Description
string
| Edit this page View Source

IndexPrevious

If this Directory consists of multiple pages, this ID links to the previous object in the chain, wrapping around at the beginning.

Declaration
public string IndexPrevious { get; set; }
Property Value
Type Description
string
| Edit this page View Source

Indexes

The contents of this Directory: an array of IDs of other objects.

Declaration
public List<string> Indexes { get; set; }
Property Value
Type Description
List<string>
| Edit this page View Source

Owner

The address of the account that owns the objects in this directory.

Declaration
public string Owner { get; set; }
Property Value
Type Description
string
| Edit this page View Source

RootIndex

The ID of root object for this directory.

Declaration
public string RootIndex { get; set; }
Property Value
Type Description
string
| Edit this page View Source

TakerGetsCurrency

The currency code of the TakerGets amount from the offers in this directory.

Declaration
public string TakerGetsCurrency { get; set; }
Property Value
Type Description
string
| Edit this page View Source

TakerGetsIssuer

The issuer of the TakerGets amount from the offers in this directory.

Declaration
public string TakerGetsIssuer { get; set; }
Property Value
Type Description
string
| Edit this page View Source

TakerPaysCurrency

The currency code of the TakerPays amount from the offers in this directory.

Declaration
public string TakerPaysCurrency { get; set; }
Property Value
Type Description
string
| Edit this page View Source

TakerPaysIssuer

The issuer of the TakerPays amount from the offers in this directory.

Declaration
public string TakerPaysIssuer { get; set; }
Property Value
Type Description
string
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX