Show / Hide Table of Contents

Class LOFeeSettings

The FeeSettings object type contains the current base transaction cost and reserve amounts as determined by fee voting.

Inheritance
object
BaseLedgerEntry
LOFeeSettings
Inherited Members
BaseLedgerEntry.LedgerEntryType
BaseLedgerEntry.Index
BaseLedgerEntry.LedgerIndex
Namespace: Xrpl.Models.Ledger
Assembly: Xrpl.dll
Syntax
public class LOFeeSettings : BaseLedgerEntry

Constructors

| Edit this page View Source

LOFeeSettings()

Declaration
public LOFeeSettings()

Properties

| Edit this page View Source

BaseFee

The transaction cost of the "reference transaction" in drops of XRP as hexadecimal.

Declaration
public string BaseFee { get; set; }
Property Value
Type Description
string
| Edit this page View Source

Flags

A bit-map of boolean flags for this object.
No flags are defined for this type

Declaration
public uint Flags { get; set; }
Property Value
Type Description
uint
| Edit this page View Source

ReferenceFeeUnits

The BaseFee translated into "fee units".

Declaration
public uint ReferenceFeeUnits { get; set; }
Property Value
Type Description
uint
| Edit this page View Source

ReserveBase

The base reserve for an account in the XRP Ledger, as drops of XRP.

Declaration
public uint ReserveBase { get; set; }
Property Value
Type Description
uint
| Edit this page View Source

ReserveIncrement

The incremental owner reserve for owning objects, as drops of XRP.

Declaration
public uint ReserveIncrement { get; set; }
Property Value
Type Description
uint
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX