Class LOLedger
Response expected from a LedgerRequest. https://github.com/XRPLF/xrpl.js/blob/b20c05c3680d80344006d20c44b4ae1c3b0ffcac/packages/xrpl/src/models/methods/ledger.ts#L113
Namespace: Xrpl.Models.Ledger
Assembly: Xrpl.dll
Syntax
public class LOLedger : LOBaseLedger
Properties
| Edit this page View SourceLedgerEntity
The complete header data of this {@link Ledger}.
Declaration
[JsonPropertyName("ledger")]
[JsonConverter(typeof(LedgerBinaryConverter))]
public IBaseLedgerEntity LedgerEntity { get; set; }
Property Value
| Type | Description |
|---|---|
| IBaseLedgerEntity |
QueueData
Array of objects describing queued transactions, in the same order as the queue.
If the request specified expand as true, members contain full representations of the transactions,
in either JSON or binary depending on whether the request specified binary as true.
Declaration
[JsonPropertyName("queue_data")]
public List<QueuedTransaction>? QueueData { get; set; }
Property Value
| Type | Description |
|---|---|
| List<QueuedTransaction> |
Validated
If true, this is a validated ledger version. If omitted or set to false, this ledger's data is not final.
Declaration
[JsonPropertyName("validated")]
public bool Validated { get; set; }
Property Value
| Type | Description |
|---|---|
| bool |