Class LOLedgerData
The response expected from a LedgerDataRequest.
Inheritance
object
LOLedgerData
Namespace: Xrpl.Models.Ledger
Assembly: Xrpl.dll
Syntax
public class LOLedgerData
Properties
| Edit this page View SourceLedger
Declaration
[JsonPropertyName("ledger")]
public LedgerEntity Ledger { get; set; }
Property Value
| Type | Description |
|---|---|
| LedgerEntity |
LedgerHash
Unique identifying hash of this ledger version.
Declaration
[JsonPropertyName("ledger_hash")]
public string LedgerHash { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
LedgerIndex
The ledger index of this ledger version.
Declaration
[JsonPropertyName("ledger_index")]
public uint LedgerIndex { get; set; }
Property Value
| Type | Description |
|---|---|
| uint |
Marker
Server-defined value indicating the response is paginated.
Pass this to the next call to resume where this call left off.
Declaration
[JsonPropertyName("marker")]
public object Marker { get; set; }
Property Value
| Type | Description |
|---|---|
| object |
State
Array of JSON objects containing data from the ledger's state tree, as defined below.
Declaration
[JsonPropertyName("state")]
public List<BaseLedgerEntry> State { get; set; }
Property Value
| Type | Description |
|---|---|
| List<BaseLedgerEntry> |
Validated
True if this data is from a validated ledger version;
if omitted or set to false, this data is not final.
Declaration
[JsonPropertyName("validated")]
public bool? Validated { get; set; }
Property Value
| Type | Description |
|---|---|
| bool? |