Class LOLoanBroker
A LoanBroker ledger object represents a loan broker that manages lending pools and cover deposits.
Namespace: Xrpl.Models.Ledger
Assembly: Xrpl.dll
Syntax
public class LOLoanBroker : BaseLedgerEntry
Remarks
Requires the Loan amendment (XLS-66d). This feature is in draft and subject to change.
Constructors
| Edit this page View SourceLOLoanBroker()
Declaration
public LOLoanBroker()
Properties
| Edit this page View SourceAccount
The address of the LoanBroker pseudo-account.
Declaration
[JsonPropertyName("Account")]
public string Account { get; init; }
Property Value
| Type | Description |
|---|---|
| string |
CoverAvailable
Total amount of first-loss capital deposited (Number type, string representation).
Declaration
[JsonPropertyName("CoverAvailable")]
public string CoverAvailable { get; init; }
Property Value
| Type | Description |
|---|---|
| string |
CoverRateLiquidation
Minimum required first-loss capital moved to cover loan default.
Declaration
[JsonPropertyName("CoverRateLiquidation")]
public uint? CoverRateLiquidation { get; init; }
Property Value
| Type | Description |
|---|---|
| uint? |
CoverRateMinimum
Minimum first-loss capital coverage ratio, in 1/10th basis points.
Declaration
[JsonPropertyName("CoverRateMinimum")]
public uint? CoverRateMinimum { get; init; }
Property Value
| Type | Description |
|---|---|
| uint? |
Data
Arbitrary metadata about the loan broker, limited to 256 bytes. Hex-encoded string.
Declaration
[JsonPropertyName("Data")]
public string Data { get; init; }
Property Value
| Type | Description |
|---|---|
| string |
DebtMaximum
Protocol debt ceiling; 0 indicates unlimited (Number type, string representation).
Declaration
[JsonPropertyName("DebtMaximum")]
public string DebtMaximum { get; init; }
Property Value
| Type | Description |
|---|---|
| string |
DebtTotal
Total asset amount the protocol owes the vault, including interest (Number type, string representation).
Declaration
[JsonPropertyName("DebtTotal")]
public string DebtTotal { get; init; }
Property Value
| Type | Description |
|---|---|
| string |
LoanSequence
Sequential identifier for Loan ledger entries, incremented each time a new loan is created.
Declaration
[JsonPropertyName("LoanSequence")]
public uint? LoanSequence { get; init; }
Property Value
| Type | Description |
|---|---|
| uint? |
ManagementFeeRate
Protocol fee in 1/10th basis points (0-100000).
Declaration
[JsonPropertyName("ManagementFeeRate")]
public ushort? ManagementFeeRate { get; init; }
Property Value
| Type | Description |
|---|---|
| ushort? |
Owner
The account address of the vault owner.
Declaration
[JsonPropertyName("Owner")]
public string Owner { get; init; }
Property Value
| Type | Description |
|---|---|
| string |
OwnerCount
The number of active loans issued by the LoanBroker.
Declaration
[JsonPropertyName("OwnerCount")]
public uint? OwnerCount { get; init; }
Property Value
| Type | Description |
|---|---|
| uint? |
OwnerNode
A hint indicating which page of the owner's directory links to this object (UInt64).
Declaration
[JsonPropertyName("OwnerNode")]
public string OwnerNode { get; init; }
Property Value
| Type | Description |
|---|---|
| string |
PreviousTxnID
The identifying hash of the transaction that most recently modified this object.
Declaration
[JsonPropertyName("PreviousTxnID")]
public string PreviousTxnID { get; init; }
Property Value
| Type | Description |
|---|---|
| string |
PreviousTxnLgrSeq
The index of the ledger that contains the transaction that most recently modified this object.
Declaration
[JsonPropertyName("PreviousTxnLgrSeq")]
public uint? PreviousTxnLgrSeq { get; init; }
Property Value
| Type | Description |
|---|---|
| uint? |
Sequence
The transaction sequence number that created the LoanBroker.
Declaration
[JsonPropertyName("Sequence")]
public uint? Sequence { get; init; }
Property Value
| Type | Description |
|---|---|
| uint? |
VaultID
The associated vault identifier.
Declaration
[JsonPropertyName("VaultID")]
public string VaultID { get; init; }
Property Value
| Type | Description |
|---|---|
| string |
VaultNode
Reference page in vault's pseudo-account directory (UInt64).
Declaration
[JsonPropertyName("VaultNode")]
public string VaultNode { get; init; }
Property Value
| Type | Description |
|---|---|
| string |