Show / Hide Table of Contents

Class LOMPToken

The MPToken object represents an amount of an MPT held by an account that is not the issuer.

Inheritance
object
BaseLedgerEntry
LOMPToken
Inherited Members
BaseLedgerEntry.LedgerEntryType
BaseLedgerEntry.Index
BaseLedgerEntry.LedgerIndex
Namespace: Xrpl.Models.Ledger
Assembly: Xrpl.dll
Syntax
public class LOMPToken : BaseLedgerEntry

Constructors

| Edit this page View Source

LOMPToken()

Declaration
public LOMPToken()

Properties

| Edit this page View Source

Account

Owner (holder) of these MPTs. AccountID

Declaration
[JsonPropertyName("Account")]
public string Account { get; init; }
Property Value
Type Description
string
| Edit this page View Source

Flags

A bit-map of boolean flags enabled for this MPToken.

Declaration
public MPTokenFlags? Flags { get; set; }
Property Value
Type Description
MPTokenFlags?
| Edit this page View Source

LockedAmount

Amount of tokens currently locked (included in MPTAmount). UInt64 (0 .. 2^63-1) Requires TokenEscrow amendment. Optional

Declaration
[JsonPropertyName("LockedAmount")]
[JsonConverter(typeof(UInt64StringJsonConverter))]
public ulong? LockedAmount { get; init; }
Property Value
Type Description
ulong?
| Edit this page View Source

MPTAmount

Amount of tokens currently held by the owner. UInt64 (0 .. 2^63-1)

Declaration
[JsonPropertyName("MPTAmount")]
[JsonConverter(typeof(UInt64StringJsonConverter))]
public ulong? MPTAmount { get; init; }
Property Value
Type Description
ulong?
| Edit this page View Source

MPTokenIssuanceID

MPTokenIssuance identifier. UInt192 (hex)

Declaration
[JsonPropertyName("MPTokenIssuanceID")]
public string MPTokenIssuanceID { get; init; }
Property Value
Type Description
string
| Edit this page View Source

OwnerNode

Owner directory page hint. UInt64 (hex)

Declaration
[JsonPropertyName("OwnerNode")]
[JsonConverter(typeof(UInt64HexJsonConverter))]
public ulong? OwnerNode { get; init; }
Property Value
Type Description
ulong?
| Edit this page View Source

PreviousTxnID

Hash of the transaction that last modified this entry. UInt256

Declaration
[JsonPropertyName("PreviousTxnID")]
public string? PreviousTxnID { get; init; }
Property Value
Type Description
string
| Edit this page View Source

PreviousTxnLgrSeq

Ledger index of the previous modifying transaction. UInt32

Declaration
[JsonPropertyName("PreviousTxnLgrSeq")]
public uint? PreviousTxnLgrSeq { get; init; }
Property Value
Type Description
uint?
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX