Show / Hide Table of Contents

Class LONegativeUNL

The NegativeUNL object type contains the current status of the Negative UNL, a list of trusted validators currently believed to be offline.

Inheritance
object
BaseLedgerEntry
LONegativeUNL
Inherited Members
BaseLedgerEntry.LedgerEntryType
BaseLedgerEntry.Index
BaseLedgerEntry.LedgerIndex
Namespace: Xrpl.Models.Ledger
Assembly: Xrpl.dll
Syntax
public class LONegativeUNL : BaseLedgerEntry

Constructors

| Edit this page View Source

LONegativeUNL()

Declaration
public LONegativeUNL()

Properties

| Edit this page View Source

DisabledValidators

A list of trusted validators that are currently disabled.

Declaration
public List<DisabledValidator> DisabledValidators { get; set; }
Property Value
Type Description
List<DisabledValidator>
| Edit this page View Source

ValidatorToDisable

The public key of a trusted validator that is scheduled to be disabled in the next flag ledger.

Declaration
public string ValidatorToDisable { get; set; }
Property Value
Type Description
string
| Edit this page View Source

ValidatorToReEnable

The public key of a trusted validator in the Negative UNL that is scheduled to be re-enabled in the next flag ledger.

Declaration
public string ValidatorToReEnable { get; set; }
Property Value
Type Description
string
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX