Class LONegativeUNL
The NegativeUNL object type contains the current status of the Negative UNL, a list of trusted validators currently believed to be offline.
Namespace: Xrpl.Models.Ledger
Assembly: Xrpl.dll
Syntax
public class LONegativeUNL : BaseLedgerEntry
Constructors
| Edit this page View SourceLONegativeUNL()
Declaration
public LONegativeUNL()
Properties
| Edit this page View SourceDisabledValidators
A list of trusted validators that are currently disabled.
Declaration
public List<DisabledValidator> DisabledValidators { get; set; }
Property Value
| Type | Description |
|---|---|
| List<DisabledValidator> |
ValidatorToDisable
The public key of a trusted validator that is scheduled to be disabled in the next flag ledger.
Declaration
public string ValidatorToDisable { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
ValidatorToReEnable
The public key of a trusted validator in the Negative UNL that is scheduled to be re-enabled in the next flag ledger.
Declaration
public string ValidatorToReEnable { get; set; }
Property Value
| Type | Description |
|---|---|
| string |