Class LOOracle
An Oracle ledger entry holds data associated with a single price oracle, which can store information on up to 10 asset pairs.
Namespace: Xrpl.Models.Ledger
Assembly: Xrpl.dll
Syntax
public class LOOracle : BaseLedgerEntry
Constructors
| Edit this page View SourceLOOracle()
Initializes a new instance of the LOOracle class.
Declaration
public LOOracle()
Properties
| Edit this page View SourceAssetClass
Describes the type of asset, such as "currency", "commodity", or "index". Must be formatted as hexadecimal representing ASCII characters (0x20-0x7E), maximum 16 bytes.
Declaration
[JsonPropertyName("AssetClass")]
[JsonConverter(typeof(OracleHexStringConverter))]
public string AssetClass { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
Flags
A bit-map of boolean flags. No flags are defined for the Oracle object type, so this value is always 0.
Declaration
[JsonPropertyName("Flags")]
public uint Flags { get; set; }
Property Value
| Type | Description |
|---|---|
| uint |
LastUpdateTime
The time the data was last updated, represented in Unix time. Note: Unlike many other time values on the XRP Ledger, this value does not use the Ripple Epoch.
Declaration
[JsonPropertyName("LastUpdateTime")]
[JsonConverter(typeof(UnixDateTimeConverter))]
public DateTime? LastUpdateTime { get; set; }
Property Value
| Type | Description |
|---|---|
| Nullable |
Owner
The XRPL account with update and delete privileges for the oracle. It's recommended to set up multi-signing on this account.
Declaration
[JsonPropertyName("Owner")]
public string Owner { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
OwnerNode
A hint indicating which page of the oracle owner's owner directory links to this entry, in case the directory consists of multiple pages.
Declaration
[JsonPropertyName("OwnerNode")]
public string OwnerNode { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
PreviousTxnID
The hash of the previous transaction that modified this entry.
Declaration
[JsonPropertyName("PreviousTxnID")]
public string PreviousTxnID { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
PreviousTxnLgrSeq
The ledger index that this object was most recently modified or created in.
Declaration
[JsonPropertyName("PreviousTxnLgrSeq")]
public uint PreviousTxnLgrSeq { get; set; }
Property Value
| Type | Description |
|---|---|
| uint |
PriceDataSeries
An array of up to 10 PriceData objects, each representing the price information for an asset pair. More than five PriceData objects require two owner reserves.
Declaration
[JsonPropertyName("PriceDataSeries")]
public List<PriceDataWrapper> PriceDataSeries { get; set; }
Property Value
| Type | Description |
|---|---|
| List<PriceDataWrapper> |
Provider
An arbitrary value that identifies an oracle provider, such as Chainlink, Band, or DIA. This field is a string, up to 256 ASCII hex encoded characters (0x20-0x7E).
Declaration
[JsonPropertyName("Provider")]
[JsonConverter(typeof(OracleHexStringConverter))]
public string Provider { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
URI
An optional Universal Resource Identifier to reference price data off-chain. This field is limited to 256 bytes.
Declaration
[JsonPropertyName("URI")]
[JsonConverter(typeof(OracleHexStringConverter))]
public string URI { get; set; }
Property Value
| Type | Description |
|---|---|
| string |