Class LOSponsorship
A Sponsorship ledger object records a sponsorship relationship between a sponsor (Owner) and a sponsee: which fees and reserves the sponsor covers.
Namespace: Xrpl.Models.Ledger
Assembly: Xrpl.dll
Syntax
public class LOSponsorship : BaseLedgerEntry
Remarks
Requires the Sponsor amendment (XLS-68).
Constructors
| Edit this page View SourceLOSponsorship()
Declaration
public LOSponsorship()
Properties
| Edit this page View SourceFeeAmount
The remaining amount of fees the sponsor covers.
Declaration
[JsonPropertyName("FeeAmount")]
[JsonConverter(typeof(CurrencyConverter))]
public Currency FeeAmount { get; init; }
Property Value
| Type | Description |
|---|---|
| Currency |
Flags
A bit-map of boolean flags (see SponsorshipFlags).
Declaration
[JsonPropertyName("Flags")]
public SponsorshipFlags Flags { get; init; }
Property Value
| Type | Description |
|---|---|
| SponsorshipFlags |
MaxFee
The maximum fee per transaction the sponsor covers.
Declaration
[JsonPropertyName("MaxFee")]
[JsonConverter(typeof(CurrencyConverter))]
public Currency MaxFee { get; init; }
Property Value
| Type | Description |
|---|---|
| Currency |
Owner
The sponsoring account.
Declaration
[JsonPropertyName("Owner")]
public string Owner { get; init; }
Property Value
| Type | Description |
|---|---|
| string |
OwnerNode
A hint indicating which page of the owner's directory links to this object.
Declaration
[JsonPropertyName("OwnerNode")]
public string OwnerNode { get; init; }
Property Value
| Type | Description |
|---|---|
| string |
PreviousTxnID
The identifying hash of the transaction that most recently modified this object.
Declaration
[JsonPropertyName("PreviousTxnID")]
public string PreviousTxnID { get; init; }
Property Value
| Type | Description |
|---|---|
| string |
PreviousTxnLgrSeq
The index of the ledger that contains the transaction that most recently modified this object.
Declaration
[JsonPropertyName("PreviousTxnLgrSeq")]
public uint? PreviousTxnLgrSeq { get; init; }
Property Value
| Type | Description |
|---|---|
| uint? |
RemainingOwnerCount
The remaining number of owner-reserve slots the sponsor covers.
Declaration
[JsonPropertyName("RemainingOwnerCount")]
public uint? RemainingOwnerCount { get; init; }
Property Value
| Type | Description |
|---|---|
| uint? |
Sponsee
The sponsored account.
Declaration
[JsonPropertyName("Sponsee")]
public string Sponsee { get; init; }
Property Value
| Type | Description |
|---|---|
| string |
SponseeNode
A hint indicating which page of the sponsee's directory links to this object.
Declaration
[JsonPropertyName("SponseeNode")]
public string SponseeNode { get; init; }
Property Value
| Type | Description |
|---|---|
| string |