Show / Hide Table of Contents

Class LOVault

A Vault ledger object represents a pooled asset vault.

Inheritance
object
BaseLedgerEntry
LOVault
Inherited Members
BaseLedgerEntry.LedgerEntryType
BaseLedgerEntry.Index
BaseLedgerEntry.LedgerIndex
Namespace: Xrpl.Models.Ledger
Assembly: Xrpl.dll
Syntax
public class LOVault : BaseLedgerEntry
Remarks

Requires the Vault amendment (XLS-65d). This feature is in draft and subject to change.

Constructors

| Edit this page View Source

LOVault()

Declaration
public LOVault()

Properties

| Edit this page View Source

Account

The address of the vault's pseudo-account.

Declaration
[JsonPropertyName("Account")]
public string Account { get; init; }
Property Value
Type Description
string
| Edit this page View Source

Asset

The primary asset held by the vault. Supports XRP, trust line tokens, and MPTs.

Declaration
[JsonPropertyName("Asset")]
[JsonConverter(typeof(IssuedCurrencyConverter))]
public Common.IssuedCurrency Asset { get; init; }
Property Value
Type Description
Common.IssuedCurrency
| Edit this page View Source

AssetsAvailable

The asset amount that is available in the vault (STNumber type, serialized as string in JSON).

Declaration
[JsonPropertyName("AssetsAvailable")]
public string AssetsAvailable { get; init; }
Property Value
Type Description
string
| Edit this page View Source

AssetsMaximum

The maximum amount of assets the vault can hold, or 0 for no limit (STNumber type).

Declaration
[JsonPropertyName("AssetsMaximum")]
public string AssetsMaximum { get; init; }
Property Value
Type Description
string
| Edit this page View Source

AssetsTotal

The total value of the vault (STNumber type, serialized as string in JSON).

Declaration
[JsonPropertyName("AssetsTotal")]
public string AssetsTotal { get; init; }
Property Value
Type Description
string
| Edit this page View Source

Data

Arbitrary hex-encoded data associated with the vault, limited to 256 bytes. Use DataParsed for a human-readable representation.

Declaration
[JsonPropertyName("Data")]
public string Data { get; init; }
Property Value
Type Description
string
| Edit this page View Source

DataParsed

Decoded human-readable value of the Data field. Follows the recommended format: {"n":"name","w":"website"}. Returns null if parsing fails or Data is empty.

Declaration
[JsonIgnore]
public VaultDataFormat DataParsed { get; }
Property Value
Type Description
VaultDataFormat
| Edit this page View Source

DataRaw

Decoded human-readable UTF-8 string of the Data field.

Declaration
[JsonIgnore]
public string DataRaw { get; }
Property Value
Type Description
string
| Edit this page View Source

DomainID

The ID of a permissioned domain associated with the vault.

Declaration
[JsonPropertyName("DomainID")]
public string DomainID { get; init; }
Property Value
Type Description
string
| Edit this page View Source

LossUnrealized

The potential loss amount that is not yet realized, expressed as the vault's asset (STNumber type).

Declaration
[JsonPropertyName("LossUnrealized")]
public string LossUnrealized { get; init; }
Property Value
Type Description
string
| Edit this page View Source

Owner

The account address of the Vault Owner.

Declaration
[JsonPropertyName("Owner")]
public string Owner { get; init; }
Property Value
Type Description
string
| Edit this page View Source

OwnerNode

A hint indicating which page of the owner's directory links to this object (UInt64).

Declaration
[JsonPropertyName("OwnerNode")]
public string OwnerNode { get; init; }
Property Value
Type Description
string
| Edit this page View Source

PreviousTxnID

The identifying hash of the transaction that most recently modified this object.

Declaration
[JsonPropertyName("PreviousTxnID")]
public string PreviousTxnID { get; init; }
Property Value
Type Description
string
| Edit this page View Source

PreviousTxnLgrSeq

The index of the ledger that contains the transaction that most recently modified this object.

Declaration
[JsonPropertyName("PreviousTxnLgrSeq")]
public uint? PreviousTxnLgrSeq { get; init; }
Property Value
Type Description
uint?
| Edit this page View Source

Scale

The scale (decimal precision) for share calculations. 0-18 for trust line tokens; fixed at 0 for XRP/MPTs.

Declaration
[JsonPropertyName("Scale")]
public uint? Scale { get; init; }
Property Value
Type Description
uint?
| Edit this page View Source

Sequence

The transaction sequence number that created the vault.

Declaration
[JsonPropertyName("Sequence")]
public uint? Sequence { get; init; }
Property Value
Type Description
uint?
| Edit this page View Source

ShareMPTID

The identifier of the share MPTokenIssuance object.

Declaration
[JsonPropertyName("ShareMPTID")]
public string ShareMPTID { get; init; }
Property Value
Type Description
string
| Edit this page View Source

WithdrawalPolicy

The withdrawal policy for the vault (UInt8).

Declaration
[JsonPropertyName("WithdrawalPolicy")]
public uint? WithdrawalPolicy { get; init; }
Property Value
Type Description
uint?
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX