Class LOXChainOwnedClaimID
An XChainOwnedClaimID ledger object represents one cross-chain transfer of value and includes information of the value locked on the source chain.
Namespace: Xrpl.Models.Ledger
Assembly: Xrpl.dll
Syntax
public class LOXChainOwnedClaimID : BaseLedgerEntry
Constructors
| Edit this page View SourceLOXChainOwnedClaimID()
Declaration
public LOXChainOwnedClaimID()
Properties
| Edit this page View SourceAccount
The account that owns this claim ID.
Declaration
[JsonPropertyName("Account")]
public string Account { get; init; }
Property Value
| Type | Description |
|---|---|
| string |
OtherChainSource
The account that must send the corresponding XChainCommit on the source chain.
Declaration
[JsonPropertyName("OtherChainSource")]
public string OtherChainSource { get; init; }
Property Value
| Type | Description |
|---|---|
| string |
OwnerNode
A hint indicating which page of the sender's owner directory links to this object.
Declaration
[JsonPropertyName("OwnerNode")]
public string OwnerNode { get; init; }
Property Value
| Type | Description |
|---|---|
| string |
PreviousTxnID
The identifying hash of the transaction that most recently modified this object.
Declaration
[JsonPropertyName("PreviousTxnID")]
public string PreviousTxnID { get; init; }
Property Value
| Type | Description |
|---|---|
| string |
PreviousTxnLgrSeq
The index of the ledger that contains the transaction that most recently modified this object.
Declaration
[JsonPropertyName("PreviousTxnLgrSeq")]
public uint? PreviousTxnLgrSeq { get; init; }
Property Value
| Type | Description |
|---|---|
| uint? |
SignatureReward
The total amount to be rewarded for providing attestation signatures.
Declaration
[JsonPropertyName("SignatureReward")]
[JsonConverter(typeof(CurrencyConverter))]
public Currency SignatureReward { get; init; }
Property Value
| Type | Description |
|---|---|
| Currency |
XChainBridge
The bridge specification.
Declaration
[JsonPropertyName("XChainBridge")]
public XChainBridgeModel XChainBridge { get; init; }
Property Value
| Type | Description |
|---|---|
| XChainBridgeModel |
XChainClaimAttestations
Attestations collected from the witness servers.
Declaration
[JsonPropertyName("XChainClaimAttestations")]
public List<XChainClaimAttestationCollectionElement> XChainClaimAttestations { get; init; }
Property Value
| Type | Description |
|---|---|
| List<XChainClaimAttestationCollectionElement> |
XChainClaimID
The unique sequence number for the cross-chain claim.
Declaration
[JsonPropertyName("XChainClaimID")]
public string XChainClaimID { get; init; }
Property Value
| Type | Description |
|---|---|
| string |