Class LOXChainOwnedCreateAccountClaimID
An XChainOwnedCreateAccountClaimID ledger object represents one cross-chain account create transaction and collects attestations for it.
Namespace: Xrpl.Models.Ledger
Assembly: Xrpl.dll
Syntax
public class LOXChainOwnedCreateAccountClaimID : BaseLedgerEntry
Constructors
| Edit this page View SourceLOXChainOwnedCreateAccountClaimID()
Declaration
public LOXChainOwnedCreateAccountClaimID()
Properties
| Edit this page View SourceAccount
The account that owns this object.
Declaration
[JsonPropertyName("Account")]
public string Account { get; init; }
Property Value
| Type | Description |
|---|---|
| string |
OwnerNode
A hint indicating which page of the sender's owner directory links to this object.
Declaration
[JsonPropertyName("OwnerNode")]
public string OwnerNode { get; init; }
Property Value
| Type | Description |
|---|---|
| string |
PreviousTxnID
The identifying hash of the transaction that most recently modified this object.
Declaration
[JsonPropertyName("PreviousTxnID")]
public string PreviousTxnID { get; init; }
Property Value
| Type | Description |
|---|---|
| string |
PreviousTxnLgrSeq
The index of the ledger that contains the transaction that most recently modified this object.
Declaration
[JsonPropertyName("PreviousTxnLgrSeq")]
public uint? PreviousTxnLgrSeq { get; init; }
Property Value
| Type | Description |
|---|---|
| uint? |
XChainAccountCreateCount
An integer that determines the order that accounts created through cross-chain transfers must be performed.
Declaration
[JsonPropertyName("XChainAccountCreateCount")]
public string XChainAccountCreateCount { get; init; }
Property Value
| Type | Description |
|---|---|
| string |
XChainBridge
The bridge specification.
Declaration
[JsonPropertyName("XChainBridge")]
public XChainBridgeModel XChainBridge { get; init; }
Property Value
| Type | Description |
|---|---|
| XChainBridgeModel |
XChainCreateAccountAttestations
Attestations collected from the witness servers for the account creation.
Declaration
[JsonPropertyName("XChainCreateAccountAttestations")]
public List<XChainCreateAccountAttestationCollectionElement> XChainCreateAccountAttestations { get; init; }
Property Value
| Type | Description |
|---|---|
| List<XChainCreateAccountAttestationCollectionElement> |