Show / Hide Table of Contents

Class LedgerTransaction

Inheritance
object
LedgerTransaction
Namespace: Xrpl.Models.Ledger
Assembly: Xrpl.dll
Syntax
public class LedgerTransaction

Properties

| Edit this page View Source

CloseTimeIso

The ledger close time represented in ISO 8601 time format.

Declaration
[JsonPropertyName("close_time_iso")]
[JsonConverter(typeof(FromStringDateTimeConverter))]
public DateTime? CloseTimeIso { get; set; }
Property Value
Type Description
Nullable
| Edit this page View Source

Hash

Unique hashed String representing the transaction.

Declaration
[JsonPropertyName("hash")]
public string Hash { get; set; }
Property Value
Type Description
string
| Edit this page View Source

LedgerHash

A hex string of the ledger version that included this transaction.

Declaration
[JsonPropertyName("ledger_hash")]
public string LedgerHash { get; set; }
Property Value
Type Description
string
| Edit this page View Source

LedgerIndex

The ledger index of the ledger version that included this transaction.

Declaration
[JsonPropertyName("ledger_index")]
public ulong? LedgerIndex { get; set; }
Property Value
Type Description
ulong?
| Edit this page View Source

Meta

If binary is True, then this is a hex string of the transaction metadata.
Otherwise, the transaction metadata is included in JSON format.

Declaration
[JsonPropertyName("meta")]
[JsonConverter(typeof(MetaBinaryConverter))]
public Meta Meta { get; set; }
Property Value
Type Description
Meta
| Edit this page View Source

Transaction

JSON object defining the transaction.

Declaration
[JsonPropertyName("tx_json")]
[JsonConverter(typeof(TransactionRequestConverter))]
public ITransactionRequest Transaction { get; set; }
Property Value
Type Description
ITransactionRequest
| Edit this page View Source

Validated

Whether or not the transaction is included in a validated ledger.
Any transaction not yet in a validated ledger is subject to change.

Declaration
[JsonPropertyName("validated")]
public bool Validated { get; set; }
Property Value
Type Description
bool
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX