Enum LoanFlags
Flags of a Loan ledger object.
Namespace: Xrpl.Models.Ledger
Assembly: Xrpl.dll
Syntax
[Flags]
public enum LoanFlags : uint
Fields
| Name | Description |
|---|---|
| lsfLoanDefault | The loan is in default: the borrower missed a payment past the grace period. |
| lsfLoanImpaired | The loan is impaired: the broker expects it not to be repaid in full. |
| lsfLoanOverpayment | The loan allows overpayments. |