Enum MPTokenFlags
Namespace: Xrpl.Models.Ledger
Assembly: Xrpl.dll
Syntax
[Flags]
public enum MPTokenFlags : uint
Fields
| Name | Description |
|---|---|
| lsfMPTAuthorized | (Only applicable for allow-listing) If set, indicates that the issuer has authorized the holder for the MPT. |
| lsfMPTLocked | If enabled, indicates that the MPT owned by this account is currently locked and cannot be used in any XRP transactions other than sending value back to the issuer. |