Enum RippleStateFlags
There are several options which can be either enabled or disabled for a trust line.
These options can be changed with a TrustSet transaction.
In the ledger, flags are represented as binary values that can be combined with bitwise-or operations.
The bit values for the flags in the ledger are different than the values used to enable or disable those flags in a transaction.
Ledger flags have names that begin with lsf.
Namespace: Xrpl.Models.Ledger
Assembly: Xrpl.dll
Syntax
[Flags]
public enum RippleStateFlags
Fields
| Name | Description |
|---|---|
| lsfAMMNode | This trust line holds one of the assets in an Automated Market Maker's pool; one of this trust line's accounts is the AMM, and the other is the issuer of the token. |
| lsfHighAuth | The high account has authorized the low account to hold tokens issued by the high account. |
| lsfHighDeepFreeze | The high account has deep-frozen the trust line, preventing the low account from sending and receiving the asset. |
| lsfHighFreeze | The high account has frozen the trust line, preventing the low account from transferring the asset. |
| lsfHighNoRipple | The high account has disabled rippling from this trust line. |
| lsfHighReserve | This RippleState object contributes to the high account's owner reserve. |
| lsfLowAuth | The low account has authorized the high account to hold tokens issued by the low account. |
| lsfLowDeepFreeze | The low account has deep-frozen the trust line, preventing the high account from sending and receiving the asset. |
| lsfLowFreeze | The low account has frozen the trust line, preventing the high account from transferring the asset. |
| lsfLowNoRipple | The low account has disabled rippling from this trust line. |
| lsfLowReserve | This RippleState object contributes to the low account's owner reserve. |