Namespace Xrpl.Models.Methods
Classes
AMMInfo
AMMInfoRequest
The amm_info command retrieves information about an AMM instance.
AMMInfoResponse
Response expected from an AMMInfoRequest.
AccountChannels
The expected response from an AccountChannelsRequest .
AccountChannelsRequest
The account_channels method returns information about an account's Payment Channels.
This includes only channels where the specified account is the channel's source, not the destination.
(A channel's "source" and "owner" are the same.)
All information retrieved is relative to a particular version of the ledger.
Returns an AccountChannels.
AccountCurrencies
The expected response from an AccountCurrenciesRequest.
AccountCurrenciesRequest
The account_currencies command retrieves a list of currencies that an account can send or receive, based on its trust lines.
Expects an AccountCurrencies
AccountInfo
Response expected from an AccountInfoRequest.
AccountInfoAccountFlags
AccountInfoRequest
The account_info command retrieves information about an account, its activity, and its XRP balance.
All information retrieved is relative to a particular version of the ledger. Returns an AccountInfo.
AccountLines
Response expected from an AccountLinesRequest.
AccountLinesRequest
The account_lines method returns information about an account's trust lines,
including balances in all non-XRP currencies and assets.
All information retrieved is relative to a particular version of the ledger.
Expects an AccountLines.
AccountNFTs
Response expected from an AccountNFTsRequest.
AccountNFTsRequest
The account_nfts method retrieves all of the NFTs currently owned by the specified account.
AccountObjects
Response expected from an AccountObjectsRequest.
AccountObjectsRequest
The account_objects command returns the raw ledger format for all objects owned by an account.
For a higher-level view of an account's trust lines and balances, see the account_lines method instead.
Expects a response in the form of an AccountObjects.
AccountOffers
Response expected from an form an AccountOffersRequest.
AccountOffersRequest
The account_offers method retrieves a list of offers made by a given account that are outstanding as of a particular ledger version.
Expects a response in the form of a AccountOffers.
AccountQueueData
Information about queued transactions sent by account.
This information describes the state of the local rippled server, which may be different from other servers in the peer-to-peer XRP Ledger network.
Some fields may be omitted because the values are calculated "lazily" by the queuing mechanism.
AccountQueueTransaction
Information about each queued transaction from address.
AccountTransactions
Expected response from an AccountTransactionsRequest.
AccountTransactionsRequest
The account_tx method retrieves a list of transactions that involved the specified account.
Expects a response in the form of a AccountTransactions.
AccountingStateInfo
AccountingStateSummary
A map of various server states with information about the time the server spends in each.
This can be useful for tracking the long-term health of your server's connectivity to the network.
AmmQuery
Retrieve an Automated Market Maker (AMM) object from the ledger. This is similar to amm_info method, but the ledger_entry version returns only the ledger entry as stored.
AuthorizedCredential
BaseLedgerRequest
BaseRequest
Book
Defines the order book for monitoring updates
BookCurrency
Order book currency
BookOffersRequest
The book_offers method retrieves a list of offers, also known as the order.
Book, between two currencies.
Returns an BookOffers.
Channel
Payment channel owned by account. https://xrpl.org/account_channels.html
ChannelAuthorizeRequest
The channel_authorize method creates a signature that can be used to redeem a specific amount of XRP from a payment channel.
The request must specify exactly one of secret, seed, seed_hex, or passphrase.
*** Warning: Do not send secret keys to untrusted servers or through unsecured network connections. ***
(This includes the secret, seed, seed_hex, or passphrase fields of this request.))
You should only use this method on a secure, encrypted network connection to a server you run or fully trust with your funds.
Otherwise, eavesdroppers could use your secret key to sign claims and take all the money from this payment channel and anything else using the same key pair.
See Set Up Secure Signing for instructions.
ChannelVerifyRequest
The channel_verify method checks the validity of a signature that can be used to redeem a specific amount of XRP from a payment channel.
Expects a response in the form of a ChannelVerifyResponse.
CredentialQuery
Specify the Credential to retrieve. If a string, must be the ledger entry ID of the entry, as hexadecimal.If an object, requires subject, issuer, and credential_type sub-fields.
DelegateQuery
DepositAuthorized
Response expected from a DepositAuthorizedRequest.
DepositAuthorizedRequest
The deposit_authorized command indicates whether one account is authorized to send payments
directly to another. See Deposit Authorization for information on how to require authorization to deliver
money to an account. Returns a DepositAuthorized.
DepositPreauthQuery
Specify the DepositPreauth to retrieve. If a string, must be the ledger entry ID of the DepositPreauth entry, as hexadecimal. If an object, requires owner sub-field and either authorized or authorize_credentials sub-field.
DirectoryQuery
The DirectoryNode to retrieve. If a string, must be the object ID of the
directory, as hexadecimal.If an object, requires either dir_root o
Owner as a sub-field, plus optionally a sub_index sub-field.
Drops
The transaction cost
EscrowQuery
The Escrow object to retrieve. If a string, must be the object ID of the escrow, as hexadecimal. If an object, requires owner and seq sub-fields.
FeatureInfo
Describes a single XRPL amendment (feature).
Depending on rippled version and node mode (validator / non-validator), the server may return either a minimal or an extended set of fields. This model is designed to be forward-compatible.
Fee
Response expected from a FeeRequest.
FeeRequest
The fee command reports the current state of the open-ledger requirements for the transaction cost.
This requires the FeeEscalation amendment to be enabled.
Expects a response in the form of a Fee.
GatewayBalancesRequest
The gateway_balances command calculates the total balances issued by a given account, optionally excluding amounts held by operational addresses.
Expects a response in the form of a GatewayBalancesResponse.
GatewayBalancesResponse
Expected response from a GatewayBalancesRequest.
Info
JobType
(Admin only) Detailed information about the current load state of the server.
LONFTokenOffer
LONFTokenPage
LastClose
Information about the last time the server closed a ledger, including the amount of time it took to reach a consensus and the number of trusted validators participating.
LedgerClosedRequest
The ledger_closed method returns the unique identifiers of the most recently closed ledger.
Expects a response in the form of a LOBaseLedger.
LedgerCurrentRequest
The ledger_current method returns the unique identifiers of the current in-progress ledger.
Expects a response in the form of a LOLedgerCurrentIndex
LedgerDataRequest
The ledger_data method retrieves contents of the specified ledger.
You can iterate through several calls to retrieve the entire contents of a single ledger version.
LedgerEntryRequest
The ledger_entry method returns a single ledger object from the XRP Ledger in its raw format.
Expects a response in the form of a LedgerEntryResponse.
LedgerRequest
Retrieve information about the public ledger.
Expects a response in the form.
LedgerStream
The ledger stream only sends ledgerClosed messages when the consensus process declares a new validated ledger.
The message identifies the ledger and provides some information about its contents.
https://xrpl.org/subscribe.html#ledger-stream
LedgerStreamResponse
This response mirrors the LedgerStream, except it does NOT include the 'type' nor 'txn_count' fields.
Levels
required transaction cost level
Load
(Admin only) Detailed information about the current load state of the server.
LoanBrokerQuery
Specify the LoanBroker to retrieve. If a string, must be the ledger entry ID of the LoanBroker, as hexadecimal. If an object, requires owner and seq sub-fields.
LoanQuery
Specify the Loan to retrieve. If a string, must be the ledger entry ID of the Loan, as hexadecimal. If an object, requires loan_broker_id and loan_seq sub-fields.
MPTokenQuery
Object specifying the MPToken object to retrieve.
The mpt_issuance_id and account sub-fields are required.
NFT
One NFToken that might be returned from an AccountNFTsRequest. https://xrpl.org/account_nfts.html#account_nfts
NFTBuyOffers
Response expected from an NFTBuyOffersRequest ..
NFTBuyOffersRequest
The nft_buy_offers method retrieves all of buy offers for the specified NFToken.
NFTOffer
NFTSellOffers
Response expected from an NFTSellOffersRequest .
NFTSellOffersRequest
The nft_sell_offers method retrieves all of sell offers for the specified NFToken.
NFToken
NoRippleCheck
Response expected by a NoRippleCheckRequest .
NoRippleCheckRequest
The noripple_check command provides a quick way to check the status of th default ripple field for an account and the No Ripple flag of its trust lines, compared with the recommended settings.
Expects a response in the form of an {@link NoRippleCheckResponse}.
Offer
offer made by account that is outstanding as of the requested ledger version.
OfferQuery
The Escrow object to retrieve. If a string, must be the object ID of the escrow, as hexadecimal. If an object, requires owner and seq sub-fields.
OracleQuery
The oracle identifier.
Path
A path set is an array.
Each member of the path set is another array that represents an individual path.
Each member of a path is an object that specifies the step.
PathAlternative
Each element in the alternatives array represents a path from one possible source currency to the destination account and currency.
PathFindCloseRequest
The path_find close sub-command instructs the server to stop sending information
about the current open pathfinding request.
WebSocket API only.
PathFindCreateRequest
The path_find create sub-command creates an ongoing request to find possible paths
along which a payment transaction could be made from one specified account such that
another account receives a desired amount of some currency.
WebSocket API only.
PathFindResponse
Response expected from a path_find create, close, or status request.
PathFindStatusRequest
The path_find status sub-command requests an immediate update about the client's
currently-open pathfinding request.
WebSocket API only.
PermissionedDomainQuery
Specify the PermissionedDomain to retrieve. If a string, must be the ledger entry ID of the entry, as hexadecimal. If an object, requires account and seq sub-fields.
PingRequest
The ping command returns an acknowledgement, so that clients can test the connection status and latency.
Expects a response in the form of a PingRequest.
PseudoAccountInfo
RandomRequest
The random command provides a random number to be used as a source of entropy for random number generation by clients.
Expects a response in the form of a RandomResponse.
RipplePathFindRequest
The ripple_path_find method is a simplified version of the path_find method
that provides a single response with a payment path you can use right away.
It is available in both the WebSocket and JSON-RPC APIs.
Returns a RipplePathFindResponse.
RipplePathFindResponse
Response expected from a RipplePathFindRequest.
RippleStateQuery
Object specifying the RippleState (trust line) object to retrieve.
The accounts and currency sub-fields are required to uniquely specify the rippleState entry to retrieve.
ServerFeatures
ServerFeaturesRequest
ServerInfo
ServerInfoRequest
The server_info command asks the server for a human-readable version of various information about the rippled server being queried.
Expects a response in the form of a {@link ServerInfoResponse}.
ServerState
ServerStateRequest
The server_info command asks the server for a human-readable version of various information about the rippled server being queried.
Expects a response in the form of a {@link ServerInfoResponse}.
SimulateRequest
The simulate method executes a dry run of any transaction type,
enabling you to preview the results and metadata of a transaction without committing them to the XRP Ledger.
Since this command never submits a transaction to the network, it doesn't incur any fees.
Expects a response in the form of a Submit .
SimulateResponse
SourceCurrency
A currency that the source account might want to spend.
State
StateLedger
Information about the most recent fully-validated ledger.
SubmitRequest
The submit method applies a transaction and sends it to the network to be confirmed and included in future ledgers.
Expects a response in the form of a Submit .
SubscribeRequest
The subscribe method requests periodic notifications from the server when certain events happen.
https://xrpl.org/subscribe.html
TakerAmount
TicketQuery
The Ticket object to retrieve. If a string, must be the object ID of the
Ticket, as hexadecimal.If an object, the owner and ticket_sequence
sub-fields are required to uniquely specify the Ticket entry.
TransactionSummary
TrustLine
Trust line objects.
TxRequest
The tx method retrieves information on a single transaction, by its identifying hash.
Expects a response in the form of a TxResponse.
UnsubscribeRequest
The unsubscribe command tells the server to stop sending messages for a particular subscription or set of subscriptions.
The parameters in the request are specified almost exactly like the parameters to the subscribe method,
except that they are used to define which subscriptions to end instead.
The rt_accounts and url parameters, and the rt_transactions stream name, are deprecated and may be removed without further notice.
The response follows the standard format, with a successful result containing no fields.
https://xrpl.org/unsubscribe.html
ValidatedLedger
Information about the most recent fully-validated ledger.
ValidationStream
The validations stream sends messages whenever it receives validation messages, also called validation votes, regardless of whether or not the validation message is from a trusted validator. https://xrpl.org/subscribe.html#validations-stream
Interfaces
IAccountTransaction
Enums
NFTokenOffer
RoleType
Whether the address refers to a gateway or user.
Recommendations depend on the role of the account.
Issuers must have Default Ripple enabled and must disable No Ripple on all trust lines.
Users should have Default Ripple disabled, and should enable No Ripple on all trust lines.
ServerStateInner
Depending on how the rippled server is configured, how long it has been running, and other factors,
a server may be participating in the global XRP Ledger peer-to-peer network to different degrees.
This is represented as the server_state field in the responses to the server_info method and server_state method.
The possible responses follow a range of ascending interaction, with each later value superseding the previous one.
https://xrpl.org/rippled-server-states.html