Class AMMInfo
Inheritance
object
AMMInfo
Assembly: Xrpl.dll
Syntax
Properties
|
Edit this page
Account
The account that tracks the balance of LPTokens between the AMM instance via Trustline.
Declaration
[JsonPropertyName("account")]
public string Account { get; set; }
Property Value
|
Edit this page
Amount
Specifies one of the pool assets (XRP or token) of the AMM instance.
Declaration
[JsonPropertyName("amount")]
[JsonConverter(typeof(CurrencyConverter))]
public Currency Amount { get; set; }
Property Value
|
Edit this page
Amount2
Specifies the other pool asset of the AMM instance.
Declaration
[JsonPropertyName("amount2")]
[JsonConverter(typeof(CurrencyConverter))]
public Currency Amount2 { get; set; }
Property Value
|
Edit this page
Asset2Frozen
Declaration
[JsonPropertyName("asset2_frozen")]
public bool? Asset2Frozen { get; set; }
Property Value
|
Edit this page
AssetFrozen
Declaration
[JsonPropertyName("asset_frozen")]
public bool? AssetFrozen { get; set; }
Property Value
|
Edit this page
AuctionSlot
Details of the current owner of the auction slot.
Declaration
[JsonPropertyName("auction_slot")]
public AuctionSlot AuctionSlot { get; set; }
Property Value
|
Edit this page
LPTokenBalance
The total outstanding balance of liquidity provider tokens from this AMM instance.
The holders of these tokens can vote on the AMM's trading fee in proportion to their holdings,
or redeem the tokens for a share of the AMM's assets which grows with the trading fees collected.
Declaration
[JsonPropertyName("lp_token")]
[JsonConverter(typeof(CurrencyConverter))]
public Currency LPTokenBalance { get; set; }
Property Value
|
Edit this page
TradingFee
Specifies the fee, in basis point, to be charged to the traders for the trades
executed against the AMM instance.
Trading fee is a percentage of the trading volume.
Valid values for this field are between 0 and 1000 inclusive.
A value of 1 is equivalent to 1/10 bps or 0.001%, allowing trading fee
between 0% and 1%.
This field is required.
Declaration
[JsonPropertyName("trading_fee")]
public uint TradingFee { get; set; }
Property Value
|
Edit this page
VoteSlots
Keeps a track of up to eight active votes for the instance.
Declaration
[JsonPropertyName("vote_slots")]
public List<VoteEntry> VoteSlots { get; set; }
Property Value