Class AMMInfoResponse
Response expected from an AMMInfoRequest.
Inheritance
object
AMMInfoResponse
Namespace: Xrpl.Models.Methods
Assembly: Xrpl.dll
Syntax
public class AMMInfoResponse
Properties
| Edit this page View SourceAmm
Declaration
[JsonPropertyName("amm")]
public AMMInfo Amm { get; set; }
Property Value
| Type | Description |
|---|---|
| AMMInfo |
LedgerHash
The identifying hash of the ledger that was used to generate this response.
Declaration
[JsonPropertyName("ledger_hash")]
public string? LedgerHash { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
LedgerIndex
The ledger index of the ledger version that was used to generate this response.
Declaration
[JsonPropertyName("ledger_index")]
public int? LedgerIndex { get; set; }
Property Value
| Type | Description |
|---|---|
| int? |
Validated
True if this data is from a validated ledger version;
if omitted or set to false, this data is not final.
Declaration
[JsonPropertyName("validated")]
public bool? Validated { get; set; }
Property Value
| Type | Description |
|---|---|
| bool? |