Class AccountCurrencies
The expected response from an AccountCurrenciesRequest.
Inheritance
object
AccountCurrencies
Namespace: Xrpl.Models.Methods
Assembly: Xrpl.dll
Syntax
public class AccountCurrencies
Properties
| Edit this page View SourceLedgerHash
The identifying hash of the ledger version used to retrieve this data as hex.
Declaration
[JsonPropertyName("ledger_hash")]
public string LedgerHash { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
LedgerIndex
The ledger index of the ledger version used to retrieve this data.
Declaration
[JsonPropertyName("ledger_index")]
public int LedgerIndex { get; set; }
Property Value
| Type | Description |
|---|---|
| int |
ReceiveCurrencies
Array of Currency Codes for currencies that this account can receive.
Declaration
[JsonPropertyName("receive_currencies")]
public List<string> ReceiveCurrencies { get; set; }
Property Value
| Type | Description |
|---|---|
| List<string> |
SendCurrencies
Array of Currency Codes for currencies that this account can send.
Declaration
[JsonPropertyName("send_currencies")]
public List<string> SendCurrencies { get; set; }
Property Value
| Type | Description |
|---|---|
| List<string> |
Validated
If true, this data comes from a validated ledger.
Declaration
[JsonPropertyName("validated")]
public bool Validated { get; set; }
Property Value
| Type | Description |
|---|---|
| bool |