Class AccountInfoAccountFlags
Inheritance
object
AccountInfoAccountFlags
Assembly: Xrpl.dll
Syntax
public sealed class AccountInfoAccountFlags
Properties
|
Edit this page
AllowTrustLineClawback
This address can claw back issued IOUs. Once enabled, cannot be disabled.
Declaration
[JsonPropertyName("allowTrustLineClawback")]
public bool AllowTrustLineClawback { get; set; }
Property Value
|
Edit this page
AllowTrustLineLocking
Declaration
[JsonPropertyName("allowTrustLineLocking")]
public bool AllowTrustLineLocking { get; set; }
Property Value
|
Edit this page
DefaultRipple
Enable rippling on this address's trust lines by default. Required for issuing addresses; discouraged for others.
Declaration
[JsonPropertyName("defaultRipple")]
public bool DefaultRipple { get; set; }
Property Value
|
Edit this page
DepositAuth
This account can only receive funds from transactions it sends, and from preauthorized accounts. (DepositAuth enabled.)
Declaration
[JsonPropertyName("depositAuth")]
public bool DepositAuth { get; set; }
Property Value
|
Edit this page
DisableMasterKey
Disallows use of the master key to sign transactions for this account.
Declaration
[JsonPropertyName("disableMasterKey")]
public bool DisableMasterKey { get; set; }
Property Value
|
Edit this page
DisallowIncomingCheck
Disallow incoming Checks from other accounts. (DisallowIncoming amendment)
Declaration
[JsonPropertyName("disallowIncomingCheck")]
public bool? DisallowIncomingCheck { get; set; }
Property Value
|
Edit this page
DisallowIncomingNFTokenOffer
Disallow incoming NFTOffers from other accounts. (DisallowIncoming amendment)
Declaration
[JsonPropertyName("disallowIncomingNFTokenOffer")]
public bool? DisallowIncomingNFTokenOffer { get; set; }
Property Value
|
Edit this page
DisallowIncomingPayChan
Disallow incoming PayChannels from other accounts. (DisallowIncoming amendment)
Declaration
[JsonPropertyName("disallowIncomingPayChan")]
public bool? DisallowIncomingPayChan { get; set; }
Property Value
|
Edit this page
DisallowIncomingTrustline
Disallow incoming Trustlines from other accounts. (DisallowIncoming amendment)
Declaration
[JsonPropertyName("disallowIncomingTrustline")]
public bool? DisallowIncomingTrustline { get; set; }
Property Value
|
Edit this page
DisallowIncomingXRP
Client applications should not send XRP to this account. Not enforced by rippled.
Declaration
[JsonPropertyName("disallowIncomingXRP")]
public bool DisallowIncomingXRP { get; set; }
Property Value
|
Edit this page
GlobalFreeze
All assets issued by this address are frozen.
Declaration
[JsonPropertyName("globalFreeze")]
public bool GlobalFreeze { get; set; }
Property Value
|
Edit this page
NoFreeze
This address cannot freeze trust lines connected to it. Once enabled, cannot be disabled.
Declaration
[JsonPropertyName("noFreeze")]
public bool NoFreeze { get; set; }
Property Value
|
Edit this page
PasswordSpent
The account has used its free SetRegularKey transaction.
Declaration
[JsonPropertyName("passwordSpent")]
public bool PasswordSpent { get; set; }
Property Value
|
Edit this page
RequireAuthorization
This account must individually approve other users for those users to hold this account's issued currencies.
Declaration
[JsonPropertyName("requireAuthorization")]
public bool RequireAuthorization { get; set; }
Property Value
|
Edit this page
RequireDestinationTag
Requires incoming payments to specify a Destination Tag.
Declaration
[JsonPropertyName("requireDestinationTag")]
public bool RequireDestinationTag { get; set; }
Property Value