Class AccountLinesRequest
The account_lines method returns information about an account's trust lines,
including balances in all non-XRP currencies and assets.
All information retrieved is relative to a particular version of the ledger.
Expects an AccountLines.
Inherited Members
Namespace: Xrpl.Models.Methods
Assembly: Xrpl.dll
Syntax
public class AccountLinesRequest : BaseLedgerRequest
Constructors
| Edit this page View SourceAccountLinesRequest(string)
Declaration
public AccountLinesRequest(string account)
Parameters
| Type | Name | Description |
|---|---|---|
| string | account |
Properties
| Edit this page View SourceAccount
A unique identifier for the account, most commonly the account's Address.
Declaration
[JsonPropertyName("account")]
public string Account { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
IgnoreDefault
If true, don't return trust lines where this account's side is in the default state. The default is false.
Declaration
[JsonPropertyName("ignore_default")]
public bool? IgnoreDefault { get; set; }
Property Value
| Type | Description |
|---|---|
| bool? |
Limit
Limit the number of trust lines to retrieve.
The server is not required to honor this value.
Must be within the inclusive range 10 to 400.
Declaration
[JsonPropertyName("limit")]
public int? Limit { get; set; }
Property Value
| Type | Description |
|---|---|
| int? |
Marker
Value from a previous paginated response.
Resume retrieving data where that response left off.
Declaration
[JsonPropertyName("marker")]
public object Marker { get; set; }
Property Value
| Type | Description |
|---|---|
| object |
Peer
The Address of a second account. If provided, show only lines of trust connecting the two accounts.
Declaration
[JsonPropertyName("peer")]
public string Peer { get; set; }
Property Value
| Type | Description |
|---|---|
| string |