Class AccountNFTs
Response expected from an AccountNFTsRequest.
Inheritance
object
AccountNFTs
Namespace: Xrpl.Models.Methods
Assembly: Xrpl.dll
Syntax
public class AccountNFTs
Properties
| Edit this page View SourceAccount
The account requested.
Declaration
[JsonPropertyName("account")]
public string Account { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
LedgerCurrentIndex
The ledger index of the current open ledger, which was used when retrieving this information.
Declaration
[JsonPropertyName("ledger_current_index")]
public uint? LedgerCurrentIndex { get; set; }
Property Value
| Type | Description |
|---|---|
| uint? |
Limit
The limit that was used to fulfill this request.
Declaration
[JsonPropertyName("limit")]
public int? Limit { get; set; }
Property Value
| Type | Description |
|---|---|
| int? |
Marker
Server-defined value indicating the response is paginated.
Pass this to the next call to resume where this call left off.
Omitted when there are No additional pages after this one.
Declaration
[JsonPropertyName("marker")]
public object Marker { get; set; }
Property Value
| Type | Description |
|---|---|
| object |
NFTs
A list of NFTs owned by the specified account.
Declaration
[JsonPropertyName("account_nfts")]
public List<NFT> NFTs { get; set; }
Property Value
| Type | Description |
|---|---|
| List<NFT> |
Validated
If true, this data comes from a validated ledger.
Declaration
[JsonPropertyName("validated")]
public bool Validated { get; set; }
Property Value
| Type | Description |
|---|---|
| bool |