Class AccountObjectsRequest
The account_objects command returns the raw ledger format for all objects owned by an account.
For a higher-level view of an account's trust lines and balances, see the account_lines method instead.
Expects a response in the form of an AccountObjects.
Inherited Members
Namespace: Xrpl.Models.Methods
Assembly: Xrpl.dll
Syntax
public class AccountObjectsRequest : BaseLedgerRequest
Constructors
| Edit this page View SourceAccountObjectsRequest(string)
Declaration
public AccountObjectsRequest(string account)
Parameters
| Type | Name | Description |
|---|---|---|
| string | account |
Properties
| Edit this page View SourceAccount
A unique identifier for the account, most commonly the account's address.
Declaration
[JsonPropertyName("account")]
public string Account { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
DeletionBlockersOnly
A 20-byte hex string for the ledger version to use.
Declaration
[JsonPropertyName("deletion_blockers_only")]
public bool DeletionBlockersOnly { get; set; }
Property Value
| Type | Description |
|---|---|
| bool |
Limit
The maximum number of objects to include in the results.
Must be within the inclusive range 10 to 400 on non-admin connections.
The default is 200.
Declaration
[JsonPropertyName("limit")]
public int Limit { get; set; }
Property Value
| Type | Description |
|---|---|
| int |
Marker
Value from a previous paginated response.
Resume retrieving data where that response left off.
Declaration
[JsonPropertyName("marker")]
public object Marker { get; set; }
Property Value
| Type | Description |
|---|---|
| object |
Type
If included, filter results to include only this type of ledger object.
The valid types are: Check , DepositPreauth, Escrow, Offer, PayChannel, SignerList, Ticket, and RippleState (trust line).
Declaration
[JsonPropertyName("type")]
[JsonConverter(typeof(LedgerEntryTypeConverter))]
public LedgerEntryType? Type { get; set; }
Property Value
| Type | Description |
|---|---|
| LedgerEntryType? |