Class AccountOffersRequest
The account_offers method retrieves a list of offers made by a given account that are outstanding as of a particular ledger version.
Expects a response in the form of a AccountOffers.
Inherited Members
Namespace: Xrpl.Models.Methods
Assembly: Xrpl.dll
Syntax
public class AccountOffersRequest : BaseLedgerRequest
Constructors
| Edit this page View SourceAccountOffersRequest(string)
Declaration
public AccountOffersRequest(string account)
Parameters
| Type | Name | Description |
|---|---|---|
| string | account |
Properties
| Edit this page View SourceAccount
A unique identifier for the account, most commonly the account's Address.
Declaration
[JsonPropertyName("account")]
public string Account { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
Limit
Limit the number of transactions to retrieve.
The server is not required to honor this value.
Must be within the inclusive range 10 to 400.
Declaration
[JsonPropertyName("limit")]
public int? Limit { get; set; }
Property Value
| Type | Description |
|---|---|
| int? |
Marker
Value from a previous paginated response.
Resume retrieving data where that response left off.
Declaration
[JsonPropertyName("marker")]
public object Marker { get; set; }
Property Value
| Type | Description |
|---|---|
| object |
Strict
If true, then the account field only accepts a public key or XRP Ledger address.
Otherwise, account can be a secret or passphrase (not recommended).
The default is false.
Declaration
[JsonPropertyName("strict")]
public bool Strict { get; set; }
Property Value
| Type | Description |
|---|---|
| bool |