Class AccountQueueTransaction
Information about each queued transaction from address.
Inheritance
object
AccountQueueTransaction
Namespace: Xrpl.Models.Methods
Assembly: Xrpl.dll
Syntax
public class AccountQueueTransaction
Properties
| Edit this page View SourceAuthChange
Whether this transaction changes this address's ways of authorizing transactions.
Declaration
[JsonPropertyName("auth_change")]
public bool AuthChange { get; set; }
Property Value
| Type | Description |
|---|---|
| bool |
Fee
The Transaction Cost of this transaction, in drops of XRP.
Declaration
[JsonPropertyName("fee")]
public string Fee { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
FeeLevel
The transaction cost of this transaction, relative to the minimum cost for this type of transaction, in fee levels.
Declaration
[JsonPropertyName("fee_level")]
public string FeeLevel { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
MaxSpendDrops
The maximum amount of XRP, in drops, this transaction could send or destroy.
Declaration
[JsonPropertyName("max_spend_drops")]
public string MaxSpendDrops { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
Sequence
The Sequence Number of this transaction.
Declaration
[JsonPropertyName("seq")]
public int Sequence { get; set; }
Property Value
| Type | Description |
|---|---|
| int |