Class AccountTransactions
Expected response from an AccountTransactionsRequest.
Inheritance
object
AccountTransactions
Namespace: Xrpl.Models.Methods
Assembly: Xrpl.dll
Syntax
public class AccountTransactions
Properties
| Edit this page View SourceAccount
Unique Address identifying the related account.
Declaration
[JsonPropertyName("account")]
public string Account { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
LedgerIndexMax
The ledger index of the most recent ledger actually searched for transactions.
Declaration
[JsonPropertyName("ledger_index_max")]
public uint LedgerIndexMax { get; set; }
Property Value
| Type | Description |
|---|---|
| uint |
LedgerIndexMin
The ledger index of the earliest ledger actually searched for transactions.
Declaration
[JsonPropertyName("ledger_index_min")]
public uint LedgerIndexMin { get; set; }
Property Value
| Type | Description |
|---|---|
| uint |
Limit
The limit value used in the request.
Declaration
[JsonPropertyName("limit")]
public int Limit { get; set; }
Property Value
| Type | Description |
|---|---|
| int |
Marker
Server-defined value indicating the response is paginated.
Pass this to the next call to resume where this call left off.
Declaration
[JsonPropertyName("marker")]
public object Marker { get; set; }
Property Value
| Type | Description |
|---|---|
| object |
Transactions
Array of transactions matching the request's criteria, as explained below.
Declaration
[JsonPropertyName("transactions")]
public List<TransactionSummary> Transactions { get; set; }
Property Value
| Type | Description |
|---|---|
| List<TransactionSummary> |
Validated
If included and set to true, the information in this response comes from a validated ledger version.
Otherwise, the information is subject to change.
Declaration
[JsonPropertyName("validated")]
public bool Validated { get; set; }
Property Value
| Type | Description |
|---|---|
| bool |