Class AccountTransactionsRequest
The account_tx method retrieves a list of transactions that involved the specified account.
Expects a response in the form of a AccountTransactions.
Inherited Members
Namespace: Xrpl.Models.Methods
Assembly: Xrpl.dll
Syntax
public class AccountTransactionsRequest : BaseLedgerRequest
Constructors
| Edit this page View SourceAccountTransactionsRequest(string)
Declaration
public AccountTransactionsRequest(string account)
Parameters
| Type | Name | Description |
|---|---|---|
| string | account |
Properties
| Edit this page View SourceAccount
A unique identifier for the account, most commonly the account's address.
Declaration
[JsonPropertyName("account")]
public string Account { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
Binary
If true, return transactions as hex strings instead of JSON.
The default is false.
Declaration
[JsonPropertyName("binary")]
public bool? Binary { get; set; }
Property Value
| Type | Description |
|---|---|
| bool? |
Forward
If true, returns values indexed with the oldest ledger first.
Otherwise, the results are indexed with the newest ledger first.
Declaration
[JsonPropertyName("forward")]
public bool? Forward { get; set; }
Property Value
| Type | Description |
|---|---|
| bool? |
LedgerIndexMax
Use to specify the most recent ledger to include transactions from.
A value of -1 instructs the server to use the most recent validated ledger version available.
Declaration
[JsonPropertyName("ledger_index_max")]
public int? LedgerIndexMax { get; set; }
Property Value
| Type | Description |
|---|---|
| int? |
LedgerIndexMin
Use to specify the earliest ledger to include transactions from.
A value of -1 instructs the server to use the earliest validated ledger version available.
Declaration
[JsonPropertyName("ledger_index_min")]
public int? LedgerIndexMin { get; set; }
Property Value
| Type | Description |
|---|---|
| int? |
Limit
Default varies.
Limit the number of transactions to retrieve.
The server is not required to honor this value.
Declaration
[JsonPropertyName("limit")]
public int? Limit { get; set; }
Property Value
| Type | Description |
|---|---|
| int? |
Marker
Value from a previous paginated response.
Resume retrieving data where that response left off.
This value is stable even if there is a change in the server's range of available ledgers.
Declaration
[JsonPropertyName("marker")]
public object Marker { get; set; }
Property Value
| Type | Description |
|---|---|
| object |
TxType
Optional) Clio Only Return only transactions of a specific type,
such as "Clawback", "AccountSet", "AccountDelete", et al. Case-insensitive.
Supports any transaction type except AMM* (See Transaction Types https://xrpl.org/transaction-types.html)
Declaration
[JsonPropertyName("tx_type")]
public string TxType { get; set; }
Property Value
| Type | Description |
|---|---|
| string |