Class BaseLedgerRequest
Inheritance
object
BaseLedgerRequest
Namespace: Xrpl.Models.Methods
Assembly: Xrpl.dll
Syntax
public class BaseLedgerRequest : BaseRequest
Constructors
| Edit this page View SourceBaseLedgerRequest()
Declaration
public BaseLedgerRequest()
BaseLedgerRequest(Guid)
Declaration
public BaseLedgerRequest(Guid requestId)
Parameters
| Type | Name | Description |
|---|---|---|
| Guid | requestId |
Properties
| Edit this page View SourceLedgerHash
20-byte hex string for the ledger version to use.
Declaration
[JsonPropertyName("ledger_hash")]
public string LedgerHash { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
LedgerIndex
The ledger index of the ledger to use, or a shortcut string to choose a ledger automatically.
Declaration
[JsonPropertyName("ledger_index")]
[JsonConverter(typeof(LedgerIndexConverter))]
public LedgerIndex LedgerIndex { get; set; }
Property Value
| Type | Description |
|---|---|
| LedgerIndex |