Class BaseRequest
Inheritance
object
BaseRequest
Namespace: Xrpl.Models.Methods
Assembly: Xrpl.dll
Syntax
public class BaseRequest
Constructors
| Edit this page View SourceBaseRequest()
Declaration
public BaseRequest()
BaseRequest(Guid)
Declaration
public BaseRequest(Guid id)
Parameters
| Type | Name | Description |
|---|---|---|
| Guid | id |
Properties
| Edit this page View SourceApiVersion
The API version to use.
If omitted, use version 1.
Declaration
[JsonPropertyName("api_version")]
public uint? ApiVersion { get; set; }
Property Value
| Type | Description |
|---|---|
| uint? |
Command
Declaration
[JsonPropertyName("command")]
public string Command { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
Id
A unique value to identify this request.
The response to this request uses the same id field.
This way, even if responses arrive out of order, you know which request prompted which response.
Declaration
[JsonPropertyName("id")]
public object? Id { get; set; }
Property Value
| Type | Description |
|---|---|
| object |