Class Book
Defines the order book for monitoring updates
Inheritance
Namespace: Xrpl.Models.Methods
Assembly: Xrpl.dll
Syntax
public class Book
Properties
| Edit this page View SourceBoth
(Optional) If true, return both sides of the order book. The default is false.
Declaration
[JsonPropertyName("both")]
public bool? Both { get; set; }
Property Value
| Type | Description |
|---|---|
| bool? |
Snapshot
(Optional) If true, return the current state of the order book once when you subscribe before sending updates. The default is false.
Declaration
[JsonPropertyName("snapshot")]
public bool? Snapshot { get; set; }
Property Value
| Type | Description |
|---|---|
| bool? |
Taker
Unique account address to use as a perspective for viewing offers, in the XRP Ledger's base58 format. (This affects the funding status and fees of Offers.)
Declaration
[JsonPropertyName("taker")]
public string Taker { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
TakerGets
Specification of which currency the account taking the Offer would receive, as a currency object with no amount.
Declaration
[JsonPropertyName("taker_gets")]
public BookCurrency TakerGets { get; set; }
Property Value
| Type | Description |
|---|---|
| BookCurrency |
TakerPays
Specification of which currency the account taking the Offer would pay, as a currency object with no amount.
Declaration
[JsonPropertyName("taker_pays")]
public BookCurrency TakerPays { get; set; }
Property Value
| Type | Description |
|---|---|
| BookCurrency |
Methods
| Edit this page View SourceEquals(object)
Determines whether the specified object is equal to the current object.
Declaration
public override bool Equals(object obj)
Parameters
| Type | Name | Description |
|---|---|---|
| object | obj | The object to compare with the current object. |
Returns
| Type | Description |
|---|---|
| bool | true if the specified object is equal to the current object; otherwise, false. |
Overrides
Equals(Book)
Indicates whether the current object is equal to another object of the same type.
Declaration
public bool Equals(Book other)
Parameters
| Type | Name | Description |
|---|---|---|
| Book | other | An object to compare with this object. |
Returns
| Type | Description |
|---|---|
| bool | true if the current object is equal to the |
GetHashCode()
Serves as the default hash function.
Declaration
public override int GetHashCode()
Returns
| Type | Description |
|---|---|
| int | A hash code for the current object. |