Class BookOffersRequest
The book_offers method retrieves a list of offers, also known as the order.
Book, between two currencies.
Returns an BookOffers.
Inherited Members
Namespace: Xrpl.Models.Methods
Assembly: Xrpl.dll
Syntax
public class BookOffersRequest : BaseLedgerRequest
Constructors
| Edit this page View SourceBookOffersRequest()
Declaration
public BookOffersRequest()
Properties
| Edit this page View SourceLimit
If provided, the server does not provide more than this many offers in the results.
The total number of results returned may be fewer than the limit, because the server omits unfunded offers.
Declaration
[JsonPropertyName("limit")]
public uint? Limit { get; set; }
Property Value
| Type | Description |
|---|---|
| uint? |
Taker
The Address of an account to use as a perspective.
Unfunded offers placed by this account are always included in the response.
Declaration
[JsonPropertyName("taker")]
public string Taker { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
TakerGets
Specification of which currency the account taking the offer would receive, as an object with currency and issuer fields (omit issuer for XRP), like currency amounts.
Declaration
[JsonPropertyName("taker_gets")]
public TakerAmount TakerGets { get; set; }
Property Value
| Type | Description |
|---|---|
| TakerAmount |
TakerPays
Specification of which currency the account taking the offer would pay, as an object with currency and issuer fields (omit issuer for XRP), like currency amounts.
Declaration
[JsonPropertyName("taker_pays")]
public TakerAmount TakerPays { get; set; }
Property Value
| Type | Description |
|---|---|
| TakerAmount |