Class ChannelAuthorizeResponse
Response expected from a ChannelAuthorizeRequest.
Inheritance
object
ChannelAuthorizeResponse
Namespace: Xrpl.Models.Methods
Assembly: Xrpl.dll
Syntax
public class ChannelAuthorizeResponse
Properties
| Edit this page View SourceSignature
The signature for this claim, as a hexadecimal value. To process the claim, the destination account of the payment channel must submit a PaymentChannelClaim transaction with this signature, the exact Channel ID, XRP amount, and public key of the channel.
Declaration
[JsonPropertyName("signature")]
public string Signature { get; set; }
Property Value
| Type | Description |
|---|---|
| string |