Class DepositAuthorizedRequest
The deposit_authorized command indicates whether one account is authorized to send payments
directly to another. See Deposit Authorization for information on how to require authorization to deliver
money to an account. Returns a DepositAuthorized.
Inherited Members
Namespace: Xrpl.Models.Methods
Assembly: Xrpl.dll
Syntax
public class DepositAuthorizedRequest : BaseLedgerRequest
Constructors
| Edit this page View SourceDepositAuthorizedRequest()
Declaration
public DepositAuthorizedRequest()
DepositAuthorizedRequest(string, string)
Declaration
public DepositAuthorizedRequest(string sourceAccount, string destinationAccount)
Parameters
| Type | Name | Description |
|---|---|---|
| string | sourceAccount | |
| string | destinationAccount |
Properties
| Edit this page View SourceCredentials
(Optional, XLS-70) Hex-encoded object IDs (64 hex chars each) of accepted Credentials objects to use for credential-based deposit preauthorization.
Declaration
[JsonPropertyName("credentials")]
public List<string> Credentials { get; set; }
Property Value
| Type | Description |
|---|---|
| List<string> |
DestinationAccount
The recipient of a possible payment.
Declaration
[JsonPropertyName("destination_account")]
public string DestinationAccount { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
SourceAccount
The sender of a possible payment.
Declaration
[JsonPropertyName("source_account")]
public string SourceAccount { get; set; }
Property Value
| Type | Description |
|---|---|
| string |