Class DirectoryQuery
The DirectoryNode to retrieve. If a string, must be the object ID of the
directory, as hexadecimal.If an object, requires either dir_root o
Owner as a sub-field, plus optionally a sub_index sub-field.
Inheritance
object
DirectoryQuery
Namespace: Xrpl.Models.Methods
Assembly: Xrpl.dll
Syntax
public class DirectoryQuery
Properties
| Edit this page View SourceDirRoot
Unique index identifying the directory to retrieve, as a hex string.
Declaration
[JsonPropertyName("dir_root")]
public string? DirRoot { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
Owner
Unique address of the account associated with this directory.
Declaration
[JsonPropertyName("owner")]
public string? Owner { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
SubIndex
If provided, jumps to a later "page" of the DirectoryNode.
Declaration
[JsonPropertyName("sub_index")]
public uint? SubIndex { get; set; }
Property Value
| Type | Description |
|---|---|
| uint? |