Class Fee
Response expected from a FeeRequest.
Inheritance
object
Fee
Namespace: Xrpl.Models.Methods
Assembly: Xrpl.dll
Syntax
public class Fee
Properties
| Edit this page View SourceCurrentLedgerSize
Number of transactions provisionally included in the in-progress ledger.
Declaration
[JsonPropertyName("current_ledger_size")]
[JsonConverter(typeof(GenericStringConverter<uint>))]
public uint CurrentLedgerSize { get; set; }
Property Value
| Type | Description |
|---|---|
| uint |
CurrentQueueSize
Number of transactions currently queued for the next ledger.
Declaration
[JsonPropertyName("current_queue_size")]
[JsonConverter(typeof(GenericStringConverter<uint>))]
public uint CurrentQueueSize { get; set; }
Property Value
| Type | Description |
|---|---|
| uint |
Drops
The transaction cost
Declaration
[JsonPropertyName("drops")]
public Drops Drops { get; set; }
Property Value
| Type | Description |
|---|---|
| Drops |
ExpectedLedgerSize
The approximate number of transactions expected to be included in the current ledger.
This is based on the number of transactions in the previous ledger.
Declaration
[JsonPropertyName("expected_ledger_size")]
[JsonConverter(typeof(GenericStringConverter<uint>))]
public uint ExpectedLedgerSize { get; set; }
Property Value
| Type | Description |
|---|---|
| uint |
LedgerCurrentIndex
The Ledger Index of the current open ledger these stats describe.
Declaration
[JsonPropertyName("ledger_current_index")]
[JsonConverter(typeof(GenericStringConverter<uint>))]
public uint LedgerCurrentIndex { get; set; }
Property Value
| Type | Description |
|---|---|
| uint |
Levels
required transaction cost level
Declaration
[JsonPropertyName("levels")]
public Levels Levels { get; set; }
Property Value
| Type | Description |
|---|---|
| Levels |
MaxQueueSize
The maximum number of transactions that the transaction queue can currently hold.
Declaration
[JsonPropertyName("max_queue_size")]
[JsonConverter(typeof(GenericStringConverter<uint>))]
public uint MaxQueueSize { get; set; }
Property Value
| Type | Description |
|---|---|
| uint |