Class GatewayBalancesResponse
Inheritance
object
GatewayBalancesResponse
Assembly: Xrpl.dll
Syntax
[JsonConverter(typeof(GatewayBalancesResponseConverter))]
public class GatewayBalancesResponse
Properties
|
Edit this page
Account
The address of the account that issued the balances.
Declaration
[JsonPropertyName("account")]
public string Account { get; set; }
Property Value
|
Edit this page
Assets
Total amounts held that are issued by others.
In the recommended configuration, the issuing address should have none.
Declaration
[JsonPropertyName("assets")]
public List<Currency> Assets { get; set; }
Property Value
|
Edit this page
Balances
Amounts issued to the hotwallet addresses from the request.
The keys are addresses and the values are arrays of currency amounts they hold.
Declaration
[JsonPropertyName("balances")]
public List<Currency> Balances { get; init; }
Property Value
|
Edit this page
FrozenBalances
Declaration
[JsonPropertyName("frozen_balances")]
public List<Currency> FrozenBalances { get; init; }
Property Value
|
Edit this page
LedgerHash
Declaration
[JsonPropertyName("ledger_hash")]
public string LedgerHash { get; set; }
Property Value
|
Edit this page
LedgerIndex
Declaration
[JsonPropertyName("ledger_index")]
public uint? LedgerIndex { get; set; }
Property Value
|
Edit this page
Obligations
Total amounts issued to addresses not excluded, as a map of currencies to the total value issued.
Declaration
[JsonPropertyName("obligations")]
public List<Currency> Obligations { get; init; }
Property Value
|
Edit this page
Validated
Declaration
[JsonPropertyName("validated")]
public bool? Validated { get; set; }
Property Value