Interface IAccountTransaction
Namespace: Xrpl.Models.Methods
Assembly: Xrpl.dll
Syntax
public interface IAccountTransaction
Properties
| Edit this page View SourceCloseTimeIso
The ledger close time represented in ISO 8601 time format.
Declaration
DateTime? CloseTimeIso { get; set; }
Property Value
| Type | Description |
|---|---|
| Nullable |
Hash
The unique hash identifier of the transaction.
Declaration
string Hash { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
LedgerHash
(Validated transactions only) The identifying hash of the ledger version that includes this transaction
Declaration
string LedgerHash { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
LedgerIndex
(Validated transactions only) The ledger index of the ledger version that includes this transaction.
Declaration
ulong? LedgerIndex { get; set; }
Property Value
| Type | Description |
|---|---|
| ulong? |
Meta
(Validated transactions only) The transaction metadata, which shows the exact outcome of the transaction in detail.
Declaration
Meta Meta { get; set; }
Property Value
| Type | Description |
|---|---|
| Meta |
Transaction
(JSON mode) JSON object defining the transaction.
Declaration
TransactionResponse Transaction { get; }
Property Value
| Type | Description |
|---|---|
| TransactionResponse |
Validated
If true, this transaction is included in a validated ledger and its outcome is final.
Responses from the transaction stream should always be validated.
Declaration
bool Validated { get; set; }
Property Value
| Type | Description |
|---|---|
| bool |