Class LONFTokenOffer
Implements
Namespace: Xrpl.Models.Methods
Assembly: Xrpl.dll
Syntax
public class LONFTokenOffer : BaseLedgerEntry, IDestination
Constructors
| Edit this page View SourceLONFTokenOffer()
Declaration
public LONFTokenOffer()
Properties
| Edit this page View SourceAmount
Amount expected or offered for the NFToken. If the token has the lsfOnlyXRP flag set, the amount must be specified in XRP.
Sell offers that specify assets other than XRP must specify a non-zero amount.
Sell offers that specify XRP can be 'free' (that is, the Amount field can be equal to "0").
Declaration
[JsonConverter(typeof(CurrencyConverter))]
public Currency Amount { get; set; }
Property Value
| Type | Description |
|---|---|
| Currency |
Destination
The AccountID for which this offer is intended. If present, only that account can accept the offer.
Declaration
public string Destination { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
Expiration
The time after which the offer is no longer active. The value is the number of seconds since the Ripple Epoch.
Declaration
[JsonConverter(typeof(RippleDateTimeConverter))]
public DateTime? Expiration { get; set; }
Property Value
| Type | Description |
|---|---|
| Nullable |
Flags
A set of flags associated with this object, used to specify various options or settings. Flags are listed in the table below.
Declaration
public uint Flags { get; set; }
Property Value
| Type | Description |
|---|---|
| uint |
NFTokenID
NFTokenID of the NFToken object referenced by this offer.
Declaration
public string NFTokenID { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
NFTokenOfferNode
Internal bookkeeping, indicating the page inside the token buy or sell offer directory, as appropriate, where this token is being tracked. This field allows the efficient deletion of offers.
Declaration
public string NFTokenOfferNode { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
Owner
Owner of the account that is creating and owns the offer. Only the current Owner of an NFToken can create an offer to sell an NFToken, but any account can create an offer to buy an NFToken.
Declaration
public string Owner { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
OwnerNode
Internal bookkeeping, indicating the page inside the owner directory where this token is being tracked. This field allows the efficient deletion of offers.
Declaration
public string OwnerNode { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
PreviousTransactionId
Identifying hash of the transaction that most recently modified this object.
Declaration
[JsonPropertyName("PreviousTxnID")]
public string PreviousTransactionId { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
PreviousTransactionLedgerSequence
Index of the ledger that contains the transaction that most recently modified this object.
Declaration
[JsonPropertyName("PreviousTxnLgrSeq")]
public uint PreviousTransactionLedgerSequence { get; set; }
Property Value
| Type | Description |
|---|---|
| uint |