Show / Hide Table of Contents

Class LONFTokenPage

Inheritance
object
BaseLedgerEntry
LONFTokenPage
Inherited Members
BaseLedgerEntry.LedgerEntryType
BaseLedgerEntry.Index
BaseLedgerEntry.LedgerIndex
Namespace: Xrpl.Models.Methods
Assembly: Xrpl.dll
Syntax
public class LONFTokenPage : BaseLedgerEntry

Constructors

| Edit this page View Source

LONFTokenPage()

Declaration
public LONFTokenPage()

Properties

| Edit this page View Source

Flags

Declaration
[JsonConverter(typeof(NumberOrStringConverter))]
public string Flags { get; set; }
Property Value
Type Description
string
| Edit this page View Source

NFTokenPage

The locator of the next page, if any. Details about this field and how it should be used are outlined below.

Declaration
public string NFTokenPage { get; set; }
Property Value
Type Description
string
| Edit this page View Source

NFTokens

The collection of NFToken objects contained in this NFTokenPage object. This specification places an upper bound of 32 NFToken objects per page. Objects are sorted from low to high with the NFTokenID used as the sorting parameter..

Declaration
public List<NFToken> NFTokens { get; set; }
Property Value
Type Description
List<NFToken>
| Edit this page View Source

PreviousPageMin

The locator of the previous page, if any. Details about this field and how it should be used are outlined below.

Declaration
public string PreviousPageMin { get; set; }
Property Value
Type Description
string
| Edit this page View Source

PreviousTxnID

Identifies the transaction ID of the transaction that most recently modified this NFTokenPage object.

Declaration
public string PreviousTxnID { get; set; }
Property Value
Type Description
string
| Edit this page View Source

PreviousTxnLgrSeq

The sequence of the ledger that contains the transaction that most recently modified this NFTokenPage object.

Declaration
public long PreviousTxnLgrSeq { get; set; }
Property Value
Type Description
long
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX