Class LONFTokenPage
Inheritance
object
LONFTokenPage
Assembly: Xrpl.dll
Syntax
public class LONFTokenPage : BaseLedgerEntry
Constructors
|
Edit this page
LONFTokenPage()
Declaration
Properties
|
Edit this page
Flags
Declaration
[JsonConverter(typeof(NumberOrStringConverter))]
public string Flags { get; set; }
Property Value
|
Edit this page
NFTokenPage
The locator of the next page, if any. Details about this field and how it should be used are outlined below.
Declaration
public string NFTokenPage { get; set; }
Property Value
|
Edit this page
NFTokens
The collection of NFToken objects contained in this NFTokenPage object.
This specification places an upper bound of 32 NFToken objects per page.
Objects are sorted from low to high with the NFTokenID used as the sorting parameter..
Declaration
public List<NFToken> NFTokens { get; set; }
Property Value
|
Edit this page
PreviousPageMin
The locator of the previous page, if any. Details about this field and how it should be used are outlined below.
Declaration
public string PreviousPageMin { get; set; }
Property Value
|
Edit this page
PreviousTxnID
Identifies the transaction ID of the transaction that most recently modified this NFTokenPage object.
Declaration
public string PreviousTxnID { get; set; }
Property Value
|
Edit this page
PreviousTxnLgrSeq
The sequence of the ledger that contains the transaction that most recently modified this NFTokenPage object.
Declaration
public long PreviousTxnLgrSeq { get; set; }
Property Value