Class LedgerCurrentRequest
The ledger_current method returns the unique identifiers of the current in-progress ledger.
Expects a response in the form of a LOLedgerCurrentIndex
Namespace: Xrpl.Models.Methods
Assembly: Xrpl.dll
Syntax
public class LedgerCurrentRequest : BaseRequest
Constructors
| Edit this page View SourceLedgerCurrentRequest()
Declaration
public LedgerCurrentRequest()