Class LedgerDataRequest
The ledger_data method retrieves contents of the specified ledger.
You can iterate through several calls to retrieve the entire contents of a single ledger version.
Inherited Members
Namespace: Xrpl.Models.Methods
Assembly: Xrpl.dll
Syntax
public class LedgerDataRequest : BaseLedgerRequest
Constructors
| Edit this page View SourceLedgerDataRequest()
Declaration
public LedgerDataRequest()
Properties
| Edit this page View SourceBinary
If set to true, return ledger objects as hashed hex strings instead of JSON.
Declaration
[JsonPropertyName("binary")]
public bool? Binary { get; set; }
Property Value
| Type | Description |
|---|---|
| bool? |
LedgerEntryType
Filter results to a specific type of ledger entry. This field accepts canonical names of ledger entry types (case insensitive) or short names. If omitted, return ledger entries of all types.
Declaration
[JsonPropertyName("type")]
[JsonConverter(typeof(LedgerEntryTypeConverter))]
public LedgerEntryType? LedgerEntryType { get; set; }
Property Value
| Type | Description |
|---|---|
| LedgerEntryType? |
Limit
Limit the number of ledger objects to retrieve.
The server is not required to honor this value.
Declaration
[JsonPropertyName("limit")]
public uint? Limit { get; set; }
Property Value
| Type | Description |
|---|---|
| uint? |
Marker
Value from a previous paginated response.
Resume retrieving data where that response left off.
Declaration
[JsonPropertyName("marker")]
public object? Marker { get; set; }
Property Value
| Type | Description |
|---|---|
| object |