Class LedgerRequest
Retrieve information about the public ledger.
Expects a response in the form.
Inherited Members
Namespace: Xrpl.Models.Methods
Assembly: Xrpl.dll
Syntax
public class LedgerRequest : BaseLedgerRequest
Constructors
| Edit this page View SourceLedgerRequest()
Declaration
public LedgerRequest()
Properties
| Edit this page View SourceBinary
If true, and transactions and expand are both also true, return transaction information in binary format (hexadecimal string) instead of JSON format.
Declaration
[JsonPropertyName("binary")]
public bool? Binary { get; set; }
Property Value
| Type | Description |
|---|---|
| bool? |
Expand
Provide full JSON-formatted information for transaction/account information instead of only hashes.
Defaults to false.
Ignored unless you request transactions, accounts, or both.
Declaration
[JsonPropertyName("expand")]
public bool? Expand { get; set; }
Property Value
| Type | Description |
|---|---|
| bool? |
OwnerFunds
If true, include owner_funds field in the metadata of OfferCreate transactions in the response.
Defaults to false.
Ignored unless transactions are included and expand is true.
Declaration
[JsonPropertyName("owner_funds")]
public bool? OwnerFunds { get; set; }
Property Value
| Type | Description |
|---|---|
| bool? |
Queue
If true, and the command is requesting the current ledger, includes an array of queued transactions in the results.
Declaration
[JsonPropertyName("queue")]
public bool? Queue { get; set; }
Property Value
| Type | Description |
|---|---|
| bool? |
Transactions
If true, return information on transactions in the specified ledger version.
Defaults to false.
Ignored if you did not specify a ledger version.
Declaration
[JsonPropertyName("transactions")]
public bool? Transactions { get; set; }
Property Value
| Type | Description |
|---|---|
| bool? |