Show / Hide Table of Contents

Class LedgerStreamResponse

This response mirrors the LedgerStream, except it does NOT include the 'type' nor 'txn_count' fields.

Inheritance
object
BaseResponse
LedgerStreamResponse
Inherited Members
BaseResponse.Id
BaseResponse.Status
BaseResponse.Type
BaseResponse.Result
BaseResponse.Warning
BaseResponse.Warnings
BaseResponse.Forwarded
BaseResponse.ApiVersion
Namespace: Xrpl.Models.Methods
Assembly: Xrpl.dll
Syntax
public class LedgerStreamResponse : BaseResponse

Properties

| Edit this page View Source

FeeBase

The reference transaction cost as of this ledger version, in drops of XRP.
If this ledger version includes a SetFee pseudo-transaction the new transaction cost applies starting with the following ledger version.

Declaration
[JsonPropertyName("fee_base")]
public uint FeeBase { get; set; }
Property Value
Type Description
uint
| Edit this page View Source

FeeRef

The reference transaction cost in "fee units".

Declaration
[JsonPropertyName("fee_ref")]
public uint FeeRef { get; set; }
Property Value
Type Description
uint
| Edit this page View Source

LedgerHash

The identifying hash of the ledger version that was closed.

Declaration
[JsonPropertyName("ledger_hash")]
public string LedgerHash { get; set; }
Property Value
Type Description
string
| Edit this page View Source

LedgerIndex

The ledger index of the ledger that was closed.

Declaration
[JsonPropertyName("ledger_index")]
public ulong LedgerIndex { get; set; }
Property Value
Type Description
ulong
| Edit this page View Source

LedgerTime

The time this ledger was closed, in seconds since the Ripple Epoch

Declaration
[JsonPropertyName("ledger_time")]
public ulong LedgerTime { get; set; }
Property Value
Type Description
ulong
| Edit this page View Source

ReserveBase

The minimum reserve, in drops of XRP, that is required for an account.
If this ledger version includes a SetFee pseudo-transaction the new base reserve applies starting with the following ledger version.

Declaration
[JsonPropertyName("reserve_base")]
public uint ReserveBase { get; set; }
Property Value
Type Description
uint
| Edit this page View Source

ReserveInc

The owner reserve for each object an account owns in the ledger, in drops of XRP.
If the ledger includes a SetFee pseudo-transaction the new owner reserve applies after this ledger.

Declaration
[JsonPropertyName("reserve_inc")]
public uint ReserveInc { get; set; }
Property Value
Type Description
uint
| Edit this page View Source

TxnCount

Number of new transactions included in this ledger version.

Declaration
[JsonPropertyName("txn_count")]
public uint TxnCount { get; set; }
Property Value
Type Description
uint
| Edit this page View Source

ValidatedLedgers

(May be omitted) Range of ledgers that the server has available.
This may be a disjoint sequence such as 24900901-24900984,24901116-24901158.
This field is not returned if the server is not connected to the network, or if it is connected but has not yet obtained a ledger from the network.

Declaration
[JsonPropertyName("validated_ledgers")]
public string ValidatedLedgers { get; set; }
Property Value
Type Description
string

Extension Methods

Utilities.HasNextPage(BaseResponse)
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX