Class Load
(Admin only) Detailed information about the current load state of the server.
Inheritance
object
Load
Namespace: Xrpl.Models.Methods
Assembly: Xrpl.dll
Syntax
public class Load
Properties
| Edit this page View SourceJobTypes
(Admin only) Information about the rate of different types of jobs the server is doing and how much time it spends on each.
Declaration
[JsonPropertyName("job_types")]
public List<JobType> JobTypes { get; set; }
Property Value
| Type | Description |
|---|---|
| List<JobType> |
Threads
(Admin only) The number of threads in the server's main job pool.
Declaration
[JsonPropertyName("threads")]
public int Threads { get; set; }
Property Value
| Type | Description |
|---|---|
| int |