Class NFT
Assembly: Xrpl.dll
Syntax
Properties
|
Edit this page
Account
Declaration
[JsonPropertyName("account")]
public string Account { get; set; }
Property Value
|
Edit this page
Flags
A bit-map of boolean flags enabled for this NFToken.
See NFToken Flags for possible values.
Declaration
[JsonPropertyName("Flags")]
[JsonConverter(typeof(NumberOrStringConverter))]
public string Flags { get; set; }
Property Value
|
Edit this page
Issuer
The account that issued this NFToken.
Declaration
[JsonPropertyName("issuer")]
public string Issuer { get; set; }
Property Value
|
Edit this page
NFTSerial
The token sequence number of this NFToken, which is unique for its issuer
Declaration
[JsonPropertyName("nft_serial")]
[JsonConverter(typeof(NumberOrStringConverter))]
public string NFTSerial { get; set; }
Property Value
|
Edit this page
NFTokenID
The unique identifier of this NFToken, in hexadecimal.
Declaration
[JsonPropertyName("NFTokenID")]
public string NFTokenID { get; set; }
Property Value
|
Edit this page
NFTokenTaxon
The unscrambled version of this token's taxon. Several tokens with the same taxon might represent instances of a limited series.
Declaration
[JsonPropertyName("NFTokenTaxon")]
public uint NFTokenTaxon { get; set; }
Property Value
|
Edit this page
TransactionFee
Declaration
[JsonPropertyName("transaction_fee")]
public uint TransactionFee { get; set; }
Property Value
|
Edit this page
TransferFee
The TransferFee value specifies the percentage fee, in units of 1/100,000, charged by the issuer for secondary sales of the token.
Valid values for this field are between 0 and 50,000, inclusive.
A value of 1 is equivalent to 0.001% or 1/10 of a basis point (bps), allowing transfer rates between 0% and 50%.
Declaration
[JsonPropertyName("TransferFee")]
[JsonConverter(typeof(NumberOrStringConverter))]
public string TransferFee { get; set; }
Property Value
|
Edit this page
URI
The URI data associated with this NFToken, in hexadecimal.
Declaration
[JsonPropertyName("URI")]
public string URI { get; set; }
Property Value
|
Edit this page
URIAsString
Declaration
[JsonIgnore]
public string URIAsString { get; }
Property Value