Class NoRippleCheck
Response expected by a NoRippleCheckRequest .
Inheritance
object
NoRippleCheck
Namespace: Xrpl.Models.Methods
Assembly: Xrpl.dll
Syntax
public class NoRippleCheck
Properties
| Edit this page View SourceLedgerCurrentIndex
Declaration
[JsonPropertyName("ledger_current_index")]
public uint LedgerCurrentIndex { get; set; }
Property Value
| Type | Description |
|---|---|
| uint |
Problems
Array of strings with human-readable descriptions of the problems.
This includes up to one entry if the account's Default Ripple setting is not as recommended, plus up to limit entries for trust lines whose no ripple setting is not as recommended.
Declaration
[JsonPropertyName("problems")]
public List<string> Problems { get; set; }
Property Value
| Type | Description |
|---|---|
| List<string> |
Transactions
If the request specified transactions as true, this is an array of JSON objects, each of which is the JSON form of a transaction that should fix one of the described problems.
The length of this array is the same as the problems array, and each entry is intended to fix the problem described at the same index into that array.
Declaration
[JsonPropertyName("transactions")]
public List<ITransactionRequest> Transactions { get; set; }
Property Value
| Type | Description |
|---|---|
| List<ITransactionRequest> |
Validated
Declaration
[JsonPropertyName("validated")]
public bool Validated { get; set; }
Property Value
| Type | Description |
|---|---|
| bool |