Show / Hide Table of Contents

Class PathAlternative

Each element in the alternatives array represents a path from one possible source currency to the destination account and currency.

Inheritance
object
PathAlternative
Namespace: Xrpl.Models.Methods
Assembly: Xrpl.dll
Syntax
public class PathAlternative

Properties

| Edit this page View Source

DestinationAmount

(May be omitted) Currency Amount that the destination would receive along this path.
Only included when the destination_amount from the request was the "-1" special case.

Declaration
[JsonPropertyName("destination_amount")]
[JsonConverter(typeof(CurrencyConverter))]
public Currency DestinationAmount { get; set; }
Property Value
Type Description
Currency
| Edit this page View Source

PathsCanonical

(Deprecated) Array of arrays of objects defining canonical payment paths.
May be present in server responses but should be disregarded.

Declaration
[JsonPropertyName("paths_canonical")]
public List<List<Path>> PathsCanonical { get; set; }
Property Value
Type Description
List<List<Path>>
| Edit this page View Source

PathsComputed

Array of arrays of objects defining payment paths.

Declaration
[JsonPropertyName("paths_computed")]
public List<List<Path>> PathsComputed { get; set; }
Property Value
Type Description
List<List<Path>>
| Edit this page View Source

SourceAmount

Currency Amount that the source would have to send along this path for the destination to receive the desired amount.

Declaration
[JsonPropertyName("source_amount")]
[JsonConverter(typeof(CurrencyConverter))]
public Currency SourceAmount { get; set; }
Property Value
Type Description
Currency
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX