Class PermissionedDomainQuery
Specify the PermissionedDomain to retrieve. If a string, must be the ledger entry ID of the entry, as hexadecimal. If an object, requires account and seq sub-fields.
Inheritance
object
PermissionedDomainQuery
Namespace: Xrpl.Models.Methods
Assembly: Xrpl.dll
Syntax
public class PermissionedDomainQuery
Properties
| Edit this page View SourceAccount
The account that owns the PermissionedDomain.
Declaration
[JsonPropertyName("account")]
public string Account { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
Seq
The sequence number of the transaction that created the PermissionedDomain.
Declaration
[JsonPropertyName("seq")]
public uint Seq { get; set; }
Property Value
| Type | Description |
|---|---|
| uint |