Class PingRequest
The ping command returns an acknowledgement, so that clients can test the connection status and latency.
Expects a response in the form of a PingRequest.
Namespace: Xrpl.Models.Methods
Assembly: Xrpl.dll
Syntax
public class PingRequest : BaseRequest
Constructors
| Edit this page View SourcePingRequest()
Declaration
public PingRequest()