Class RipplePathFindRequest
The ripple_path_find method is a simplified version of the path_find method
that provides a single response with a payment path you can use right away.
It is available in both the WebSocket and JSON-RPC APIs.
Returns a RipplePathFindResponse.
Inherited Members
Namespace: Xrpl.Models.Methods
Assembly: Xrpl.dll
Syntax
public class RipplePathFindRequest : BaseLedgerRequest
Constructors
| Edit this page View SourceRipplePathFindRequest(string, string, Currency)
Declaration
public RipplePathFindRequest(string sourceAccount, string destinationAccount, Currency destinationAmount)
Parameters
| Type | Name | Description |
|---|---|---|
| string | sourceAccount | |
| string | destinationAccount | |
| Currency | destinationAmount |
Properties
| Edit this page View SourceDestinationAccount
Unique address of the account that would receive funds.
Declaration
[JsonPropertyName("destination_account")]
public string DestinationAccount { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
DestinationAmount
Currency Amount that the destination account would receive.
Special case: provide "-1" for XRP or -1 as value for tokens
to request a path to deliver as much as possible,
while spending no more than the amount specified in send_max.
Declaration
[JsonPropertyName("destination_amount")]
[JsonConverter(typeof(CurrencyConverter))]
public Currency DestinationAmount { get; set; }
Property Value
| Type | Description |
|---|---|
| Currency |
SendMax
(Optional) Currency Amount — the maximum amount that would be spent.
Cannot be used with source_currencies.
Declaration
[JsonPropertyName("send_max")]
[JsonConverter(typeof(CurrencyConverter))]
public Currency SendMax { get; set; }
Property Value
| Type | Description |
|---|---|
| Currency |
SourceAccount
Unique address of the account that would send funds.
Declaration
[JsonPropertyName("source_account")]
public string SourceAccount { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
SourceCurrencies
(Optional) Array of currencies that the source account might want to spend.
Each entry should have a mandatory currency field and optional issuer field.
Cannot contain more than 18 source currencies.
By default, uses all source currencies available up to a maximum of 88 different currency/issuer pairs.
Declaration
[JsonPropertyName("source_currencies")]
public List<SourceCurrency> SourceCurrencies { get; set; }
Property Value
| Type | Description |
|---|---|
| List<SourceCurrency> |