Class ServerDefinitionsResponse
Response expected from a ServerDefinitionsRequest.
Inheritance
object
ServerDefinitionsResponse
Namespace: Xrpl.Models.Methods
Assembly: Xrpl.dll
Syntax
public class ServerDefinitionsResponse
Properties
| Edit this page View SourceFields
An array of field definitions used in binary serialization. Each element is an array of [field_name, field_info_object]. Uses JsonElement for flexibility since the structure is complex.
Declaration
[JsonPropertyName("FIELDS")]
public JsonElement? Fields { get; set; }
Property Value
| Type | Description |
|---|---|
| JsonElement? |
Hash
A hash value representing the current definitions. Can be passed in a subsequent request to avoid re-downloading unchanged definitions.
Declaration
[JsonPropertyName("hash")]
public string Hash { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
LedgerEntryTypes
A mapping of ledger entry type names to their numeric codes.
Declaration
[JsonPropertyName("LEDGER_ENTRY_TYPES")]
public Dictionary<string, int> LedgerEntryTypes { get; set; }
Property Value
| Type | Description |
|---|---|
| Dictionary<string, int> |
TransactionResults
A mapping of transaction result names to their numeric codes.
Declaration
[JsonPropertyName("TRANSACTION_RESULTS")]
public Dictionary<string, int> TransactionResults { get; set; }
Property Value
| Type | Description |
|---|---|
| Dictionary<string, int> |
TransactionTypes
A mapping of transaction type names to their numeric codes.
Declaration
[JsonPropertyName("TRANSACTION_TYPES")]
public Dictionary<string, int> TransactionTypes { get; set; }
Property Value
| Type | Description |
|---|---|
| Dictionary<string, int> |
Types
A mapping of serialization type names to their numeric codes.
Declaration
[JsonPropertyName("TYPES")]
public Dictionary<string, int> Types { get; set; }
Property Value
| Type | Description |
|---|---|
| Dictionary<string, int> |