Class ServerStateRequest
The server_info command asks the server for a human-readable version of various information about the rippled server being queried.
Expects a response in the form of a {@link ServerInfoResponse}.
Namespace: Xrpl.Models.Methods
Assembly: Xrpl.dll
Syntax
public class ServerStateRequest : BaseRequest
Constructors
| Edit this page View SourceServerStateRequest()
Declaration
public ServerStateRequest()