Class SimulateResponse
Inheritance
object
SimulateResponse
Assembly: Xrpl.dll
Syntax
public class SimulateResponse
Properties
|
Edit this page
Applied
Declaration
[JsonPropertyName("applied")]
public bool Applied { get; set; }
Property Value
|
Edit this page
Binary
The default value is false, which returns data and metadata in JSON format.
If true, returns data and metadata in binary format, serialized to a hexadecimal string.
Declaration
[JsonPropertyName("binary")]
public bool? Binary { get; set; }
Property Value
|
Edit this page
EngineResult
Text result code indicating the preliminary result of the transaction, for example tesSUCCESS.
Declaration
[JsonPropertyName("engine_result")]
public string EngineResult { get; set; }
Property Value
|
Edit this page
EngineResultCode
Numeric version of the result code.
Declaration
[JsonPropertyName("engine_result_code")]
public int EngineResultCode { get; set; }
Property Value
|
Edit this page
EngineResultMessage
Human-readable explanation of the transaction's preliminary result.
Declaration
[JsonPropertyName("engine_result_message")]
public string EngineResultMessage { get; set; }
Property Value
|
Edit this page
LedgerIndex
Declaration
[JsonPropertyName("ledger_index")]
public ulong? LedgerIndex { get; set; }
Property Value
|
Edit this page
Declaration
[JsonPropertyName("meta")]
public Meta Meta { get; set; }
Property Value
|
Edit this page
TxBlob
The transaction to simulate, in binary format.
If you include this field, do not also include tx_json.
Declaration
[JsonPropertyName("tx_blob")]
public string TxBlob { get; set; }
Property Value
|
Edit this page
TxJson
The transaction to simulate, in JSON format.
If you include this field, do not also include tx_blob.
Declaration
[JsonPropertyName("tx_json")]
[JsonConverter(typeof(TransactionRequestConverter))]
public ITransactionRequest TxJson { get; set; }
Property Value