Class State
Assembly: Xrpl.dll
Syntax
Properties
|
Edit this page
AccountingStateSummary
A map of various server states with information about the time the server spends in each.
This can be useful for tracking the long-term health of your server's connectivity to the network.
Declaration
[JsonPropertyName("state_accounting")]
public AccountingStateSummary AccountingStateSummary { get; set; }
Property Value
|
Edit this page
BuildVersion
The version number of the running rippled version.
Declaration
[JsonPropertyName("build_version")]
public string BuildVersion { get; set; }
Property Value
|
Edit this page
ClosedLedger
Range expression indicating the sequence numbers of the ledger versions the local rippled has in its database.
Declaration
[JsonPropertyName("closed_ledger")]
public StateLedger ClosedLedger { get; set; }
Property Value
|
Edit this page
CompleteLedgers
Range expression indicating the sequence numbers of the ledger versions the local rippled has in its database.
Declaration
[JsonPropertyName("complete_ledgers")]
public string CompleteLedgers { get; set; }
Property Value
|
Edit this page
IoLatencyMs
Amount of time spent waiting for I/O operations, in milliseconds.
If this number is not very, very low, then the rippled server is probably having serious load issues.
Declaration
[JsonPropertyName("io_latency_ms")]
public int IoLatencyMs { get; set; }
Property Value
|
Edit this page
JqTransOverflow
Amount of time spent waiting for I/O operations, in milliseconds.
If this number is not very, very low, then the rippled server is probably having serious load issues.
Declaration
[JsonPropertyName("jq_trans_overflow")]
public string JqTransOverflow { get; set; }
Property Value
|
Edit this page
LastClose
Information about the last time the server closed a ledger,
including the amount of time it took to reach a consensus and the number of trusted validators participating.
Declaration
[JsonPropertyName("last_close")]
public LastClose LastClose { get; set; }
Property Value
|
Edit this page
Load
(Admin only) Detailed information about the current load state of the server.
Declaration
[JsonPropertyName("load")]
public Load Load { get; set; }
Property Value
|
Edit this page
LoadBase
Declaration
[JsonPropertyName("load_base")]
public double LoadBase { get; set; }
Property Value
|
Edit this page
LoadFactor
The load-scaled open ledger transaction cost the server is currently enforcing, as a multiplier on the base transaction cost.
For example, at 1000 load factor and a reference transaction cost of 10 drops of XRP, the load-scaled transaction cost is 10,000 drops (0.01 XRP).
The load factor is determined by the highest of the individual server's load factor,
the cluster's load factor, the open ledger cost and the overall network's load factor.
Declaration
[JsonPropertyName("load_factor")]
public double? LoadFactor { get; set; }
Property Value
|
Edit this page
LoadFactorFeeEscalation
Declaration
[JsonPropertyName("load_factor_fee_escalation")]
public double? LoadFactorFeeEscalation { get; set; }
Property Value
|
Edit this page
LoadFactorFeeQueue
Declaration
[JsonPropertyName("load_factor_fee_queue")]
public double? LoadFactorFeeQueue { get; set; }
Property Value
|
Edit this page
LoadFactorFeeReference
Declaration
[JsonPropertyName("load_factor_fee_reference")]
public double? LoadFactorFeeReference { get; set; }
Property Value
|
Edit this page
LoadFactorServer
Declaration
[JsonPropertyName("load_factor_server")]
public double? LoadFactorServer { get; set; }
Property Value
|
Edit this page
Peers
How many other rippled servers this one is currently connected to.
Declaration
[JsonPropertyName("peers")]
public int Peers { get; set; }
Property Value
|
Edit this page
PubkeyNode
Public key used to verify this server for peer-to-peer communications.
This node key pair is automatically generated by the server the first time it starts up.
(If deleted, the server can create a new pair of Keys).
Declaration
[JsonPropertyName("pubkey_node")]
public string PubkeyNode { get; set; }
Property Value
|
Edit this page
PubkeyValidator
Public key used by this node to sign ledger validations.
Declaration
[JsonPropertyName("pubkey_validator")]
public string PubkeyValidator { get; set; }
Property Value
|
Edit this page
ServerState
A string indicating to what extent the server is participating in the network.
Declaration
[JsonPropertyName("server_state")]
[JsonConverter(typeof(EnumMemberValueConverter<ServerStateInner>))]
public ServerStateInner ServerState { get; set; }
Property Value
|
Edit this page
ServerStateDurationUs
Declaration
[JsonPropertyName("server_state_duration_us")]
public double ServerStateDurationUs { get; set; }
Property Value
|
Edit this page
Time
Declaration
[JsonPropertyName("time")]
public string Time { get; set; }
Property Value
|
Edit this page
Uptime
Number of consecutive seconds that the server has been operational.
Declaration
[JsonPropertyName("uptime")]
public int Uptime { get; set; }
Property Value
|
Edit this page
UptimeTimeSpan
Declaration
[JsonIgnore]
public TimeSpan UptimeTimeSpan { get; }
Property Value
| Type |
Description |
| TimeSpan |
|
|
Edit this page
ValidatedLedger
Information about the most recent fully-validated ledger.
Declaration
[JsonPropertyName("validated_ledger")]
public StateLedger ValidatedLedger { get; set; }
Property Value
|
Edit this page
ValidationQuorum
Minimum number of trusted validations required to validate a ledger version.
Some circumstances may cause the server to require more validations.
Declaration
[JsonPropertyName("validation_quorum")]
public long ValidationQuorum { get; set; }
Property Value
|
Edit this page
ValidatorListExpires
Either the human readable time, in UTC, when the current validator list will expire,
the string unknown if the server has yet to load a published validator list or the string never if the server uses a static validator list.
Declaration
[JsonPropertyName("validator_list_expires")]
[JsonConverter(typeof(NumberOrStringConverter))]
public string ValidatorListExpires { get; set; }
Property Value