Class StateLedger
Information about the most recent fully-validated ledger.
Inheritance
object
StateLedger
Namespace: Xrpl.Models.Methods
Assembly: Xrpl.dll
Syntax
public class StateLedger
Properties
| Edit this page View SourceAge
The time since the ledger was closed, in seconds.
Declaration
[JsonPropertyName("age")]
public int Age { get; set; }
Property Value
| Type | Description |
|---|---|
| int |
AgeTimeSpan
Declaration
[JsonIgnore]
public TimeSpan AgeTimeSpan { get; }
Property Value
| Type | Description |
|---|---|
| TimeSpan |
BaseFee
Base fee, in XRP.
This may be represented in scientific notation.
Such as 1e-05 for 0.00005.
Declaration
[JsonPropertyName("base_fee")]
public double BaseFee { get; set; }
Property Value
| Type | Description |
|---|---|
| double |
Hash
Unique hash for the ledger, as hexadecimal.
Declaration
[JsonPropertyName("hash")]
public string Hash { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
ReserveBase
Minimum amount of XRP (not drops) necessary for every account to.
Keep in reserve.
Declaration
[JsonPropertyName("reserve_base")]
public uint ReserveBase { get; set; }
Property Value
| Type | Description |
|---|---|
| uint |
ReserveInc
Amount of XRP (not drops) added to the account reserve for each object an account owns in the ledger.
Declaration
[JsonPropertyName("reserve_inc")]
public uint ReserveInc { get; set; }
Property Value
| Type | Description |
|---|---|
| uint |
Sequence
The ledger index of the latest validated ledger.
Declaration
[JsonPropertyName("seq")]
public int Sequence { get; set; }
Property Value
| Type | Description |
|---|---|
| int |