Class SubscribeRequest
The subscribe method requests periodic notifications from the server when certain events happen.
https://xrpl.org/subscribe.html
Namespace: Xrpl.Models.Methods
Assembly: Xrpl.dll
Syntax
public class SubscribeRequest : BaseRequest
Constructors
| Edit this page View SourceSubscribeRequest()
Declaration
public SubscribeRequest()
Properties
| Edit this page View SourceAccounts
(Optional) Array with the unique addresses of accounts to monitor for validated transactions. The addresses must be in the XRP Ledger's base58 format. The server sends a notification for any transaction that affects at least one of these accounts
Declaration
[JsonPropertyName("accounts")]
public List<string> Accounts { get; set; }
Property Value
| Type | Description |
|---|---|
| List<string> |
AccountsProposed
(Optional) Like accounts, but include transactions that are not yet finalized.
Declaration
[JsonPropertyName("accounts_proposed")]
public List<string> AccountsProposed { get; set; }
Property Value
| Type | Description |
|---|---|
| List<string> |
Books
(Optional) Array of objects defining order books to monitor for updates.
Declaration
[JsonPropertyName("books")]
public List<Book> Books { get; set; }
Property Value
| Type | Description |
|---|---|
| List<Book> |
Streams
Array with the unique addresses of accounts to monitor for validated transactions.The addresses must be in the XRP Ledger's base58 format. The server sends a notification for any transaction that affects at least one of these accounts.
Declaration
[JsonPropertyName("streams")]
[JsonConverter(typeof(StreamTypeListConverter))]
public List<StreamType> Streams { get; set; }
Property Value
| Type | Description |
|---|---|
| List<StreamType> |
Url
(Optional for Websocket; Required otherwise) URL where the server sends a JSON-RPC callbacks for each event. Admin-only.
Declaration
[JsonPropertyName("url")]
public string Url { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
UrlPassword
(Optional) Password to provide for basic authentication at the callback URL.
Declaration
[JsonPropertyName("url_password")]
public string UrlPassword { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
UrlUsername
(Optional) Username to provide for basic authentication at the callback URL.
Declaration
[JsonPropertyName("url_username")]
public string UrlUsername { get; set; }
Property Value
| Type | Description |
|---|---|
| string |