Class TransactionEntryRequest
The transaction_entry method retrieves information on a single transaction
from a specific ledger version. It differs from the tx method in that it
requires you to specify the ledger version to search.
Inherited Members
Namespace: Xrpl.Models.Methods
Assembly: Xrpl.dll
Syntax
public class TransactionEntryRequest : BaseLedgerRequest
Constructors
| Edit this page View SourceTransactionEntryRequest()
Declaration
public TransactionEntryRequest()
Properties
| Edit this page View SourceTxHash
Unique hash of the transaction you are looking up.
Declaration
[JsonPropertyName("tx_hash")]
public string TxHash { get; set; }
Property Value
| Type | Description |
|---|---|
| string |