Class TransactionSummary
Inheritance
object
TransactionSummary
Implements
Namespace: Xrpl.Models.Methods
Assembly: Xrpl.dll
Syntax
public class TransactionSummary : IAccountTransaction
Properties
| Edit this page View SourceCloseTimeIso
The ledger close time represented in ISO 8601 time format.
Declaration
[JsonPropertyName("close_time_iso")]
[JsonConverter(typeof(FromStringDateTimeConverter))]
public DateTime? CloseTimeIso { get; set; }
Property Value
| Type | Description |
|---|---|
| Nullable |
Hash
Unique hashed String representing the transaction.
Declaration
[JsonPropertyName("hash")]
public string Hash { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
LedgerHash
A hex string of the ledger version that included this transaction.
Declaration
[JsonPropertyName("ledger_hash")]
public string LedgerHash { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
LedgerIndex
The ledger index of the ledger version that included this transaction.
Declaration
[JsonPropertyName("ledger_index")]
public ulong? LedgerIndex { get; set; }
Property Value
| Type | Description |
|---|---|
| ulong? |
Meta
If binary is True, then this is a hex string of the transaction metadata.
Otherwise, the transaction metadata is included in JSON format.
Declaration
[JsonPropertyName("meta")]
[JsonConverter(typeof(MetaBinaryConverter))]
public Meta Meta { get; set; }
Property Value
| Type | Description |
|---|---|
| Meta |
Transaction
JSON object defining the transaction.
Declaration
[JsonPropertyName("tx_json")]
public TransactionResponse Transaction { get; set; }
Property Value
| Type | Description |
|---|---|
| TransactionResponse |
Validated
Whether or not the transaction is included in a validated ledger.
Any transaction not yet in a validated ledger is subject to change.
Declaration
[JsonPropertyName("validated")]
public bool Validated { get; set; }
Property Value
| Type | Description |
|---|---|
| bool |