Class ValidatedLedger
Information about the most recent fully-validated ledger.
Inheritance
object
ValidatedLedger
Namespace: Xrpl.Models.Methods
Assembly: Xrpl.dll
Syntax
public class ValidatedLedger
Properties
| Edit this page View SourceAge
The time since the ledger was closed, in seconds.
Declaration
[JsonPropertyName("age")]
public int Age { get; set; }
Property Value
| Type | Description |
|---|---|
| int |
AgeTimeSpan
Declaration
[JsonIgnore]
public TimeSpan AgeTimeSpan { get; }
Property Value
| Type | Description |
|---|---|
| TimeSpan |
BaseFeeXrp
Base fee, in XRP.
This may be represented in scientific notation.
Such as 1e-05 for 0.00005.
Declaration
[JsonPropertyName("base_fee_xrp")]
[JsonConverter(typeof(ScientificDecimalConverter))]
public decimal BaseFeeXrp { get; set; }
Property Value
| Type | Description |
|---|---|
| decimal |
Hash
Unique hash for the ledger, as hexadecimal.
Declaration
[JsonPropertyName("hash")]
public string Hash { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
ReserveBaseXrp
Minimum amount of XRP (not drops) necessary for every account to.
Keep in reserve.
Declaration
[JsonPropertyName("reserve_base_xrp")]
[JsonConverter(typeof(ScientificDecimalConverter))]
public decimal ReserveBaseXrp { get; set; }
Property Value
| Type | Description |
|---|---|
| decimal |
ReserveIncXrp
Amount of XRP (not drops) added to the account reserve for each object an account owns in the ledger.
Declaration
[JsonPropertyName("reserve_inc_xrp")]
[JsonConverter(typeof(ScientificDecimalConverter))]
public decimal ReserveIncXrp { get; set; }
Property Value
| Type | Description |
|---|---|
| decimal |
Sequence
The ledger index of the latest validated ledger.
Declaration
[JsonPropertyName("seq")]
public int Sequence { get; set; }
Property Value
| Type | Description |
|---|---|
| int |