Class VaultInfoResponse
Response expected from a VaultInfoRequest.
Inheritance
object
VaultInfoResponse
Namespace: Xrpl.Models.Methods
Assembly: Xrpl.dll
Syntax
public class VaultInfoResponse
Properties
| Edit this page View SourceLedgerHash
The identifying hash of the ledger version used to generate this response.
Declaration
[JsonPropertyName("ledger_hash")]
public string LedgerHash { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
LedgerIndex
The ledger index of the ledger version used to generate this response.
Declaration
[JsonPropertyName("ledger_index")]
public uint? LedgerIndex { get; set; }
Property Value
| Type | Description |
|---|---|
| uint? |
Validated
If true, the information comes from a validated ledger version.
Declaration
[JsonPropertyName("validated")]
public bool? Validated { get; set; }
Property Value
| Type | Description |
|---|---|
| bool? |
Vault
The vault ledger object.
Declaration
[JsonPropertyName("vault")]
public LOVault Vault { get; set; }
Property Value
| Type | Description |
|---|---|
| LOVault |