Namespace Xrpl.Models.Subscriptions
Classes
BaseResponse
BaseStream
ConsensusStream
The consensus stream sends consensusPhase messages when the consensus process changes phase.
The message contains the new phase of consensus the server is in.
https://xrpl.org/subscribe.html#consensus-stream
ErrorResponse
OrderBookStream
When you subscribe to one or more order books with the books field, you get back any transactions that affect those order books. https://xrpl.org/subscribe.html#order-book-streams
PathFindStream
Asynchronous follow-up message from the server for an ongoing path_find request.
These messages have "type": "path_find" and include the id of the original WebSocket request.
PeerStatusStream
The admin-only peer_status stream reports a large amount of information on the activities of other rippled servers to which this server is connected, in particular their status in the consensus process. https://xrpl.org/subscribe.html#peer-status-stream
RippleResponseWarning
When the response contains a warnings array, each member of the array represents a separate warning from the server.
TransactionStream
Many subscriptions result in messages about transactions, including the following:
The transactions stream
The transactions_proposed stream
accounts subscriptions
accounts_proposed subscriptions
book (Order Book) subscriptions
https://xrpl.org/subscribe.html#transaction-streams