Show / Hide Table of Contents

Class BaseResponse

Inheritance
object
BaseResponse
LedgerStreamResponse
ErrorResponse
Namespace: Xrpl.Models.Subscriptions
Assembly: Xrpl.dll
Syntax
public class BaseResponse

Properties

| Edit this page View Source

ApiVersion

(May be omitted) The api_version specified in the request, if any.

Declaration
[JsonPropertyName("api_version")]
public uint? ApiVersion { get; set; }
Property Value
Type Description
uint?
| Edit this page View Source

Forwarded

(May be omitted) If true, this request and response have been forwarded from a Reporting Mode server to a P2P Mode server (and back) because the request requires data that is not available in Reporting Mode.
The default is false.

Declaration
[JsonPropertyName("forwarded")]
public bool? Forwarded { get; set; }
Property Value
Type Description
bool?
| Edit this page View Source

Id

(WebSocket only) ID provided in the request that prompted this response

Declaration
[JsonPropertyName("id")]
public object? Id { get; set; }
Property Value
Type Description
object
| Edit this page View Source

Result

(WebSocket only) The value success indicates the request was successfully received and understood by the server.
Some client libraries omit this field on success.

Declaration
[JsonPropertyName("result")]
public object Result { get; set; }
Property Value
Type Description
object
| Edit this page View Source

Status

"error" if the request caused an error

Declaration
[JsonPropertyName("status")]
public string Status { get; set; }
Property Value
Type Description
string
| Edit this page View Source

Type

(WebSocket only) The value response indicates a direct response to an API request.
Asynchronous notifications use a different value such as ledgerClosed or transaction.

Declaration
[JsonPropertyName("type")]
public string Type { get; set; }
Property Value
Type Description
string
| Edit this page View Source

Warning

(May be omitted) If this field is provided, the value is the string load.
This means the client is approaching the rate limiting threshold where the server will disconnect this client.

Declaration
[JsonPropertyName("warning")]
public string Warning { get; set; }
Property Value
Type Description
string
| Edit this page View Source

Warnings

May be omitted) If this field is provided, it contains one or more Warnings Objects with important warnings.
For details, see API Warnings (https://xrpl.org/response-formatting.html#api-warnings)

Declaration
[JsonPropertyName("warnings")]
public List<RippleResponseWarning>? Warnings { get; set; }
Property Value
Type Description
List<RippleResponseWarning>

Extension Methods

Utilities.HasNextPage(BaseResponse)
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX