Class ErrorResponse
Inheritance
object
ErrorResponse
Assembly: Xrpl.dll
Syntax
public class ErrorResponse : BaseResponse
Properties
|
Edit this page
Error
A unique code for the type of error that occurred.
Declaration
[JsonPropertyName("error")]
public string Error { get; set; }
Property Value
|
Edit this page
ErrorCode
Declaration
[JsonPropertyName("error_code")]
public int? ErrorCode { get; set; }
Property Value
|
Edit this page
ErrorException
Declaration
[JsonPropertyName("error_exception")]
public string? ErrorException { get; set; }
Property Value
|
Edit this page
ErrorMessage
(WebSocket only) The value success indicates the request was successfully received and understood by the server.
Some client libraries omit this field on success.
Declaration
[JsonPropertyName("error_message")]
public string ErrorMessage { get; set; }
Property Value
|
Edit this page
RawRequest
A copy of the request that prompted this error, exactly as the node echoed it back.
Declaration
[JsonIgnore]
public RawJson RawRequest { get; }
Property Value
Extension Methods