Show / Hide Table of Contents

Class ErrorResponse

Inheritance
object
BaseResponse
ErrorResponse
Inherited Members
BaseResponse.Id
BaseResponse.Status
BaseResponse.Type
BaseResponse.Result
BaseResponse.Warning
BaseResponse.Warnings
BaseResponse.Forwarded
BaseResponse.ApiVersion
Namespace: Xrpl.Models.Subscriptions
Assembly: Xrpl.dll
Syntax
public class ErrorResponse : BaseResponse

Properties

| Edit this page View Source

Error

A unique code for the type of error that occurred.

Declaration
[JsonPropertyName("error")]
public string Error { get; set; }
Property Value
Type Description
string
| Edit this page View Source

ErrorCode

Declaration
[JsonPropertyName("error_code")]
public int? ErrorCode { get; set; }
Property Value
Type Description
int?
| Edit this page View Source

ErrorException

Declaration
[JsonPropertyName("error_exception")]
public string? ErrorException { get; set; }
Property Value
Type Description
string
| Edit this page View Source

ErrorMessage

(WebSocket only) The value success indicates the request was successfully received and understood by the server.
Some client libraries omit this field on success.

Declaration
[JsonPropertyName("error_message")]
public string ErrorMessage { get; set; }
Property Value
Type Description
string
| Edit this page View Source

Request

A copy of the request that prompted this error, in JSON format.
Caution: If the request contained any secrets, they are copied here!

Declaration
[JsonPropertyName("request")]
public object Request { get; set; }
Property Value
Type Description
object

Extension Methods

Utilities.HasNextPage(BaseResponse)
XrplErrorClassifier.Classify(ErrorResponse)
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX