Class ErrorResponse
Inheritance
object
ErrorResponse
Assembly: Xrpl.dll
Syntax
public class ErrorResponse : BaseResponse
Properties
|
Edit this page
Error
A unique code for the type of error that occurred.
Declaration
[JsonPropertyName("error")]
public string Error { get; set; }
Property Value
|
Edit this page
ErrorCode
Declaration
[JsonPropertyName("error_code")]
public int? ErrorCode { get; set; }
Property Value
|
Edit this page
ErrorException
Declaration
[JsonPropertyName("error_exception")]
public string? ErrorException { get; set; }
Property Value
|
Edit this page
ErrorMessage
(WebSocket only) The value success indicates the request was successfully received and understood by the server.
Some client libraries omit this field on success.
Declaration
[JsonPropertyName("error_message")]
public string ErrorMessage { get; set; }
Property Value
|
Edit this page
Request
A copy of the request that prompted this error, in JSON format.
Caution: If the request contained any secrets, they are copied here!
Declaration
[JsonPropertyName("request")]
public object Request { get; set; }
Property Value
Extension Methods