Class OrderBookStream
Inheritance
object
OrderBookStream
Assembly: Xrpl.dll
Syntax
public class OrderBookStream : BaseStream
Properties
|
Edit this page
EngineResult
String Transaction result code
Declaration
[JsonPropertyName("engine_result")]
public string EngineResult { get; set; }
Property Value
|
Edit this page
EngineResultCode
Numeric transaction response code, if applicable.
Declaration
[JsonPropertyName("engine_result_code")]
public int EngineResultCode { get; set; }
Property Value
|
Edit this page
EngineResultMessage
Human-readable explanation for the transaction response
Declaration
[JsonPropertyName("engine_result_message")]
public string EngineResultMessage { get; set; }
Property Value
|
Edit this page
(Validated transactions only) The transaction metadata, which shows the exact outcome of the transaction in detail.
Declaration
[JsonPropertyName("meta")]
public Meta Meta { get; set; }
Property Value
|
Edit this page
Status
Declaration
[JsonPropertyName("status")]
public string Status { get; set; }
Property Value
|
Edit this page
Transaction
Declaration
[JsonIgnore]
public ITransactionResponse Transaction { get; }
Property Value
|
Edit this page
TransactionJson
The definition of the transaction in JSON format
Declaration
[JsonPropertyName("transaction")]
public object TransactionJson { get; set; }
Property Value
|
Edit this page
Validated
If true, this transaction is included in a validated ledger and its outcome is final.
Responses from the transaction stream should always be validated.
Declaration
[JsonPropertyName("validated")]
public bool Validated { get; set; }
Property Value