Show / Hide Table of Contents

Class TransactionStream

Many subscriptions result in messages about transactions, including the following: The transactions stream
The transactions_proposed stream
accounts subscriptions
accounts_proposed subscriptions
book (Order Book) subscriptions https://xrpl.org/subscribe.html#transaction-streams

Inheritance
object
BaseStream
TransactionStream
Implements
IAccountTransaction
Inherited Members
BaseStream.Type
Namespace: Xrpl.Models.Subscriptions
Assembly: Xrpl.dll
Syntax
public class TransactionStream : BaseStream, IAccountTransaction

Properties

| Edit this page View Source

CloseTimeIso

The ledger close time represented in ISO 8601 time format.

Declaration
[JsonPropertyName("close_time_iso")]
public DateTime? CloseTimeIso { get; set; }
Property Value
Type Description
Nullable
| Edit this page View Source

EngineResult

String Transaction result code

Declaration
[JsonPropertyName("engine_result")]
public string EngineResult { get; set; }
Property Value
Type Description
string
| Edit this page View Source

EngineResultCode

Numeric transaction response code, if applicable.

Declaration
[JsonPropertyName("engine_result_code")]
public int EngineResultCode { get; set; }
Property Value
Type Description
int
| Edit this page View Source

EngineResultMessage

Human-readable explanation for the transaction response

Declaration
[JsonPropertyName("engine_result_message")]
public string EngineResultMessage { get; set; }
Property Value
Type Description
string
| Edit this page View Source

Hash

The unique hash identifier of the transaction.

Declaration
[JsonPropertyName("hash")]
public string Hash { get; set; }
Property Value
Type Description
string
| Edit this page View Source

LedgerCurrentIndex

(Unvalidated transactions only) The ledger index of the current in-progress ledger version for which this transaction is currently proposed.

Declaration
[JsonPropertyName("ledger_current_index")]
public uint? LedgerCurrentIndex { get; set; }
Property Value
Type Description
uint?
| Edit this page View Source

LedgerHash

(Validated transactions only) The identifying hash of the ledger version that includes this transaction

Declaration
[JsonPropertyName("ledger_hash")]
public string LedgerHash { get; set; }
Property Value
Type Description
string
| Edit this page View Source

LedgerIndex

(Validated transactions only) The ledger index of the ledger version that includes this transaction.

Declaration
[JsonPropertyName("ledger_index")]
public ulong? LedgerIndex { get; set; }
Property Value
Type Description
ulong?
| Edit this page View Source

Meta

(Validated transactions only) The transaction metadata, which shows the exact outcome of the transaction in detail.

Declaration
[JsonPropertyName("meta")]
public Meta Meta { get; set; }
Property Value
Type Description
Meta
| Edit this page View Source

Proposed

The definition of the proposed transaction in JSON format

Declaration
[JsonPropertyName("transaction")]
public object Proposed { get; set; }
Property Value
Type Description
object
| Edit this page View Source

Status

Declaration
[JsonPropertyName("status")]
public string Status { get; set; }
Property Value
Type Description
string
| Edit this page View Source

Transaction

(JSON mode) JSON object defining the transaction.

Declaration
[JsonIgnore]
public TransactionResponse Transaction { get; }
Property Value
Type Description
TransactionResponse
| Edit this page View Source

TransactionJson

The definition of the transaction in JSON format

Declaration
[JsonPropertyName("tx_json")]
public object TransactionJson { get; set; }
Property Value
Type Description
object
| Edit this page View Source

Validated

If true, this transaction is included in a validated ledger and its outcome is final.
Responses from the transaction stream should always be validated.

Declaration
[JsonPropertyName("validated")]
public bool Validated { get; set; }
Property Value
Type Description
bool
| Edit this page View Source

Warnings

May be omitted) If this field is provided, it contains one or more Warnings Objects with important warnings.
For details, see API Warnings (https://xrpl.org/response-formatting.html#api-warnings)

Declaration
[JsonPropertyName("warnings")]
public object Warnings { get; set; }
Property Value
Type Description
object

Implements

IAccountTransaction
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX