Enum TransactionType
The type of a transaction (TransactionType field) is the most fundamental information about a transaction.
This indicates what type of operation the transaction is supposed to do.
Namespace: Xrpl.Models
Assembly: Xrpl.dll
Syntax
public enum TransactionType
Fields
| Name | Description |
|---|---|
| AMMBid | AMMBid is used for submitting a vote for the trading fee of an AMM Instance. |
| AMMClawback | The AMMClawback transaction claws back tokens from an Automated Market Maker (AMM) pool. It allows the issuer to recover tokens that a holder has deposited into an AMM. |
| AMMCreate | AMMCreate is used to create AccountRoot and the corresponding AMM ledger entries. |
| AMMDelete | Delete an empty Automated Market Maker (AMM) instance that could not be fully deleted automatically. |
| AMMDeposit | AMMDeposit is the deposit transaction used to add liquidity to the AMM instance pool, thus obtaining some share of the instance's pools in the form of LPTokenOut. |
| AMMVote | AMMVote is used for submitting a vote for the trading fee of an AMM Instance. |
| AMMWithdraw | AMMWithdraw is the withdraw transaction used to remove liquidity from the AMM instance pool, thus redeeming some share of the pools that one owns in the form of LPTokenIn. |
| AccountDelete | Delete an account. |
| AccountSet | Set options on an account. |
| Batch | |
| CheckCancel | Cancel a check. |
| CheckCash | Redeem a check. |
| CheckCreate | Create a check. |
| Clawback | The Clawback transaction is used by the token issuer to claw back issued tokens from a holder. |
| CredentialAccept | Accepts a provisionally-issued credential, making it valid. Requires the Credentials amendment. |
| CredentialCreate | Creates a new credential issued to a subject account. Requires the Credentials amendment. |
| CredentialDelete | Deletes (revokes) a credential from the ledger. Requires the Credentials amendment. |
| DIDDelete | Deletes the DID (Decentralized Identifier) associated with an account. |
| DIDSet | Creates or updates the DID (Decentralized Identifier) associated with an account. |
| DepositPreauth | Preauthorizes an account to send payments to this one. |
| EnableAmendment | An EnableAmendment pseudo-transaction marks a change in the status of a proposed amendment when it:
|
| EscrowCancel | Reclaim escrowed XRP. |
| EscrowCreate | Create an escrowed XRP payment. |
| EscrowFinish | Deliver escrowed XRP to recipient. |
| MPTokenAuthorize | The MPTokenAuthorize transaction authorizes an account to hold an MPT. |
| MPTokenIssuanceCreate | The MPTokenIssuanceCreate transaction creates an MPTokenIssuance object. |
| MPTokenIssuanceDestroy | The MPTokenIssuanceDestroy transaction removes an MPTokenIssuance object. |
| MPTokenIssuanceSet | The MPTokenIssuanceSet transaction is used to globally lock/unlock an MPTokenIssuance. |
| NFTokenAcceptOffer | Accept an offer to buy or sell an NFToken. |
| NFTokenBurn | Use TokenBurn to permanently destroy NFTs. |
| NFTokenCancelOffer | Cancel existing token offers to buy or sell an NFToken. |
| NFTokenCreateOffer | Create an offer to buy or sell NFTs. |
| NFTokenMint | Use TokenMint to issue new NFTs. |
| NFTokenModify | The NFTokenModify transaction modifies an NFToken's URI if its tfMutable is set to true. |
| OfferCancel | Withdraw a currency-exchange order. |
| OfferCreate | Submit an order to exchange currency. |
| OracleDelete | Deletes an Oracle ledger entry. |
| OracleSet | Creates a new Oracle ledger entry or updates the fields of an existing one. |
| Payment | Send funds from one account to another. |
| PaymentChannelClaim | Claim money from a payment channel. |
| PaymentChannelCreate | Open a new payment channel. |
| PaymentChannelFund | Add more XRP to a payment channel. |
| PermissionedDomainDelete | Delete a permissioned domain that you own. |
| PermissionedDomainSet | Create a permissioned domain, or modify one that you own. |
| SetFee | A SetFee pseudo-transaction marks a change in transaction cost or reserve requirements as a result of Fee Voting. |
| SetRegularKey | Add, remove, or modify an account's regular key pair. |
| SignerListSet | Add, remove, or modify an account's multi-signing list. |
| TicketCreate | Set aside one or more sequence numbers as Tickets. |
| TrustSet | Add or modify a trust line. |
| UNLModify | A UNLModify pseudo-transaction marks a change to the Negative UNL, indicating that a trusted validator has gone offline or come back online. |
| Unknown | Unknown tx Type. |