Show / Hide Table of Contents

Namespace Xrpl.Models.Transactions

Classes

AMMBid

AMMBid is used for submitting a vote for the trading fee of an AMM Instance. Any XRPL account that holds LPToken for an AMM instance may submit this transaction to vote for the trading fee for that instance.

AMMBidResponse

AMMBid is used for submitting a vote for the trading fee of an AMM Instance. Any XRPL account that holds LPToken for an AMM instance may submit this transaction to vote for the trading fee for that instance.

AMMClawBack

Claw back tokens from an Automated Market Maker (AMM) pool. This transaction allows a token issuer to recover tokens that a holder has deposited into an AMM. The issuer must have enabled clawback on their account before issuing any tokens.

AMMClawBackResponse

Claw back tokens from an Automated Market Maker (AMM) pool. This transaction allows a token issuer to recover tokens that a holder has deposited into an AMM. The issuer must have enabled clawback on their account before issuing any tokens.

AMMCreate

AMMCreate is used to create AccountRoot and the corresponding AMM ledger entries. This allows for the creation of only one AMM instance per unique asset pair.

AMMCreateResponse

AMMCreate is used to create AccountRoot and the corresponding AMM ledger entries. This allows for the creation of only one AMM instance per unique asset pair.

AMMDelete

Delete an empty Automated Market Maker (AMM) instance that could not be fully deleted automatically. Tip: The AMMWithdraw transaction automatically tries to delete an AMM, along with associated ledger entries such as empty trust lines, if it withdrew all the assets from the AMM's pool. However, if there are too many trust lines to the AMM account to remove in one transaction, it may stop before fully removing the AMM.Similarly, an AMMDelete transaction removes up to a maximum number of trust lines; in extreme cases, it may take several AMMDelete transactions to fully delete the trust lines and the associated AMM. In all cases, the AMM ledger entry and AMM account are deleted by the last such transaction.

AMMDeleteResponse

Delete an empty Automated Market Maker (AMM) instance that could not be fully deleted automatically. Tip: The AMMWithdraw transaction automatically tries to delete an AMM, along with associated ledger entries such as empty trust lines, if it withdrew all the assets from the AMM's pool. However, if there are too many trust lines to the AMM account to remove in one transaction, it may stop before fully removing the AMM.Similarly, an AMMDelete transaction removes up to a maximum number of trust lines; in extreme cases, it may take several AMMDelete transactions to fully delete the trust lines and the associated AMM. In all cases, the AMM ledger entry and AMM account are deleted by the last such transaction.

AMMDeposit

AMMDeposit is the deposit transaction used to add liquidity to the AMM instance pool, thus obtaining some share of the instance's pools in the form of LPTokenOut. The following are the recommended valid combinations:

  • LPTokenOut
  • Amount
  • Amount and Amount2
  • Amount and LPTokenOut
  • Amount and EPrice

AMMDepositResponse

AMMDeposit is the deposit transaction used to add liquidity to the AMM instance pool, thus obtaining some share of the instance's pools in the form of LPTokenOut. The following are the recommended valid combinations:

  • LPTokenOut
  • Amount
  • Amount and Amount2
  • Amount and LPTokenOut
  • Amount and EPrice

AMMVote

AMMVoteResponse

AMMWithdraw

AMMWithdraw is the withdraw transaction used to remove liquidity from the AMM instance pool, thus redeeming some share of the pools that one owns in the form of LPTokenIn.

AMMWithdrawResponse

AMMWithdraw is the withdraw transaction used to remove liquidity from the AMM instance pool, thus redeeming some share of the pools that one owns in the form of LPTokenIn.

AcceptedCredential

Represents a credential that grants access to a permissioned domain.

AcceptedCredentialWrapper

Wrapper for a Credential object in the AcceptedCredentials array. Each member of the AcceptedCredentials array is an inner object named Credential.

AccountDelete

An AccountDelete transaction deletes an account and any objects it owns in the XRP Ledger, if possible, sending the account's remaining XRP to a specified destination account.

AccountDeleteResponse

An AccountDelete transaction deletes an account and any objects it owns in the XRP Ledger, if possible, sending the account's remaining XRP to a specified destination account.

AccountSet

An AccountSet transaction modifies the properties of an account in the XRP Ledger.
The AccountSet transaction type has several "AccountSet Flags" (prefixed asf) that can enable an option when passed as the SetFlag parameter,
or disable an option when passed as the ClearFlag parameter.
Newer options have only this style of flag.
You can enable up to one asf flag per transaction, and disable up to one asf flag per transaction.

AccountSetResponse

An AccountSet transaction modifies the properties of an account in the XRP Ledger.
The AccountSet transaction type has several "AccountSet Flags" (prefixed asf) that can enable an option when passed as the SetFlag parameter,
or disable an option when passed as the ClearFlag parameter.
Newer options have only this style of flag.
You can enable up to one asf flag per transaction, and disable up to one asf flag per transaction.

AffectedNode

The AffectedNodes array contains a complete list of the objects in the ledger that this transaction modified in some way.

BaseTransactionResponse

Supports all classes in the .NET class hierarchy and provides low-level services to derived classes. This is the ultimate base class of all .NET classes; it is the root of the type hierarchy.

Batch

BatchResponse

BatchSigner

BatchSigner.BatchInnerSigner

BinaryTransaction

BinaryTransactionResponse

BookOffers

  • Expected response from a BookOffersRequest.

CheckCancel

Cancels an unredeemed Check, removing it from the ledger without sending any money.
The source or the destination of the check can cancel a Check at any time using this transaction type.
If the Check has expired, any address can cancel it.

CheckCancelResponse

Cancels an unredeemed Check, removing it from the ledger without sending any money.
The source or the destination of the check can cancel a Check at any time using this transaction type.
If the Check has expired, any address can cancel it.

CheckCash

Attempts to redeem a Check object in the ledger to receive up to the amount authorized by the corresponding CheckCreate transaction.
Only the Destination address of a Check can cash it with a CheckCash transaction.

CheckCashResponse

Attempts to redeem a Check object in the ledger to receive up to the amount authorized by the corresponding CheckCreate transaction.
Only the Destination address of a Check can cash it with a CheckCash transaction.

CheckCreate

Create a Check object in the ledger, which is a deferred payment that can be cashed by its intended destination.
The sender of this transaction is the sender of the Check.

CheckCreateResponse

Create a Check object in the ledger, which is a deferred payment that can be cashed by its intended destination.
The sender of this transaction is the sender of the Check.

ClawBack

Claw back tokens issued by your account. Issuers can only claw back trust line tokens if they enabled the Allow Trust Line Clawback setting before issuing any tokens. Issuers can claw back MPTs if the corresponding MPT Issuance has clawback enabled.

ClawBackResponse

Claw back tokens issued by your account. Issuers can only claw back trust line tokens if they enabled the Allow Trust Line Clawback setting before issuing any tokens. Issuers can claw back MPTs if the corresponding MPT Issuance has clawback enabled.

Common

CreatedNode

Represents a node that was created in a transaction.

CredentialAccept

Accepts a credential that has been provisionally issued to the Account. Once accepted, the credential becomes valid on the ledger and the reserve responsibility transfers from the issuer to the subject (Account). Requires the Credentials amendment.

CredentialAcceptResponse

Response for a CredentialAccept transaction.

CredentialCreate

Creates a credential on the XRP Ledger. The credential is issued by the transaction sender (Account) to a Subject. The credential is not valid until the Subject accepts it using CredentialAccept. Requires the Credentials amendment.

CredentialCreateResponse

Response for a CredentialCreate transaction.

CredentialDelete

Deletes a credential from the XRP Ledger. Can be submitted by:

  • The issuer of the credential (to revoke it).
  • The subject of the credential (to un-accept it).
  • Any account, if the credential has expired. Requires the Credentials amendment.

CredentialDeleteResponse

Response for a CredentialDelete transaction.

CredentialsValidator

Shared validator for XLS-70 credential collections used across transactions. Mirrors the behavior of validateCredentialsList from xrpl.js.

DIDDelete

Deletes the DID (Decentralized Identifier) associated with the sending account.

DIDDeleteResponse

Deletes the DID (Decentralized Identifier) associated with the sending account.

DIDSet

Creates a new DID ledger entry or updates the fields of an existing one. The DID (Decentralized Identifier) is associated with the sending account.

DIDSetResponse

Creates a new DID ledger entry or updates the fields of an existing one. The DID (Decentralized Identifier) is associated with the sending account.

DeletedNode

Represents a node that was deleted in a transaction.

DepositPreauth

A DepositPreauth transaction gives another account pre-approval to deliver payments to the sender of this transaction.
This is only useful if the sender of this transaction is using (or plans to use) Deposit Authorization.
XLS-70 extends this with credential-based preauthorization via AuthorizeCredentials / UnauthorizeCredentials.

DepositPreauthResponse

A DepositPreauth transaction gives another account pre-approval to deliver payments to the sender of this transaction.
This is only useful if the sender of this transaction is using (or plans to use) Deposit Authorization.
XLS-70 extends this with credential-based preauthorization via AuthorizeCredentials / UnauthorizeCredentials.

EnableAmendment

EnableAmendmentResponse

EscrowCancel

Return escrowed XRP or fungible tokens (IOUs, MPTs) to the sender. Requires the TokenEscrow amendment for fungible token support.

EscrowCancelResponse

Return escrowed XRP or fungible tokens (IOUs, MPTs) to the sender. Requires the TokenEscrow amendment for fungible token support.

EscrowCreate

Sequester XRP or fungible tokens (IOUs, MPTs) until the escrow process either finishes or is canceled. Requires the TokenEscrow amendment for fungible token support.

EscrowCreateResponse

Sequester XRP or fungible tokens (IOUs, MPTs) until the escrow process either finishes or is canceled. Requires the TokenEscrow amendment for fungible token support.

EscrowFinish

Deliver XRP or escrowed fungible tokens (IOUs, MPTs) from a held payment to the recipient. Requires the TokenEscrow amendment for fungible token support.

EscrowFinishResponse

Deliver XRP or escrowed fungible tokens (IOUs, MPTs) from a held payment to the recipient. Requires the TokenEscrow amendment for fungible token support.

InnerSigner

The Signers field contains a multi-signature, which has signatures from up to 8 key pairs, that together should authorize the transaction.

MPTokenAuthorize

The MPTokenAuthorize transaction authorizes an account to hold an MPT.

MPTokenAuthorizeResponse

The MPTokenAuthorize transaction is used to allow an account to hold a particular MPT issuance, or by an issuer to authorize or revoke authorization for a holder.

MPTokenIssuanceCreate

The MPTokenIssuanceCreate transaction creates an MPTokenIssuance object.

MPTokenIssuanceCreateResponse

The MPTokenIssuanceCreate transaction creates an MPTokenIssuance object and adds it to the relevant directory node of the creator account.

MPTokenIssuanceDestroy

The MPTokenIssuanceDestroy transaction removes an MPTokenIssuance object.

MPTokenIssuanceDestroyResponse

The MPTokenIssuanceDestroy transaction is used to remove an MPTokenIssuance object from the directory node in which it is being held, effectively removing the token from the ledger.

MPTokenIssuanceSet

The MPTokenIssuanceSet transaction is used to globally lock/unlock an MPTokenIssuance.

MPTokenIssuanceSetResponse

The MPTokenIssuanceSet transaction is used to globally lock/unlock an MPTokenIssuance, or to lock/unlock a specific holder's MPToken balance for an MPTokenIssuance.

Memo

The Memos field includes arbitrary messaging data with the transaction.

MemoWrapper

Additional arbitrary information used to identify transaction.

Meta

Transaction metadata is a section of data that gets added to a transaction after it is processed.
Any transaction that gets included in a ledger has metadata, regardless of whether it is successful.
The transaction metadata describes the outcome of the transaction in detail.
Warning: The changes described in transaction metadata are only final if the transaction is in a validated ledger version.

ModifiedNode

Represents a node that was modified in a transaction.

NFTokenAcceptOffer

The NFTokenOfferAccept transaction is used to accept offers to buy or sell an NFToken.
It can either:
1.
Allow one offer to be accepted.
This is called direct mode.
2.
Allow two distinct offers, one offering to buy a given NFToken and the other offering to sell the same NFToken, to be accepted in an atomic fashion.
This is called brokered mode.
To indicate direct mode, use either the sell_offer or buy_offer fields, but not both.
To indicate brokered mode, use both the sell_offer and buy_offer fields.
If you use neither sell_offer nor buy_offer, the transaction is invalid.

NFTokenAcceptOfferResponse

The NFTokenOfferAccept transaction is used to accept offers to buy or sell an NFToken.
It can either:
1.
Allow one offer to be accepted.
This is called direct mode.
2.
Allow two distinct offers, one offering to buy a given NFToken and the other offering to sell the same NFToken, to be accepted in an atomic fashion.
This is called brokered mode.
To indicate direct mode, use either the sell_offer or buy_offer fields, but not both.
To indicate brokered mode, use both the sell_offer and buy_offer fields.
If you use neither sell_offer nor buy_offer, the transaction is invalid.

NFTokenBurn

The NFTokenBurn transaction is used to remove an NFToken object from the NFTokenPage in which it is being held, effectively removing the token from the ledger ("burning" it).
If this operation succeeds, the corresponding NFToken is removed.
If this operation empties the NFTokenPage holding the NFToken or results in the consolidation, thus removing an NFTokenPage, the owner’s reserve requirement is reduced by one.

NFTokenBurnResponse

The NFTokenBurn transaction is used to remove an NFToken object from the NFTokenPage in which it is being held, effectively removing the token from the ledger ("burning" it).
If this operation succeeds, the corresponding NFToken is removed.
If this operation empties the NFTokenPage holding the NFToken or results in the consolidation, thus removing an NFTokenPage, the owner’s reserve requirement is reduced by one.

NFTokenCancelOffer

The NFTokenCancelOffer transaction deletes existing NFTokenOffer objects.
It is useful if you want to free up space on your account to lower your reserve requirement.
The transaction can be executed by the account that originally created the NFTokenOffer, the account in the Recipient field of the NFTokenOffer (if present), or any account if the NFTokenOffer has an Expiration and the NFTokenOffer has already expired.

NFTokenCancelOfferResponse

The NFTokenCancelOffer transaction deletes existing NFTokenOffer objects.
It is useful if you want to free up space on your account to lower your reserve requirement.
The transaction can be executed by the account that originally created the NFTokenOffer, the account in the Recipient field of the NFTokenOffer (if present), or any account if the NFTokenOffer has an Expiration and the NFTokenOffer has already expired.

NFTokenCreateOffer

The NFTokenCreateOffer transaction creates either an offer to buy an NFT the submitting account does not own, or an offer to sell an NFT the submitting account does own.

NFTokenCreateOfferResponse

The NFTokenCreateOffer transaction creates either an offer to buy an NFT the submitting account does not own, or an offer to sell an NFT the submitting account does own.

NFTokenMint

The NFTokenMint transaction creates an NFToken object and adds it to the relevant NFTokenPage object of the minter.
If the transaction is successful, the newly minted token will be owned by the minter account specified by the transaction.

NFTokenMintResponse

The NFTokenMint transaction creates an NFToken object and adds it to the relevant NFTokenPage object of the minter.
If the transaction is successful, the newly minted token will be owned by the minter account specified by the transaction.

NFTokenModify

NFTokenModify is used to change the URI field of an NFT to point to a different URI in order to update the supporting data for the NFT.
The NFT must have been minted with the tfMutable flag set.
See Dynamic Non-Fungible Tokens.

NFTokenModifyResponse

NFTokenModify is used to change the URI field of an NFT to point to a different URI in order to update the supporting data for the NFT.
The NFT must have been minted with the tfMutable flag set.
See Dynamic Non-Fungible Tokens.

NodeBase

Base class for ledger entries

NodeInfo

transaction object

Offer

The Offer object type describes an offer to exchange currencies, more traditionally known as an order, in the XRP Ledger's distributed exchange.
An OfferCreate transaction only creates an Offer object in the ledger when the offer cannot be fully executed immediately by consuming other offers already in the ledger.

OfferCancel

An OfferCancel transaction removes an Offer object from the XRP Ledger.

OfferCancelResponse

An OfferCancel transaction removes an Offer object from the XRP Ledger.

OfferCreate

An OfferCreate transaction is effectively a limit order.
It defines an intent to exchange currencies, and creates an Offer object if not completely.
Fulfilled when placed.
Offers can be partially fulfilled.

OfferCreateResponse

An OfferCreate transaction is effectively a limit order.
It defines an intent to exchange currencies, and creates an Offer object if not completely.
Fulfilled when placed.
Offers can be partially fulfilled.

OracleDelete

Deletes an Oracle ledger entry. Only the owner of the price oracle can send this transaction.

OracleDeleteResponse

Deletes an Oracle ledger entry. Only the owner of the price oracle can send this transaction.

OracleSet

Creates a new Oracle ledger entry or updates the fields of an existing one, using the Oracle ID.

OracleSetResponse

Creates a new Oracle ledger entry or updates the fields of an existing one, using the Oracle ID.

Payment

A Payment transaction represents a transfer of value from one account to another.

PaymentChannelClaim

Claim XRP from a payment channel, adjust the payment channel's expiration, or both.

PaymentChannelClaimResponse

Claim XRP from a payment channel, adjust the payment channel's expiration, or both.

PaymentChannelCreate

Create a unidirectional channel and fund it with XRP.
The address sending this transaction becomes the "source address" of the payment channel.

PaymentChannelCreateResponse

Create a unidirectional channel and fund it with XRP.
The address sending this transaction becomes the "source address" of the payment channel.

PaymentChannelFund

Add additional XRP to an open payment channel, and optionally update the expiration time of the channel.
Only the source address of the channel can use this transaction.

PaymentChannelFundResponse

Add additional XRP to an open payment channel, and optionally update the expiration time of the channel.
Only the source address of the channel can use this transaction.

PaymentResponse

A Payment transaction represents a transfer of value from one account to another.

PermissionedDomainDelete

Delete a permissioned domain that you own. Requires the PermissionedDomains amendment.

PermissionedDomainDeleteResponse

Response for a PermissionedDomainDelete transaction.

PermissionedDomainSet

Create a permissioned domain, or modify one that you own. Requires the PermissionedDomains amendment.

PermissionedDomainSetResponse

Response for a PermissionedDomainSet transaction.

RawTransactionWrapper

SetFee

SetFeeResponse

SetRegularKey

A SetRegularKey transaction assigns, changes, or removes the regular key pair associated with an account.

SetRegularKeyResponse

A SetRegularKey transaction assigns, changes, or removes the regular key pair associated with an account.

SignerExtensions

SignerListSet

The SignerListSet transaction creates, replaces, or removes a list of signers that can be used to multi-sign a transaction.

SignerListSetResponse

The SignerListSet transaction creates, replaces, or removes a list of signers that can be used to multi-sign a transaction.

SignerWrapper

Transaction signer

Submit

Response expected from a SubmitRequest.

TicketCreate

A TicketCreate transaction sets aside one or more sequence numbers as Tickets.

TicketCreateResponse

A TicketCreate transaction sets aside one or more sequence numbers as Tickets.

TransactionRequest

Supports all classes in the .NET class hierarchy and provides low-level services to derived classes. This is the ultimate base class of all .NET classes; it is the root of the type hierarchy.

TransactionResponse

Every transaction has the same set of common fields.

TrustSet

Create or modify a trust line linking two accounts.

TrustSetResponse

Create or modify a trust line linking two accounts.

UNLModify

UNLModifyResponse

Validation

Validation for CredentialAccept transactions.

Interfaces

IAMMBid

AMMBid is used for submitting a vote for the trading fee of an AMM Instance. Any XRPL account that holds LPToken for an AMM instance may submit this transaction to vote for the trading fee for that instance.

IAMMClawBack

Claw back tokens from an Automated Market Maker (AMM) pool. This transaction allows a token issuer to recover tokens that a holder has deposited into an AMM. The issuer must have enabled clawback on their account before issuing any tokens.

IAMMCreate

AMMCreate is used to create AccountRoot and the corresponding AMM ledger entries. This allows for the creation of only one AMM instance per unique asset pair.

IAMMDelete

Delete an empty Automated Market Maker (AMM) instance that could not be fully deleted automatically. Tip: The AMMWithdraw transaction automatically tries to delete an AMM, along with associated ledger entries such as empty trust lines, if it withdrew all the assets from the AMM's pool. However, if there are too many trust lines to the AMM account to remove in one transaction, it may stop before fully removing the AMM.Similarly, an AMMDelete transaction removes up to a maximum number of trust lines; in extreme cases, it may take several AMMDelete transactions to fully delete the trust lines and the associated AMM. In all cases, the AMM ledger entry and AMM account are deleted by the last such transaction.

IAMMDeposit

AMMDeposit is the deposit transaction used to add liquidity to the AMM instance pool, thus obtaining some share of the instance's pools in the form of LPTokenOut. The following are the recommended valid combinations:

  • LPTokenOut
  • Amount
  • Amount and Amount2
  • Amount and LPTokenOut
  • Amount and EPrice

IAMMVote

IAMMWithdraw

AMMWithdraw is the withdraw transaction used to remove liquidity from the AMM instance pool, thus redeeming some share of the pools that one owns in the form of LPTokenIn.

IAccountDelete

An AccountDelete transaction deletes an account and any objects it owns in the XRP Ledger, if possible, sending the account's remaining XRP to a specified destination account.

IAccountSet

An AccountSet transaction modifies the properties of an account in the XRP Ledger.
The AccountSet transaction type has several "AccountSet Flags" (prefixed asf) that can enable an option when passed as the SetFlag parameter,
or disable an option when passed as the ClearFlag parameter.
Newer options have only this style of flag.
You can enable up to one asf flag per transaction, and disable up to one asf flag per transaction.

IAffectedNode

IBaseTransactionResponse

This information is added to Transactions in request responses, but is not part of the canonical Transaction information on ledger.
These fields are denoted with lowercase letters to indicate this in the rippled responses.

IBatch

ICheckCancel

Cancels an unredeemed Check, removing it from the ledger without sending any money.
The source or the destination of the check can cancel a Check at any time using this transaction type.
If the Check has expired, any address can cancel it.

ICheckCash

Attempts to redeem a Check object in the ledger to receive up to the amount authorized by the corresponding CheckCreate transaction.
Only the Destination address of a Check can cash it with a CheckCash transaction.

ICheckCreate

Create a Check object in the ledger, which is a deferred payment that can be cashed by its intended destination.
The sender of this transaction is the sender of the Check.

IClawBack

Claw back tokens issued by your account. Issuers can only claw back trust line tokens if they enabled the Allow Trust Line Clawback setting before issuing any tokens. Issuers can claw back MPTs if the corresponding MPT Issuance has clawback enabled.

ICreatedNode

ICredentialAccept

Accepts a credential that has been provisionally issued to the Account. Once accepted, the credential becomes valid on the ledger and the reserve responsibility transfers from the issuer to the subject (Account). Requires the Credentials amendment.

ICredentialCreate

Creates a credential on the XRP Ledger. The credential is issued by the transaction sender (Account) to a Subject. The credential is not valid until the Subject accepts it using CredentialAccept. Requires the Credentials amendment.

ICredentialDelete

Deletes a credential from the XRP Ledger. Can be submitted by:

  • The issuer of the credential (to revoke it).
  • The subject of the credential (to un-accept it).
  • Any account, if the credential has expired. Requires the Credentials amendment.

IDIDDelete

Deletes the DID (Decentralized Identifier) associated with the sending account.

IDIDSet

Creates a new DID ledger entry or updates the fields of an existing one. The DID (Decentralized Identifier) is associated with the sending account.

IDeletedNode

IDepositPreauth

A DepositPreauth transaction gives another account pre-approval to deliver payments to the sender of this transaction.
This is only useful if the sender of this transaction is using (or plans to use) Deposit Authorization.
XLS-70 extends this with credential-based preauthorization via AuthorizeCredentials / UnauthorizeCredentials.

IDestination

object has destination field

IEnableAmendment

IEscrowCancel

Return escrowed XRP or fungible tokens (IOUs, MPTs) to the sender. Requires the TokenEscrow amendment for fungible token support.

IEscrowCreate

Sequester XRP or fungible tokens (IOUs, MPTs) until the escrow process either finishes or is canceled. Requires the TokenEscrow amendment for fungible token support.

IEscrowFinish

Deliver XRP or escrowed fungible tokens (IOUs, MPTs) from a held payment to the recipient. Requires the TokenEscrow amendment for fungible token support.

IMPTokenAuthorize

The MPTokenAuthorize transaction is used to allow an account to hold a particular MPT issuance, or by an issuer to authorize or revoke authorization for a holder.

IMPTokenIssuanceCreate

The MPTokenIssuanceCreate transaction creates an MPTokenIssuance object and adds it to the relevant directory node of the creator account.

IMPTokenIssuanceDestroy

The MPTokenIssuanceDestroy transaction is used to remove an MPTokenIssuance object from the directory node in which it is being held, effectively removing the token from the ledger.

IMPTokenIssuanceSet

The MPTokenIssuanceSet transaction is used to globally lock/unlock an MPTokenIssuance, or to lock/unlock a specific holder's MPToken balance for an MPTokenIssuance.

IModifiedNode

INFTokenAcceptOffer

The NFTokenOfferAccept transaction is used to accept offers to buy or sell an NFToken.
It can either:
1.
Allow one offer to be accepted.
This is called direct mode.
2.
Allow two distinct offers, one offering to buy a given NFToken and the other offering to sell the same NFToken, to be accepted in an atomic fashion.
This is called brokered mode.
To indicate direct mode, use either the sell_offer or buy_offer fields, but not both.
To indicate brokered mode, use both the sell_offer and buy_offer fields.
If you use neither sell_offer nor buy_offer, the transaction is invalid.

INFTokenBurn

The NFTokenBurn transaction is used to remove an NFToken object from the NFTokenPage in which it is being held, effectively removing the token from the ledger ("burning" it).
If this operation succeeds, the corresponding NFToken is removed.
If this operation empties the NFTokenPage holding the NFToken or results in the consolidation, thus removing an NFTokenPage, the owner’s reserve requirement is reduced by one.

INFTokenCancelOffer

The NFTokenCancelOffer transaction deletes existing NFTokenOffer objects.
It is useful if you want to free up space on your account to lower your reserve requirement.
The transaction can be executed by the account that originally created the NFTokenOffer, the account in the Recipient field of the NFTokenOffer (if present), or any account if the NFTokenOffer has an Expiration and the NFTokenOffer has already expired.

INFTokenCreateOffer

The NFTokenCreateOffer transaction creates either an offer to buy an NFT the submitting account does not own, or an offer to sell an NFT the submitting account does own.

INFTokenMint

The NFTokenMint transaction creates an NFToken object and adds it to the relevant NFTokenPage object of the minter.
If the transaction is successful, the newly minted token will be owned by the minter account specified by the transaction.

INFTokenModify

NFTokenModify is used to change the URI field of an NFT to point to a different URI in order to update the supporting data for the NFT.
The NFT must have been minted with the tfMutable flag set.
See Dynamic Non-Fungible Tokens.

IOfferCancel

An OfferCancel transaction removes an Offer object from the XRP Ledger.

IOfferCreate

An OfferCreate transaction is effectively a limit order.
It defines an intent to exchange currencies, and creates an Offer object if not completely.
Fulfilled when placed.
Offers can be partially fulfilled.

IOracleDelete

Deletes an Oracle ledger entry. Only the owner of the price oracle can send this transaction.

IOracleSet

Creates a new Oracle ledger entry or updates the fields of an existing one, using the Oracle ID.

IPayment

A Payment transaction represents a transfer of value from one account to another.

IPaymentChannelClaim

Claim XRP from a payment channel, adjust the payment channel's expiration, or both.

IPaymentChannelCreate

Create a unidirectional channel and fund it with XRP.
The address sending this transaction becomes the "source address" of the payment channel.

IPaymentChannelFund

Add additional XRP to an open payment channel, and optionally update the expiration time of the channel.
Only the source address of the channel can use this transaction.

IPermissionedDomainDelete

Delete a permissioned domain that you own. Requires the PermissionedDomains amendment.

IPermissionedDomainSet

Create a permissioned domain, or modify one that you own. Requires the PermissionedDomains amendment.

ISetFee

ISetRegularKey

A SetRegularKey transaction assigns, changes, or removes the regular key pair associated with an account.

ISignerListSet

The SignerListSet transaction creates, replaces, or removes a list of signers that can be used to multi-sign a transaction.

ITicketCreate

A TicketCreate transaction sets aside one or more sequence numbers as Tickets.

ITransactionCommon

Every transaction has the same set of common fields.

ITransactionMetadata

ITransactionRequest

ITransactionResponse

Every transaction has the same set of common fields.

ITrustSet

Create or modify a trust line linking two accounts.

IUNLModify

Enums

AMMDepositFlags

Enum representing values for AMMDeposit Transaction Flags.

AMMWithdrawFlags

Enum representing values for AMMWithdrawFlags Transaction Flags

AccountSetAsfFlags

Enum for AccountSet Flags.

BatchFlags

MPTokenAuthorizeFlags

Enum representing flags for MPTokenAuthorize transactions.

MPTokenIssuanceCreateFlags

Enum representing flags for MPTokenIssuanceCreate transactions.

MPTokenIssuanceSetFlags

Enum representing flags for MPTokenIssuanceSet transactions.

NFTokenCreateOfferFlags

Transaction Flags for an NFTokenCreateOffer Transaction.

NFTokenMintFlags

Transaction Flags for an NFTokenMint Transaction.

OfferCreateFlags

Transaction Flags for an OfferCreate Transaction.

OfferFlags

There are several options which can be either enabled or disabled when an OfferCreate transaction creates an offer object.
In the ledger, flags are represented as binary values that can be combined with bitwise-or operations.
The bit values for the flags in the ledger are different than the values used to enable or disable those flags in a transaction.
Ledger flags have names that begin with lsf.

PaymentChannelClaimFlags

Enum representing values for PaymentChannelClaim transaction flags.

PaymentFlags

Enum representing values for Payment Transaction Flags.

TrustSetFlags

Enum representing values of ITrustSet transaction flags.

In this article
Back to top Generated by DocFX