Class AMMClawBackResponse
Claw back tokens from an Automated Market Maker (AMM) pool. This transaction allows a token issuer to recover tokens that a holder has deposited into an AMM. The issuer must have enabled clawback on their account before issuing any tokens.
Inherited Members
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public class AMMClawBackResponse : TransactionResponse, ITransactionResponse, IBaseTransactionResponse, IAMMClawBack, ITransactionCommon
Properties
| Edit this page View SourceAmount
The amount of the asset to claw back from the AMM pool. If not provided, claws back the maximum possible amount.
Declaration
[JsonConverter(typeof(CurrencyConverter))]
public Currency Amount { get; set; }
Property Value
| Type | Description |
|---|---|
| Currency |
Asset
Specifies one of the pool assets (XRP or token) of the AMM instance. Together with Asset2, this identifies which AMM pool to claw back from.
Declaration
[JsonConverter(typeof(IssuedCurrencyConverter))]
public Common.IssuedCurrency Asset { get; set; }
Property Value
| Type | Description |
|---|---|
| Common.IssuedCurrency |
Asset2
Specifies the other pool asset of the AMM instance. Together with Asset, this identifies which AMM pool to claw back from.
Declaration
[JsonConverter(typeof(IssuedCurrencyConverter))]
public Common.IssuedCurrency Asset2 { get; set; }
Property Value
| Type | Description |
|---|---|
| Common.IssuedCurrency |
Holder
The account holding the asset to be clawed back. This is the holder who deposited tokens into the AMM pool.
Declaration
[JsonPropertyName("Holder")]
public string Holder { get; set; }
Property Value
| Type | Description |
|---|---|
| string |