Class AMMCreateResponse
AMMCreate is used to create AccountRoot and the corresponding AMM ledger entries. This allows for the creation of only one AMM instance per unique asset pair.
Inherited Members
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public class AMMCreateResponse : TransactionResponse, ITransactionResponse, IBaseTransactionResponse, IAMMCreate, ITransactionCommon
Properties
| Edit this page View SourceAmount
Specifies one of the pool assets (XRP or token) of the AMM instance.
Declaration
[JsonConverter(typeof(CurrencyConverter))]
public Currency Amount { get; set; }
Property Value
| Type | Description |
|---|---|
| Currency |
Amount2
Specifies the other pool asset of the AMM instance.
Declaration
[JsonConverter(typeof(CurrencyConverter))]
public Currency Amount2 { get; set; }
Property Value
| Type | Description |
|---|---|
| Currency |
TradingFee
Specifies the fee, in basis point, to be charged to the traders for the trades executed against the AMM instance. Trading fee is a percentage of the trading volume. Valid values for this field are between 0 and 1000 inclusive. A value of 1 is equivalent to 1/10 bps or 0.001%, allowing trading fee between 0% and 1%.
Declaration
public uint TradingFee { get; set; }
Property Value
| Type | Description |
|---|---|
| uint |