Class AMMDeleteResponse
Delete an empty Automated Market Maker (AMM) instance that could not be fully deleted automatically. Tip: The AMMWithdraw transaction automatically tries to delete an AMM, along with associated ledger entries such as empty trust lines, if it withdrew all the assets from the AMM's pool. However, if there are too many trust lines to the AMM account to remove in one transaction, it may stop before fully removing the AMM.Similarly, an AMMDelete transaction removes up to a maximum number of trust lines; in extreme cases, it may take several AMMDelete transactions to fully delete the trust lines and the associated AMM. In all cases, the AMM ledger entry and AMM account are deleted by the last such transaction.
Inherited Members
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public class AMMDeleteResponse : TransactionResponse, ITransactionResponse, IBaseTransactionResponse, IAMMDelete, ITransactionCommon
Properties
| Edit this page View SourceAsset
The definition for one of the assets in the AMM's pool.
Declaration
[JsonConverter(typeof(IssuedCurrencyConverter))]
public Common.IssuedCurrency Asset { get; set; }
Property Value
| Type | Description |
|---|---|
| Common.IssuedCurrency |
Asset2
The definition for the other asset in the AMM's pool.
Declaration
[JsonConverter(typeof(IssuedCurrencyConverter))]
public Common.IssuedCurrency Asset2 { get; set; }
Property Value
| Type | Description |
|---|---|
| Common.IssuedCurrency |