Enum AMMDepositFlags
Enum representing values for AMMDeposit Transaction Flags.
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public enum AMMDepositFlags : uint
Fields
| Name | Description |
|---|---|
| tfInnerBatchTxn | batch inner transaction |
| tfLPToken | Perform a double-asset deposit and receive the specified amount of LP Tokens. |
| tfLimitLPToken | Perform a single-asset deposit with a specified effective price. |
| tfOneAssetLPToken | Perform a single-asset deposit and receive the specified amount of LP Tokens. |
| tfSingleAsset | Perform a single-asset deposit with a specified amount of the asset to deposit. |
| tfTwoAsset | Perform a double-asset deposit with specified amounts of both assets. |
| tfTwoAssetIfEmpty | Deposit both of this AMM's assets, in exactly the specified amounts, to an AMM with an empty asset pool. |