Enum AMMWithdrawFlags
Enum representing values for AMMWithdrawFlags Transaction Flags
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public enum AMMWithdrawFlags : uint
Fields
| Name | Description |
|---|---|
| tfInnerBatchTxn | batch inner transaction |
| tfLPToken | Perform a double-asset withdrawal and receive the specified amount of LP Tokens. |
| tfLimitLPToken | Perform a single-asset withdrawal with a specified effective price. |
| tfOneAssetLPToken | Perform a single-asset withdrawal and receive the specified amount of LP Tokens. |
| tfOneAssetWithdrawAll | Perform a single-asset withdrawal returning all of your LP Tokens. |
| tfSingleAsset | Perform a single-asset withdrawal with a specified amount of the asset to withdrawal. |
| tfTwoAsset | Perform a double-asset withdrawal with specified amounts of both assets. |
| tfWithdrawAll | Perform a double-asset withdrawal returning all your LP Tokens. |