Class AcceptedCredential
Represents a credential that grants access to a permissioned domain.
Inheritance
object
AcceptedCredential
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public class AcceptedCredential
Properties
| Edit this page View SourceCredentialType
The type of credential, as hexadecimal. This is an arbitrary value from 1 to 64 bytes that the issuer sets when they issue a credential.
Declaration
[JsonPropertyName("CredentialType")]
public string CredentialType { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
Issuer
The issuer of the credential.
Declaration
[JsonPropertyName("Issuer")]
public string Issuer { get; set; }
Property Value
| Type | Description |
|---|---|
| string |