Class AffectedNode
The AffectedNodes array contains a complete list of the objects in the ledger that this transaction modified in some way.
Inheritance
Implements
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public class AffectedNode : IAffectedNode
Properties
| Edit this page View SourceCreatedNode
indicates that the transaction created a new object in the ledger.
Declaration
public CreatedNode? CreatedNode { get; set; }
Property Value
| Type | Description |
|---|---|
| CreatedNode |
DeletedNode
indicates that the transaction removed an object from the ledger.
Declaration
public DeletedNode? DeletedNode { get; set; }
Property Value
| Type | Description |
|---|---|
| DeletedNode |
ModifiedNode
indicates that the transaction modified an existing object in the ledger.
Declaration
public ModifiedNode? ModifiedNode { get; set; }
Property Value
| Type | Description |
|---|---|
| ModifiedNode |