Show / Hide Table of Contents

Class BaseTransactionResponse

Supports all classes in the .NET class hierarchy and provides low-level services to derived classes. This is the ultimate base class of all .NET classes; it is the root of the type hierarchy.

Inheritance
object
BaseTransactionResponse
BinaryTransactionResponse
TransactionResponse
Implements
IBaseTransactionResponse
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public class BaseTransactionResponse : IBaseTransactionResponse

Properties

| Edit this page View Source

Date

The date/time when this transaction was included in a validated ledger.

Declaration
[JsonConverter(typeof(RippleDateTimeConverter))]
[JsonPropertyName("date")]
public DateTime? Date { get; set; }
Property Value
Type Description
Nullable
| Edit this page View Source

Hash

An identifying hash value unique to this transaction, as a hex string.

Declaration
[JsonPropertyName("hash")]
public string Hash { get; set; }
Property Value
Type Description
string
| Edit this page View Source

InLedger

Declaration
[JsonPropertyName("inLedger")]
public uint? InLedger { get; set; }
Property Value
Type Description
uint?
| Edit this page View Source

LedgerIndex

The sequence number of the ledger that included this transaction.

Declaration
[JsonPropertyName("ledger_index")]
public uint? LedgerIndex { get; set; }
Property Value
Type Description
uint?
| Edit this page View Source

Validated

Declaration
[JsonPropertyName("validated")]
public bool? Validated { get; set; }
Property Value
Type Description
bool?

Implements

IBaseTransactionResponse
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX