Class BaseTransactionResponse
Supports all classes in the .NET class hierarchy and provides low-level services to derived classes. This is the ultimate base class of all .NET classes; it is the root of the type hierarchy.
Inheritance
object
BaseTransactionResponse
Assembly: Xrpl.dll
Syntax
public class BaseTransactionResponse : IBaseTransactionResponse
Properties
|
Edit this page
Date
The date/time when this transaction was included in a validated ledger.
Declaration
[JsonConverter(typeof(RippleDateTimeConverter))]
[JsonPropertyName("date")]
public DateTime? Date { get; set; }
Property Value
| Type |
Description |
| Nullable |
|
|
Edit this page
Hash
An identifying hash value unique to this transaction, as a hex string.
Declaration
[JsonPropertyName("hash")]
public string Hash { get; set; }
Property Value
|
Edit this page
InLedger
Declaration
[JsonPropertyName("inLedger")]
public uint? InLedger { get; set; }
Property Value
|
Edit this page
LedgerIndex
The sequence number of the ledger that included this transaction.
Declaration
[JsonPropertyName("ledger_index")]
public uint? LedgerIndex { get; set; }
Property Value
|
Edit this page
Validated
Declaration
[JsonPropertyName("validated")]
public bool? Validated { get; set; }
Property Value
Implements