Class Common
Inheritance
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public class Common
Methods
| Edit this page View SourceIsAmount(object)
Verify the form and type of an Amount at runtime.
Declaration
public static bool IsAmount(object amount)
Parameters
| Type | Name | Description |
|---|---|---|
| object | amount | The object to check the form and type of. |
Returns
| Type | Description |
|---|---|
| bool | Whether the Amount is malformed. |
IsIssue(object)
Verify the form and type of an Issue at runtime.
Declaration
public static bool IsIssue(object input)
Parameters
| Type | Name | Description |
|---|---|---|
| object | input | The object to check the form and type of. |
Returns
| Type | Description |
|---|---|
| bool | Whether the Issue is malformed. |
IsIssuedCurrency(object)
Verify the form and type of an IssuedCurrencyAmount at runtime.
Declaration
public static bool IsIssuedCurrency(object input)
Parameters
| Type | Name | Description |
|---|---|---|
| object | input | The input to check the form and type of. |
Returns
| Type | Description |
|---|---|
| bool | Whether the IssuedCurrencyAmount is malformed. |
IsMemo(object)
Verify the form and type of Memo at runtime.
Declaration
public static bool IsMemo(object memo)
Parameters
| Type | Name | Description |
|---|---|---|
| object | memo | The object to check the form and type of. |
Returns
| Type | Description |
|---|---|
| bool | Whether the Memo is malformed. |
IsRecord(object)
Declaration
public static bool IsRecord(object value)
Parameters
| Type | Name | Description |
|---|---|---|
| object | value |
Returns
| Type | Description |
|---|---|
| bool |
IsSigner(object)
Verify the form and type of Signer at runtime.
Declaration
public static bool IsSigner(object signer)
Parameters
| Type | Name | Description |
|---|---|---|
| object | signer | The object to check the form and type of. |
Returns
| Type | Description |
|---|---|
| bool | Whether the Signer is malformed. |
ParseAmountValue(object)
Parse the value of an amount, expressed either in XRP or as an Issued Currency, into a number.
Declaration
public static double ParseAmountValue(object amount)
Parameters
| Type | Name | Description |
|---|---|---|
| object | amount | An Amount to parse for its value. |
Returns
| Type | Description |
|---|---|
| double |
Exceptions
| Type | Condition |
|---|---|
| ValidationException | The parsed amount value, or null if the amount count not be parsed. |
ValidateBaseTransaction(Dictionary<string, object>)
Verify the common fields of a transaction.
The validate functionality will be optional, and will check transaction form at runtime.
This should be called any time a transaction will be verified.
Declaration
public static Task ValidateBaseTransaction(Dictionary<string, object> tx)
Parameters
| Type | Name | Description |
|---|---|---|
| Dictionary<string, object> | tx | An interface w/ common transaction fields. |
Returns
| Type | Description |
|---|---|
| Task |
Exceptions
| Type | Condition |
|---|---|
| ValidationException | When the common param is malformed. |