Class ConfidentialMPTSend
Sends a confidential MPT amount to another holder's confidential inbox.
Inherited Members
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public class ConfidentialMPTSend : TransactionRequest, ITransactionRequest, IConfidentialMPTSend, ITransactionCommon, IDestination
Remarks
Requires the ConfidentialTransfer amendment. This feature is in draft and subject to change.
Constructors
| Edit this page View SourceConfidentialMPTSend()
Declaration
public ConfidentialMPTSend()
Properties
| Edit this page View SourceAmountCommitment
A commitment to the sent amount, hex-encoded.
Declaration
[JsonPropertyName("AmountCommitment")]
public string AmountCommitment { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
AuditorEncryptedAmount
(Optional) The sent amount encrypted under the auditor's key, hex-encoded.
Declaration
[JsonPropertyName("AuditorEncryptedAmount")]
public string AuditorEncryptedAmount { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
BalanceCommitment
A commitment to the sender's confidential balance left after the transfer, hex-encoded.
Declaration
[JsonPropertyName("BalanceCommitment")]
public string BalanceCommitment { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
CredentialIDs
(Optional) Set of Credentials (object IDs, hex 64-char each) to authorize the transfer when the destination account requires Deposit Authorization with credential-based preauth (XLS-70).
Declaration
[JsonPropertyName("CredentialIDs")]
public List<string> CredentialIDs { get; set; }
Property Value
| Type | Description |
|---|---|
| List<string> |
Destination
The account whose confidential inbox receives the amount.
Declaration
[JsonPropertyName("Destination")]
public string Destination { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
DestinationEncryptedAmount
The sent amount encrypted under the destination's key, hex-encoded.
Declaration
[JsonPropertyName("DestinationEncryptedAmount")]
public string DestinationEncryptedAmount { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
DestinationTag
(Optional) Arbitrary tag that identifies the reason for the transfer to the destination, or a hosted recipient.
Declaration
[JsonPropertyName("DestinationTag")]
public uint? DestinationTag { get; set; }
Property Value
| Type | Description |
|---|---|
| uint? |
IssuerEncryptedAmount
The sent amount encrypted under the issuer's key, hex-encoded.
Declaration
[JsonPropertyName("IssuerEncryptedAmount")]
public string IssuerEncryptedAmount { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
MPTokenIssuanceID
The ID of the MPT issuance the amount is sent in.
Declaration
[JsonPropertyName("MPTokenIssuanceID")]
public string MPTokenIssuanceID { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
SenderEncryptedAmount
The sent amount encrypted under the sender's key, hex-encoded.
Declaration
[JsonPropertyName("SenderEncryptedAmount")]
public string SenderEncryptedAmount { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
ZKProof
The zero-knowledge proof over the encrypted amounts and commitments, hex-encoded.
Declaration
[JsonPropertyName("ZKProof")]
public string ZKProof { get; set; }
Property Value
| Type | Description |
|---|---|
| string |