Class CredentialAccept
Accepts a credential that has been provisionally issued to the Account. Once accepted, the credential becomes valid on the ledger and the reserve responsibility transfers from the issuer to the subject (Account). Requires the Credentials amendment.
Inherited Members
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public class CredentialAccept : TransactionRequest, ITransactionRequest, ICredentialAccept, ITransactionCommon
Constructors
| Edit this page View SourceCredentialAccept()
Declaration
public CredentialAccept()
Properties
| Edit this page View SourceCredentialType
The type of credential to accept, as a hex-encoded string.
Declaration
[JsonPropertyName("CredentialType")]
public string CredentialType { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
CredentialTypeValue
Decoded human-readable value of CredentialType (UTF-8).
Declaration
[JsonIgnore]
public string CredentialTypeValue { get; }
Property Value
| Type | Description |
|---|---|
| string |
Issuer
The issuer of the credential to accept.
Declaration
[JsonPropertyName("Issuer")]
public string Issuer { get; set; }
Property Value
| Type | Description |
|---|---|
| string |