Class CredentialCreateResponse
Response for a CredentialCreate transaction.
Inherited Members
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public class CredentialCreateResponse : TransactionResponse, ITransactionResponse, IBaseTransactionResponse, ICredentialCreate, ITransactionCommon
Properties
| Edit this page View SourceCredentialType
A value to identify the type of credential, as a hex-encoded string. This must be between 1 and 64 bytes (2 to 128 hex characters).
Declaration
[JsonPropertyName("CredentialType")]
public string CredentialType { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
CredentialTypeValue
Decoded human-readable value of CredentialType (UTF-8).
Declaration
[JsonIgnore]
public string CredentialTypeValue { get; }
Property Value
| Type | Description |
|---|---|
| string |
Expiration
(Optional) The time after which the credential expires, in seconds since the Ripple Epoch.
Declaration
[JsonConverter(typeof(RippleDateTimeConverter))]
[JsonPropertyName("Expiration")]
public DateTime? Expiration { get; set; }
Property Value
| Type | Description |
|---|---|
| Nullable |
Subject
The account that is the subject (recipient) of the credential.
Declaration
[JsonPropertyName("Subject")]
public string Subject { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
URI
(Optional) An arbitrary URI reference for additional credential data, as a hex-encoded string. Can be at most 256 bytes (512 hex characters).
Declaration
[JsonPropertyName("URI")]
public string URI { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
URIValue
Decoded human-readable value of URI (UTF-8).
Declaration
[JsonIgnore]
public string URIValue { get; }
Property Value
| Type | Description |
|---|---|
| string |