Class DelegateSet
The DelegateSet transaction grants permissions to another account to send transactions on your behalf.
Inherited Members
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public class DelegateSet : TransactionRequest, ITransactionRequest, IDelegateSet, ITransactionCommon
Constructors
| Edit this page View SourceDelegateSet()
Declaration
public DelegateSet()
Properties
| Edit this page View SourceDelegate
The account to delegate permissions to.
Declaration
[JsonPropertyName("Delegate")]
public string Delegate { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
Permissions
An array of permission objects defining which transaction types the delegate can submit.
Declaration
[JsonPropertyName("Permissions")]
public List<PermissionWrapper> Permissions { get; set; }
Property Value
| Type | Description |
|---|---|
| List<PermissionWrapper> |