Class DeletedNode
Represents a node that was deleted in a transaction.
Inheritance
object
DeletedNode
Assembly: Xrpl.dll
Syntax
[JsonConverter(typeof(DeletedNodeConverter))]
public class DeletedNode : NodeBase, IDeletedNode
Properties
|
Edit this page
FinalFields
The content fields of the ledger entry immediately before it was deleted.
Which fields are present depends on what type of ledger entry was created.
Declaration
[JsonPropertyName("FinalFields")]
public BaseLedgerEntry? FinalFields { get; set; }
Property Value
|
Edit this page
PreviousFields
(May be omitted) Selected fields of the ledger entry before it was deleted.
Which fields are present depends on what type of ledger entry was created.
Declaration
[JsonPropertyName("PreviousFields")]
public BaseLedgerEntry? PreviousFields { get; set; }
Property Value
Methods
|
Edit this page
TryGetFinal<T>(out T?)
Declaration
public bool TryGetFinal<T>(out T? value) where T : BaseLedgerEntry
Parameters
| Type |
Name |
Description |
| T |
value |
|
Returns
Type Parameters
|
Edit this page
TryGetPrevious<T>(out T?)
Declaration
public bool TryGetPrevious<T>(out T? value) where T : BaseLedgerEntry
Parameters
| Type |
Name |
Description |
| T |
value |
|
Returns
Type Parameters
Implements