Class EscrowCreate
Sequester XRP or fungible tokens (IOUs, MPTs) until the escrow process either finishes or is canceled. Requires the TokenEscrow amendment for fungible token support.
Inherited Members
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public class EscrowCreate : TransactionRequest, ITransactionRequest, IEscrowCreate, ITransactionCommon, IDestination
Constructors
| Edit this page View SourceEscrowCreate()
Declaration
public EscrowCreate()
Properties
| Edit this page View SourceAmount
The amount to deduct from the sender's balance and set aside in escrow. Can be XRP (in drops, as a string), an IOU token, or an MPT. Must always be a positive value. With the TokenEscrow amendment, this field supports fungible tokens in addition to XRP.
Declaration
[JsonConverter(typeof(CurrencyConverter))]
public Currency Amount { get; set; }
Property Value
| Type | Description |
|---|---|
| Currency |
CancelAfter
The time, in seconds since the Ripple Epoch, when this escrow expires.
This value is immutable; the funds can only be returned the sender after.
this time.
Declaration
[JsonConverter(typeof(RippleDateTimeConverter))]
public DateTime? CancelAfter { get; set; }
Property Value
| Type | Description |
|---|---|
| Nullable |
Condition
Hex value representing a PREIMAGE-SHA-256 crypto-condition.
The funds can.
only be delivered to the recipient if this condition is fulfilled.
Declaration
public string Condition { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
Destination
Address to receive escrowed funds.
Declaration
public string Destination { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
DestinationTag
Arbitrary tag to further specify the destination for this escrowed.
payment, such as a hosted recipient at the destination address.
Declaration
public uint? DestinationTag { get; set; }
Property Value
| Type | Description |
|---|---|
| uint? |
FinishAfter
The time, in seconds since the Ripple Epoch, when the escrowed XRP can be released to the recipient.
This value is immutable; the funds cannot move.
until this time is reached.
Declaration
[JsonConverter(typeof(RippleDateTimeConverter))]
public DateTime? FinishAfter { get; set; }
Property Value
| Type | Description |
|---|---|
| Nullable |