Interface IAMMBid
AMMBid is used for submitting a vote for the trading fee of an AMM Instance. Any XRPL account that holds LPToken for an AMM instance may submit this transaction to vote for the trading fee for that instance.
Inherited Members
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public interface IAMMBid : ITransactionCommon
Properties
| Edit this page View SourceAsset
Specifies one of the pool assets (XRP or token) of the AMM instance.
Declaration
Common.IssuedCurrency Asset { get; set; }
Property Value
| Type | Description |
|---|---|
| Common.IssuedCurrency |
Asset2
Specifies the other pool asset of the AMM instance.
Declaration
Common.IssuedCurrency Asset2 { get; set; }
Property Value
| Type | Description |
|---|---|
| Common.IssuedCurrency |
AuthAccounts
This field represents an array of XRPL account IDs that are authorized to trade at the discounted fee against the AMM instance. A maximum of four accounts can be provided.
Declaration
List<AuthAccount> AuthAccounts { get; set; }
Property Value
| Type | Description |
|---|---|
| List<AuthAccount> |
BidMax
This field represents the maximum price that the bidder wants to pay for the slot. It is specified in units of LPToken.
Declaration
Currency? BidMax { get; set; }
Property Value
| Type | Description |
|---|---|
| Currency |
BidMin
This field represents the minimum price that the bidder wants to pay for the slot. It is specified in units of LPToken.If specified let BidMin be X and let the slot-price computed by price scheduling algorithm be Y, then bidder always pays the max(X, Y).
Declaration
Currency? BidMin { get; set; }
Property Value
| Type | Description |
|---|---|
| Currency |