Interface IAMMWithdraw
AMMWithdraw is the withdraw transaction used to remove liquidity from the AMM instance pool, thus redeeming some share of the pools that one owns in the form of LPTokenIn.
Inherited Members
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public interface IAMMWithdraw : ITransactionCommon
Properties
| Edit this page View SourceAmount
Specifies one of the pools assets that the trader wants to remove. If the asset is XRP, then the Amount is a string specifying the number of drops. Otherwise it is an IssuedCurrencyAmount object.
Declaration
Currency Amount { get; set; }
Property Value
| Type | Description |
|---|---|
| Currency |
Amount2
Specifies the other pool asset that the trader wants to remove.
Declaration
Currency Amount2 { get; set; }
Property Value
| Type | Description |
|---|---|
| Currency |
Asset
Specifies one of the pool assets (XRP or token) of the AMM instance.
Declaration
Common.IssuedCurrency Asset { get; set; }
Property Value
| Type | Description |
|---|---|
| Common.IssuedCurrency |
Asset2
Specifies the other pool asset of the AMM instance.
Declaration
Common.IssuedCurrency Asset2 { get; set; }
Property Value
| Type | Description |
|---|---|
| Common.IssuedCurrency |
EPrice
Specifies the effective-price of the token out after successful execution of the transaction.
Declaration
Currency EPrice { get; set; }
Property Value
| Type | Description |
|---|---|
| Currency |
Flags
Declaration
AMMWithdrawFlags? Flags { get; set; }
Property Value
| Type | Description |
|---|---|
| AMMWithdrawFlags? |
LPTokenIn
Specifies the amount of shares of the AMM instance pools that the trader wants to redeem or trade in.
Declaration
Currency LPTokenIn { get; set; }
Property Value
| Type | Description |
|---|---|
| Currency |