Interface IAccountDelete
An AccountDelete transaction deletes an account and any objects it owns in the XRP Ledger, if possible, sending the account's remaining XRP to a specified destination account.
Inherited Members
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public interface IAccountDelete : ITransactionCommon, IDestination
Properties
| Edit this page View SourceCredentialIDs
(Optional) Set of Credentials (object IDs, hex 64-char each) used to authorize delivering the residual XRP when the destination account requires Deposit Authorization with credential-based preauth (XLS-70). Maximum 8 entries.
Declaration
List<string> CredentialIDs { get; set; }
Property Value
| Type | Description |
|---|---|
| List<string> |
Destination
The address of an account to receive any leftover XRP after deleting the sending account.
Must be a funded account in the ledger, and must not be.
the sending account.
Declaration
string Destination { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
DestinationTag
Arbitrary destination tag that identifies a hosted recipient or other.
information for the recipient of the deleted account's leftover XRP.
Declaration
uint? DestinationTag { get; set; }
Property Value
| Type | Description |
|---|---|
| uint? |