Interface IAccountSet
An AccountSet transaction modifies the properties of an account in the XRP Ledger.
The AccountSet transaction type has several "AccountSet Flags" (prefixed asf) that can enable an option when passed as the SetFlag parameter,
or disable an option when passed as the ClearFlag parameter.
Newer options have only this style of flag.
You can enable up to one asf flag per transaction, and disable up to one asf flag per transaction.
Inherited Members
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public interface IAccountSet : ITransactionCommon
Properties
| Edit this page View SourceClearFlag
Unique identifier of a flag to disable for this account.
Declaration
AccountSetAsfFlags? ClearFlag { get; set; }
Property Value
| Type | Description |
|---|---|
| AccountSetAsfFlags? |
Domain
The domain that owns this account, as a string of hex representing the.
ASCII for the domain in lowercase.
Declaration
string Domain { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
EmailHash
Hash of an email address to be used for generating an avatar image.
Declaration
string EmailHash { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
MessageKey
Public key for sending encrypted messages to this account.
Declaration
string MessageKey { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
NFTokenMinter
Optional) Another account that can mint NFTokens for you.
Declaration
string NFTokenMinter { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
SetFlag
Integer flag to enable for this account.
Declaration
AccountSetAsfFlags? SetFlag { get; set; }
Property Value
| Type | Description |
|---|---|
| AccountSetAsfFlags? |
TickSize
Tick size to use for offers involving a currency issued by this address.
The exchange rates of those offers is rounded to this many significant digits.
Valid values are 3 to 15 inclusive, or 0 to disable.
Declaration
uint? TickSize { get; set; }
Property Value
| Type | Description |
|---|---|
| uint? |
TransferRate
The fee to charge when users transfer this account's issued currencies, represented as billionths of a unit.
Cannot be more than 2000000000 or less than 1000000000, except for the special case 0 meaning no fee.
Declaration
uint? TransferRate { get; set; }
Property Value
| Type | Description |
|---|---|
| uint? |