Show / Hide Table of Contents

Interface IBaseTransactionResponse

This information is added to Transactions in request responses, but is not part of the canonical Transaction information on ledger.
These fields are denoted with lowercase letters to indicate this in the rippled responses.

Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public interface IBaseTransactionResponse

Properties

| Edit this page View Source

Date

The date/time when this transaction was included in a validated ledger.

Declaration
[JsonConverter(typeof(RippleDateTimeConverter))]
[JsonPropertyName("date")]
DateTime? Date { get; set; }
Property Value
Type Description
Nullable
| Edit this page View Source

Hash

An identifying hash value unique to this transaction, as a hex string.

Declaration
[JsonPropertyName("hash")]
string Hash { get; set; }
Property Value
Type Description
string
| Edit this page View Source

InLedger

Declaration
[JsonPropertyName("inLedger")]
uint? InLedger { get; set; }
Property Value
Type Description
uint?
| Edit this page View Source

LedgerIndex

The sequence number of the ledger that included this transaction.

Declaration
[JsonPropertyName("ledger_index")]
uint? LedgerIndex { get; set; }
Property Value
Type Description
uint?
| Edit this page View Source

Validated

Declaration
[JsonPropertyName("validated")]
bool? Validated { get; set; }
Property Value
Type Description
bool?
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX