Interface IBaseTransactionResponse
This information is added to Transactions in request responses, but is not part of the canonical Transaction information on ledger.
These fields are denoted with lowercase letters to indicate this in the rippled responses.
Assembly: Xrpl.dll
Syntax
public interface IBaseTransactionResponse
Properties
|
Edit this page
Date
The date/time when this transaction was included in a validated ledger.
Declaration
[JsonConverter(typeof(RippleDateTimeConverter))]
[JsonPropertyName("date")]
DateTime? Date { get; set; }
Property Value
| Type |
Description |
| Nullable |
|
|
Edit this page
Hash
An identifying hash value unique to this transaction, as a hex string.
Declaration
[JsonPropertyName("hash")]
string Hash { get; set; }
Property Value
|
Edit this page
InLedger
Declaration
[JsonPropertyName("inLedger")]
uint? InLedger { get; set; }
Property Value
|
Edit this page
LedgerIndex
The sequence number of the ledger that included this transaction.
Declaration
[JsonPropertyName("ledger_index")]
uint? LedgerIndex { get; set; }
Property Value
|
Edit this page
Validated
Declaration
[JsonPropertyName("validated")]
bool? Validated { get; set; }
Property Value