Interface ICredentialAccept
Accepts a credential that has been provisionally issued to the Account. Once accepted, the credential becomes valid on the ledger and the reserve responsibility transfers from the issuer to the subject (Account). Requires the Credentials amendment.
Inherited Members
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public interface ICredentialAccept : ITransactionCommon
Properties
| Edit this page View SourceCredentialType
The type of credential to accept, as a hex-encoded string.
Declaration
string CredentialType { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
Issuer
The issuer of the credential to accept.
Declaration
string Issuer { get; set; }
Property Value
| Type | Description |
|---|---|
| string |