Interface ICredentialCreate
Creates a credential on the XRP Ledger. The credential is issued by the transaction sender (Account) to a Subject. The credential is not valid until the Subject accepts it using CredentialAccept. Requires the Credentials amendment.
Inherited Members
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public interface ICredentialCreate : ITransactionCommon
Properties
| Edit this page View SourceCredentialType
A value to identify the type of credential, as a hex-encoded string. This must be between 1 and 64 bytes (2 to 128 hex characters).
Declaration
string CredentialType { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
Expiration
(Optional) The time after which the credential expires, in seconds since the Ripple Epoch.
Declaration
DateTime? Expiration { get; set; }
Property Value
| Type | Description |
|---|---|
| Nullable |
Subject
The account that is the subject (recipient) of the credential.
Declaration
string Subject { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
URI
(Optional) An arbitrary URI reference for additional credential data, as a hex-encoded string. Can be at most 256 bytes (512 hex characters).
Declaration
string URI { get; set; }
Property Value
| Type | Description |
|---|---|
| string |