Interface IDIDSet
Creates a new DID ledger entry or updates the fields of an existing one. The DID (Decentralized Identifier) is associated with the sending account.
Inherited Members
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public interface IDIDSet : ITransactionCommon
Properties
| Edit this page View SourceDIDDocument
The DID document for the DID. This field is encoded as a hexadecimal string and is limited to 256 bytes.
Declaration
string DIDDocument { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
Data
The public attestations of identity credentials associated with the DID. This field is encoded as a hexadecimal string and is limited to 256 bytes.
Declaration
string Data { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
URI
The Universal Resource Identifier associated with the DID. This field is encoded as a hexadecimal string and is limited to 256 bytes.
Declaration
string URI { get; set; }
Property Value
| Type | Description |
|---|---|
| string |