Interface ILoanBrokerCoverClawback
The LoanBrokerCoverClawback transaction claws back cover assets from a loan broker. At least one of LoanBrokerID or Amount must be specified.
Inherited Members
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public interface ILoanBrokerCoverClawback : ITransactionCommon
Remarks
Requires the Loan amendment (XLS-66d). This feature is in draft and subject to change.
Properties
| Edit this page View SourceAmount
The amount to claw back. Optional.
Declaration
Currency Amount { get; set; }
Property Value
| Type | Description |
|---|---|
| Currency |
LoanBrokerID
The ID of the loan broker to claw back from. Optional.
Declaration
string LoanBrokerID { get; set; }
Property Value
| Type | Description |
|---|---|
| string |