Interface ILoanBrokerCoverDeposit
The LoanBrokerCoverDeposit transaction deposits cover assets into a loan broker.
Inherited Members
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public interface ILoanBrokerCoverDeposit : ITransactionCommon
Remarks
Requires the Loan amendment (XLS-66d). This feature is in draft and subject to change.
Properties
| Edit this page View SourceAmount
The amount of cover assets to deposit.
Declaration
Currency Amount { get; set; }
Property Value
| Type | Description |
|---|---|
| Currency |
LoanBrokerID
The ID of the loan broker to deposit cover assets into.
Declaration
string LoanBrokerID { get; set; }
Property Value
| Type | Description |
|---|---|
| string |