Interface IMPTokenIssuanceDestroy
The MPTokenIssuanceDestroy transaction is used to remove an MPTokenIssuance object from the directory node in which it is being held, effectively removing the token from the ledger.
Inherited Members
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public interface IMPTokenIssuanceDestroy : ITransactionCommon
Properties
| Edit this page View SourceMPTokenIssuanceID
Identifies the MPTokenIssuance object to be removed by the transaction.
Declaration
string MPTokenIssuanceID { get; set; }
Property Value
| Type | Description |
|---|---|
| string |