Show / Hide Table of Contents

Interface IMPTokenIssuanceSet

The MPTokenIssuanceSet transaction is used to globally lock/unlock an MPTokenIssuance, or to lock/unlock a specific holder's MPToken balance for an MPTokenIssuance.

Inherited Members
ITransactionCommon.NetworkID
ITransactionCommon.Account
ITransactionCommon.AccountTxnID
ITransactionCommon.Fee
ITransactionCommon.LastLedgerSequence
ITransactionCommon.Memos
ITransactionCommon.MemoValue
ITransactionCommon.Sequence
ITransactionCommon.Signers
ITransactionCommon.SigningPublicKey
ITransactionCommon.TransactionSignature
ITransactionCommon.TransactionType
ITransactionCommon.SourceTag
ITransactionCommon.TicketSequence
ITransactionCommon.ToJson()
ITransactionCommon.ToDictionary()
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public interface IMPTokenIssuanceSet : ITransactionCommon

Properties

| Edit this page View Source

Flags

Declaration
MPTokenIssuanceSetFlags? Flags { get; set; }
Property Value
Type Description
MPTokenIssuanceSetFlags?
| Edit this page View Source

Holder

An optional XRPL Address of an individual token holder balance to lock/unlock. If omitted, this transaction will apply to all any accounts holding MPTs.

Declaration
string? Holder { get; set; }
Property Value
Type Description
string
| Edit this page View Source

MPTokenIssuanceID

The MPTokenIssuance identifier.

Declaration
string MPTokenIssuanceID { get; set; }
Property Value
Type Description
string
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX