Interface IMPTokenIssuanceSet
The MPTokenIssuanceSet transaction is used to globally lock/unlock an MPTokenIssuance, or to lock/unlock a specific holder's MPToken balance for an MPTokenIssuance.
Inherited Members
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public interface IMPTokenIssuanceSet : ITransactionCommon
Properties
| Edit this page View SourceFlags
Declaration
MPTokenIssuanceSetFlags? Flags { get; set; }
Property Value
| Type | Description |
|---|---|
| MPTokenIssuanceSetFlags? |
Holder
An optional XRPL Address of an individual token holder balance to lock/unlock. If omitted, this transaction will apply to all any accounts holding MPTs.
Declaration
string? Holder { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
MPTokenIssuanceID
The MPTokenIssuance identifier.
Declaration
string MPTokenIssuanceID { get; set; }
Property Value
| Type | Description |
|---|---|
| string |