Interface IOracleDelete
Deletes an Oracle ledger entry. Only the owner of the price oracle can send this transaction.
Inherited Members
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public interface IOracleDelete : ITransactionCommon
Properties
| Edit this page View SourceOracleDocumentID
A unique identifier of the price oracle for the Account.
Declaration
uint OracleDocumentID { get; set; }
Property Value
| Type | Description |
|---|---|
| uint |