Interface ISponsorshipSet
The SponsorshipSet transaction creates or updates a Sponsorship relationship, allowing the sponsor to pay transaction fees and/or reserves on behalf of the sponsee.
Inherited Members
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public interface ISponsorshipSet : ITransactionCommon
Remarks
Requires the Sponsor amendment (XLS-68). This feature is in draft and subject to change.
Properties
| Edit this page View SourceCounterpartySponsor
The sponsoring account. Present when the sponsee submits the transaction (the sponsor then co-signs via SponsorSignature).
Declaration
string CounterpartySponsor { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
FeeAmount
The amount of fees the sponsor commits to cover.
Declaration
Currency FeeAmount { get; set; }
Property Value
| Type | Description |
|---|---|
| Currency |
MaxFee
The maximum fee per transaction the sponsor is willing to cover.
Declaration
Currency MaxFee { get; set; }
Property Value
| Type | Description |
|---|---|
| Currency |
RemainingOwnerCount
The number of owner-reserve slots the sponsor commits to cover.
Declaration
uint? RemainingOwnerCount { get; set; }
Property Value
| Type | Description |
|---|---|
| uint? |
Sponsee
The account being sponsored. Present when the sponsor submits the transaction.
Declaration
string Sponsee { get; set; }
Property Value
| Type | Description |
|---|---|
| string |