Interface ITransactionMetadata
Assembly: Xrpl.dll
public interface ITransactionMetadata
Properties
|
Edit this page
Gets or sets the delivered amount (may be 'unavailable' for transactions before 2014-01-20).
Declaration
[JsonConverter(typeof(CurrencyConverter))]
[JsonPropertyName("delivered_amount")]
Currency ActuallyDeliveredAmount { get; set; }
Property Value
|
Edit this page
Declaration
List<AffectedNode> AffectedNodes { get; set; }
Property Value
|
Edit this page
Shows the MPTokenIssuanceID for the MPTokenIssuance that was created by this transaction.
Only present if the transaction is MPTokenIssuanceCreate.
Declaration
[JsonPropertyName("mpt_issuance_id")]
string MptIssuanceId { get; set; }
Property Value
|
Edit this page
Shows the NFTokenID for the NFToken that changed on the ledger as a result of the transaction.
Only present if the transaction is NFTokenMint or NFTokenAcceptOffer
Declaration
[JsonPropertyName("nftoken_id")]
string NFTokenId { get; set; }
Property Value
|
Edit this page
Shows all the NFTokenIDs for the NFTokens that changed on the ledger as a result of the transaction.
Only present if the transaction is NFTokenCancelOffer.
Declaration
[JsonPropertyName("nftoken_ids")]
string[] NFTokenIds { get; set; }
Property Value
| Type |
Description |
| string[] |
|
|
Edit this page
Shows the OfferIDof a new NFTokenOffer in a response from a NFTokenCreateOffer transaction.
Declaration
[JsonPropertyName("offer_id")]
string OfferID { get; set; }
Property Value
|
Edit this page
Batch ID of the batch that this transaction belongs to, if any.
Declaration
string? ParentBatchID { get; set; }
Property Value
|
Edit this page
Gets or sets the amount that was actually delivered.
Declaration
[JsonConverter(typeof(CurrencyConverter))]
[JsonPropertyName("DeliveredAmount")]
Currency PartialDeliveredAmount { get; set; }
Property Value
|
Edit this page
Gets or sets the transaction index.
Declaration
int TransactionIndex { get; set; }
Property Value
|
Edit this page
Gets or sets the transaction result.
Declaration
string TransactionResult { get; set; }
Property Value
Extension Methods