Show / Hide Table of Contents

Interface ITransactionResponse

Every transaction has the same set of common fields.

Inherited Members
IBaseTransactionResponse.Date
IBaseTransactionResponse.Hash
IBaseTransactionResponse.InLedger
IBaseTransactionResponse.LedgerIndex
IBaseTransactionResponse.Validated
ITransactionCommon.NetworkID
ITransactionCommon.Account
ITransactionCommon.AccountTxnID
ITransactionCommon.Fee
ITransactionCommon.Flags
ITransactionCommon.LastLedgerSequence
ITransactionCommon.Memos
ITransactionCommon.MemoValue
ITransactionCommon.Sequence
ITransactionCommon.Signers
ITransactionCommon.SigningPublicKey
ITransactionCommon.TransactionSignature
ITransactionCommon.TransactionType
ITransactionCommon.SourceTag
ITransactionCommon.TicketSequence
ITransactionCommon.ToJson()
ITransactionCommon.ToDictionary()
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public interface ITransactionResponse : IBaseTransactionResponse, ITransactionCommon

Properties

| Edit this page View Source

Meta

Transaction metadata is a section of data that gets added to a transaction after it is processed.
Any transaction that gets included in a ledger has metadata, regardless of whether it is successful.
The transaction metadata describes the outcome of the transaction in detail.
Warning: The changes described in transaction metadata are only final if the transaction is in a validated ledger version.

Declaration
Meta Meta { get; set; }
Property Value
Type Description
Meta
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX