Interface ITransactionResponse
Every transaction has the same set of common fields.
Inherited Members
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public interface ITransactionResponse : IBaseTransactionResponse, ITransactionCommon
Properties
| Edit this page View SourceMeta
Transaction metadata is a section of data that gets added to a transaction after it is processed.
Any transaction that gets included in a ledger has metadata, regardless of whether it is successful.
The transaction metadata describes the outcome of the transaction in detail.
Declaration
Meta Meta { get; set; }
Property Value
| Type | Description |
|---|---|
| Meta |