Interface IVaultClawback
The VaultClawback transaction allows an issuer to claw back assets from a vault.
Inherited Members
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public interface IVaultClawback : ITransactionCommon
Remarks
Requires the Vault amendment (XLS-65d). This feature is in draft and subject to change.
Properties
| Edit this page View SourceAmount
The amount to claw back. If omitted, claws back all available assets.
Declaration
Currency Amount { get; set; }
Property Value
| Type | Description |
|---|---|
| Currency |
Holder
The holder account to claw back from.
Declaration
string Holder { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
VaultID
The ID of the vault to claw back from.
Declaration
string VaultID { get; set; }
Property Value
| Type | Description |
|---|---|
| string |