Show / Hide Table of Contents

Interface IVaultCreate

The VaultCreate transaction creates a new Vault ledger object for holding pooled assets.

Inherited Members
ITransactionCommon.NetworkID
ITransactionCommon.Account
ITransactionCommon.AccountTxnID
ITransactionCommon.Fee
ITransactionCommon.Flags
ITransactionCommon.LastLedgerSequence
ITransactionCommon.Memos
ITransactionCommon.MemoValue
ITransactionCommon.Sequence
ITransactionCommon.Signers
ITransactionCommon.SigningPublicKey
ITransactionCommon.TransactionSignature
ITransactionCommon.TransactionType
ITransactionCommon.SourceTag
ITransactionCommon.TicketSequence
ITransactionCommon.ToJson()
ITransactionCommon.ToDictionary()
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public interface IVaultCreate : ITransactionCommon
Remarks

Requires the Vault amendment (XLS-65d). This feature is in draft and subject to change.

Properties

| Edit this page View Source

Amount

The initial deposit amount.

Declaration
Currency Amount { get; set; }
Property Value
Type Description
Currency
| Edit this page View Source

Asset

The asset held by the vault.

Declaration
Common.IssuedCurrency Asset { get; set; }
Property Value
Type Description
Common.IssuedCurrency
| Edit this page View Source

AssetsMaximum

The maximum asset amount that can be held in the vault. STNumber type (12 bytes: int64 mantissa + int32 exponent), serialized as string in JSON.

Declaration
string AssetsMaximum { get; set; }
Property Value
Type Description
string
| Edit this page View Source

Data

Arbitrary hex-encoded data associated with the vault, limited to 256 bytes.

Declaration
string Data { get; set; }
Property Value
Type Description
string
| Edit this page View Source

DomainID

The ID of a permissioned domain to associate with the vault.

Declaration
string DomainID { get; set; }
Property Value
Type Description
string
| Edit this page View Source

MPTokenMetadata

Arbitrary metadata for the vault shares (MPToken), limited in size. Hex-encoded string.

Declaration
string MPTokenMetadata { get; set; }
Property Value
Type Description
string
| Edit this page View Source

Scale

The scale (decimal precision) for the vault shares.

Declaration
uint? Scale { get; set; }
Property Value
Type Description
uint?
| Edit this page View Source

WithdrawalPolicy

The withdrawal policy for the vault. Defines how withdrawals are handled.

Declaration
uint? WithdrawalPolicy { get; set; }
Property Value
Type Description
uint?
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX