Interface IVaultCreate
The VaultCreate transaction creates a new Vault ledger object for holding pooled assets.
Inherited Members
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public interface IVaultCreate : ITransactionCommon
Remarks
Requires the Vault amendment (XLS-65d). This feature is in draft and subject to change.
Properties
| Edit this page View SourceAmount
The initial deposit amount.
Declaration
Currency Amount { get; set; }
Property Value
| Type | Description |
|---|---|
| Currency |
Asset
The asset held by the vault.
Declaration
Common.IssuedCurrency Asset { get; set; }
Property Value
| Type | Description |
|---|---|
| Common.IssuedCurrency |
AssetsMaximum
The maximum asset amount that can be held in the vault. STNumber type (12 bytes: int64 mantissa + int32 exponent), serialized as string in JSON.
Declaration
string AssetsMaximum { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
Data
Arbitrary hex-encoded data associated with the vault, limited to 256 bytes.
Declaration
string Data { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
DomainID
The ID of a permissioned domain to associate with the vault.
Declaration
string DomainID { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
MPTokenMetadata
Arbitrary metadata for the vault shares (MPToken), limited in size. Hex-encoded string.
Declaration
string MPTokenMetadata { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
Scale
The scale (decimal precision) for the vault shares.
Declaration
uint? Scale { get; set; }
Property Value
| Type | Description |
|---|---|
| uint? |
WithdrawalPolicy
The withdrawal policy for the vault. Defines how withdrawals are handled.
Declaration
uint? WithdrawalPolicy { get; set; }
Property Value
| Type | Description |
|---|---|
| uint? |