Interface IVaultWithdraw
The VaultWithdraw transaction withdraws assets from a vault.
Inherited Members
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public interface IVaultWithdraw : ITransactionCommon
Remarks
Requires the Vault amendment (XLS-65d). This feature is in draft and subject to change.
Properties
| Edit this page View SourceAmount
The exact amount of vault asset to withdraw or vault share to redeem.
Declaration
Currency Amount { get; set; }
Property Value
| Type | Description |
|---|---|
| Currency |
Destination
An account to receive the assets. This account must be able to receive the vault asset or the transaction fails.
Declaration
string Destination { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
DestinationTag
Arbitrary tag identifying the reason for the withdrawal to the destination.
Declaration
uint? DestinationTag { get; set; }
Property Value
| Type | Description |
|---|---|
| uint? |
VaultID
The ID of the vault to withdraw from.
Declaration
string VaultID { get; set; }
Property Value
| Type | Description |
|---|---|
| string |