Interface IXChainAccountCreateCommit
The XChainAccountCreateCommit transaction creates a new account for a witness's account on one of the chains a bridge connects. This transaction can only be used for XRP-XRP bridges.
Inherited Members
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public interface IXChainAccountCreateCommit : ITransactionCommon
Properties
| Edit this page View SourceAmount
The amount, in XRP, to use for account creation. This must be greater than or equal to the MinAccountCreateAmount specified in the Bridge ledger object.
Declaration
Currency Amount { get; set; }
Property Value
| Type | Description |
|---|---|
| Currency |
Destination
The destination account on the destination chain.
Declaration
string Destination { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
SignatureReward
The amount, in XRP, to be used to reward the witness servers for providing signatures. This must match the amount on the Bridge ledger object.
Declaration
Currency SignatureReward { get; set; }
Property Value
| Type | Description |
|---|---|
| Currency |
XChainBridge
The bridge to create accounts for.
Declaration
XChainBridgeModel XChainBridge { get; set; }
Property Value
| Type | Description |
|---|---|
| XChainBridgeModel |