Interface IXChainAddClaimAttestation
The XChainAddClaimAttestation transaction provides proof from a witness server, attesting to an XChainCommit transaction.
Inherited Members
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public interface IXChainAddClaimAttestation : ITransactionCommon
Properties
| Edit this page View SourceAmount
The amount committed by the XChainCommit transaction on the source chain.
Declaration
Currency Amount { get; set; }
Property Value
| Type | Description |
|---|---|
| Currency |
AttestationRewardAccount
The account that should receive this signer's share of the SignatureReward.
Declaration
string AttestationRewardAccount { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
AttestationSignerAccount
The account on the door account's signer list that is signing the transaction.
Declaration
string AttestationSignerAccount { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
Destination
The destination account for the funds on the destination chain.
Declaration
string Destination { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
OtherChainSource
The account on the source chain that submitted the XChainCommit transaction that triggered the event associated with the attestation.
Declaration
string OtherChainSource { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
PublicKey
The public key used to verify the signature.
Declaration
string PublicKey { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
Signature
The signature attesting to the event on the other chain.
Declaration
string Signature { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
WasLockingChainSend
A boolean representing the chain where the event occurred. 0 represents the issuing chain, 1 represents the locking chain.
Declaration
byte WasLockingChainSend { get; set; }
Property Value
| Type | Description |
|---|---|
| byte |
XChainBridge
The bridge to attest to.
Declaration
XChainBridgeModel XChainBridge { get; set; }
Property Value
| Type | Description |
|---|---|
| XChainBridgeModel |
XChainClaimID
The XChainClaimID associated with the transfer, which was included in the XChainCommit transaction.
Declaration
string XChainClaimID { get; set; }
Property Value
| Type | Description |
|---|---|
| string |