Interface IXChainCreateBridge
The XChainCreateBridge transaction creates a new Bridge ledger object and defines a cross-chain bridge between a locking chain and an issuing chain.
Inherited Members
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public interface IXChainCreateBridge : ITransactionCommon
Properties
| Edit this page View SourceMinAccountCreateAmount
The minimum amount, in XRP, required for an XChainAccountCreateCommit transaction. If this is not present, the XChainAccountCreateCommit transaction will fail.
Declaration
Currency MinAccountCreateAmount { get; set; }
Property Value
| Type | Description |
|---|---|
| Currency |
SignatureReward
The signature reward split between the witnesses for submitting attestations.
Declaration
Currency SignatureReward { get; set; }
Property Value
| Type | Description |
|---|---|
| Currency |
XChainBridge
The bridge (door accounts and brided assets) to create.
Declaration
XChainBridgeModel XChainBridge { get; set; }
Property Value
| Type | Description |
|---|---|
| XChainBridgeModel |