Interface IXChainModifyBridge
The XChainModifyBridge transaction allows bridge managers to modify the parameters of an existing bridge.
Inherited Members
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public interface IXChainModifyBridge : ITransactionCommon
Properties
| Edit this page View SourceFlags
Declaration
XChainModifyBridgeFlags? Flags { get; set; }
Property Value
| Type | Description |
|---|---|
| XChainModifyBridgeFlags? |
MinAccountCreateAmount
The minimum amount, in XRP, required for an XChainAccountCreateCommit transaction.
Declaration
Currency MinAccountCreateAmount { get; set; }
Property Value
| Type | Description |
|---|---|
| Currency |
SignatureReward
The signature reward split between the witnesses for submitting attestations.
Declaration
Currency SignatureReward { get; set; }
Property Value
| Type | Description |
|---|---|
| Currency |
XChainBridge
The bridge to modify.
Declaration
XChainBridgeModel XChainBridge { get; set; }
Property Value
| Type | Description |
|---|---|
| XChainBridgeModel |