Class LoanBrokerCoverWithdrawResponse
The LoanBrokerCoverWithdraw transaction withdraws cover assets from a loan broker.
Implements
Inherited Members
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public class LoanBrokerCoverWithdrawResponse : TransactionResponse, ITransactionResponse, IBaseTransactionResponse, ILoanBrokerCoverWithdraw, ITransactionCommon
Remarks
Requires the Loan amendment (XLS-66d). This feature is in draft and subject to change.
Properties
| Edit this page View SourceAmount
The amount of cover assets to withdraw.
Declaration
[JsonPropertyName("Amount")]
[JsonConverter(typeof(CurrencyConverter))]
public Currency Amount { get; set; }
Property Value
| Type | Description |
|---|---|
| Currency |
Destination
The destination account for the withdrawn assets. Optional.
Declaration
[JsonPropertyName("Destination")]
public string Destination { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
DestinationTag
An arbitrary tag to identify the destination. Optional.
Declaration
[JsonPropertyName("DestinationTag")]
public uint? DestinationTag { get; set; }
Property Value
| Type | Description |
|---|---|
| uint? |
LoanBrokerID
The ID of the loan broker to withdraw cover assets from.
Declaration
[JsonPropertyName("LoanBrokerID")]
public string LoanBrokerID { get; set; }
Property Value
| Type | Description |
|---|---|
| string |