Class LoanPayResponse
The LoanPay transaction makes a payment on a loan. Flags are mutually exclusive.
Inherited Members
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public class LoanPayResponse : TransactionResponse, ITransactionResponse, IBaseTransactionResponse, ILoanPay, ITransactionCommon
Remarks
Requires the Loan amendment (XLS-66d). This feature is in draft and subject to change.
Properties
| Edit this page View SourceAmount
The amount to pay.
Declaration
[JsonPropertyName("Amount")]
[JsonConverter(typeof(CurrencyConverter))]
public Currency Amount { get; set; }
Property Value
| Type | Description |
|---|---|
| Currency |
Flags
LoanPay transaction flags.
Declaration
public LoanPayFlags? Flags { get; set; }
Property Value
| Type | Description |
|---|---|
| LoanPayFlags? |
LoanID
The ID of the loan to make a payment on.
Declaration
[JsonPropertyName("LoanID")]
public string LoanID { get; set; }
Property Value
| Type | Description |
|---|---|
| string |