Class MPTokenAuthorize
The MPTokenAuthorize transaction authorizes an account to hold an MPT.
Inherited Members
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public class MPTokenAuthorize : TransactionRequest, ITransactionRequest, IMPTokenAuthorize, ITransactionCommon
Constructors
| Edit this page View SourceMPTokenAuthorize()
Initializes a new instance of the MPTokenAuthorize class.
Declaration
public MPTokenAuthorize()
Properties
| Edit this page View SourceFlags
Declaration
public MPTokenAuthorizeFlags? Flags { get; set; }
Property Value
| Type | Description |
|---|---|
| MPTokenAuthorizeFlags? |
Holder
An optional XRPL Address of an individual token holder balance. If this is set, the Holder field must specify the holder's address. If this is not set, the transaction is assumed to be from the holder directly.
Declaration
[JsonPropertyName("Holder")]
public string? Holder { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
MPTokenIssuanceID
The ID of the MPT to authorize.
Declaration
[JsonPropertyName("MPTokenIssuanceID")]
public string MPTokenIssuanceID { get; set; }
Property Value
| Type | Description |
|---|---|
| string |