Class MPTokenAuthorizeResponse
The MPTokenAuthorize transaction is used to allow an account to hold a particular MPT issuance, or by an issuer to authorize or revoke authorization for a holder.
Inherited Members
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public class MPTokenAuthorizeResponse : TransactionResponse, ITransactionResponse, IBaseTransactionResponse, IMPTokenAuthorize, ITransactionCommon
Properties
| Edit this page View SourceFlags
Declaration
public MPTokenAuthorizeFlags? Flags { get; set; }
Property Value
| Type | Description |
|---|---|
| MPTokenAuthorizeFlags? |
Holder
An optional XRPL Address of an individual token holder balance. If this is set, the Holder field must specify the holder's address. If this is not set, the transaction is assumed to be from the holder directly.
Declaration
[JsonPropertyName("Holder")]
public string? Holder { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
MPTokenIssuanceID
The ID of the MPT to authorize.
Declaration
[JsonPropertyName("MPTokenIssuanceID")]
public string MPTokenIssuanceID { get; set; }
Property Value
| Type | Description |
|---|---|
| string |