Enum MPTokenIssuanceCreateFlags
Enum representing flags for MPTokenIssuanceCreate transactions.
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
[Flags]
public enum MPTokenIssuanceCreateFlags : uint
Fields
| Name | Description |
|---|---|
| tfMPTCanClawback | If set, indicates that the issuer can clawback tokens. |
| tfMPTCanEscrow | If set, indicates that the MPT can be escrowed. |
| tfMPTCanLock | If set, indicates that the MPT can be locked both individually and globally. |
| tfMPTCanTrade | If set, indicates that the MPT can be traded on the DEX. |
| tfMPTCanTransfer | If set, indicates that the MPT can be transferred between accounts. |
| tfMPTRequireAuth | If set, indicates that individual holders must be authorized. |