Show / Hide Table of Contents

Class MPTokenIssuanceSetResponse

The MPTokenIssuanceSet transaction is used to globally lock/unlock an MPTokenIssuance, or to lock/unlock a specific holder's MPToken balance for an MPTokenIssuance.

Inheritance
object
BaseTransactionResponse
TransactionResponse
MPTokenIssuanceSetResponse
Implements
ITransactionResponse
IBaseTransactionResponse
IMPTokenIssuanceSet
ITransactionCommon
Inherited Members
TransactionResponse.NetworkID
TransactionResponse.Account
TransactionResponse.AccountTxnID
TransactionResponse.Fee
TransactionResponse.LastLedgerSequence
TransactionResponse.Memos
TransactionResponse.MemoValue
TransactionResponse.Sequence
TransactionResponse.SigningPublicKey
TransactionResponse.Signers
TransactionResponse.TransactionType
TransactionResponse.TransactionSignature
TransactionResponse.Meta
TransactionResponse.ToJson()
TransactionResponse.ToDictionary()
TransactionResponse.SourceTag
TransactionResponse.TicketSequence
BaseTransactionResponse.Date
BaseTransactionResponse.Hash
BaseTransactionResponse.InLedger
BaseTransactionResponse.LedgerIndex
BaseTransactionResponse.Validated
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public class MPTokenIssuanceSetResponse : TransactionResponse, ITransactionResponse, IBaseTransactionResponse, IMPTokenIssuanceSet, ITransactionCommon

Properties

| Edit this page View Source

Flags

Declaration
public MPTokenIssuanceSetFlags? Flags { get; set; }
Property Value
Type Description
MPTokenIssuanceSetFlags?
| Edit this page View Source

Holder

An optional XRPL Address of an individual token holder balance to lock/unlock. If omitted, this transaction will apply to all any accounts holding MPTs.

Declaration
[JsonPropertyName("Holder")]
public string? Holder { get; set; }
Property Value
Type Description
string
| Edit this page View Source

MPTokenIssuanceID

The MPTokenIssuance identifier.

Declaration
[JsonPropertyName("MPTokenIssuanceID")]
public string MPTokenIssuanceID { get; set; }
Property Value
Type Description
string

Implements

ITransactionResponse
IBaseTransactionResponse
IMPTokenIssuanceSet
ITransactionCommon
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX