Class Memo
The Memos field includes arbitrary messaging data with the transaction.
Inheritance
object
Memo
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public class Memo
Properties
| Edit this page View SourceMemoData
Arbitrary hex value, conventionally containing the content of the memo.
Declaration
public string MemoData { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
MemoDataAsText
Content of the memo.
Declaration
[JsonIgnore]
public string MemoDataAsText { get; }
Property Value
| Type | Description |
|---|---|
| string |
MemoFormat
Hex value representing characters allowed in URLs.
Conventionally containing information on how the memo is encoded, for example as a MIME type.
Declaration
public string MemoFormat { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
MemoFormatAsText
Conventionally containing information on how the memo is encoded, for example as a MIME type.
Declaration
[JsonIgnore]
public string MemoFormatAsText { get; }
Property Value
| Type | Description |
|---|---|
| string |
MemoType
Hex value representing characters allowed in URLs.
Conventionally, a unique relation (according to RFC 5988 ) that defines the format of this memo.
Declaration
public string MemoType { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
MemoTypeAsText
Conventionally, a unique relation (according to RFC 5988 ) that defines the format of this memo.
Declaration
[JsonIgnore]
public string MemoTypeAsText { get; }
Property Value
| Type | Description |
|---|---|
| string |