Class NFTokenModifyResponse
NFTokenModify is used to change the URI field of an NFT to point to a different URI
in order to update the supporting data for the NFT.
The NFT must have been minted with the tfMutable flag set.
See Dynamic Non-Fungible Tokens.
Inherited Members
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public class NFTokenModifyResponse : TransactionResponse, ITransactionResponse, IBaseTransactionResponse, INFTokenModify, ITransactionCommon
Properties
| Edit this page View SourceNFTokenID
Identifies the NFTokenID of the NFToken object that the offer references.
Declaration
public string NFTokenID { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
Owner
Indicates the AccountID of the account that owns the corresponding NFToken. Can be omitted if the owner is the account submitting this transaction.
Declaration
public string? Owner { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
URI
URI that points to the data and/or metadata associated with the NFT. This must be a hex-encoded string, not an empty string. Can be null or omitted if not used.
Declaration
public string? URI { get; set; }
Property Value
| Type | Description |
|---|---|
| string |