Class NodeInfo
transaction object
Inheritance
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public class NodeInfo : ICreatedNode, IModifiedNode, IDeletedNode
Properties
| Edit this page View SourceFinalFields
The content fields of the ledger object immediately before it was deleted.
Which fields are present depends on what type of ledger object was created.
The content fields of the ledger object after applying any changes from this transaction.
Which fields are present depends on what type of ledger object was created.
This omits the PreviousTxnID and PreviousTxnLgrSeq fields, even though most types of ledger objects have them.
Declaration
public BaseLedgerEntry? FinalFields { get; set; }
Property Value
| Type | Description |
|---|---|
| BaseLedgerEntry |
LedgerEntryType
The type of ledger object
Declaration
[JsonConverter(typeof(LedgerEntryTypeConverter))]
public LedgerEntryType LedgerEntryType { get; set; }
Property Value
| Type | Description |
|---|---|
| LedgerEntryType |
LedgerIndex
The ID of this ledger object in the ledger's state tree.
Note: This is not the same as a ledger index, even though the field name is very similar.
Declaration
public string LedgerIndex { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
NewFields
CreatedNode
The content fields of the newly-created ledger object.
Which fields are present depends on what type of ledger object was created.
Declaration
public BaseLedgerEntry? NewFields { get; set; }
Property Value
| Type | Description |
|---|---|
| BaseLedgerEntry |
PreviousFields
JSON
ModifiedNode
The previous values for all fields of the object that were changed as a result of this transaction.
If the transaction only added fields to the object, this field is an empty object.
Declaration
public BaseLedgerEntry? PreviousFields { get; set; }
Property Value
| Type | Description |
|---|---|
| BaseLedgerEntry |
PreviousTxnID
ModifiedNode
(May be omitted) The identifying hash of the previous transaction to modify this ledger object.
Omitted for ledger object types that do not have a PreviousTxnID field.
Declaration
[JsonPropertyName("PreviousTxnID")]
public string PreviousTxnID { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
PreviousTxnLgrSeq
ModifiedNode
(May be omitted) The Ledger Index of the ledger version containing the previous transaction to modify this ledger object.
Omitted for ledger object types that do not have a PreviousTxnLgrSeq field.
Declaration
[JsonPropertyName("PreviousTxnLgrSeq")]
public uint? PreviousTxnLgrSeq { get; set; }
Property Value
| Type | Description |
|---|---|
| uint? |