Class OfferCreate
An OfferCreate transaction is effectively a limit order.
It defines an intent to exchange currencies, and creates an Offer object if not completely.
Fulfilled when placed.
Offers can be partially fulfilled.
Inherited Members
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public class OfferCreate : TransactionRequest, ITransactionRequest, IOfferCreate, ITransactionCommon
Constructors
| Edit this page View SourceOfferCreate()
Declaration
public OfferCreate()
Properties
| Edit this page View SourceDomainID
The domain that the offer must be a part of. Required for permissioned DEX offers.
Declaration
public string DomainID { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
Expiration
Time after which the offer is no longer active, in seconds since the.
Ripple Epoch.
Declaration
[JsonConverter(typeof(RippleDateTimeConverter))]
public DateTime? Expiration { get; set; }
Property Value
| Type | Description |
|---|---|
| Nullable |
Flags
Transaction Flags for an OfferCreate Transaction.
Declaration
public OfferCreateFlags? Flags { get; set; }
Property Value
| Type | Description |
|---|---|
| OfferCreateFlags? |
OfferSequence
An offer to delete first, specified in the same way as OfferCancel.
Declaration
public uint? OfferSequence { get; set; }
Property Value
| Type | Description |
|---|---|
| uint? |
TakerGets
The amount and type of currency being provided by the offer creator.
Declaration
[JsonConverter(typeof(CurrencyConverter))]
public Currency TakerGets { get; set; }
Property Value
| Type | Description |
|---|---|
| Currency |
TakerPays
The amount and type of currency being requested by the offer creator.
Declaration
[JsonConverter(typeof(CurrencyConverter))]
public Currency TakerPays { get; set; }
Property Value
| Type | Description |
|---|---|
| Currency |