Class OracleSetResponse
Creates a new Oracle ledger entry or updates the fields of an existing one, using the Oracle ID.
Inherited Members
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public class OracleSetResponse : TransactionResponse, ITransactionResponse, IBaseTransactionResponse, IOracleSet, ITransactionCommon
Properties
| Edit this page View SourceAssetClass
Describes the type of asset, such as "currency", "commodity", or "index". This field is a string, up to 16 ASCII hex encoded characters (0x20-0x7E). This field is required when creating a new Oracle ledger entry, but is optional for updates.
Declaration
[JsonPropertyName("AssetClass")]
[JsonConverter(typeof(OracleHexStringConverter))]
public string AssetClass { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
LastUpdateTime
The time the data was last updated, represented as a unix timestamp in seconds. The value must be within 300 seconds (5 minutes) of the ledger's close time.
Declaration
[JsonPropertyName("LastUpdateTime")]
[JsonConverter(typeof(UnixDateTimeConverter))]
public DateTime? LastUpdateTime { get; set; }
Property Value
| Type | Description |
|---|---|
| Nullable |
OracleDocumentID
A unique identifier of the price oracle for the Account.
Declaration
[JsonPropertyName("OracleDocumentID")]
public uint OracleDocumentID { get; set; }
Property Value
| Type | Description |
|---|---|
| uint |
PriceDataSeries
An array of up to 10 PriceData objects, each representing the price information for a token pair. More than five PriceData objects require two owner reserves.
Declaration
[JsonPropertyName("PriceDataSeries")]
public List<PriceDataWrapper> PriceDataSeries { get; set; }
Property Value
| Type | Description |
|---|---|
| List<PriceDataWrapper> |
Provider
An arbitrary value that identifies an oracle provider, such as Chainlink, Band, or DIA. This field is a string, up to 256 ASCII hex encoded characters (0x20-0x7E). This field is required when creating a new Oracle ledger entry, but is optional for updates.
Declaration
[JsonPropertyName("Provider")]
[JsonConverter(typeof(OracleHexStringConverter))]
public string Provider { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
URI
An optional Universal Resource Identifier to reference price data off-chain. This field is limited to 256 bytes.
Declaration
[JsonPropertyName("URI")]
[JsonConverter(typeof(OracleHexStringConverter))]
public string URI { get; set; }
Property Value
| Type | Description |
|---|---|
| string |