Show / Hide Table of Contents

Enum PaymentFlags

Enum representing values for Payment Transaction Flags.

Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
[Flags]
public enum PaymentFlags : uint

Fields

Name Description
tfInnerBatchTxn

batch inner transaction

tfLimitQuality

Only take paths where all the conversions have an input:output ratio that is equal or better than the ratio of Amount:SendMax.
See Limit Quality for details.

tfNoDirectRipple

Do not use the default path;
only use paths included in the Paths field.
This is intended to force the transaction to take arbitrage opportunities.
Most clients do not need this.

tfPartialPayment

If the specified Amount cannot be sent without spending more than SendMax, reduce the received amount instead of failing outright.
See Partial Payments for more details.

Extension Methods

EmumExtensions.DecodeFlags<PaymentFlags>(PaymentFlags)
EmumExtensions.FlagsValues<PaymentFlags>(PaymentFlags)
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX