Show / Hide Table of Contents

Class SetFee

Inheritance
object
TransactionRequest
SetFee
Implements
ITransactionRequest
ISetFee
ITransactionCommon
Inherited Members
TransactionRequest.NetworkID
TransactionRequest.Account
TransactionRequest.AccountTxnID
TransactionRequest.Fee
TransactionRequest.Flags
TransactionRequest.LastLedgerSequence
TransactionRequest.Memos
TransactionRequest.Sequence
TransactionRequest.SigningPublicKey
TransactionRequest.Signers
TransactionRequest.TransactionType
TransactionRequest.TransactionSignature
TransactionRequest.ToJson()
TransactionRequest.ToDictionary()
TransactionRequest.SourceTag
TransactionRequest.TicketSequence
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public class SetFee : TransactionRequest, ITransactionRequest, ISetFee, ITransactionCommon

Constructors

| Edit this page View Source

SetFee()

Declaration
public SetFee()

Properties

| Edit this page View Source

BaseFee

The charge, in drops of XRP, for the reference transaction, as hex.
(This is the transaction cost before scaling for load.)

Declaration
public string BaseFee { get; set; }
Property Value
Type Description
string
| Edit this page View Source

LedgerSequence

(Omitted for some historical SetFee pseudo-transactions)
The index of the ledger version where this pseudo-transaction appears.
This distinguishes the pseudo-transaction from other occurrences of the same change.

Declaration
public uint LedgerSequence { get; set; }
Property Value
Type Description
uint
| Edit this page View Source

ReferenceFeeUnits

The cost, in fee units, of the reference transaction

Declaration
public uint ReferenceFeeUnits { get; set; }
Property Value
Type Description
uint
| Edit this page View Source

ReserveBase

The base reserve, in drops

Declaration
public uint ReserveBase { get; set; }
Property Value
Type Description
uint
| Edit this page View Source

ReserveIncrement

The incremental reserve, in drops

Declaration
public uint ReserveIncrement { get; set; }
Property Value
Type Description
uint

Implements

ITransactionRequest
ISetFee
ITransactionCommon

Extension Methods

BatchUtils.ToBatchTx(ITransactionRequest)
Utilities.Encode(TransactionRequest)
Utilities.EncodeForMultiSigning(TransactionRequest, string)
Utilities.EncodeForSigning(TransactionRequest)
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX