Class SetFeeResponse
Inherited Members
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public class SetFeeResponse : TransactionResponse, ITransactionResponse, IBaseTransactionResponse, ISetFee, ITransactionCommon
Properties
| Edit this page View SourceBaseFee
The charge, in drops of XRP, for the reference transaction, as hex.
(This is the transaction cost before scaling for load.)
Declaration
public string BaseFee { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
BaseFeeDrops
XRPFees: base fee in drops.
Declaration
[JsonConverter(typeof(CurrencyConverter))]
public Currency BaseFeeDrops { get; set; }
Property Value
| Type | Description |
|---|---|
| Currency |
LedgerSequence
(Omitted for some historical SetFee pseudo-transactions)
The index of the ledger version where this pseudo-transaction appears.
This distinguishes the pseudo-transaction from other occurrences of the same change.
Declaration
public uint? LedgerSequence { get; set; }
Property Value
| Type | Description |
|---|---|
| uint? |
ReferenceFeeUnits
The cost, in fee units, of the reference transaction
Declaration
public uint? ReferenceFeeUnits { get; set; }
Property Value
| Type | Description |
|---|---|
| uint? |
ReserveBase
The base reserve, in drops
Declaration
public uint? ReserveBase { get; set; }
Property Value
| Type | Description |
|---|---|
| uint? |
ReserveBaseDrops
XRPFees: account reserve in drops.
Declaration
[JsonConverter(typeof(CurrencyConverter))]
public Currency ReserveBaseDrops { get; set; }
Property Value
| Type | Description |
|---|---|
| Currency |
ReserveIncrement
The incremental reserve, in drops
Declaration
public uint? ReserveIncrement { get; set; }
Property Value
| Type | Description |
|---|---|
| uint? |
ReserveIncrementDrops
XRPFees: owner reserve increment in drops.
Declaration
[JsonConverter(typeof(CurrencyConverter))]
public Currency ReserveIncrementDrops { get; set; }
Property Value
| Type | Description |
|---|---|
| Currency |