Class SetRegularKeyResponse
A SetRegularKey transaction assigns, changes, or removes the regular key pair associated with an account.
Inherited Members
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public class SetRegularKeyResponse : TransactionResponse, ITransactionResponse, IBaseTransactionResponse, ISetRegularKey, ITransactionCommon
Properties
| Edit this page View SourceRegularKey
A base-58-encoded Address that indicates the regular key pair to be assigned to the account.
If omitted, removes any existing regular key pair from the account.
Must not match the master key pair for the address.
Declaration
public string RegularKey { get; set; }
Property Value
| Type | Description |
|---|---|
| string |