Show / Hide Table of Contents

Class SponsorshipSetResponse

The SponsorshipSet transaction creates or updates a Sponsorship relationship, allowing the sponsor to pay transaction fees and/or reserves on behalf of the sponsee.

Inheritance
object
BaseTransactionResponse
TransactionResponse
SponsorshipSetResponse
Implements
ITransactionResponse
IBaseTransactionResponse
ISponsorshipSet
ITransactionCommon
Inherited Members
TransactionResponse.NetworkID
TransactionResponse.Account
TransactionResponse.AccountTxnID
TransactionResponse.Fee
TransactionResponse.LastLedgerSequence
TransactionResponse.Memos
TransactionResponse.MemoValue
TransactionResponse.Sequence
TransactionResponse.SigningPublicKey
TransactionResponse.Signers
TransactionResponse.TransactionType
TransactionResponse.TransactionSignature
TransactionResponse.Meta
TransactionResponse.Sponsor
TransactionResponse.SponsorFlags
TransactionResponse.Delegate
TransactionResponse.OperationLimit
TransactionResponse.ToJson()
TransactionResponse.ToDictionary()
TransactionResponse.SourceTag
TransactionResponse.TicketSequence
BaseTransactionResponse.Date
BaseTransactionResponse.Hash
BaseTransactionResponse.InLedger
BaseTransactionResponse.LedgerIndex
BaseTransactionResponse.Validated
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public class SponsorshipSetResponse : TransactionResponse, ITransactionResponse, IBaseTransactionResponse, ISponsorshipSet, ITransactionCommon
Remarks

Requires the Sponsor amendment (XLS-68). This feature is in draft and subject to change.

Properties

| Edit this page View Source

CounterpartySponsor

The sponsoring account. Present when the sponsee submits the transaction (the sponsor then co-signs via SponsorSignature).

Declaration
[JsonPropertyName("CounterpartySponsor")]
public string CounterpartySponsor { get; set; }
Property Value
Type Description
string
| Edit this page View Source

FeeAmount

The amount of fees the sponsor commits to cover.

Declaration
[JsonPropertyName("FeeAmount")]
[JsonConverter(typeof(CurrencyConverter))]
public Currency FeeAmount { get; set; }
Property Value
Type Description
Currency
| Edit this page View Source

Flags

Typed view over the base Flags value (see SponsorshipSetFlags).

Declaration
[JsonPropertyName("Flags")]
[JsonIgnore(Condition = JsonIgnoreCondition.WhenWritingNull)]
public SponsorshipSetFlags? Flags { get; set; }
Property Value
Type Description
SponsorshipSetFlags?
| Edit this page View Source

MaxFee

The maximum fee per transaction the sponsor is willing to cover.

Declaration
[JsonPropertyName("MaxFee")]
[JsonConverter(typeof(CurrencyConverter))]
public Currency MaxFee { get; set; }
Property Value
Type Description
Currency
| Edit this page View Source

RemainingOwnerCount

The number of owner-reserve slots the sponsor commits to cover.

Declaration
[JsonPropertyName("RemainingOwnerCount")]
public uint? RemainingOwnerCount { get; set; }
Property Value
Type Description
uint?
| Edit this page View Source

Sponsee

The account being sponsored. Present when the sponsor submits the transaction.

Declaration
[JsonPropertyName("Sponsee")]
public string Sponsee { get; set; }
Property Value
Type Description
string

Implements

ITransactionResponse
IBaseTransactionResponse
ISponsorshipSet
ITransactionCommon
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX