Class TransactionResponse
Every transaction has the same set of common fields.
Inheritance
object
TransactionResponse
Assembly: Xrpl.dll
Syntax
[JsonConverter(typeof(TransactionResponseConverter))]
public class TransactionResponse : BaseTransactionResponse, ITransactionResponse, IBaseTransactionResponse, ITransactionCommon
Properties
|
Edit this page
Account
This is a required field
The unique address of the account that initiated the transaction.
Declaration
public string Account { get; set; }
Property Value
|
Edit this page
AccountTxnID
Hash value identifying another transaction.
If provided, this transaction is only valid if the sending account's previously-sent transaction matches the provided hash.
Declaration
public string AccountTxnID { get; set; }
Property Value
|
Edit this page
Fee
Integer amount of XRP, in drops, to be destroyed as a cost for distributing this transaction to the network.
Some transaction types have different minimum requirements.
Declaration
[JsonConverter(typeof(CurrencyConverter))]
public Currency Fee { get; set; }
Property Value
|
Edit this page
Flags
Set of bit-flags for this transaction.
number | GlobalFlags
Declaration
public uint? Flags { get; set; }
Property Value
|
Edit this page
LastLedgerSequence
Although optional, the LastLedgerSequence is strongly recommended on every transaction to ensure it's validated or rejected promptly.
Highest ledger index this transaction can appear in.
Specifying this field places a strict upper limit on how long the transaction can wait to be validated or rejected.
Declaration
public uint? LastLedgerSequence { get; set; }
Property Value
|
Edit this page
MemoValue
Declaration
[JsonIgnore]
public string MemoValue { get; }
Property Value
|
Edit this page
Memos
Additional arbitrary information used to identify this transaction.
Declaration
public List<MemoWrapper> Memos { get; set; }
Property Value
|
Edit this page
Transaction metadata is a section of data that gets added to a transaction after it is processed.
Any transaction that gets included in a ledger has metadata, regardless of whether it is successful.
The transaction metadata describes the outcome of the transaction in detail.
Warning: The changes described in transaction metadata are only final if the transaction is in a validated ledger version.
Declaration
[JsonPropertyName("meta")]
public Meta Meta { get; set; }
Property Value
|
Edit this page
NetworkID
Declaration
public uint? NetworkID { get; set; }
Property Value
|
Edit this page
Sequence
The sequence number of the account sending the transaction.
A transaction is only valid if the Sequence number is exactly 1 greater than the previous transaction from the same account.
The special case 0 means the transaction is using a Ticket instead.
Declaration
public uint? Sequence { get; set; }
Property Value
|
Edit this page
Signers
Array of objects that represent a multi-signature which authorizes this transaction.
Declaration
public List<SignerWrapper> Signers { get; set; }
Property Value
|
Edit this page
SigningPublicKey
Hex representation of the public key that corresponds to the private key used to sign this transaction.
If an empty string, indicates a multi-signature is present in the Signers field instead.
Declaration
[JsonPropertyName("SigningPubKey")]
public string SigningPublicKey { get; set; }
Property Value
|
Edit this page
SourceTag
(Optional) Arbitrary integer used to identify the reason for this payment, or a sender on whose behalf this transaction is made.
Conventionally, a refund should specify the initial payment's SourceTag as the refund payment's DestinationTag.
Declaration
public uint? SourceTag { get; set; }
Property Value
|
Edit this page
TicketSequence
(Optional) The sequence number of the ticket to use in place of a Sequence number.
If this is provided, Sequence must be 0. Cannot be used with AccountTxnID.
Declaration
public uint? TicketSequence { get; set; }
Property Value
|
Edit this page
TransactionSignature
The signature that verifies this transaction as originating from the account it says it is from.
Declaration
[JsonPropertyName("TxnSignature")]
public string TransactionSignature { get; set; }
Property Value
|
Edit this page
TransactionType
The type of transaction.
Valid types include: Payment, OfferCreate, SignerListSet,
EscrowCreate, EscrowFinish, EscrowCancel, PaymentChannelCreate,
PaymentChannelFund, PaymentChannelClaim, and DepositPreauth.
Declaration
[JsonConverter(typeof(TransactionTypeConverter))]
public TransactionType TransactionType { get; set; }
Property Value
Methods
|
Edit this page
ToDictionary()
Declaration
public Dictionary<string, object> ToDictionary()
Returns
| Type |
Description |
| Dictionary<string, object> |
|
|
Edit this page
ToJson()
convert transaction to string json value
Declaration
Returns
Implements