Enum TrustSetFlags
Enum representing values of ITrustSet transaction flags.
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
[Flags]
public enum TrustSetFlags : uint
Fields
| Name | Description |
|---|---|
| tfClearDeepFreeze | |
| tfClearFreeze | Unfreeze the trust line. |
| tfClearNoRipple | Disable the No Ripple flag, allowing rippling on this trust line. |
| tfInnerBatchTxn | batch inner transaction |
| tfSetDeepFreeze | |
| tfSetFreeze | Freeze the trust line. |
| tfSetNoRipple | Enable the No Ripple flag, which blocks rippling between two trust lines. |
| tfSetfAuth | Authorize the other party to hold currency issued by this account. |