Class UNLModifyResponse
Inherited Members
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public class UNLModifyResponse : TransactionResponse, ITransactionResponse, IBaseTransactionResponse, IUNLModify, ITransactionCommon
Properties
| Edit this page View SourceLedgerSequence
The ledger index where this pseudo-transaction appears.
This distinguishes the pseudo-transaction from other occurrences of the same change.
Declaration
public uint LedgerSequence { get; set; }
Property Value
| Type | Description |
|---|---|
| uint |
UNLModifyDisabling
If 1, this change represents adding a validator to the Negative UNL.
If 0, this change represents removing a validator from the Negative UNL.
(No other values are allowed.)
Declaration
public uint UNLModifyDisabling { get; set; }
Property Value
| Type | Description |
|---|---|
| uint |
UNLModifyValidator
The validator to add or remove, as identified by its master public key.
Declaration
public string UNLModifyValidator { get; set; }
Property Value
| Type | Description |
|---|---|
| string |