Class VaultCreate
The VaultCreate transaction creates a new Vault ledger object for holding pooled assets.
Inherited Members
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public class VaultCreate : TransactionRequest, ITransactionRequest, IVaultCreate, ITransactionCommon
Remarks
Requires the Vault amendment (XLS-65d). This feature is in draft and subject to change.
Constructors
| Edit this page View SourceVaultCreate()
Declaration
public VaultCreate()
Properties
| Edit this page View SourceAmount
The initial deposit amount.
Declaration
[JsonPropertyName("Amount")]
public Currency Amount { get; set; }
Property Value
| Type | Description |
|---|---|
| Currency |
Asset
The asset held by the vault.
Declaration
[JsonPropertyName("Asset")]
[JsonConverter(typeof(IssuedCurrencyConverter))]
public Common.IssuedCurrency Asset { get; set; }
Property Value
| Type | Description |
|---|---|
| Common.IssuedCurrency |
AssetsMaximum
The maximum asset amount that can be held in the vault. STNumber type (12 bytes: int64 mantissa + int32 exponent), serialized as string in JSON.
Declaration
[JsonPropertyName("AssetsMaximum")]
public string AssetsMaximum { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
Data
Arbitrary hex-encoded data associated with the vault, limited to 256 bytes.
Declaration
[JsonPropertyName("Data")]
public string Data { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
DomainID
The ID of a permissioned domain to associate with the vault.
Declaration
[JsonPropertyName("DomainID")]
public string DomainID { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
MPTokenMetadata
Arbitrary metadata for the vault shares (MPToken), limited in size. Hex-encoded string.
Declaration
[JsonPropertyName("MPTokenMetadata")]
public string MPTokenMetadata { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
Scale
The scale (decimal precision) for the vault shares.
Declaration
[JsonPropertyName("Scale")]
public uint? Scale { get; set; }
Property Value
| Type | Description |
|---|---|
| uint? |
WithdrawalPolicy
The withdrawal policy for the vault. Defines how withdrawals are handled.
Declaration
[JsonPropertyName("WithdrawalPolicy")]
public uint? WithdrawalPolicy { get; set; }
Property Value
| Type | Description |
|---|---|
| uint? |