Show / Hide Table of Contents

Class VaultCreateResponse

The VaultCreate transaction creates a new Vault ledger object for holding pooled assets.

Inheritance
object
BaseTransactionResponse
TransactionResponse
VaultCreateResponse
Implements
ITransactionResponse
IBaseTransactionResponse
IVaultCreate
ITransactionCommon
Inherited Members
TransactionResponse.NetworkID
TransactionResponse.Account
TransactionResponse.AccountTxnID
TransactionResponse.Fee
TransactionResponse.Flags
TransactionResponse.LastLedgerSequence
TransactionResponse.Memos
TransactionResponse.MemoValue
TransactionResponse.Sequence
TransactionResponse.SigningPublicKey
TransactionResponse.Signers
TransactionResponse.TransactionType
TransactionResponse.TransactionSignature
TransactionResponse.Meta
TransactionResponse.ToJson()
TransactionResponse.ToDictionary()
TransactionResponse.SourceTag
TransactionResponse.TicketSequence
BaseTransactionResponse.Date
BaseTransactionResponse.Hash
BaseTransactionResponse.InLedger
BaseTransactionResponse.LedgerIndex
BaseTransactionResponse.Validated
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public class VaultCreateResponse : TransactionResponse, ITransactionResponse, IBaseTransactionResponse, IVaultCreate, ITransactionCommon
Remarks

Requires the Vault amendment (XLS-65d). This feature is in draft and subject to change.

Properties

| Edit this page View Source

Amount

The initial deposit amount.

Declaration
[JsonPropertyName("Amount")]
public Currency Amount { get; set; }
Property Value
Type Description
Currency
| Edit this page View Source

Asset

The asset held by the vault.

Declaration
[JsonPropertyName("Asset")]
[JsonConverter(typeof(IssuedCurrencyConverter))]
public Common.IssuedCurrency Asset { get; set; }
Property Value
Type Description
Common.IssuedCurrency
| Edit this page View Source

AssetsMaximum

The maximum asset amount that can be held in the vault. STNumber type (12 bytes: int64 mantissa + int32 exponent), serialized as string in JSON.

Declaration
[JsonPropertyName("AssetsMaximum")]
public string AssetsMaximum { get; set; }
Property Value
Type Description
string
| Edit this page View Source

Data

Arbitrary hex-encoded data associated with the vault, limited to 256 bytes.

Declaration
[JsonPropertyName("Data")]
public string Data { get; set; }
Property Value
Type Description
string
| Edit this page View Source

DomainID

The ID of a permissioned domain to associate with the vault.

Declaration
[JsonPropertyName("DomainID")]
public string DomainID { get; set; }
Property Value
Type Description
string
| Edit this page View Source

MPTokenMetadata

Arbitrary metadata for the vault shares (MPToken), limited in size. Hex-encoded string.

Declaration
[JsonPropertyName("MPTokenMetadata")]
public string MPTokenMetadata { get; set; }
Property Value
Type Description
string
| Edit this page View Source

Scale

The scale (decimal precision) for the vault shares.

Declaration
[JsonPropertyName("Scale")]
public uint? Scale { get; set; }
Property Value
Type Description
uint?
| Edit this page View Source

WithdrawalPolicy

The withdrawal policy for the vault. Defines how withdrawals are handled.

Declaration
[JsonPropertyName("WithdrawalPolicy")]
public uint? WithdrawalPolicy { get; set; }
Property Value
Type Description
uint?

Implements

ITransactionResponse
IBaseTransactionResponse
IVaultCreate
ITransactionCommon
  • Edit this page
  • View Source
In this article
Back to top Generated by DocFX