Class VaultSetResponse
The VaultSet transaction modifies the settings of an existing vault.
Inherited Members
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public class VaultSetResponse : TransactionResponse, ITransactionResponse, IBaseTransactionResponse, IVaultSet, ITransactionCommon
Remarks
Requires the Vault amendment (XLS-65d). This feature is in draft and subject to change.
Properties
| Edit this page View SourceAssetsMaximum
The maximum asset amount that can be held in the vault. STNumber type (12 bytes: int64 mantissa + int32 exponent), serialized as string in JSON.
Declaration
[JsonPropertyName("AssetsMaximum")]
public string AssetsMaximum { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
Data
Arbitrary hex-encoded data associated with the vault, limited to 256 bytes.
Declaration
[JsonPropertyName("Data")]
public string Data { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
DomainID
The ID of a permissioned domain to associate with the vault.
Declaration
[JsonPropertyName("DomainID")]
public string DomainID { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
VaultID
The ID of the vault to modify.
Declaration
[JsonPropertyName("VaultID")]
public string VaultID { get; set; }
Property Value
| Type | Description |
|---|---|
| string |