Class XChainAccountCreateCommitResponse
The XChainAccountCreateCommit transaction creates a new account for a witness's account on one of the chains a bridge connects. This transaction can only be used for XRP-XRP bridges.
Implements
Inherited Members
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public class XChainAccountCreateCommitResponse : TransactionResponse, ITransactionResponse, IBaseTransactionResponse, IXChainAccountCreateCommit, ITransactionCommon
Properties
| Edit this page View SourceAmount
The amount, in XRP, to use for account creation. This must be greater than or equal to the MinAccountCreateAmount specified in the Bridge ledger object.
Declaration
[JsonPropertyName("Amount")]
[JsonConverter(typeof(CurrencyConverter))]
public Currency Amount { get; set; }
Property Value
| Type | Description |
|---|---|
| Currency |
Destination
The destination account on the destination chain.
Declaration
[JsonPropertyName("Destination")]
public string Destination { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
SignatureReward
The amount, in XRP, to be used to reward the witness servers for providing signatures. This must match the amount on the Bridge ledger object.
Declaration
[JsonPropertyName("SignatureReward")]
[JsonConverter(typeof(CurrencyConverter))]
public Currency SignatureReward { get; set; }
Property Value
| Type | Description |
|---|---|
| Currency |
XChainBridge
The bridge to create accounts for.
Declaration
[JsonPropertyName("XChainBridge")]
public XChainBridgeModel XChainBridge { get; set; }
Property Value
| Type | Description |
|---|---|
| XChainBridgeModel |