Class XChainClaim
The XChainClaim transaction completes a cross-chain transfer of value. It allows a user to claim the value on the destination chain — the equivalent of the value locked on the source chain.
Inherited Members
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public class XChainClaim : TransactionRequest, ITransactionRequest, IXChainClaim, ITransactionCommon
Constructors
| Edit this page View SourceXChainClaim()
Declaration
public XChainClaim()
Properties
| Edit this page View SourceAmount
The amount to claim on the destination chain. This must match the amount attested to on the attestations associated with this claim ID.
Declaration
[JsonPropertyName("Amount")]
[JsonConverter(typeof(CurrencyConverter))]
public Currency Amount { get; set; }
Property Value
| Type | Description |
|---|---|
| Currency |
Destination
The destination account on the destination chain. It must exist or the transaction will fail.
Declaration
[JsonPropertyName("Destination")]
public string Destination { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
DestinationTag
An integer destination tag.
Declaration
[JsonPropertyName("DestinationTag")]
public uint? DestinationTag { get; set; }
Property Value
| Type | Description |
|---|---|
| uint? |
XChainBridge
The bridge to use for the claim.
Declaration
[JsonPropertyName("XChainBridge")]
public XChainBridgeModel XChainBridge { get; set; }
Property Value
| Type | Description |
|---|---|
| XChainBridgeModel |
XChainClaimID
The unique integer ID for the cross-chain claim.
Declaration
[JsonPropertyName("XChainClaimID")]
public string XChainClaimID { get; set; }
Property Value
| Type | Description |
|---|---|
| string |