Class XChainCommit
The XChainCommit transaction is the second step in a cross-chain transfer. It puts assets into trust on the locking chain so that they can be wrapped on the issuing chain, or burns wrapped assets on the issuing chain so that they can be returned on the locking chain.
Inherited Members
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public class XChainCommit : TransactionRequest, ITransactionRequest, IXChainCommit, ITransactionCommon
Constructors
| Edit this page View SourceXChainCommit()
Declaration
public XChainCommit()
Properties
| Edit this page View SourceAmount
The amount to transfer.
Declaration
[JsonPropertyName("Amount")]
[JsonConverter(typeof(CurrencyConverter))]
public Currency Amount { get; set; }
Property Value
| Type | Description |
|---|---|
| Currency |
OtherChainDestination
The destination account on the destination chain. If this is not specified, the account that submitted the XChainCreateClaimID transaction on the destination chain will need to submit an XChainClaim transaction.
Declaration
[JsonPropertyName("OtherChainDestination")]
public string OtherChainDestination { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
XChainBridge
The bridge to use for the transfer.
Declaration
[JsonPropertyName("XChainBridge")]
public XChainBridgeModel XChainBridge { get; set; }
Property Value
| Type | Description |
|---|---|
| XChainBridgeModel |
XChainClaimID
The unique integer ID for the cross-chain claim.
Declaration
[JsonPropertyName("XChainClaimID")]
public string XChainClaimID { get; set; }
Property Value
| Type | Description |
|---|---|
| string |