Class XChainCreateClaimIDResponse
The XChainCreateClaimID transaction creates a new cross-chain claim ID that is used for a cross-chain transfer. A cross-chain claim ID represents one cross-chain transfer of value.
Inherited Members
Namespace: Xrpl.Models.Transactions
Assembly: Xrpl.dll
Syntax
public class XChainCreateClaimIDResponse : TransactionResponse, ITransactionResponse, IBaseTransactionResponse, IXChainCreateClaimID, ITransactionCommon
Properties
| Edit this page View SourceOtherChainSource
The account that must send the corresponding XChainCommit on the source chain.
Declaration
[JsonPropertyName("OtherChainSource")]
public string OtherChainSource { get; set; }
Property Value
| Type | Description |
|---|---|
| string |
SignatureReward
The amount, in XRP, to reward the witness servers for providing signatures. This must match the amount on the Bridge ledger object.
Declaration
[JsonPropertyName("SignatureReward")]
[JsonConverter(typeof(CurrencyConverter))]
public Currency SignatureReward { get; set; }
Property Value
| Type | Description |
|---|---|
| Currency |
XChainBridge
The bridge to create the claim ID for.
Declaration
[JsonPropertyName("XChainBridge")]
public XChainBridgeModel XChainBridge { get; set; }
Property Value
| Type | Description |
|---|---|
| XChainBridgeModel |