Class BatchSignStatusExtensions
Inheritance
object
BatchSignStatusExtensions
Assembly: Xrpl.dll
Syntax
public static class BatchSignStatusExtensions
Methods
|
Edit this page
GetBatchSignStatus(Dictionary<string, object>)
Builds the signing status of a batch transaction from a tx dictionary.
Declaration
public static BatchSignStatus GetBatchSignStatus(this Dictionary<string, object> tx)
Parameters
| Type |
Name |
Description |
| Dictionary<string, object> |
tx |
|
Returns
|
Edit this page
GetBatchSignStatus(string)
Convenience helper for the status of a hex blob (tx_blob).
Declaration
public static BatchSignStatus GetBatchSignStatus(this string txBlob)
Parameters
| Type |
Name |
Description |
| string |
txBlob |
|
Returns
|
Edit this page
GetBatchSignStatus(SignatureResult)
Convenience helper for the status of a SignatureResult.
Declaration
public static BatchSignStatus GetBatchSignStatus(this SignatureResult signed)
Parameters
Returns
|
Edit this page
IsFullySignedBatch(Dictionary<string, object>, bool)
Quickly check whether a batch is fully signed, over the inner accounts and optionally the root.
Declaration
public static bool IsFullySignedBatch(this Dictionary<string, object> tx, bool requireRoot = false)
Parameters
| Type |
Name |
Description |
| Dictionary<string, object> |
tx |
|
| bool |
requireRoot |
|
Returns