Class Index
Inheritance
object
Index
Namespace: Xrpl.Models.Utils
Assembly: Xrpl.dll
Syntax
public static class Index
Methods
| Edit this page View SourceIsFlagEnabled(uint, uint)
Declaration
public static bool IsFlagEnabled(this uint Flags, uint checkFlag)
Parameters
| Type | Name | Description |
|---|---|---|
| uint | Flags | |
| uint | checkFlag |
Returns
| Type | Description |
|---|---|
| bool |
IsHex(string)
Check if string is in hex format.
Declaration
public static bool IsHex(this string str)
Parameters
| Type | Name | Description |
|---|---|---|
| string | str | The string to check if it's in hex format. |
Returns
| Type | Description |
|---|---|
| bool | True if string is in hex format |
OnlyHasFields(Dictionary<string, object>, string[])
Verify that all fields of an object are in fields.
Declaration
public static bool OnlyHasFields(this Dictionary<string, object> obj, string[] fields)
Parameters
| Type | Name | Description |
|---|---|---|
| Dictionary<string, object> | obj | Object to verify fields. |
| string[] | fields | Fields to verify |
Returns
| Type | Description |
|---|---|
| bool | True if keys in object are all in fields. |