Class CrossChainPayment
Inheritance
object
CrossChainPayment
Namespace: Xrpl.Utils
Assembly: Xrpl.dll
Syntax
public static class CrossChainPayment
Methods
| Edit this page View SourceCreateCrossChainPayment(Payment, string)
Creates a cross-chain payment transaction.
Declaration
public static Payment CreateCrossChainPayment(this Payment payment, string destAccount)
Parameters
| Type | Name | Description |
|---|---|---|
| Payment | payment | he initial payment transaction. If the transaction is signed, then it will need to be re-signed.There must be no more than 2 memos, since one memo is used for the sidechain destination account.The destination must be the sidechain's door account. |
| string | destAccount | the destination account on the sidechain. |
Returns
| Type | Description |
|---|---|
| Payment | A cross-chain payment transaction, where the mainchain door account
is the |
Exceptions
| Type | Condition |
|---|---|
| XrplException | if there are more than 2 memos. |