Show / Hide Table of Contents

Namespace Xrpl.Wallet

Classes

BatchSigningHelper

Helper methods for batch transaction signing operations. For general signer utilities, see SignerUtilities.

EasyTimer

SignatureResult

Signer

SignerUtilities

Shared utilities for working with signers across multisign and batch signing operations. Contains common functionality used by Signer, BatchSigningHelper, and XrplWallet.

SignerUtilities.ByteArrayComparer

Comparer for byte arrays used in sorting by account ID.

WalletSugar

WalletSugar.FaucetAccount

WalletSugar.FaucetNetwork

WalletSugar.FaucetWallet

WalletSugar.Funded

XrplWallet

XummExtension

Extension methods for working with XRPL Secret Numbers format. Secret Numbers encode 16 bytes of entropy into 8 groups of 6 digits each, where 5 digits represent entropy and the 6th digit is a position-dependent checksum. This format is language-agnostic and allows real-time typo detection. See XLS-12d specification: https://github.com/XRPLF/XRPL-Standards/issues/15

Enums

TextWalletKdf

In this article
Back to top Generated by DocFX