Class Signer
Inheritance
Namespace: Xrpl.Wallet
Assembly: Xrpl.dll
Syntax
public class Signer
Methods
| Edit this page View SourceAuthorizeChannel(XrplWallet, string, string)
Creates a signature that can be used to redeem a specific amount of XRP from a payment channel.
Declaration
public static string AuthorizeChannel(XrplWallet wallet, string channelID, string amount)
Parameters
| Type | Name | Description |
|---|---|---|
| XrplWallet | wallet | The account that will sign for this payment channel. |
| string | channelID | An id for the payment channel to redeem XRP from. |
| string | amount | The amount in drops to redeem. |
Returns
| Type | Description |
|---|---|
| string | A signature that can be used to redeem a specific amount of XRP from a payment channel. |
CompareSigners(Dictionary<string, object>, Dictionary<string, object>)
If presented in binary form, the Signers array must be sorted based on the numeric value of the signer addresses, with the lowest value first. (If submitted as JSON, the submit_multisigned method handles this automatically.) https://xrpl.org/multi-signing.html.
Declaration
public static int CompareSigners(Dictionary<string, object> left, Dictionary<string, object> right)
Parameters
| Type | Name | Description |
|---|---|---|
| Dictionary<string, object> | left | A Signer to compare with. |
| Dictionary<string, object> | right | A Signer to compare with. |
Returns
| Type | Description |
|---|---|
| int | Returns 1 if left > right, 0 if left = right, -1 if left < right. |
GetDecodedTransaction(Dictionary<string, object>)
Declaration
public static Dictionary<string, object> GetDecodedTransaction(Dictionary<string, object> txOrBlob)
Parameters
| Type | Name | Description |
|---|---|---|
| Dictionary<string, object> | txOrBlob |
Returns
| Type | Description |
|---|---|
| Dictionary<string, object> |
GetDecodedTransaction(string)
Declaration
public static Dictionary<string, object> GetDecodedTransaction(string txOrBlob)
Parameters
| Type | Name | Description |
|---|---|---|
| string | txOrBlob |
Returns
| Type | Description |
|---|---|
| Dictionary<string, object> |
GetTransactionWithAllSigners(Dictionary<string, object>[])
Creates a transaction with all signers from the given transactions, deduped and sorted.
Declaration
public static Dictionary<string, object> GetTransactionWithAllSigners(Dictionary<string, object>[] transactions)
Parameters
| Type | Name | Description |
|---|---|---|
| Dictionary<string, object>[] | transactions | An array of Transactions with Signers fields. |
Returns
| Type | Description |
|---|---|
| Dictionary<string, object> | A single transaction with all Signers combined, deduped, and sorted. |
Multisign(Dictionary<string, object>[])
Takes several transactions with Signer fields (in object or blob form) and creates a single transaction with all Signers that then gets signed and returned.
Declaration
public static string Multisign(Dictionary<string, object>[] txs)
Parameters
| Type | Name | Description |
|---|---|---|
| Dictionary<string, object>[] | txs | An array of signed Transactions (in object form) to combine into a single signed Transaction. |
Returns
| Type | Description |
|---|---|
| string | A single signed Transaction which has all Signers from transactions within it. |
Multisign(string[])
Takes several transactions with Signer fields (in object or blob form) and creates a single transaction with all Signers that then gets signed and returned.
Declaration
public static string Multisign(string[] txBlobs)
Parameters
| Type | Name | Description |
|---|---|---|
| string[] | txBlobs | An array of signed Transactions in blob (hex string) form to combine into a single signed Transaction. |
Returns
| Type | Description |
|---|---|
| string | A single signed Transaction which has all Signers from transactions within it. |
ValidateTransactionEquivalence(Dictionary<string, object>[])
The transactions should all be equal except for the 'Signers' field.
Declaration
public static void ValidateTransactionEquivalence(Dictionary<string, object>[] transactions)
Parameters
| Type | Name | Description |
|---|---|---|
| Dictionary<string, object>[] | transactions | An array of Transactions which are expected to be equal other than 'Signers'. |
VerifySignature(Dictionary<string, object>)
Verifies that the given transaction has a valid signature based on public-key encryption.
Declaration
public static bool VerifySignature(Dictionary<string, object> tx)
Parameters
| Type | Name | Description |
|---|---|---|
| Dictionary<string, object> | tx | A transaction object to verify the signature of. (Can be in object or encoded string format). |
Returns
| Type | Description |
|---|---|
| bool | Returns true if tx has a valid signature, and returns false otherwise. |
VerifySignature(string)
Verifies that the given transaction has a valid signature based on public-key encryption.
Declaration
public static bool VerifySignature(string tx)
Parameters
| Type | Name | Description |
|---|---|---|
| string | tx | A transaction string to verify the signature of. |
Returns
| Type | Description |
|---|---|
| bool | Returns true if tx has a valid signature, and returns false otherwise. |