Class SignerUtilities.ByteArrayComparer
Comparer for byte arrays used in sorting by account ID.
Inheritance
object
SignerUtilities.ByteArrayComparer
Namespace: Xrpl.Wallet
Assembly: Xrpl.dll
Syntax
public sealed class SignerUtilities.ByteArrayComparer
Fields
| Edit this page View SourceInstance
Declaration
public static readonly SignerUtilities.ByteArrayComparer Instance
Field Value
| Type | Description |
|---|---|
| SignerUtilities.ByteArrayComparer |
Methods
| Edit this page View SourceCompare(byte[]?, byte[]?)
Compares two objects and returns a value indicating whether one is less than, equal to, or greater than the other.
Declaration
public int Compare(byte[]? a, byte[]? b)
Parameters
| Type | Name | Description |
|---|---|---|
| byte[] | a | |
| byte[] | b |
Returns
| Type | Description | ||||||||
|---|---|---|---|---|---|---|---|---|---|
| int | A signed integer that indicates the relative values of
|